import { Duration, IAspect } from 'aws-cdk-lib';
import { ComparisonOperator } from 'aws-cdk-lib/aws-cloudwatch';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { IConstruct } from 'constructs';
import { LambdaConfiguration } from '../../types/lambda-configuration';
/**
 * Optional custom metric configuration for CloudWatch Alarms.
 * If not provided, defaults to CPU utilization with a 5% threshold.
 */
export interface AlarmConfig {
    /**
     * The name of the CloudWatch metric to monitor
     * @default = CPUUtilization
     */
    readonly metricName: Ec2AutomatedShutdown.Ec2MetricName;
    /**
     * The period over which the metric is measured
     * @default = 1 minute
     */
    readonly period: Duration;
    /**
     * The CloudWatch metric statistic to use
     *
     * Use the `aws_cloudwatch.Stats` helper class to construct valid input
     * strings.
     *
     * @default = 'Average'
     */
    readonly statistic: string;
    /**
     * The threshold value for the alarm
     * @default = 5%
     */
    readonly threshold: number;
    /**
     * The number of periods over which data is compared to the specified threshold
     * @default = 3
     */
    readonly evaluationPeriods: number;
    /**
     * The number of datapoints that must go past/below the threshold to trigger the alarm
     * @default = 2
     */
    readonly datapointsToAlarm: number;
    /**
     * The comparison operator to use for the alarm
     * @default = ComparisonOperator.LESS_THAN_THRESHOLD
     */
    readonly comparisonOperator: ComparisonOperator;
}
export interface Ec2AutomatedShutdownProps {
    /**
     * Optional custom metric configuration.
     * If not provided, defaults to CPU utilization with a 5% threshold.
     */
    readonly alarmConfig?: AlarmConfig;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
    /**
     * Optional KMS Encryption Key to use for encrypting resources.
     */
    readonly encryption?: IKey;
}
/**
 * Automatically shut down EC2 instances when an alarm is triggered based off
 * of a provided metric.
 *
 * 🚩 If you are applying this Aspect to multiple EC2 instances, you
 * will need to configure the CDK context variable flag
 * `@aws-cdk/aws-cloudwatch-actions:changeLambdaPermissionLogicalIdForLambdaAction`
 * set to `true`. If this is not configured, applying this Aspect to multiple
 * EC2 instances will result in a CDK synth error.
 *
 * Allows for cost optimization and the reduction of resources not being
 * actively used. When the EC2 alarm is triggered for a given EC2 instance, it
 * will automatically trigger a Lambda function to shutdown the instance.
 *
 * @example
 * import { App, Aspects, Duration, Stack } from 'aws-cdk-lib';
 * import { ComparisonOperator, Stats } from 'aws-cdk-lib/aws-cloudwatch';
 * import { Instance } from 'aws-cdk-lib/aws-ec2';
 * import { Ec2AutomatedShutdown } from './src/aspects/ec2-automated-shutdown';
 *
 * const app = new App({
 *     context: {
 *         '@aws-cdk/aws-cloudwatch-actions:changeLambdaPermissionLogicalIdForLambdaAction':
 *             true
 *     }
 * });
 * const stack = new Stack(app, 'MyStack');
 *
 * // Create your EC2 instance(s)
 * const instance = new Instance(stack, 'MyInstance', {
 *     // instance properties
 * });
 *
 * // Apply the aspect to automatically shut down the EC2 instance when underutilized
 * Aspects.of(stack).add(new Ec2AutomatedShutdown());
 *
 * // Or with custom configuration
 * Aspects.of(stack).add(
 *     new Ec2AutomatedShutdown({
 *         alarmConfig: {
 *             metricName: Ec2AutomatedShutdown.Ec2MetricName.NETWORK_IN,
 *             period: Duration.minutes(5),
 *             statistic: Stats.AVERAGE,
 *             threshold: 100, // 100 bytes
 *             evaluationPeriods: 6,
 *             datapointsToAlarm: 5,
 *             comparisonOperator: ComparisonOperator.LESS_THAN_THRESHOLD
 *         }
 *     })
 * );
 */
export declare class Ec2AutomatedShutdown implements IAspect {
    private readonly props;
    private static lambdaByStack;
    private static instanceArnsByStack;
    private processedInstances;
    private readonly defaultAlarmConfig;
    constructor(props?: Ec2AutomatedShutdownProps);
    visit(node: IConstruct): void;
    private getLambdaFunction;
    private createShutdownMechanism;
}
export declare namespace Ec2AutomatedShutdown {
    /** CloudWatch Alarm Metric Names */
    enum Ec2MetricName {
        CPU_UTILIZATION = "CPUUtilization",
        DISK_READ_OPS = "DiskReadOps",
        DISK_WRITE_OPS = "DiskWriteOps",
        DISK_READ_BYTES = "DiskReadBytes",
        DISK_WRITE_BYTES = "DiskWriteBytes",
        NETWORK_IN = "NetworkIn",
        NETWORK_OUT = "NetworkOut",
        NETWORK_PACKETS_IN = "NetworkPacketsIn",
        NETWORK_PACKETS_OUT = "NetworkPacketsOut",
        STATUS_CHECK_FAILED = "StatusCheckFailed",
        STATUS_CHECK_FAILED_INSTANCE = "StatusCheckFailed_Instance",
        STATUS_CHECK_FAILED_SYSTEM = "StatusCheckFailed_System",
        METADATA_NO_TOKEN = "MetadataNoToken",
        CPU_CREDIT_USAGE = "CPUCreditUsage",
        CPU_CREDIT_BALANCE = "CPUCreditBalance",
        CPU_SURPLUS_CREDIT_BALANCE = "CPUSurplusCreditBalance",
        CPU_SURPLUS_CREDITS_CHARGED = "CPUSurplusCreditsCharged"
    }
    /** End CloudWatch Alarm Metric Names */
}
