import { IAspect } from 'aws-cdk-lib';
import { ISubnet } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
export interface SecureSageMakerNotebookProps {
    /**
     * Sets the VPC Subnet for the Sagemaker Notebook Instance. This ensures the
     * notebook is locked down to a specific VPC/subnet.
     */
    readonly notebookSubnet: ISubnet;
    /**
     * Sets the VPC Subnets that the SageMaker Notebook Instance is allowed to
     * launch training and inference jobs into. This is enforced by adding
     * DENY statements to the existing role that the Notebook Instance is using.
     */
    readonly allowedLaunchSubnets: ISubnet[];
    /**
     * Sets the `directInternetAccess` property on the SageMaker Notebooks.
     * By default, this is set to false to disable internet access on any
     * SageMaker Notebook Instance that this aspect is applied to.
     * @default false
     */
    readonly directInternetAccess?: boolean;
    /**
     * Sets the `rootAccess` property on the SageMaker Notebooks.
     * By default, this is set to false to disable root access on any
     * SageMaker Notebook Instance that this aspect is applied to.
     * @default false
     */
    readonly rootAccess?: boolean;
}
/**
 * Aspect that enforces security controls on SageMaker Notebook Instances by
 * requiring VPC placement, disabling direct internet access, and preventing
 * root access to the notebook environment.
 *
 * This Aspect enforces these settings through a combination of setting
 * the CloudFormation properties on the Notebook resource and attaching a
 * DENY policy to the role that is used by the notebook. The policy will enforce
 * that the following API actions contain the correct properties to ensure
 * network isolation and that the VPC subnets are set:
 *
 * - 'sagemaker:CreateTrainingJob',
 * - 'sagemaker:CreateHyperParameterTuningJob',
 * - 'sagemaker:CreateModel',
 * - 'sagemaker:CreateProcessingJob'
 */
export declare class SecureSageMakerNotebook implements IAspect {
    private readonly props;
    private static policyByStack;
    private static importCounter;
    constructor(props: SecureSageMakerNotebookProps);
    visit(node: IConstruct): void;
    private secureSageMakerNotebookRole;
    private secureSageMakerNotebookInstance;
}
