import { HttpClientOptions, HttpClientResponse, HttpMethod, RequestResponse, HttpClientRequest } from './types';
import { Json } from '../../../types/json';
export declare class HttpClient<TOptions extends HttpClientOptions> {
    protected readonly options: TOptions;
    /**
     * Creates a new HTTP client
     *
     * @param options - Configuration options for the client
     */
    constructor(options?: TOptions);
    /**
     * Normalizes header keys to lowercase
     *
     * @param headers - Headers to normalize
     * @returns Headers with lowercase keys
     */
    private normalizeHeaders;
    /**
     * Makes a GET request
     *
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    get<T>(url: string, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Makes a POST request
     *
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param data - Request body
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    post<T>(url: string, data?: Json, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Makes a PUT request
     *
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param data - Request body
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    put<T>(url: string, data?: Json, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Makes a DELETE request
     *
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    delete<T>(url: string, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Makes a PATCH request
     *
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param data - Request body
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    patch<T>(url: string, data?: Json, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Makes a HEAD request
     *
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    head<T>(url: string, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Makes a request with the specified method
     *
     * @param method - HTTP method
     * @param url - URL path (appended to baseUrl if provided in options)
     * @param data - Optional request body
     * @param headers - Optional additional headers
     * @returns Promise resolving to the typed response
     */
    request<T>(method: HttpMethod, url: string, data?: Json, headers?: Record<string, string>): Promise<HttpClientResponse<T>>;
    /**
     * Builds a full URL from the path and base URL (if provided)
     *
     * @param url - URL path
     * @returns Full URL
     */
    protected buildUrl(url: string): string;
    /**
     * Creates and sends an HTTP request.
     *
     * @param url - The full URL for the request
     * @param method - HTTP method (GET, POST, etc.)
     * @param headers - Optional additional headers
     * @param body - Optional request body
     * @returns Promise resolving to the response
     */
    protected sendHttpRequest(url: string, method: HttpMethod, headers?: Record<string, string>, body?: Json): Promise<RequestResponse>;
    /**
     * Creates an HTTP request object.
     *
     * @param requestUrl - Full URL for the request
     * @param method - HTTP method (GET, POST, etc.)
     * @param headers - Optional additional headers
     * @param body - Optional request body
     * @returns An HTTP request object
     */
    protected createRequest(requestUrl: string, method: HttpMethod, headers?: Record<string, string>, body?: Json): HttpClientRequest;
    /**
     * Sends an HTTP request with the provided configuration.
     *
     * @param request - The HTTP request to send
     * @returns Promise resolving to the response
     */
    protected sendRequest(request: HttpClientRequest): Promise<RequestResponse>;
}
