import { ITable } from 'aws-cdk-lib/aws-dynamodb';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types';
import { TableItem } from './handler/types/table-item';
/**
 * Properties for the DynamoDbProvisionTable construct.
 */
export interface DynamoDbProvisionTableProps {
    /**
     * Table to provision
     */
    readonly table: DynamoDbProvisionTable.TableProps;
    /**
     * Items to provision within the DynamoDB table
     */
    readonly items: TableItem[];
    /**
     * Encryption key for protecting the framework resources
     */
    readonly encryption?: IKey;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
}
/**
 * Controls the contents of an Amazon DynamoDB table from Infrastructure as Code.
 *
 * This construct uses information about the key attributes of a table and a list of rows to populate the table upon
 * creation, update the table upon update, and remove entries from the table upon delete.
 *
 * WARNING: This construct should only be used with tables that are created and fully managed via IaC. While the
 * the construct will only manage rows within the table that it is aware of, there is no way to detect drift and thus
 * it is possible to cause data loss within the table if it is managed outside of IaC as well.
 *
 * The construct also handles encryption for the framework resources using either a provided KMS key or an
 * AWS managed key.
 *
 * @example
 *
 * import { DynamoDbProvisionTable } from '@cdklabs/cdk-proserve-lib/constructs';
 * import { Table } from 'aws-cdk-lib/aws-dynamodb';
 * import { Key } from 'aws-cdk-lib/aws-kms';
 *
 * interface TableRow {
 *     readonly uid: number;
 *     readonly isActive: boolean;
 * }
 *
 * const partitionKey: keyof TableRow = 'uid';
 *
 * const rows: TableRow[] = [
 *     {
 *         isActive: true,
 *         uid: 1
 *     },
 *     {
 *         isActive: true,
 *         uid: 2
 *     },
 *     {
 *         isActive: false,
 *         uid: 3
 *     }
 * ];
 *
 * const tableArn = 'arn:aws:dynamodb:us-west-1:111111111111:table/sample';
 * const table = Table.fromTableArn(this, 'Table', tableArn);
 *
 * const keyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-key-id';
 * const key = Key.fromKeyArn(this, 'Encryption', keyArn);
 *
 * new DynamoDbProvisionTable(this, 'ProvisionTable', {
 *     items: rows,
 *     table: {
 *         partitionKeyName: partitionKey,
 *         resource: table,
 *         encryption: key
 *     }
 * });

 * }
 */
export declare class DynamoDbProvisionTable extends Construct {
    /**
     * Mapping of providers for each CDK stack
     * Used to ensure only one provider is created per stack
     */
    private static serviceTokens;
    /**
     * Builds the provider to support the Custom Resource
     *
     * @param scope Parent to which the Custom Resource belongs
     * @param props Metadata for configuring the Custom Resource
     *
     * @returns Provider for the worker
     */
    private static getOrBuildProvider;
    /**
     * Translates the CDK construct properties to the Custom Resource
     * property format
     * @param props Metadata for configuring the Custom Resource
     * @returns Input for the actual Custom Resource worker
     */
    private static createCustomResourceProperties;
    /**
     * Provisions an existing DynamoDB Table with user-specified data
     * @param scope Parent to which the Custom Resource belongs
     * @param id Unique identifier for this instance
     * @param props Metadata for configuring the Custom Resource
     */
    constructor(scope: Construct, id: string, props: DynamoDbProvisionTableProps);
}
export declare namespace DynamoDbProvisionTable {
    /**
     * Information about the table to provision
     */
    interface TableProps {
        /**
         * CDK representation of the table itself
         */
        readonly resource: ITable;
        /**
         * Name of the partition key for the table
         */
        readonly partitionKeyName: string;
        /**
         * Name of the sort key for the table if applicable
         */
        readonly sortKeyName?: string;
        /**
         * Optional existing encryption key associated with the table
         */
        readonly encryption?: IKey;
    }
}
