import { IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { IFunction } from 'aws-cdk-lib/aws-lambda';
import { IDomain } from 'aws-cdk-lib/aws-opensearchservice';
import { Asset } from 'aws-cdk-lib/aws-s3-assets';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types';
import { DestructiveOperation } from '../../types/destructive-operation';
/**
 * Properties for configuring an OpenSearch workflow
 */
export interface OpenSearchWorkflowProps {
    /**
     * The OpenSearch domain to deploy the workflow to
     */
    readonly domain: IDomain;
    /**
     * IAM role used for domain authentication
     */
    readonly domainAuthentication: IRole;
    /**
     * Path to the Flow Framework template file (YAML or JSON)
     */
    readonly flowFrameworkTemplatePath: string;
    /**
     * Optional creation variables for the workflow. Your template must be
     * configured to accept these variables using `${{{ my_variable }}}` syntax.
     *
     * These variables will be substituted in prior to creation, so that will
     * be available during creation time and provision time.
     */
    readonly templateCreationVariables?: Record<string, string>;
    /**
     * Optional provisioning variables for the workflow. Your template must be
     * configured to accept these variables using `${{ my_variable }}` syntax.
     *
     * https://opensearch.org/docs/latest/automating-configurations/api/provision-workflow
     */
    readonly templateProvisionVariables?: Record<string, string>;
    /**
     * Optional asset variables for the workflow. This can either be an AWS CDK
     * S3 Asset object or a string that represents an S3 path (e.g. `s3://my-bucket/my-key`).
     * Your template must be configured to accept these variables using
     * `${{{ my_variable }}}` syntax. For each one of these variables, an S3
     * pre-signed URL will be generated and substituted into your template right
     * before workflow creation time. If you provide an S3 path, you must grant
     * read permissions to the appropriate bucket in order for the custom
     * resource to be able to generate a pre-signed url.
     */
    readonly templateAssetVariables?: Record<string, Asset | string>;
    /**
     * Whether to allow destructive operations like updating/deleting workflows
     */
    readonly allowDestructiveOperations?: DestructiveOperation;
    /**
     * Optional KMS key for encryption
     */
    readonly encryption?: IKey;
    /**
     * Optional lambda configuration settings for the custom resource provider
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
}
/**
 * Create OpenSearch Workflows using the flow framework to automate the
 * provisioning of complex tasks using JSON or YAML.
 *
 * This construct creates a custom resource that deploys a Flow Framework
 * template to an OpenSearch domain. It handles the deployment and lifecycle
 * management of the workflow through a Lambda-backed custom resources. You can
 * read more about the flow framework on AWS at the reference link below.
 *
 * @ref https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ml-workflow-framework.html
 *
 * @example
 * import { OpenSearchWorkflow } from '@cdklabs/cdk-proserve-lib/constructs';
 * import { Domain } from 'aws-cdk-lib/aws-opensearchservice';
 * import { Role } from 'aws-cdk-lib/aws-iam';
 *
 * const aosDomain = Domain.fromDomainEndpoint(this, 'Domain', 'aos-endpoint');
 * const aosRole = Role.fromRoleName(this, 'Role', 'AosRole');
 *
 * // Create OpenSearch Workflow using a YAML workflow template
 * const nlpIngestPipeline = new OpenSearchWorkflow(
 *     this,
 *     'NlpIngestPipeline',
 *     {
 *         domain: aosDomain,
 *         domainAuthentication: aosRole,
 *         flowFrameworkTemplatePath: join(
 *             __dirname,
 *             'nlp-ingest-pipeline.yaml'
 *         )
 *     }
 * );
 *
 * // Retrieve the deployed model from the OpenSearch Workflow
 * this.embeddingModelId = nlpIngestPipeline.getResourceId(
 *     'deploy_sentence_model'
 * );
 */
export declare class OpenSearchWorkflow extends Construct {
    private static serviceTokens;
    /**
     * Builds the provider to support the custom resource
     *
     * @param scope Parent to which the custom resource belongs
     * @param props Metadata for configuring the custom resource
     *
     * @returns Service token for interacting with the worker
     */
    private static getOrBuildProvider;
    /**
     * Translates the CDK construct properties to the custom resource
     * property format
     * @param props Metadata for configuring the custom resource
     * @param asset S3 asset for the workflow template
     * @param templateS3ObjectUrlVariables S3 object URLs for any asset variables
     * @returns Input for the actual custom resource worker
     */
    private static createCustomResourceProperties;
    /**
     * The unique identifier of the deployed OpenSearch workflow.
     * This ID can be used to reference and manage the workflow after deployment.
     */
    readonly workflowId: string;
    /**
     * The Lambda function that will handle On Event requests for the custom
     * resource.
     */
    readonly onEventHandler: IFunction;
    /**
     * The Lambda function that will be called to determine if the execution is
     * complete for the custom resource.
     */
    readonly isCompleteHandler: IFunction;
    /**
     * The custom resource that manages the OpenSearch workflow lifecycle.
     */
    private readonly cr;
    /**
     * Constructor
     * @param scope Parent to which the custom resource belongs
     * @param id Unique identifier for the custom resource
     * @param props Metadata for configuring the custom resource
     */
    constructor(scope: Construct, id: string, props: OpenSearchWorkflowProps);
    /**
     * Retrieves a created Resource ID from the Workflow by the provided
     * workflowStepId. The workflowStepId is the `id` value of the node in your
     * list of workflow nodes from your workflow template
     *
     * @param workflowStepId the workflow step id from the workflow template
     * @returns string value of the resource id that was created
     */
    getResourceId(workflowStepId: string): string;
}
