# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### ApiGatewayStaticHosting <a name="ApiGatewayStaticHosting" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting"></a>

A pattern that deploys resources to support the hosting of static assets within an AWS account.

Unlike the normal pattern for static content hosting (Amazon S3 fronted by Amazon CloudFront), this pattern instead
uses a combination of Amazon S3, AWS Lambda, and Amazon API Gateway. This can be useful for rapidly deploying a
static website that follows best practices when Amazon CloudFront is not available.

The construct also handles encryption for the framework resources using either a provided KMS key or an
AWS managed key.

There are two methods for exposing the URL to consumers - the default API execution endpoint or via a custom domain
name setup.

If using the default API execution endpoint, you must provide a base path as this will translate to the
stage name of the REST API. You must also ensure that all relative links in the static content either reference
the base path in URLs relative to the root (e.g. preceded by '/') or uses URLs that are relative to the current
directory (e.g. no '/').

If using the custom domain name, then you do not need to provide a base path and relative links in your static
content will not require modification. You can choose to specify a base path with this option if so desired - in
that case, similar rules regarding relative URLs in the static content above must be followed.

*Example*

```typescript
import { ApiGatewayStaticHosting } from '@cdklabs/cdk-proserve-lib/patterns';
import { EndpointType } from 'aws-cdk-lib/aws-apigateway';

new ApiGatewayStaticHosting(this, 'MyWebsite', {
    asset: {
        id: 'Entry',
        path: join(__dirname, 'assets', 'website', 'dist'),
        spaIndexPageName: 'index.html'
    },
    domain: {
        basePath: 'public'
    },
    endpoint: {
        types: [EndpointType.REGIONAL]
    },
    retainStoreOnDeletion: true,
    versionTag: '1.0.2'
});
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

new patterns.ApiGatewayStaticHosting(scope: Construct, id: string, props: ApiGatewayStaticHostingProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | Parent to which the pattern belongs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer.parameter.id">id</a></code> | <code>string</code> | Unique identifier for this instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps</code> | Metadata for configuring the pattern. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

Parent to which the pattern belongs.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer.parameter.id"></a>

- *Type:* string

Unique identifier for this instance.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps

Metadata for configuring the pattern.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.isConstruct"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

patterns.ApiGatewayStaticHosting.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.components">components</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents</code> | Provides access to the underlying components of the pattern as an escape hatch. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.url">url</a></code> | <code>string</code> | URL for the API that distributes the static content. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.customDomainNameAlias">customDomainNameAlias</a></code> | <code>string</code> | Alias domain name for the API that distributes the static content. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `components`<sup>Required</sup> <a name="components" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.components"></a>

```typescript
public readonly components: PatternComponents;
```

- *Type:* @cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents

Provides access to the underlying components of the pattern as an escape hatch.

WARNING: Making changes to the properties of the underlying components of this pattern may cause it to not
behave as expected or designed. You do so at your own risk.

---

##### `url`<sup>Required</sup> <a name="url" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.url"></a>

```typescript
public readonly url: string;
```

- *Type:* string

URL for the API that distributes the static content.

---

##### `customDomainNameAlias`<sup>Optional</sup> <a name="customDomainNameAlias" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.property.customDomainNameAlias"></a>

```typescript
public readonly customDomainNameAlias: string;
```

- *Type:* string

Alias domain name for the API that distributes the static content.

This is only available if the custom domain name configuration was provided to the pattern. In that event, you
would then create either a CNAME or ALIAS record in your DNS system that maps your custom domain name to this
value.

---


### DynamoDbProvisionTable <a name="DynamoDbProvisionTable" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable"></a>

Controls the contents of an Amazon DynamoDB table from Infrastructure as Code.

This construct uses information about the key attributes of a table and a list of rows to populate the table upon
creation, update the table upon update, and remove entries from the table upon delete.

WARNING: This construct should only be used with tables that are created and fully managed via IaC. While the
the construct will only manage rows within the table that it is aware of, there is no way to detect drift and thus
it is possible to cause data loss within the table if it is managed outside of IaC as well.

The construct also handles encryption for the framework resources using either a provided KMS key or an
AWS managed key.

*Example*

```typescript
import { DynamoDbProvisionTable } from '@cdklabs/cdk-proserve-lib/constructs';
import { Table } from 'aws-cdk-lib/aws-dynamodb';
import { Key } from 'aws-cdk-lib/aws-kms';

interface TableRow {
    readonly uid: number;
    readonly isActive: boolean;
}

const partitionKey: keyof TableRow = 'uid';

const rows: TableRow[] = [
    {
        isActive: true,
        uid: 1
    },
    {
        isActive: true,
        uid: 2
    },
    {
        isActive: false,
        uid: 3
    }
];

const tableArn = 'arn:aws:dynamodb:us-west-1:111111111111:table/sample';
const table = Table.fromTableArn(this, 'Table', tableArn);

const keyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-key-id';
const key = Key.fromKeyArn(this, 'Encryption', keyArn);

new DynamoDbProvisionTable(this, 'ProvisionTable', {
    items: rows,
    table: {
        partitionKeyName: partitionKey,
        resource: table,
        encryption: key
    }
});

}
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.DynamoDbProvisionTable(scope: Construct, id: string, props: DynamoDbProvisionTableProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | Parent to which the Custom Resource belongs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer.parameter.id">id</a></code> | <code>string</code> | Unique identifier for this instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps</code> | Metadata for configuring the Custom Resource. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

Parent to which the Custom Resource belongs.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer.parameter.id"></a>

- *Type:* string

Unique identifier for this instance.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps

Metadata for configuring the Custom Resource.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.DynamoDbProvisionTable.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### Ec2ImageBuilderGetImage <a name="Ec2ImageBuilderGetImage" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage"></a>

Retrieves an EC2 Image Builder image build version.

This is useful for retrieving the AMI ID of an image that was built by an
EC2 Image Builder pipeline.

*Example*

```typescript
import { CfnOutput } from 'aws-cdk-lib';
import { Ec2ImageBuilderGetImage } from '@cdklabs/cdk-proserve-lib/constructs';

const image = new Ec2ImageBuilderGetImage(this, 'SomeImage', {
  imageBuildVersionArn: 'arn:aws:imagebuilder:us-east-1:123456789012:image/some-image/0.0.1/1'
});
new CfnOutput(this, 'AmiId', { value: image.ami });
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.Ec2ImageBuilderGetImage(scope: Construct, id: string, props: Ec2ImageBuilderGetImageProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which to define this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer.parameter.id">id</a></code> | <code>string</code> | The scoped construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps</code> | Configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which to define this construct.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer.parameter.id"></a>

- *Type:* string

The scoped construct ID.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps

Configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.Ec2ImageBuilderGetImage.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.property.ami">ami</a></code> | <code>string</code> | The AMI ID retrieved from the EC2 Image Builder image. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `ami`<sup>Required</sup> <a name="ami" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImage.property.ami"></a>

```typescript
public readonly ami: string;
```

- *Type:* string

The AMI ID retrieved from the EC2 Image Builder image.

---


### Ec2ImageBuilderStart <a name="Ec2ImageBuilderStart" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart"></a>

Starts an EC2 Image Builder Pipeline and optionally waits for the build to complete.

This construct is useful if you want to create an image as part of your IaC
deployment. By waiting for completion of this construct, you can use the
image in the same deployment by retrieving the AMI and passing it to an EC2
build step.

*Example*

```typescript
import { Duration } from 'aws-cdk-lib';
import { Topic } from 'aws-cdk-lib/aws-sns';
import { Ec2ImageBuilderStart } from '@cdklabs/cdk-proserve-lib/constructs';

const topic = Topic.fromTopicArn(
  this,
  'MyTopic',
  'arn:aws:sns:us-east-1:123456789012:my-notification-topic'
);
new Ec2ImageBuilderStart(this, 'ImageBuilderStart', {
  pipelineArn:
    'arn:aws:imagebuilder:us-east-1:123456789012:image-pipeline/my-image-pipeline',
  waitForCompletion: {
    topic: topic,
    timeout: Duration.hours(7)  // wait up to 7 hours for completion
  }
});
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.Ec2ImageBuilderStart(scope: Construct, id: string, props: Ec2ImageBuilderStartProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The construct scope. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer.parameter.id">id</a></code> | <code>string</code> | The construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps</code> | Configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The construct scope.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer.parameter.id"></a>

- *Type:* string

The construct ID.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps

Configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.Ec2ImageBuilderStart.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.property.imageBuildVersionArn">imageBuildVersionArn</a></code> | <code>string</code> | The ARN of the image build version created by the pipeline execution. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `imageBuildVersionArn`<sup>Required</sup> <a name="imageBuildVersionArn" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.property.imageBuildVersionArn"></a>

```typescript
public readonly imageBuildVersionArn: string;
```

- *Type:* string

The ARN of the image build version created by the pipeline execution.

---


### Ec2ImagePipeline <a name="Ec2ImagePipeline" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline"></a>

An EC2 Image Pipeline that can be used to build a Amazon Machine Image (AMI) automatically.

This construct simplifies the process of creating an EC2 Image Pipeline and
provides all of the available components that can be used that are maintained
by AWS.

*Example*

```typescript
import { CfnOutput } from 'aws-cdk-lib';
import { Ec2ImagePipeline } from '@cdklabs/cdk-proserve-lib/constructs';

const pipeline = new Ec2ImagePipeline(this, 'ImagePipeline', {
  version: '0.1.0',
  buildConfiguration: {
    start: true,
    waitForCompletion: true
  },
  components: [
    Ec2ImagePipeline.Component.AWS_CLI_VERSION_2_LINUX,
    Ec2ImagePipeline.Component.DOCKER_CE_LINUX
  ]
});
new CfnOutput(this, 'ImagePipelineAmi', { value: pipeline.latestAmi! });
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.Ec2ImagePipeline(scope: Construct, id: string, props: Ec2ImagePipelineProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which to define this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer.parameter.id">id</a></code> | <code>string</code> | The scoped construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps</code> | Configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which to define this construct.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer.parameter.id"></a>

- *Type:* string

The scoped construct ID.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps

Configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.Ec2ImagePipeline.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.imagePipelineArn">imagePipelineArn</a></code> | <code>string</code> | The Image Pipeline ARN that gets created. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.imagePipelineTopic">imagePipelineTopic</a></code> | <code>aws-cdk-lib.aws_sns.ITopic</code> | The Image Pipeline Topic that gets created. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.latestAmi">latestAmi</a></code> | <code>string</code> | The latest AMI built by the pipeline. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `imagePipelineArn`<sup>Required</sup> <a name="imagePipelineArn" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.imagePipelineArn"></a>

```typescript
public readonly imagePipelineArn: string;
```

- *Type:* string

The Image Pipeline ARN that gets created.

---

##### `imagePipelineTopic`<sup>Required</sup> <a name="imagePipelineTopic" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.imagePipelineTopic"></a>

```typescript
public readonly imagePipelineTopic: ITopic;
```

- *Type:* aws-cdk-lib.aws_sns.ITopic

The Image Pipeline Topic that gets created.

---

##### `latestAmi`<sup>Optional</sup> <a name="latestAmi" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.property.latestAmi"></a>

```typescript
public readonly latestAmi: string;
```

- *Type:* string

The latest AMI built by the pipeline.

NOTE: You must have enabled the
Build Configuration option to wait for image build completion for this
property to be available.

---


### Ec2LinuxImagePipeline <a name="Ec2LinuxImagePipeline" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline"></a>

A pattern to build an EC2 Image Pipeline specifically for Linux.

This pattern contains opinionated code and features to help create a linux
pipeline. This pattern further simplifies setting up an image pipeline by
letting you choose specific operating systems and features. In addition, this
pattern will automatically start the pipeline and wait for it to complete.
This allows you to reference the AMI from this construct and utilize it in
your application (see example).

The example below shows how you can configure an image that contains the AWS
CLI and retains the SSM agent on the image. The image will have a 100GB root
volume.

*Example*

```typescript
import { CfnOutput } from 'aws-cdk-lib';
import { Ec2LinuxImagePipeline } from '@cdklabs/cdk-proserve-lib/patterns';

const pipeline = new Ec2LinuxImagePipeline(this, 'ImagePipeline', {
  version: '0.1.0',
  operatingSystem:
    Ec2LinuxImagePipeline.OperatingSystem.AMAZON_LINUX_2023,
  rootVolumeSize: 100,
  features: [
    Ec2LinuxImagePipeline.Feature.AWS_CLI,
    Ec2LinuxImagePipeline.Feature.RETAIN_SSM_AGENT
  ]
);

new CfnOutput(this, 'AmiId', {
  value: pipeline.latestAmi,
})
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

new patterns.Ec2LinuxImagePipeline(scope: Construct, id: string, props: Ec2LinuxImagePipelineProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which to define this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer.parameter.id">id</a></code> | <code>string</code> | The scoped construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps</code> | Configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which to define this construct.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer.parameter.id"></a>

- *Type:* string

The scoped construct ID.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps

Configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.isConstruct"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

patterns.Ec2LinuxImagePipeline.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.imagePipelineArn">imagePipelineArn</a></code> | <code>string</code> | The Amazon Resource Name (ARN) of the Image Pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.imagePipelineTopic">imagePipelineTopic</a></code> | <code>aws-cdk-lib.aws_sns.ITopic</code> | The SNS Topic associated with this Image Pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.latestAmi">latestAmi</a></code> | <code>string</code> | The latest AMI built by the pipeline. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `imagePipelineArn`<sup>Required</sup> <a name="imagePipelineArn" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.imagePipelineArn"></a>

```typescript
public readonly imagePipelineArn: string;
```

- *Type:* string

The Amazon Resource Name (ARN) of the Image Pipeline.

Used to uniquely identify this image pipeline.

---

##### `imagePipelineTopic`<sup>Required</sup> <a name="imagePipelineTopic" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.imagePipelineTopic"></a>

```typescript
public readonly imagePipelineTopic: ITopic;
```

- *Type:* aws-cdk-lib.aws_sns.ITopic

The SNS Topic associated with this Image Pipeline.

Publishes notifications about pipeline execution events.

---

##### `latestAmi`<sup>Optional</sup> <a name="latestAmi" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.property.latestAmi"></a>

```typescript
public readonly latestAmi: string;
```

- *Type:* string

The latest AMI built by the pipeline.

NOTE: You must have enabled the
Build Configuration option to wait for image build completion for this
property to be available.

---


### FriendlyEmbrace <a name="FriendlyEmbrace" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace"></a>

The Friendly Embrace construct can be used to remove CloudFormation stack dependencies that are based on stack exports and imports.

🚨 WARNING: This construct is experimental and will directly modify
CloudFormation stacks in your CDK application via a Lambda-backed Custom
Resource. It is not recommended to use this construct in a production
environment.

A custom resource that is designed to remove the "Deadly Embrace" problem that
occurs when you attempt to update a CloudFormation stack that is exporting
a resource used by another stack. This custom resource will run before all of
your stacks deploy/update and remove the dependencies by hardcoding each
export for all stacks that use it. For this reason, this construct should run
inside of its own stack and should be the last stack that is instantiated for
your application. That way the construct will be able to retrieve all of the
stacks from your CDK resource tree that it needs to update.

> NOTE: You may need to add more permissions to the handler if the custom
resource cannot update your stacks. You can call upon the `handler` property
of the class to add more permissions to it.

*Example*

```typescript
import { App, Stack } from 'aws-cdk-lib';
import { FriendlyEmbrace } from '@cdklabs/cdk-proserve-lib/constructs';

const app = new App();
// ... other stack definitions
const embrace = new Stack(app, 'FriendlyEmbrace'); // last stack
new FriendlyEmbrace(embrace, 'FriendlyEmbrace'); // only construct in stack
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.FriendlyEmbrace(scope: Construct, id: string, props?: FriendlyEmbraceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which to define this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer.parameter.id">id</a></code> | <code>string</code> | The construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps</code> | Configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which to define this construct.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer.parameter.id"></a>

- *Type:* string

The construct ID.

---

##### `props`<sup>Optional</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps

Configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.FriendlyEmbrace.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.property.onEventHandler">onEventHandler</a></code> | <code>aws-cdk-lib.aws_lambda_nodejs.NodejsFunction</code> | Handler for the custom resource. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `onEventHandler`<sup>Required</sup> <a name="onEventHandler" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbrace.property.onEventHandler"></a>

```typescript
public readonly onEventHandler: NodejsFunction;
```

- *Type:* aws-cdk-lib.aws_lambda_nodejs.NodejsFunction

Handler for the custom resource.

---


### IamServerCertificate <a name="IamServerCertificate" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate"></a>

Manages an AWS Identity and Access Management Server Certificate for use in regions/partitions where AWS Certificate Manager is not available.

This construct allows you to create an IAM Server Certificate using a certificate and private key stored in either
AWS Systems Manager Parameter Store or AWS Secrets Manager. It uses a Custom Resource to manage the lifecycle of the
server certificate.

The construct also handles encryption for the framework resources using either a provided KMS key or an
AWS managed key.

*Example*

```typescript
import { Key } from 'aws-cdk-lib/aws-kms';
import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
import { StringParameter } from 'aws-cdk-lib/aws-ssm';
import { IamServerCertificate } from '@cdklabs/cdk-proserve-lib/constructs';

const keyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-key-id';
const key = Key.fromKeyArn(this, 'Encryption', keyArn);

const certificateData = StringParameter.fromSecureStringParameterAttributes(this, 'CertificateData', {
     parameterName: 'sample-parameter',
     encryptionKey: key
});

const privateKeyData = Secret.fromSecretAttributes(this, 'PrivateKeySecret', {
     encryptionKey: key,
     secretCompleteArn: 'arn:aws:secretsmanager:us-east-1:111111111111:secret:PrivateKeySecret-aBc123'
});

const certificate = new IamServerCertificate(this, 'ServerCertificate', {
     certificate: {
         parameter: certificateData,
         encryption: key
     },
     privateKey: {
         secret: privateKeyData,
         encryption: key
     },
     prefix: 'myapp'
});
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.IamServerCertificate(scope: Construct, id: string, props: IamServerCertificateProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | Parent to which the Custom Resource belongs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer.parameter.id">id</a></code> | <code>string</code> | Unique identifier for this instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps</code> | Metadata for configuring the Custom Resource. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

Parent to which the Custom Resource belongs.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer.parameter.id"></a>

- *Type:* string

Unique identifier for this instance.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps

Metadata for configuring the Custom Resource.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.IamServerCertificate.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.property.arn">arn</a></code> | <code>string</code> | ARN for the created AWS IAM Server Certificate. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `arn`<sup>Required</sup> <a name="arn" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.property.arn"></a>

```typescript
public readonly arn: string;
```

- *Type:* string

ARN for the created AWS IAM Server Certificate.

---


### NetworkFirewall <a name="NetworkFirewall" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall"></a>

Creates an AWS Network Firewall using a user-supplied Suricata rules file in a VPC.

Follows guidelines that can be found at:

> [https://aws.github.io/aws-security-services-best-practices/guides/network-firewall/](https://aws.github.io/aws-security-services-best-practices/guides/network-firewall/)

*Example*

```typescript
import { NetworkFirewall } from '@cdklabs/cdk-proserve-lib/constructs';

new NetworkFirewall(this, 'Firewall', {
  vpc,
  firewallSubnets: vpc.selectSubnets({subnetGroupName: 'firewall'}).subnets,
  suricataRulesFilePath: './firewall-rules-suricata.txt',
  suricataRulesCapacity: 1000  // perform your own calculation based on the rules
});
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.NetworkFirewall(scope: Construct, id: string, props: NetworkFirewallProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | - Parent construct scope. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer.parameter.id">id</a></code> | <code>string</code> | - Construct ID used to generate unique resource names. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps</code> | - Network Firewall configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

Parent construct scope.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer.parameter.id"></a>

- *Type:* string

Construct ID used to generate unique resource names.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps

Network Firewall configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.NetworkFirewall.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.property.firewall">firewall</a></code> | <code>aws-cdk-lib.aws_networkfirewall.CfnFirewall</code> | The underlying CloudFormation Network Firewall resource. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `firewall`<sup>Required</sup> <a name="firewall" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.property.firewall"></a>

```typescript
public readonly firewall: CfnFirewall;
```

- *Type:* aws-cdk-lib.aws_networkfirewall.CfnFirewall

The underlying CloudFormation Network Firewall resource.

---


### NetworkFirewallEndpoints <a name="NetworkFirewallEndpoints" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints"></a>

Retrieves Network Firewall endpoints so that you can reference them in your other resources.

Uses an AWS Custom Resource to fetch endpoint information from the Network
Firewall service. This is useful so that you can both create a Network
Firewall and reference the endpoints it creates, to do things like configure
routing to the firewall.

*Example*

```typescript
import { CfnOutput } from 'aws-cdk-lib';
import { NetworkFirewallEndpoints } from '@cdklabs/cdk-proserve-lib/constructs';

const endpoints = new NetworkFirewallEndpoints(this, 'Endpoints', {
  firewall: cfnFirewall,  // CfnFirewall resource to find endpoints for
});
const az1EndpointId = endpoints.getEndpointId('us-east-1a');
const az2EndpointId = endpoints.getEndpointId('us-east-1b');
new CfnOutput(this, 'Az1EndpointId', { value: az1Endpoint });
new CfnOutput(this, 'Az2EndpointId', { value: az2Endpoint });
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.NetworkFirewallEndpoints(scope: Construct, id: string, props: NetworkFirewallEndpointsProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which to define this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer.parameter.id">id</a></code> | <code>string</code> | The scoped construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps</code> | Configuration properties for the construct. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which to define this construct.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer.parameter.id"></a>

- *Type:* string

The scoped construct ID.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps

Configuration properties for the construct.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.getEndpointId">getEndpointId</a></code> | Gets the endpoint ID for a specific availability zone. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `getEndpointId` <a name="getEndpointId" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.getEndpointId"></a>

```typescript
public getEndpointId(availabilityZone: string): string
```

Gets the endpoint ID for a specific availability zone.

###### `availabilityZone`<sup>Required</sup> <a name="availabilityZone" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.getEndpointId.parameter.availabilityZone"></a>

- *Type:* string

The availability zone to get the endpoint ID for.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.NetworkFirewallEndpoints.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpoints.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### OpenSearchAdminUser <a name="OpenSearchAdminUser" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser"></a>

Manages an admin user for an Amazon OpenSearch domain.

This construct creates a Lambda-backed custom resource that adds an admin user to the specified OpenSearch domain.
It uses the provided SSM parameter for the username, a provided SSM parameter or Secrets Manager secret for the
password, and sets up the necessary IAM permissions for the Lambda function to interact with the OpenSearch domain
and SSM parameter(s) and/or secret.

The construct also handles encryption for the Lambda function's environment variables and dead letter queue,
using either a provided KMS key or an AWS managed key.

*Example*

```typescript
import { Key } from 'aws-cdk-lib/aws-kms';
import { Domain } from 'aws-cdk-lib/aws-opensearchservice';
import { Secret } from 'aws-cdk-lib/aws-secretsmanager';
import { OpenSearchAdminUser } from '@cdklabs/cdk-proserve-lib/constructs';

const keyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-key-id';
const key = Key.fromKeyArn(this, 'Encryption', keyArn);

const adminCredential = StringParameter.fromSecureStringParameterAttributes(this, 'AdminCredential', {
     parameterName: 'sample-parameter',
     encryptionKey: key
});

const domainKeyArn = 'arn:aws:kms:us-east-1:111111111111:key/sample-domain-key-id';
const domainKey = Key.fromKeyArn(this, 'DomainEncryption', domainKeyArn);
const domain = Domain.fromDomainEndpoint(this, 'Domain', 'vpc-testdomain.us-east-1.es.amazonaws.com');

const adminUser = new OpenSearchAdminUser(this, 'AdminUser', {
     credential: {
         secret: adminCredential,
         encryption: key
     },
     domain: domain,
     domainKey: domainKey,
     username: 'admin'
});
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.OpenSearchAdminUser(scope: Construct, id: string, props: OpenSearchAdminUserProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | Parent to which the custom resource belongs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer.parameter.id">id</a></code> | <code>string</code> | Unique identifier for this instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps</code> | Metadata for configuring the custom resource. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

Parent to which the custom resource belongs.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer.parameter.id"></a>

- *Type:* string

Unique identifier for this instance.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps

Metadata for configuring the custom resource.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.toString">toString</a></code> | Returns a string representation of this construct. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.OpenSearchAdminUser.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---


### OpenSearchWorkflow <a name="OpenSearchWorkflow" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow"></a>

Create OpenSearch Workflows using the flow framework to automate the provisioning of complex tasks using JSON or YAML.

This construct creates a custom resource that deploys a Flow Framework
template to an OpenSearch domain. It handles the deployment and lifecycle
management of the workflow through a Lambda-backed custom resources. You can
read more about the flow framework on AWS at the reference link below.

*Example*

```typescript
import { OpenSearchWorkflow } from '@cdklabs/cdk-proserve-lib/constructs';
import { Domain } from 'aws-cdk-lib/aws-opensearchservice';
import { Role } from 'aws-cdk-lib/aws-iam';

const aosDomain = Domain.fromDomainEndpoint(this, 'Domain', 'aos-endpoint');
const aosRole = Role.fromRoleName(this, 'Role', 'AosRole');

// Create OpenSearch Workflow using a YAML workflow template
const nlpIngestPipeline = new OpenSearchWorkflow(
    this,
    'NlpIngestPipeline',
    {
        domain: aosDomain,
        domainAuthentication: aosRole,
        flowFrameworkTemplatePath: join(
            __dirname,
            'nlp-ingest-pipeline.yaml'
        )
    }
);

// Retrieve the deployed model from the OpenSearch Workflow
this.embeddingModelId = nlpIngestPipeline.getResourceId(
    'deploy_sentence_model'
);
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.OpenSearchWorkflow(scope: Construct, id: string, props: OpenSearchWorkflowProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | Parent to which the custom resource belongs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer.parameter.id">id</a></code> | <code>string</code> | Unique identifier for the custom resource. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps</code> | Metadata for configuring the custom resource. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

Parent to which the custom resource belongs.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer.parameter.id"></a>

- *Type:* string

Unique identifier for the custom resource.

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps

Metadata for configuring the custom resource.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.getResourceId">getResourceId</a></code> | Retrieves a created Resource ID from the Workflow by the provided workflowStepId. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `getResourceId` <a name="getResourceId" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.getResourceId"></a>

```typescript
public getResourceId(workflowStepId: string): string
```

Retrieves a created Resource ID from the Workflow by the provided workflowStepId.

The workflowStepId is the `id` value of the node in your
list of workflow nodes from your workflow template

###### `workflowStepId`<sup>Required</sup> <a name="workflowStepId" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.getResourceId.parameter.workflowStepId"></a>

- *Type:* string

the workflow step id from the workflow template.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.OpenSearchWorkflow.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.isCompleteHandler">isCompleteHandler</a></code> | <code>aws-cdk-lib.aws_lambda.IFunction</code> | The Lambda function that will be called to determine if the execution is complete for the custom resource. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.onEventHandler">onEventHandler</a></code> | <code>aws-cdk-lib.aws_lambda.IFunction</code> | The Lambda function that will handle On Event requests for the custom resource. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.workflowId">workflowId</a></code> | <code>string</code> | The unique identifier of the deployed OpenSearch workflow. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `isCompleteHandler`<sup>Required</sup> <a name="isCompleteHandler" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.isCompleteHandler"></a>

```typescript
public readonly isCompleteHandler: IFunction;
```

- *Type:* aws-cdk-lib.aws_lambda.IFunction

The Lambda function that will be called to determine if the execution is complete for the custom resource.

---

##### `onEventHandler`<sup>Required</sup> <a name="onEventHandler" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.onEventHandler"></a>

```typescript
public readonly onEventHandler: IFunction;
```

- *Type:* aws-cdk-lib.aws_lambda.IFunction

The Lambda function that will handle On Event requests for the custom resource.

---

##### `workflowId`<sup>Required</sup> <a name="workflowId" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflow.property.workflowId"></a>

```typescript
public readonly workflowId: string;
```

- *Type:* string

The unique identifier of the deployed OpenSearch workflow.

This ID can be used to reference and manage the workflow after deployment.

---


### WebApplicationFirewall <a name="WebApplicationFirewall" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall"></a>

Creates an AWS Web Application Firewall (WAF) that can be associated with resources such as an Application Load Balancer.

It allows configuring AWS managed rule groups, logging, and visibility
settings. The construct simplifies the creation of a WAF by providing
available AWS managed rule groups that can be utilized.

Currently, the only resource that is supported to associate the WAF with is
an ALB.

*Example*

```typescript
import { ApplicationLoadBalancer } from 'aws-cdk-lib/aws-elasticloadbalancingv2';
import { WebApplicationFirewall } from '@cdklabs/cdk-proserve-lib/constructs';

const alb = new ApplicationLoadBalancer(this, 'Alb', { vpc });
const waf = new WebApplicationFirewall(this, 'WAF', {
  awsManagedRuleGroups: [
    WebApplicationFirewall.AwsManagedRuleGroup.COMMON_RULE_SET,
    WebApplicationFirewall.AwsManagedRuleGroup.LINUX_RULE_SET
  ]
});
waf.associate(alb);  // Associate the WAF with the ALB
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

new constructs.WebApplicationFirewall(scope: Construct, id: string, props?: WebApplicationFirewallProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | The scope in which to define this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer.parameter.id">id</a></code> | <code>string</code> | The scoped construct ID. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps</code> | Configuration properties. |

---

##### `scope`<sup>Required</sup> <a name="scope" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

The scope in which to define this construct.

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer.parameter.id"></a>

- *Type:* string

The scoped construct ID.

---

##### `props`<sup>Optional</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps

Configuration properties.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.associate">associate</a></code> | Associates the Web Application Firewall to an applicable resource. |

---

##### `toString` <a name="toString" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `associate` <a name="associate" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.associate"></a>

```typescript
public associate(resource: ApplicationLoadBalancer): void
```

Associates the Web Application Firewall to an applicable resource.

###### `resource`<sup>Required</sup> <a name="resource" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.associate.parameter.resource"></a>

- *Type:* aws-cdk-lib.aws_elasticloadbalancingv2.ApplicationLoadBalancer

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.isConstruct"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

constructs.WebApplicationFirewall.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.property.webAcl">webAcl</a></code> | <code>aws-cdk-lib.aws_wafv2.CfnWebACL</code> | The WAF Web ACL (Access Control List) resource. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.property.logGroup">logGroup</a></code> | <code>aws-cdk-lib.aws_logs.LogGroup</code> | Optional CloudWatch log group for WAF logging. |

---

##### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---

##### `webAcl`<sup>Required</sup> <a name="webAcl" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.property.webAcl"></a>

```typescript
public readonly webAcl: CfnWebACL;
```

- *Type:* aws-cdk-lib.aws_wafv2.CfnWebACL

The WAF Web ACL (Access Control List) resource.

---

##### `logGroup`<sup>Optional</sup> <a name="logGroup" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.property.logGroup"></a>

```typescript
public readonly logGroup: LogGroup;
```

- *Type:* aws-cdk-lib.aws_logs.LogGroup

Optional CloudWatch log group for WAF logging.

This is available if you
have configured `logging` on the construct.

---


## Structs <a name="Structs" id="Structs"></a>

### AlarmConfig <a name="AlarmConfig" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig"></a>

Optional custom metric configuration for CloudWatch Alarms.

If not provided, defaults to CPU utilization with a 5% threshold.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const alarmConfig: aspects.AlarmConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.comparisonOperator">comparisonOperator</a></code> | <code>aws-cdk-lib.aws_cloudwatch.ComparisonOperator</code> | The comparison operator to use for the alarm. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.datapointsToAlarm">datapointsToAlarm</a></code> | <code>number</code> | The number of datapoints that must go past/below the threshold to trigger the alarm. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.evaluationPeriods">evaluationPeriods</a></code> | <code>number</code> | The number of periods over which data is compared to the specified threshold. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.metricName">metricName</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName</code> | The name of the CloudWatch metric to monitor. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.period">period</a></code> | <code>aws-cdk-lib.Duration</code> | The period over which the metric is measured. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.statistic">statistic</a></code> | <code>string</code> | The CloudWatch metric statistic to use. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.threshold">threshold</a></code> | <code>number</code> | The threshold value for the alarm. |

---

##### `comparisonOperator`<sup>Required</sup> <a name="comparisonOperator" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.comparisonOperator"></a>

```typescript
public readonly comparisonOperator: ComparisonOperator;
```

- *Type:* aws-cdk-lib.aws_cloudwatch.ComparisonOperator
- *Default:* = ComparisonOperator.LESS_THAN_THRESHOLD

The comparison operator to use for the alarm.

---

##### `datapointsToAlarm`<sup>Required</sup> <a name="datapointsToAlarm" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.datapointsToAlarm"></a>

```typescript
public readonly datapointsToAlarm: number;
```

- *Type:* number
- *Default:* = 2

The number of datapoints that must go past/below the threshold to trigger the alarm.

---

##### `evaluationPeriods`<sup>Required</sup> <a name="evaluationPeriods" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.evaluationPeriods"></a>

```typescript
public readonly evaluationPeriods: number;
```

- *Type:* number
- *Default:* = 3

The number of periods over which data is compared to the specified threshold.

---

##### `metricName`<sup>Required</sup> <a name="metricName" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.metricName"></a>

```typescript
public readonly metricName: Ec2MetricName;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName
- *Default:* = CPUUtilization

The name of the CloudWatch metric to monitor.

---

##### `period`<sup>Required</sup> <a name="period" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.period"></a>

```typescript
public readonly period: Duration;
```

- *Type:* aws-cdk-lib.Duration
- *Default:* = 1 minute

The period over which the metric is measured.

---

##### `statistic`<sup>Required</sup> <a name="statistic" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.statistic"></a>

```typescript
public readonly statistic: string;
```

- *Type:* string
- *Default:* = 'Average'

The CloudWatch metric statistic to use.

Use the `aws_cloudwatch.Stats` helper class to construct valid input
strings.

---

##### `threshold`<sup>Required</sup> <a name="threshold" id="@cdklabs/cdk-proserve-lib.aspects.AlarmConfig.property.threshold"></a>

```typescript
public readonly threshold: number;
```

- *Type:* number
- *Default:* = 5%

The threshold value for the alarm.

---

### ApiGatewaySettings <a name="ApiGatewaySettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ApiGatewaySettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ApiGatewaySettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const apiGatewaySettings: aspects.SecurityCompliance.ApiGatewaySettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ApiGatewaySettings.property.stageMethodLogging">stageMethodLogging</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging</code> | Enable or disable CloudWatch logging for API Gateway stages. |

---

##### `stageMethodLogging`<sup>Optional</sup> <a name="stageMethodLogging" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ApiGatewaySettings.property.stageMethodLogging"></a>

```typescript
public readonly stageMethodLogging: StageMethodLogging;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging

Enable or disable CloudWatch logging for API Gateway stages.

Resolves:
  - AwsSolutions-APIG6

Defaults to log all errors if not specified or disabled.

---

### ApiGatewayStaticHostingProps <a name="ApiGatewayStaticHostingProps" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps"></a>

Properties for configuring the static hosting pattern.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

const apiGatewayStaticHostingProps: patterns.ApiGatewayStaticHostingProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.asset">asset</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset</code> | Metadata about the static assets to host. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.domain">domain</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.CustomDomainConfiguration \| @cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration</code> | Configuration information for the distribution endpoint that will be used to serve static content. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.accessLoggingBucket">accessLoggingBucket</a></code> | <code>aws-cdk-lib.aws_s3.IBucket</code> | Amazon S3 bucket where access logs should be stored. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.accessPolicy">accessPolicy</a></code> | <code>aws-cdk-lib.aws_iam.PolicyDocument</code> | Resource access policy to define on the API itself to control who can invoke the endpoint. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.apiLogDestination">apiLogDestination</a></code> | <code>aws-cdk-lib.aws_apigateway.IAccessLogDestination</code> | Destination where Amazon API Gateway logs can be sent. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Encryption key for protecting the framework resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.endpoint">endpoint</a></code> | <code>aws-cdk-lib.aws_apigateway.EndpointConfiguration</code> | Endpoint deployment information for the REST API. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional configuration settings for the backend handler. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.retainStoreOnDeletion">retainStoreOnDeletion</a></code> | <code>boolean</code> | Whether or not to retain the Amazon S3 bucket where static assets are deployed on stack deletion. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.versionTag">versionTag</a></code> | <code>string</code> | A version identifier to deploy to the Amazon S3 bucket to help with rapid identification of current deployment This will appear as `metadata.json` at the root of the bucket. |

---

##### `asset`<sup>Required</sup> <a name="asset" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.asset"></a>

```typescript
public readonly asset: Asset;
```

- *Type:* @cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset

Metadata about the static assets to host.

---

##### `domain`<sup>Required</sup> <a name="domain" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.domain"></a>

```typescript
public readonly domain: CustomDomainConfiguration | DefaultEndpointConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.CustomDomainConfiguration | @cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration

Configuration information for the distribution endpoint that will be used to serve static content.

---

##### `accessLoggingBucket`<sup>Optional</sup> <a name="accessLoggingBucket" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.accessLoggingBucket"></a>

```typescript
public readonly accessLoggingBucket: IBucket;
```

- *Type:* aws-cdk-lib.aws_s3.IBucket
- *Default:* undefined A new bucket will be created for storing access logs

Amazon S3 bucket where access logs should be stored.

---

##### `accessPolicy`<sup>Optional</sup> <a name="accessPolicy" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.accessPolicy"></a>

```typescript
public readonly accessPolicy: PolicyDocument;
```

- *Type:* aws-cdk-lib.aws_iam.PolicyDocument

Resource access policy to define on the API itself to control who can invoke the endpoint.

---

##### `apiLogDestination`<sup>Optional</sup> <a name="apiLogDestination" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.apiLogDestination"></a>

```typescript
public readonly apiLogDestination: IAccessLogDestination;
```

- *Type:* aws-cdk-lib.aws_apigateway.IAccessLogDestination

Destination where Amazon API Gateway logs can be sent.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey
- *Default:* undefined AWS service-managed encryption keys will be used where available

Encryption key for protecting the framework resources.

---

##### `endpoint`<sup>Optional</sup> <a name="endpoint" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.endpoint"></a>

```typescript
public readonly endpoint: EndpointConfiguration;
```

- *Type:* aws-cdk-lib.aws_apigateway.EndpointConfiguration
- *Default:* undefined Will deploy an edge-optimized API

Endpoint deployment information for the REST API.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional configuration settings for the backend handler.

---

##### `retainStoreOnDeletion`<sup>Optional</sup> <a name="retainStoreOnDeletion" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.retainStoreOnDeletion"></a>

```typescript
public readonly retainStoreOnDeletion: boolean;
```

- *Type:* boolean
- *Default:* false The Amazon S3 bucket and all assets contained within will be deleted

Whether or not to retain the Amazon S3 bucket where static assets are deployed on stack deletion.

---

##### `versionTag`<sup>Optional</sup> <a name="versionTag" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHostingProps.property.versionTag"></a>

```typescript
public readonly versionTag: string;
```

- *Type:* string
- *Default:* undefined No version information will be deployed to the Amazon S3 bucket

A version identifier to deploy to the Amazon S3 bucket to help with rapid identification of current deployment This will appear as `metadata.json` at the root of the bucket.

---

*Example*

```typescript
1.0.2
```


### ApplyRemovalPolicyProps <a name="ApplyRemovalPolicyProps" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicyProps"></a>

Properties for configuring the removal policy settings.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicyProps.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const applyRemovalPolicyProps: aspects.ApplyRemovalPolicyProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicyProps.property.removalPolicy">removalPolicy</a></code> | <code>aws-cdk-lib.RemovalPolicy</code> | The removal policy to apply to the resource. |

---

##### `removalPolicy`<sup>Required</sup> <a name="removalPolicy" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicyProps.property.removalPolicy"></a>

```typescript
public readonly removalPolicy: RemovalPolicy;
```

- *Type:* aws-cdk-lib.RemovalPolicy

The removal policy to apply to the resource.

---

### Asset <a name="Asset" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset"></a>

Static Asset Definition.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

const asset: patterns.ApiGatewayStaticHosting.Asset = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.property.id">id</a></code> | <code>string</code> | Unique identifier to delineate an asset from other assets. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.property.path">path</a></code> | <code>string \| string[]</code> | Path(s) on the local file system to the static asset(s). |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.property.spaIndexPageName">spaIndexPageName</a></code> | <code>string</code> | Name of the index page for a Single Page Application (SPA). |

---

##### `id`<sup>Required</sup> <a name="id" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique identifier to delineate an asset from other assets.

---

##### `path`<sup>Required</sup> <a name="path" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.property.path"></a>

```typescript
public readonly path: string | string[];
```

- *Type:* string | string[]

Path(s) on the local file system to the static asset(s).

Each path must be either a directory or zip containing the assets

---

##### `spaIndexPageName`<sup>Optional</sup> <a name="spaIndexPageName" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.Asset.property.spaIndexPageName"></a>

```typescript
public readonly spaIndexPageName: string;
```

- *Type:* string

Name of the index page for a Single Page Application (SPA).

This is used as a default key to load when the path provided does not map to a concrete static asset.

---

*Example*

```typescript
index.html
```


### AwsCustomResourceLambdaConfiguration <a name="AwsCustomResourceLambdaConfiguration" id="@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration.Initializer"></a>

```typescript
import { types } from '@cdklabs/cdk-proserve-lib'

const awsCustomResourceLambdaConfiguration: types.AwsCustomResourceLambdaConfiguration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration.property.subnets">subnets</a></code> | <code>aws-cdk-lib.aws_ec2.SubnetSelection</code> | Optional subnet selection for the Lambda functions. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration.property.vpc">vpc</a></code> | <code>aws-cdk-lib.aws_ec2.IVpc</code> | VPC where the Lambda functions will be deployed. |

---

##### `subnets`<sup>Optional</sup> <a name="subnets" id="@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration.property.subnets"></a>

```typescript
public readonly subnets: SubnetSelection;
```

- *Type:* aws-cdk-lib.aws_ec2.SubnetSelection

Optional subnet selection for the Lambda functions.

---

##### `vpc`<sup>Optional</sup> <a name="vpc" id="@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* aws-cdk-lib.aws_ec2.IVpc

VPC where the Lambda functions will be deployed.

---

### AwsManagedRuleGroupConfig <a name="AwsManagedRuleGroupConfig" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig"></a>

Configuration interface for AWS Managed Rule Groups.

This interface allows you to specify a managed rule group and optionally
override the default actions for specific rules within that group.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const awsManagedRuleGroupConfig: constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig.property.ruleGroup">ruleGroup</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup</code> | The AWS Managed Rule Group to apply. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig.property.ruleGroupActionOverrides">ruleGroupActionOverrides</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig[]</code> | Optional list of rule action overrides. |

---

##### `ruleGroup`<sup>Required</sup> <a name="ruleGroup" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig.property.ruleGroup"></a>

```typescript
public readonly ruleGroup: AwsManagedRuleGroup;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup

The AWS Managed Rule Group to apply.

---

##### `ruleGroupActionOverrides`<sup>Optional</sup> <a name="ruleGroupActionOverrides" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig.property.ruleGroupActionOverrides"></a>

```typescript
public readonly ruleGroupActionOverrides: OverrideConfig[];
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig[]

Optional list of rule action overrides.

---

### BuildConfigurationProps <a name="BuildConfigurationProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const buildConfigurationProps: constructs.Ec2ImagePipeline.BuildConfigurationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.property.start">start</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.property.hash">hash</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.property.waitForCompletion">waitForCompletion</a></code> | <code>boolean</code> | *No description.* |

---

##### `start`<sup>Required</sup> <a name="start" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.property.start"></a>

```typescript
public readonly start: boolean;
```

- *Type:* boolean

---

##### `hash`<sup>Optional</sup> <a name="hash" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.property.hash"></a>

```typescript
public readonly hash: string;
```

- *Type:* string

---

##### `waitForCompletion`<sup>Optional</sup> <a name="waitForCompletion" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps.property.waitForCompletion"></a>

```typescript
public readonly waitForCompletion: boolean;
```

- *Type:* boolean

---

### CustomDomainConfiguration <a name="CustomDomainConfiguration" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.CustomDomainConfiguration"></a>

Domain configuration when using a Custom Domain Name for Amazon API Gateway.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.CustomDomainConfiguration.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

const customDomainConfiguration: patterns.ApiGatewayStaticHosting.CustomDomainConfiguration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.CustomDomainConfiguration.property.options">options</a></code> | <code>aws-cdk-lib.aws_apigateway.DomainNameOptions</code> | Options for specifying the custom domain name setup. |

---

##### `options`<sup>Required</sup> <a name="options" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.CustomDomainConfiguration.property.options"></a>

```typescript
public readonly options: DomainNameOptions;
```

- *Type:* aws-cdk-lib.aws_apigateway.DomainNameOptions

Options for specifying the custom domain name setup.

---

### DefaultEndpointConfiguration <a name="DefaultEndpointConfiguration" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration"></a>

Domain configuration when using the Amazon API Gateway Default Execution Endpoint.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

const defaultEndpointConfiguration: patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration.property.basePath">basePath</a></code> | <code>string</code> | Base path where all assets will be located. |

---

##### `basePath`<sup>Required</sup> <a name="basePath" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.DefaultEndpointConfiguration.property.basePath"></a>

```typescript
public readonly basePath: string;
```

- *Type:* string

Base path where all assets will be located.

This is because the default execution endpoint does not serve content at the root but off of a stage. As
such this base path will be used to create the deployment stage to serve assets from.

---

*Example*

```typescript
/dev/site1
```


### DisableableSetting <a name="DisableableSetting" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const disableableSetting: aspects.SecurityCompliance.DisableableSetting = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting.property.disabled">disabled</a></code> | <code>boolean</code> | Sets the setting to disabled. |

---

##### `disabled`<sup>Optional</sup> <a name="disabled" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting.property.disabled"></a>

```typescript
public readonly disabled: boolean;
```

- *Type:* boolean

Sets the setting to disabled.

This does not actually make an impact on
the setting itself, it just stops this aspect from making changes to
the specific setting.

---

### DynamoDbProvisionTableProps <a name="DynamoDbProvisionTableProps" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps"></a>

Properties for the DynamoDbProvisionTable construct.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const dynamoDbProvisionTableProps: constructs.DynamoDbProvisionTableProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.items">items</a></code> | <code>{[ key: string ]: any}[]</code> | Items to provision within the DynamoDB table. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.table">table</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps</code> | Table to provision. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Encryption key for protecting the framework resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |

---

##### `items`<sup>Required</sup> <a name="items" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.items"></a>

```typescript
public readonly items: {[ key: string ]: any}[];
```

- *Type:* {[ key: string ]: any}[]

Items to provision within the DynamoDB table.

---

##### `table`<sup>Required</sup> <a name="table" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.table"></a>

```typescript
public readonly table: TableProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps

Table to provision.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Encryption key for protecting the framework resources.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTableProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

### DynamoDbSettings <a name="DynamoDbSettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DynamoDbSettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DynamoDbSettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const dynamoDbSettings: aspects.SecurityCompliance.DynamoDbSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DynamoDbSettings.property.pointInTimeRecovery">pointInTimeRecovery</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting</code> | Enables Point-in-Time Recovery for DynamoDB tables. |

---

##### `pointInTimeRecovery`<sup>Optional</sup> <a name="pointInTimeRecovery" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DynamoDbSettings.property.pointInTimeRecovery"></a>

```typescript
public readonly pointInTimeRecovery: DisableableSetting;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting

Enables Point-in-Time Recovery for DynamoDB tables.

Resolves:
  - AwsSolutions-DDB3

Defaults to true if not disabled.

---

### Ec2AutomatedShutdownProps <a name="Ec2AutomatedShutdownProps" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const ec2AutomatedShutdownProps: aspects.Ec2AutomatedShutdownProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.property.alarmConfig">alarmConfig</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.AlarmConfig</code> | Optional custom metric configuration. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional KMS Encryption Key to use for encrypting resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |

---

##### `alarmConfig`<sup>Optional</sup> <a name="alarmConfig" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.property.alarmConfig"></a>

```typescript
public readonly alarmConfig: AlarmConfig;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.AlarmConfig

Optional custom metric configuration.

If not provided, defaults to CPU utilization with a 5% threshold.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional KMS Encryption Key to use for encrypting resources.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

### Ec2ImageBuilderGetImageProps <a name="Ec2ImageBuilderGetImageProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps"></a>

Properties for the Ec2ImageBuilderGetImage construct.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const ec2ImageBuilderGetImageProps: constructs.Ec2ImageBuilderGetImageProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps.property.imageBuildVersionArn">imageBuildVersionArn</a></code> | <code>string</code> | The ARN of the EC2 Image Builder image build version. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration</code> | Optional Lambda configuration settings. |

---

##### `imageBuildVersionArn`<sup>Required</sup> <a name="imageBuildVersionArn" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps.property.imageBuildVersionArn"></a>

```typescript
public readonly imageBuildVersionArn: string;
```

- *Type:* string

The ARN of the EC2 Image Builder image build version.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderGetImageProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: AwsCustomResourceLambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration

Optional Lambda configuration settings.

---

### Ec2ImageBuilderStartProps <a name="Ec2ImageBuilderStartProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps"></a>

Properties for the EC2 Image Builder Start custom resource.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const ec2ImageBuilderStartProps: constructs.Ec2ImageBuilderStartProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.pipelineArn">pipelineArn</a></code> | <code>string</code> | The ARN of the Image Builder pipeline to start. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional KMS Encryption Key to use for encrypting resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.hash">hash</a></code> | <code>string</code> | An optional user-generated hash value that will determine if the construct will start the build pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.waitForCompletion">waitForCompletion</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps</code> | Set these properties to wait for the Image Build to complete. |

---

##### `pipelineArn`<sup>Required</sup> <a name="pipelineArn" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.pipelineArn"></a>

```typescript
public readonly pipelineArn: string;
```

- *Type:* string

The ARN of the Image Builder pipeline to start.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional KMS Encryption Key to use for encrypting resources.

---

##### `hash`<sup>Optional</sup> <a name="hash" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.hash"></a>

```typescript
public readonly hash: string;
```

- *Type:* string

An optional user-generated hash value that will determine if the construct will start the build pipeline.

If this is not set, the pipeline
will only start once on initial deployment. By setting this, you can for
example start a new build if your build instructions have changed and
then wait for the pipeline to complete again.

This hash should be a short
string, ideally ~7 characters or less. It will be set as the Physical ID
of the Custom Resource and also used to append to Waiter function
Physical IDs.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

##### `waitForCompletion`<sup>Optional</sup> <a name="waitForCompletion" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStartProps.property.waitForCompletion"></a>

```typescript
public readonly waitForCompletion: WaitForCompletionProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps

Set these properties to wait for the Image Build to complete.

This is
useful if you need the AMI before your next infrastructure step.

---

### Ec2ImagePipelineBaseProps <a name="Ec2ImagePipelineBaseProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps"></a>

Base properties for EC2 Image Pipeline configuration.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const ec2ImagePipelineBaseProps: constructs.Ec2ImagePipelineBaseProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.version">version</a></code> | <code>string</code> | Version of the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.buildConfiguration">buildConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps</code> | Configuration options for the build process. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.description">description</a></code> | <code>string</code> | Description of the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | KMS key for encryption. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.instanceTypes">instanceTypes</a></code> | <code>string[]</code> | Instance types for the Image Builder Pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.vpcConfiguration">vpcConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps</code> | VPC configuration for the image pipeline. |

---

##### `version`<sup>Required</sup> <a name="version" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.version"></a>

```typescript
public readonly version: string;
```

- *Type:* string

Version of the image pipeline.

This must be updated if you make
underlying changes to the pipeline configuration.

---

##### `buildConfiguration`<sup>Optional</sup> <a name="buildConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.buildConfiguration"></a>

```typescript
public readonly buildConfiguration: BuildConfigurationProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps

Configuration options for the build process.

---

##### `description`<sup>Optional</sup> <a name="description" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Description of the image pipeline.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

KMS key for encryption.

---

##### `instanceTypes`<sup>Optional</sup> <a name="instanceTypes" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.instanceTypes"></a>

```typescript
public readonly instanceTypes: string[];
```

- *Type:* string[]

Instance types for the Image Builder Pipeline.

Default: [t3.medium]

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

##### `vpcConfiguration`<sup>Optional</sup> <a name="vpcConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineBaseProps.property.vpcConfiguration"></a>

```typescript
public readonly vpcConfiguration: VpcConfigurationProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps

VPC configuration for the image pipeline.

---

### Ec2ImagePipelineProps <a name="Ec2ImagePipelineProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps"></a>

Properties for EC2 Image Pipeline, extending the base properties.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const ec2ImagePipelineProps: constructs.Ec2ImagePipelineProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.version">version</a></code> | <code>string</code> | Version of the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.buildConfiguration">buildConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps</code> | Configuration options for the build process. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.description">description</a></code> | <code>string</code> | Description of the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | KMS key for encryption. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.instanceTypes">instanceTypes</a></code> | <code>string[]</code> | Instance types for the Image Builder Pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.vpcConfiguration">vpcConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps</code> | VPC configuration for the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.blockDeviceMappings">blockDeviceMappings</a></code> | <code>aws-cdk-lib.aws_imagebuilder.CfnImageRecipe.InstanceBlockDeviceMappingProperty[]</code> | Block device mappings for the image. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.components">components</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component \| aws-cdk-lib.aws_imagebuilder.CfnComponent[]</code> | Components to be included in the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.machineImage">machineImage</a></code> | <code>aws-cdk-lib.aws_ec2.IMachineImage</code> | The machine image to use as a base for the pipeline. |

---

##### `version`<sup>Required</sup> <a name="version" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.version"></a>

```typescript
public readonly version: string;
```

- *Type:* string

Version of the image pipeline.

This must be updated if you make
underlying changes to the pipeline configuration.

---

##### `buildConfiguration`<sup>Optional</sup> <a name="buildConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.buildConfiguration"></a>

```typescript
public readonly buildConfiguration: BuildConfigurationProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps

Configuration options for the build process.

---

##### `description`<sup>Optional</sup> <a name="description" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Description of the image pipeline.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

KMS key for encryption.

---

##### `instanceTypes`<sup>Optional</sup> <a name="instanceTypes" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.instanceTypes"></a>

```typescript
public readonly instanceTypes: string[];
```

- *Type:* string[]

Instance types for the Image Builder Pipeline.

Default: [t3.medium]

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

##### `vpcConfiguration`<sup>Optional</sup> <a name="vpcConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.vpcConfiguration"></a>

```typescript
public readonly vpcConfiguration: VpcConfigurationProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps

VPC configuration for the image pipeline.

---

##### `blockDeviceMappings`<sup>Optional</sup> <a name="blockDeviceMappings" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.blockDeviceMappings"></a>

```typescript
public readonly blockDeviceMappings: InstanceBlockDeviceMappingProperty[];
```

- *Type:* aws-cdk-lib.aws_imagebuilder.CfnImageRecipe.InstanceBlockDeviceMappingProperty[]

Block device mappings for the image.

---

##### `components`<sup>Optional</sup> <a name="components" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.components"></a>

```typescript
public readonly components: Component | CfnComponent[];
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component | aws-cdk-lib.aws_imagebuilder.CfnComponent[]

Components to be included in the image pipeline.

Can be either custom Ec2ImagePipeline.Component or AWS CDK imagebuilder.CfnComponent.

---

##### `machineImage`<sup>Optional</sup> <a name="machineImage" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipelineProps.property.machineImage"></a>

```typescript
public readonly machineImage: IMachineImage;
```

- *Type:* aws-cdk-lib.aws_ec2.IMachineImage
- *Default:* AmazonLinux2023

The machine image to use as a base for the pipeline.

---

### Ec2LinuxImagePipelineProps <a name="Ec2LinuxImagePipelineProps" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps"></a>

Properties for creating a Linux STIG Image Pipeline.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

const ec2LinuxImagePipelineProps: patterns.Ec2LinuxImagePipelineProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.version">version</a></code> | <code>string</code> | Version of the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.buildConfiguration">buildConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps</code> | Configuration options for the build process. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.description">description</a></code> | <code>string</code> | Description of the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | KMS key for encryption. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.instanceTypes">instanceTypes</a></code> | <code>string[]</code> | Instance types for the Image Builder Pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.vpcConfiguration">vpcConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps</code> | VPC configuration for the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.extraComponents">extraComponents</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component \| aws-cdk-lib.aws_imagebuilder.CfnComponent[]</code> | Additional components to install in the image. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.extraDeviceMappings">extraDeviceMappings</a></code> | <code>aws-cdk-lib.aws_imagebuilder.CfnImageRecipe.InstanceBlockDeviceMappingProperty[]</code> | Additional EBS volume mappings to add to the image. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.features">features</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature[]</code> | A list of features to install on the image. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.operatingSystem">operatingSystem</a></code> | <code>@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem</code> | The operating system to use for the image pipeline. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.rootVolumeSize">rootVolumeSize</a></code> | <code>number</code> | Size for the root volume in GB. |

---

##### `version`<sup>Required</sup> <a name="version" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.version"></a>

```typescript
public readonly version: string;
```

- *Type:* string

Version of the image pipeline.

This must be updated if you make
underlying changes to the pipeline configuration.

---

##### `buildConfiguration`<sup>Optional</sup> <a name="buildConfiguration" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.buildConfiguration"></a>

```typescript
public readonly buildConfiguration: BuildConfigurationProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.BuildConfigurationProps

Configuration options for the build process.

---

##### `description`<sup>Optional</sup> <a name="description" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.description"></a>

```typescript
public readonly description: string;
```

- *Type:* string

Description of the image pipeline.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

KMS key for encryption.

---

##### `instanceTypes`<sup>Optional</sup> <a name="instanceTypes" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.instanceTypes"></a>

```typescript
public readonly instanceTypes: string[];
```

- *Type:* string[]

Instance types for the Image Builder Pipeline.

Default: [t3.medium]

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

##### `vpcConfiguration`<sup>Optional</sup> <a name="vpcConfiguration" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.vpcConfiguration"></a>

```typescript
public readonly vpcConfiguration: VpcConfigurationProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps

VPC configuration for the image pipeline.

---

##### `extraComponents`<sup>Optional</sup> <a name="extraComponents" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.extraComponents"></a>

```typescript
public readonly extraComponents: Component | CfnComponent[];
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component | aws-cdk-lib.aws_imagebuilder.CfnComponent[]

Additional components to install in the image.

These components will be added after the default Linux components.
Use this to add custom components beyond the predefined features.

---

##### `extraDeviceMappings`<sup>Optional</sup> <a name="extraDeviceMappings" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.extraDeviceMappings"></a>

```typescript
public readonly extraDeviceMappings: InstanceBlockDeviceMappingProperty[];
```

- *Type:* aws-cdk-lib.aws_imagebuilder.CfnImageRecipe.InstanceBlockDeviceMappingProperty[]

Additional EBS volume mappings to add to the image.

These volumes will be added in addition to the root volume.
Use this to specify additional storage volumes that should be included in the AMI.

---

##### `features`<sup>Optional</sup> <a name="features" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.features"></a>

```typescript
public readonly features: Feature[];
```

- *Type:* @cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature[]
- *Default:* [Ec2LinuxImagePipeline.Feature.AWS_CLI, Ec2LinuxImagePipeline.Feature.RETAIN_SSM_AGENT]

A list of features to install on the image.

Features are predefined sets of components and configurations.
Default: [AWS_CLI, RETAIN_SSM_AGENT]

---

##### `operatingSystem`<sup>Optional</sup> <a name="operatingSystem" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.operatingSystem"></a>

```typescript
public readonly operatingSystem: OperatingSystem;
```

- *Type:* @cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem
- *Default:* Ec2LinuxImagePipeline.OperatingSystem.AMAZON_LINUX_2023

The operating system to use for the image pipeline.

Specifies which operating system version to use as the base image.
Default: AMAZON_LINUX_2023.

---

##### `rootVolumeSize`<sup>Optional</sup> <a name="rootVolumeSize" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipelineProps.property.rootVolumeSize"></a>

```typescript
public readonly rootVolumeSize: number;
```

- *Type:* number
- *Default:* 10

Size for the root volume in GB.

Default: 10 GB.

---

### EcsSettings <a name="EcsSettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.EcsSettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.EcsSettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const ecsSettings: aspects.SecurityCompliance.EcsSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.EcsSettings.property.clusterContainerInsights">clusterContainerInsights</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting</code> | Enables container insights for ECS clusters. |

---

##### `clusterContainerInsights`<sup>Optional</sup> <a name="clusterContainerInsights" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.EcsSettings.property.clusterContainerInsights"></a>

```typescript
public readonly clusterContainerInsights: DisableableSetting;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting

Enables container insights for ECS clusters.

Resolves:
  - AwsSolutions-ECS4

Defaults to ContainerInsights.ENABLED if not disabled.

---

### FriendlyEmbraceProps <a name="FriendlyEmbraceProps" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps"></a>

Input metadata for the custom resource.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const friendlyEmbraceProps: constructs.FriendlyEmbraceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.bucketConfiguration">bucketConfiguration</a></code> | <code>aws-cdk-lib.aws_s3.BucketProps</code> | Optional S3 Bucket configuration settings. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Encryption key for protecting the Lambda environment. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.ignoreInvalidStates">ignoreInvalidStates</a></code> | <code>boolean</code> | Whether or not stacks in error state should be fatal to CR completion. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.manualReadPermissions">manualReadPermissions</a></code> | <code>aws-cdk-lib.aws_iam.PolicyStatement[]</code> | Manually provide specific read-only permissions for resources in your CloudFormation templates to support instead of using the AWS managed policy [ReadOnlyAccess](https://docs.aws.amazon.com/aws-managed-policy/latest/reference/ReadOnlyAccess.html). |

---

##### `bucketConfiguration`<sup>Optional</sup> <a name="bucketConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.bucketConfiguration"></a>

```typescript
public readonly bucketConfiguration: BucketProps;
```

- *Type:* aws-cdk-lib.aws_s3.BucketProps

Optional S3 Bucket configuration settings.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Encryption key for protecting the Lambda environment.

---

##### `ignoreInvalidStates`<sup>Optional</sup> <a name="ignoreInvalidStates" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.ignoreInvalidStates"></a>

```typescript
public readonly ignoreInvalidStates: boolean;
```

- *Type:* boolean

Whether or not stacks in error state should be fatal to CR completion.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

##### `manualReadPermissions`<sup>Optional</sup> <a name="manualReadPermissions" id="@cdklabs/cdk-proserve-lib.constructs.FriendlyEmbraceProps.property.manualReadPermissions"></a>

```typescript
public readonly manualReadPermissions: PolicyStatement[];
```

- *Type:* aws-cdk-lib.aws_iam.PolicyStatement[]

Manually provide specific read-only permissions for resources in your CloudFormation templates to support instead of using the AWS managed policy [ReadOnlyAccess](https://docs.aws.amazon.com/aws-managed-policy/latest/reference/ReadOnlyAccess.html).

This can be useful in environments where the caller wants to maintain tight control over the permissions granted
to the custom resource worker.

---

### IamServerCertificateProps <a name="IamServerCertificateProps" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps"></a>

Properties for the IamServerCertificate construct.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const iamServerCertificateProps: constructs.IamServerCertificateProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.certificate">certificate</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps \| @cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps</code> | AWS Systems Manager parameter or AWS Secrets Manager secret which contains the public certificate. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.prefix">prefix</a></code> | <code>string</code> | Prefix to prepend to the AWS IAM Server Certificate name. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.privateKey">privateKey</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps \| @cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps</code> | AWS Systems Manager parameter or AWS Secrets Manager secret which contains the private key. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Encryption key for protecting the framework resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |

---

##### `certificate`<sup>Required</sup> <a name="certificate" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.certificate"></a>

```typescript
public readonly certificate: ParameterProps | SecretProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps | @cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps

AWS Systems Manager parameter or AWS Secrets Manager secret which contains the public certificate.

---

##### `prefix`<sup>Required</sup> <a name="prefix" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.prefix"></a>

```typescript
public readonly prefix: string;
```

- *Type:* string

Prefix to prepend to the AWS IAM Server Certificate name.

---

##### `privateKey`<sup>Required</sup> <a name="privateKey" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.privateKey"></a>

```typescript
public readonly privateKey: ParameterProps | SecretProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps | @cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps

AWS Systems Manager parameter or AWS Secrets Manager secret which contains the private key.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Encryption key for protecting the framework resources.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificateProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

### LambdaConfiguration <a name="LambdaConfiguration" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.Initializer"></a>

```typescript
import { types } from '@cdklabs/cdk-proserve-lib'

const lambdaConfiguration: types.LambdaConfiguration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.deadLetterQueue">deadLetterQueue</a></code> | <code>aws-cdk-lib.aws_sqs.IQueue</code> | Optional SQS queue to use as a dead letter queue. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.logGroupRetention">logGroupRetention</a></code> | <code>aws-cdk-lib.aws_logs.RetentionDays</code> | Optional retention period for the Lambda functions log group. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.reservedConcurrentExecutions">reservedConcurrentExecutions</a></code> | <code>number</code> | The number of concurrent executions for the provider Lambda function. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.securityGroups">securityGroups</a></code> | <code>aws-cdk-lib.aws_ec2.ISecurityGroup[]</code> | Security groups to attach to the provider Lambda functions. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.subnets">subnets</a></code> | <code>aws-cdk-lib.aws_ec2.SubnetSelection</code> | Optional subnet selection for the Lambda functions. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.vpc">vpc</a></code> | <code>aws-cdk-lib.aws_ec2.IVpc</code> | VPC where the Lambda functions will be deployed. |

---

##### `deadLetterQueue`<sup>Optional</sup> <a name="deadLetterQueue" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.deadLetterQueue"></a>

```typescript
public readonly deadLetterQueue: IQueue;
```

- *Type:* aws-cdk-lib.aws_sqs.IQueue

Optional SQS queue to use as a dead letter queue.

---

##### `logGroupRetention`<sup>Optional</sup> <a name="logGroupRetention" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.logGroupRetention"></a>

```typescript
public readonly logGroupRetention: RetentionDays;
```

- *Type:* aws-cdk-lib.aws_logs.RetentionDays
- *Default:* RetentionDays.ONE_MONTH

Optional retention period for the Lambda functions log group.

---

##### `reservedConcurrentExecutions`<sup>Optional</sup> <a name="reservedConcurrentExecutions" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.reservedConcurrentExecutions"></a>

```typescript
public readonly reservedConcurrentExecutions: number;
```

- *Type:* number

The number of concurrent executions for the provider Lambda function.

Default: 5

---

##### `securityGroups`<sup>Optional</sup> <a name="securityGroups" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.securityGroups"></a>

```typescript
public readonly securityGroups: ISecurityGroup[];
```

- *Type:* aws-cdk-lib.aws_ec2.ISecurityGroup[]

Security groups to attach to the provider Lambda functions.

---

##### `subnets`<sup>Optional</sup> <a name="subnets" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.subnets"></a>

```typescript
public readonly subnets: SubnetSelection;
```

- *Type:* aws-cdk-lib.aws_ec2.SubnetSelection

Optional subnet selection for the Lambda functions.

---

##### `vpc`<sup>Optional</sup> <a name="vpc" id="@cdklabs/cdk-proserve-lib.types.LambdaConfiguration.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* aws-cdk-lib.aws_ec2.IVpc

VPC where the Lambda functions will be deployed.

---

### LambdaSettings <a name="LambdaSettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.LambdaSettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.LambdaSettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const lambdaSettings: aspects.SecurityCompliance.LambdaSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.LambdaSettings.property.reservedConcurrentExecutions">reservedConcurrentExecutions</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings</code> | Enables reserved concurrent executions for Lambda Functions. |

---

##### `reservedConcurrentExecutions`<sup>Optional</sup> <a name="reservedConcurrentExecutions" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.LambdaSettings.property.reservedConcurrentExecutions"></a>

```typescript
public readonly reservedConcurrentExecutions: ReservedConcurrentSettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings

Enables reserved concurrent executions for Lambda Functions.

Resolves:
  - NIST.800.53.R5-LambdaConcurrency

Defaults to 1 if not disabled or set.

---

### LoggingConfiguration <a name="LoggingConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const loggingConfiguration: constructs.NetworkFirewall.LoggingConfiguration = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.logTypes">logTypes</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType[]</code> | The type of logs to write for the Network Firewall. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional KMS key for encrypting Network Firewall logs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.logGroup">logGroup</a></code> | <code>aws-cdk-lib.aws_logs.ILogGroup</code> | Log group to use for Network Firewall Logging. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.logRetention">logRetention</a></code> | <code>aws-cdk-lib.aws_logs.RetentionDays</code> | If you do not specify a log group, the amount of time to keep logs in the automatically created Log Group. |

---

##### `logTypes`<sup>Required</sup> <a name="logTypes" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.logTypes"></a>

```typescript
public readonly logTypes: LogType[];
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType[]

The type of logs to write for the Network Firewall.

This can be `TLS`, `FLOW`, or `ALERT`.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional KMS key for encrypting Network Firewall logs.

---

##### `logGroup`<sup>Optional</sup> <a name="logGroup" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.logGroup"></a>

```typescript
public readonly logGroup: ILogGroup;
```

- *Type:* aws-cdk-lib.aws_logs.ILogGroup

Log group to use for Network Firewall Logging.

If not specified, a log group is created for you. The encryption key provided will be used to encrypt it if one was provided to the construct.

---

##### `logRetention`<sup>Optional</sup> <a name="logRetention" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration.property.logRetention"></a>

```typescript
public readonly logRetention: RetentionDays;
```

- *Type:* aws-cdk-lib.aws_logs.RetentionDays

If you do not specify a log group, the amount of time to keep logs in the automatically created Log Group.

Default: one week

---

### NetworkFirewallEndpointsProps <a name="NetworkFirewallEndpointsProps" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps"></a>

Properties for the NetworkFirewallEndpoints construct.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const networkFirewallEndpointsProps: constructs.NetworkFirewallEndpointsProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps.property.firewall">firewall</a></code> | <code>aws-cdk-lib.aws_networkfirewall.CfnFirewall</code> | The AWS Network Firewall to get the Endpoints for. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration</code> | Optional Lambda configuration settings. |

---

##### `firewall`<sup>Required</sup> <a name="firewall" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps.property.firewall"></a>

```typescript
public readonly firewall: CfnFirewall;
```

- *Type:* aws-cdk-lib.aws_networkfirewall.CfnFirewall

The AWS Network Firewall to get the Endpoints for.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallEndpointsProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: AwsCustomResourceLambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration

Optional Lambda configuration settings.

---

### NetworkFirewallProps <a name="NetworkFirewallProps" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps"></a>

Properties for configuring a NetworkFirewall.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const networkFirewallProps: constructs.NetworkFirewallProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.firewallSubnets">firewallSubnets</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet[]</code> | List of subnets where the Network Firewall will be placed These should typically be dedicated firewall subnets. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.suricataRulesCapacity">suricataRulesCapacity</a></code> | <code>number</code> | The capacity to set for the Suricata rule group. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.suricataRulesFilePath">suricataRulesFilePath</a></code> | <code>string</code> | Path to the Suricata rules file on the local file system. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.vpc">vpc</a></code> | <code>aws-cdk-lib.aws_ec2.IVpc</code> | VPC where the Network Firewall will be deployed. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.configureVpcRoutes">configureVpcRoutes</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps</code> | Network Firewall routing configuration. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.logging">logging</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration</code> | Optional logging configuration for the Network Firewall. |

---

##### `firewallSubnets`<sup>Required</sup> <a name="firewallSubnets" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.firewallSubnets"></a>

```typescript
public readonly firewallSubnets: ISubnet[];
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet[]

List of subnets where the Network Firewall will be placed These should typically be dedicated firewall subnets.

---

##### `suricataRulesCapacity`<sup>Required</sup> <a name="suricataRulesCapacity" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.suricataRulesCapacity"></a>

```typescript
public readonly suricataRulesCapacity: number;
```

- *Type:* number

The capacity to set for the Suricata rule group.

This cannot be modified
after creation. You should set this to the upper bound of what you expect
your firewall rule group to consume.

---

##### `suricataRulesFilePath`<sup>Required</sup> <a name="suricataRulesFilePath" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.suricataRulesFilePath"></a>

```typescript
public readonly suricataRulesFilePath: string;
```

- *Type:* string

Path to the Suricata rules file on the local file system.

---

##### `vpc`<sup>Required</sup> <a name="vpc" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* aws-cdk-lib.aws_ec2.IVpc

VPC where the Network Firewall will be deployed.

---

##### `configureVpcRoutes`<sup>Optional</sup> <a name="configureVpcRoutes" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.configureVpcRoutes"></a>

```typescript
public readonly configureVpcRoutes: NetworkFirewallVpcRouteProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps

Network Firewall routing configuration.

By configuring these settings,
the Construct will automatically setup basic routing statements for you
for the provided subnets. This should be used with caution and you should
double check the routing is correct prior to deployment.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewallProps.property.logging"></a>

```typescript
public readonly logging: LoggingConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LoggingConfiguration

Optional logging configuration for the Network Firewall.

If not provided,
logs will not be written.

---

### NetworkFirewallVpcRouteProps <a name="NetworkFirewallVpcRouteProps" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const networkFirewallVpcRouteProps: constructs.NetworkFirewall.NetworkFirewallVpcRouteProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.protectedSubnets">protectedSubnets</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet[]</code> | Subnets that will sit behind the network firewall and should have routes to the Network Firewall. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.destinationCidr">destinationCidr</a></code> | <code>string</code> | The destination CIDR block for the firewall (protectedSubnets) route. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration</code> | Configuration for the Lambda function that will be used to retrieve info about the AWS Network Firewall in order to setup the routing. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.returnSubnets">returnSubnets</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet[]</code> | Subnets that should have routes back to the protected subnets. |

---

##### `protectedSubnets`<sup>Required</sup> <a name="protectedSubnets" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.protectedSubnets"></a>

```typescript
public readonly protectedSubnets: ISubnet[];
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet[]

Subnets that will sit behind the network firewall and should have routes to the Network Firewall.

By supplying this parameter, routes will
be created for these subnets to the Network Firewall. Specify the
optional `destinationCidr` parameter if you want to restrict the
routes to a specific CIDR block. By default, routes will be created
for all outbound traffic (0.0.0.0/0) to the firewall.

---

##### `destinationCidr`<sup>Optional</sup> <a name="destinationCidr" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.destinationCidr"></a>

```typescript
public readonly destinationCidr: string;
```

- *Type:* string

The destination CIDR block for the firewall (protectedSubnets) route.

If not specified, defaults to '0.0.0.0/0' (all IPv4 traffic).

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: AwsCustomResourceLambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.AwsCustomResourceLambdaConfiguration

Configuration for the Lambda function that will be used to retrieve info about the AWS Network Firewall in order to setup the routing.

---

##### `returnSubnets`<sup>Optional</sup> <a name="returnSubnets" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.NetworkFirewallVpcRouteProps.property.returnSubnets"></a>

```typescript
public readonly returnSubnets: ISubnet[];
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet[]

Subnets that should have routes back to the protected subnets.

Since
traffic is flowing through the firewall, routes should be put into the
subnets where traffic is returning to. This is most likely your public
subnets in the VPC. By supplying this parameter, routes will be created
that send all traffic destined for the `protectedSubnets` back to the
firewall for proper routing.

---

### OpenSearchAdminUserProps <a name="OpenSearchAdminUserProps" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps"></a>

Properties for the OpenSearchAdminUser construct.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const openSearchAdminUserProps: constructs.OpenSearchAdminUserProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.credential">credential</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps \| @cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps</code> | The SSM parameter or Secret containing the password for the OpenSearch admin user. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.domain">domain</a></code> | <code>aws-cdk-lib.aws_opensearchservice.IDomain</code> | The OpenSearch domain to which the admin user will be added. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.username">username</a></code> | <code>aws-cdk-lib.aws_ssm.IParameter</code> | The SSM parameter containing the username for the OpenSearch admin user. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.domainKey">domainKey</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional Lambda configuration settings. |

---

##### `credential`<sup>Required</sup> <a name="credential" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.credential"></a>

```typescript
public readonly credential: PasswordParameterProps | PasswordSecretProps;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps | @cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps

The SSM parameter or Secret containing the password for the OpenSearch admin user.

---

##### `domain`<sup>Required</sup> <a name="domain" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.domain"></a>

```typescript
public readonly domain: IDomain;
```

- *Type:* aws-cdk-lib.aws_opensearchservice.IDomain

The OpenSearch domain to which the admin user will be added.

---

##### `username`<sup>Required</sup> <a name="username" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.username"></a>

```typescript
public readonly username: IParameter;
```

- *Type:* aws-cdk-lib.aws_ssm.IParameter

The SSM parameter containing the username for the OpenSearch admin user.

---

##### `domainKey`<sup>Optional</sup> <a name="domainKey" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.domainKey"></a>

```typescript
public readonly domainKey: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional.

The KMS key used to encrypt the OpenSearch domain.
If provided, the construct will grant the necessary permissions to use this key.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional.

The KMS key used to encrypt the worker resources (e.g., Lambda function environment variables).
If provided, this key will be used for encryption; otherwise, an AWS managed key will be used.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUserProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional Lambda configuration settings.

---

### OpenSearchWorkflowProps <a name="OpenSearchWorkflowProps" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps"></a>

Properties for configuring an OpenSearch workflow.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const openSearchWorkflowProps: constructs.OpenSearchWorkflowProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.domain">domain</a></code> | <code>aws-cdk-lib.aws_opensearchservice.IDomain</code> | The OpenSearch domain to deploy the workflow to. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.domainAuthentication">domainAuthentication</a></code> | <code>aws-cdk-lib.aws_iam.IRole</code> | IAM role used for domain authentication. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.flowFrameworkTemplatePath">flowFrameworkTemplatePath</a></code> | <code>string</code> | Path to the Flow Framework template file (YAML or JSON). |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.allowDestructiveOperations">allowDestructiveOperations</a></code> | <code>@cdklabs/cdk-proserve-lib.types.DestructiveOperation</code> | Whether to allow destructive operations like updating/deleting workflows. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional KMS key for encryption. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.lambdaConfiguration">lambdaConfiguration</a></code> | <code>@cdklabs/cdk-proserve-lib.types.LambdaConfiguration</code> | Optional lambda configuration settings for the custom resource provider. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.templateAssetVariables">templateAssetVariables</a></code> | <code>{[ key: string ]: string \| aws-cdk-lib.aws_s3_assets.Asset}</code> | Optional asset variables for the workflow. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.templateCreationVariables">templateCreationVariables</a></code> | <code>{[ key: string ]: string}</code> | Optional creation variables for the workflow. Your template must be configured to accept these variables using `${{{ my_variable }}}` syntax. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.templateProvisionVariables">templateProvisionVariables</a></code> | <code>{[ key: string ]: string}</code> | Optional provisioning variables for the workflow. Your template must be configured to accept these variables using `${{ my_variable }}` syntax. |

---

##### `domain`<sup>Required</sup> <a name="domain" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.domain"></a>

```typescript
public readonly domain: IDomain;
```

- *Type:* aws-cdk-lib.aws_opensearchservice.IDomain

The OpenSearch domain to deploy the workflow to.

---

##### `domainAuthentication`<sup>Required</sup> <a name="domainAuthentication" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.domainAuthentication"></a>

```typescript
public readonly domainAuthentication: IRole;
```

- *Type:* aws-cdk-lib.aws_iam.IRole

IAM role used for domain authentication.

---

##### `flowFrameworkTemplatePath`<sup>Required</sup> <a name="flowFrameworkTemplatePath" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.flowFrameworkTemplatePath"></a>

```typescript
public readonly flowFrameworkTemplatePath: string;
```

- *Type:* string

Path to the Flow Framework template file (YAML or JSON).

---

##### `allowDestructiveOperations`<sup>Optional</sup> <a name="allowDestructiveOperations" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.allowDestructiveOperations"></a>

```typescript
public readonly allowDestructiveOperations: DestructiveOperation;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.DestructiveOperation

Whether to allow destructive operations like updating/deleting workflows.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional KMS key for encryption.

---

##### `lambdaConfiguration`<sup>Optional</sup> <a name="lambdaConfiguration" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.lambdaConfiguration"></a>

```typescript
public readonly lambdaConfiguration: LambdaConfiguration;
```

- *Type:* @cdklabs/cdk-proserve-lib.types.LambdaConfiguration

Optional lambda configuration settings for the custom resource provider.

---

##### `templateAssetVariables`<sup>Optional</sup> <a name="templateAssetVariables" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.templateAssetVariables"></a>

```typescript
public readonly templateAssetVariables: {[ key: string ]: string | Asset};
```

- *Type:* {[ key: string ]: string | aws-cdk-lib.aws_s3_assets.Asset}

Optional asset variables for the workflow.

This can either be an AWS CDK
S3 Asset object or a string that represents an S3 path (e.g. `s3://my-bucket/my-key`).
Your template must be configured to accept these variables using
`${{{ my_variable }}}` syntax. For each one of these variables, an S3
pre-signed URL will be generated and substituted into your template right
before workflow creation time. If you provide an S3 path, you must grant
read permissions to the appropriate bucket in order for the custom
resource to be able to generate a pre-signed url.

---

##### `templateCreationVariables`<sup>Optional</sup> <a name="templateCreationVariables" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.templateCreationVariables"></a>

```typescript
public readonly templateCreationVariables: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Optional creation variables for the workflow. Your template must be configured to accept these variables using `${{{ my_variable }}}` syntax.

These variables will be substituted in prior to creation, so that will
be available during creation time and provision time.

---

##### `templateProvisionVariables`<sup>Optional</sup> <a name="templateProvisionVariables" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchWorkflowProps.property.templateProvisionVariables"></a>

```typescript
public readonly templateProvisionVariables: {[ key: string ]: string};
```

- *Type:* {[ key: string ]: string}

Optional provisioning variables for the workflow. Your template must be configured to accept these variables using `${{ my_variable }}` syntax.

https://opensearch.org/docs/latest/automating-configurations/api/provision-workflow

---

### OverrideConfig <a name="OverrideConfig" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig"></a>

Configuration for rule overrides.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const overrideConfig: constructs.WebApplicationFirewall.OverrideConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig.property.action">action</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction</code> | The action to take for the specific rule. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig.property.name">name</a></code> | <code>string</code> | The name of the specific rule to override. |

---

##### `action`<sup>Required</sup> <a name="action" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig.property.action"></a>

```typescript
public readonly action: OverrideAction;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction

The action to take for the specific rule.

---

##### `name`<sup>Required</sup> <a name="name" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideConfig.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

The name of the specific rule to override.

---

### ParameterProps <a name="ParameterProps" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps"></a>

Properties for a server certificate element when it is stored in AWS Systems Manager Parameter Store.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const parameterProps: constructs.IamServerCertificate.ParameterProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps.property.parameter">parameter</a></code> | <code>aws-cdk-lib.aws_ssm.IParameter</code> | Reference to the AWS Systems Manager Parameter Store parameter that contains the data. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional encryption key that protects the secret. |

---

##### `parameter`<sup>Required</sup> <a name="parameter" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps.property.parameter"></a>

```typescript
public readonly parameter: IParameter;
```

- *Type:* aws-cdk-lib.aws_ssm.IParameter

Reference to the AWS Systems Manager Parameter Store parameter that contains the data.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.ParameterProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional encryption key that protects the secret.

---

### PasswordParameterProps <a name="PasswordParameterProps" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps"></a>

Properties for the admin user password specific to when the credential is stored in AWS Systems Manager Parameter Store.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const passwordParameterProps: constructs.OpenSearchAdminUser.PasswordParameterProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps.property.parameter">parameter</a></code> | <code>aws-cdk-lib.aws_ssm.IParameter</code> | Reference to the AWS Systems Manager Parameter Store parameter that contains the admin credential. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional encryption key that protects the secret. |

---

##### `parameter`<sup>Required</sup> <a name="parameter" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps.property.parameter"></a>

```typescript
public readonly parameter: IParameter;
```

- *Type:* aws-cdk-lib.aws_ssm.IParameter

Reference to the AWS Systems Manager Parameter Store parameter that contains the admin credential.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordParameterProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional encryption key that protects the secret.

---

### PasswordSecretProps <a name="PasswordSecretProps" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps"></a>

Properties for the admin user password specific to when the credential is stored in AWS Secrets Manager.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const passwordSecretProps: constructs.OpenSearchAdminUser.PasswordSecretProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps.property.secret">secret</a></code> | <code>aws-cdk-lib.aws_secretsmanager.ISecret</code> | Reference to the AWS Secrets Manager secret that contains the admin credential. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional encryption key that protects the secret. |

---

##### `secret`<sup>Required</sup> <a name="secret" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps.property.secret"></a>

```typescript
public readonly secret: ISecret;
```

- *Type:* aws-cdk-lib.aws_secretsmanager.ISecret

Reference to the AWS Secrets Manager secret that contains the admin credential.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.OpenSearchAdminUser.PasswordSecretProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional encryption key that protects the secret.

---

### PatternComponents <a name="PatternComponents" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents"></a>

Underlying components for the pattern.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.Initializer"></a>

```typescript
import { patterns } from '@cdklabs/cdk-proserve-lib'

const patternComponents: patterns.ApiGatewayStaticHosting.PatternComponents = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.property.distribution">distribution</a></code> | <code>aws-cdk-lib.aws_apigateway.RestApi</code> | Provides access to the underlying Amazon API Gateway REST API that serves as the distribution endpoint for the static content. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.property.proxy">proxy</a></code> | <code>aws-cdk-lib.aws_lambda.Function</code> | Provides access to the underlying AWS Lambda function that proxies the static content from Amazon S3. |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.property.store">store</a></code> | <code>aws-cdk-lib.aws_s3.Bucket</code> | Provides access to the underlying Amazon S3 bucket that stores the static content. |

---

##### `distribution`<sup>Required</sup> <a name="distribution" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.property.distribution"></a>

```typescript
public readonly distribution: RestApi;
```

- *Type:* aws-cdk-lib.aws_apigateway.RestApi

Provides access to the underlying Amazon API Gateway REST API that serves as the distribution endpoint for the static content.

WARNING: Making changes to the properties of the underlying components of this pattern may cause it to not
behave as expected or designed. You do so at your own risk.

---

##### `proxy`<sup>Required</sup> <a name="proxy" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.property.proxy"></a>

```typescript
public readonly proxy: Function;
```

- *Type:* aws-cdk-lib.aws_lambda.Function

Provides access to the underlying AWS Lambda function that proxies the static content from Amazon S3.

WARNING: Making changes to the properties of the underlying components of this pattern may cause it to not
behave as expected or designed. You do so at your own risk.

---

##### `store`<sup>Required</sup> <a name="store" id="@cdklabs/cdk-proserve-lib.patterns.ApiGatewayStaticHosting.PatternComponents.property.store"></a>

```typescript
public readonly store: Bucket;
```

- *Type:* aws-cdk-lib.aws_s3.Bucket

Provides access to the underlying Amazon S3 bucket that stores the static content.

WARNING: Making changes to the properties of the underlying components of this pattern may cause it to not
behave as expected or designed. You do so at your own risk.

---

### ReservedConcurrentSettings <a name="ReservedConcurrentSettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const reservedConcurrentSettings: aspects.SecurityCompliance.ReservedConcurrentSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings.property.disabled">disabled</a></code> | <code>boolean</code> | Sets the setting to disabled. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings.property.concurrentExecutionCount">concurrentExecutionCount</a></code> | <code>number</code> | The number of reserved concurrency executions. |

---

##### `disabled`<sup>Optional</sup> <a name="disabled" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings.property.disabled"></a>

```typescript
public readonly disabled: boolean;
```

- *Type:* boolean

Sets the setting to disabled.

This does not actually make an impact on
the setting itself, it just stops this aspect from making changes to
the specific setting.

---

##### `concurrentExecutionCount`<sup>Optional</sup> <a name="concurrentExecutionCount" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ReservedConcurrentSettings.property.concurrentExecutionCount"></a>

```typescript
public readonly concurrentExecutionCount: number;
```

- *Type:* number

The number of reserved concurrency executions.

Resolves:
  - NIST.800.53.R5-LambdaConcurrency

Defaults to 1 if not specified.

---

### S3Settings <a name="S3Settings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const s3Settings: aspects.SecurityCompliance.S3Settings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings.property.serverAccessLogs">serverAccessLogs</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ServerAccessLogsSettings</code> | Enable server access logs to a destination S3 bucket. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings.property.versioning">versioning</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting</code> | Enables versioning for S3 buckets. |

---

##### `serverAccessLogs`<sup>Optional</sup> <a name="serverAccessLogs" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings.property.serverAccessLogs"></a>

```typescript
public readonly serverAccessLogs: ServerAccessLogsSettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ServerAccessLogsSettings

Enable server access logs to a destination S3 bucket.

Since this requires
a destination S3 bucket, it is not set by default. You must set a target
S3 bucket to enable access logs.

Resolves:
  - AwsSolutions-S1
  - NIST.800.53.R5-S3BucketLoggingEnabled

---

##### `versioning`<sup>Optional</sup> <a name="versioning" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings.property.versioning"></a>

```typescript
public readonly versioning: DisableableSetting;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting

Enables versioning for S3 buckets.

Resolves:
  - NIST.800.53.R5-S3BucketVersioningEnabled

Defaults to true if not disabled.

---

### SecretProps <a name="SecretProps" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps"></a>

Properties for a server certificate element when it is stored in AWS Secrets Manager.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const secretProps: constructs.IamServerCertificate.SecretProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps.property.secret">secret</a></code> | <code>aws-cdk-lib.aws_secretsmanager.ISecret</code> | Reference to the AWS Secrets Manager secret that contains the data. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional encryption key that protects the secret. |

---

##### `secret`<sup>Required</sup> <a name="secret" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps.property.secret"></a>

```typescript
public readonly secret: ISecret;
```

- *Type:* aws-cdk-lib.aws_secretsmanager.ISecret

Reference to the AWS Secrets Manager secret that contains the data.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.IamServerCertificate.SecretProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional encryption key that protects the secret.

---

### SecureSageMakerNotebookProps <a name="SecureSageMakerNotebookProps" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const secureSageMakerNotebookProps: aspects.SecureSageMakerNotebookProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.allowedLaunchSubnets">allowedLaunchSubnets</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet[]</code> | Sets the VPC Subnets that the SageMaker Notebook Instance is allowed to launch training and inference jobs into. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.notebookSubnet">notebookSubnet</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet</code> | Sets the VPC Subnet for the Sagemaker Notebook Instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.directInternetAccess">directInternetAccess</a></code> | <code>boolean</code> | Sets the `directInternetAccess` property on the SageMaker Notebooks. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.rootAccess">rootAccess</a></code> | <code>boolean</code> | Sets the `rootAccess` property on the SageMaker Notebooks. |

---

##### `allowedLaunchSubnets`<sup>Required</sup> <a name="allowedLaunchSubnets" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.allowedLaunchSubnets"></a>

```typescript
public readonly allowedLaunchSubnets: ISubnet[];
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet[]

Sets the VPC Subnets that the SageMaker Notebook Instance is allowed to launch training and inference jobs into.

This is enforced by adding
DENY statements to the existing role that the Notebook Instance is using.

---

##### `notebookSubnet`<sup>Required</sup> <a name="notebookSubnet" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.notebookSubnet"></a>

```typescript
public readonly notebookSubnet: ISubnet;
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet

Sets the VPC Subnet for the Sagemaker Notebook Instance.

This ensures the
notebook is locked down to a specific VPC/subnet.

---

##### `directInternetAccess`<sup>Optional</sup> <a name="directInternetAccess" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.directInternetAccess"></a>

```typescript
public readonly directInternetAccess: boolean;
```

- *Type:* boolean
- *Default:* false

Sets the `directInternetAccess` property on the SageMaker Notebooks.

By default, this is set to false to disable internet access on any
SageMaker Notebook Instance that this aspect is applied to.

---

##### `rootAccess`<sup>Optional</sup> <a name="rootAccess" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps.property.rootAccess"></a>

```typescript
public readonly rootAccess: boolean;
```

- *Type:* boolean
- *Default:* false

Sets the `rootAccess` property on the SageMaker Notebooks.

By default, this is set to false to disable root access on any
SageMaker Notebook Instance that this aspect is applied to.

---

### SecurityComplianceProps <a name="SecurityComplianceProps" id="@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const securityComplianceProps: aspects.SecurityComplianceProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps.property.settings">settings</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings</code> | Settings for the aspect. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps.property.suppressions">suppressions</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions</code> | Suppressions to add for CDK Nag. |

---

##### `settings`<sup>Optional</sup> <a name="settings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps.property.settings"></a>

```typescript
public readonly settings: Settings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings

Settings for the aspect.

---

##### `suppressions`<sup>Optional</sup> <a name="suppressions" id="@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps.property.suppressions"></a>

```typescript
public readonly suppressions: Suppressions;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions

Suppressions to add for CDK Nag.

You must add your own reasoning to each
suppression. These helpers have been created for common nag suppression
use-cases. It is recommended to review the suppressions that are added
and ensure that they adhere to your organizational level of acceptance.
Each suppression must be supplied with a reason for the suppression as
a string to each suppression property.

If you are not using CDK Nag or do not want to use any suppressions, you
can ignore this property.

---

### ServerAccessLogsSettings <a name="ServerAccessLogsSettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ServerAccessLogsSettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ServerAccessLogsSettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const serverAccessLogsSettings: aspects.SecurityCompliance.ServerAccessLogsSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ServerAccessLogsSettings.property.destinationBucketName">destinationBucketName</a></code> | <code>string</code> | The bucket where server access logs will be sent. |

---

##### `destinationBucketName`<sup>Required</sup> <a name="destinationBucketName" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ServerAccessLogsSettings.property.destinationBucketName"></a>

```typescript
public readonly destinationBucketName: string;
```

- *Type:* string

The bucket where server access logs will be sent.

This must be configured
with the correct permissions to allow the target bucket to receive logs.

If not specified, server access logs will not be enabled.

> [https://docs.aws.amazon.com/AmazonS3/latest/userguide/enable-server-access-logging.html](https://docs.aws.amazon.com/AmazonS3/latest/userguide/enable-server-access-logging.html)

---

### SetLogRetentionProps <a name="SetLogRetentionProps" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetentionProps"></a>

Properties for configuring log retention settings.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetentionProps.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const setLogRetentionProps: aspects.SetLogRetentionProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SetLogRetentionProps.property.period">period</a></code> | <code>aws-cdk-lib.aws_logs.RetentionDays</code> | The retention period for the logs. |

---

##### `period`<sup>Required</sup> <a name="period" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetentionProps.property.period"></a>

```typescript
public readonly period: RetentionDays;
```

- *Type:* aws-cdk-lib.aws_logs.RetentionDays

The retention period for the logs.

---

### Settings <a name="Settings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings"></a>

Configuration settings for the security-compliance aspect.

This interface provides a centralized way to configure security and compliance
settings for various AWS resources. Each property corresponds to a specific
AWS service and contains settings that help ensure resources comply with
security best practices and compliance requirements.

By default, most security settings are enabled unless explicitly disabled.
Some settings may require additional configuration to be effective.

*Example*

```typescript
const securitySettings: Settings = {
  lambda: {
    reservedConcurrentExecutions: {
      concurrentExecutionCount: 5
    }
  },
  s3: {
    serverAccessLogs: {
      destinationBucketName: 'access-logs-bucket'
    }
  }
};
```


#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const settings: aspects.SecurityCompliance.Settings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.apiGateway">apiGateway</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ApiGatewaySettings</code> | Security and compliance settings for API Gateway resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.dynamoDb">dynamoDb</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DynamoDbSettings</code> | Security and compliance settings for DynamoDB tables. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.ecs">ecs</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.EcsSettings</code> | Security and compliance settings for ECS clusters and services. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.lambda">lambda</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.LambdaSettings</code> | Security and compliance settings for Lambda functions. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.s3">s3</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings</code> | Security and compliance settings for S3 buckets. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.stepFunctions">stepFunctions</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StepFunctionsSettings</code> | Security and compliance settings for Step Functions state machines. |

---

##### `apiGateway`<sup>Optional</sup> <a name="apiGateway" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.apiGateway"></a>

```typescript
public readonly apiGateway: ApiGatewaySettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.ApiGatewaySettings

Security and compliance settings for API Gateway resources.

Controls settings like method logging to ensure proper monitoring
and auditability of API usage.

---

##### `dynamoDb`<sup>Optional</sup> <a name="dynamoDb" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.dynamoDb"></a>

```typescript
public readonly dynamoDb: DynamoDbSettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DynamoDbSettings

Security and compliance settings for DynamoDB tables.

Configures features like Point-in-Time Recovery to improve
data durability and recoverability.

---

##### `ecs`<sup>Optional</sup> <a name="ecs" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.ecs"></a>

```typescript
public readonly ecs: EcsSettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.EcsSettings

Security and compliance settings for ECS clusters and services.

Enables features like Container Insights for better
monitoring and observability.

---

##### `lambda`<sup>Optional</sup> <a name="lambda" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.lambda"></a>

```typescript
public readonly lambda: LambdaSettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.LambdaSettings

Security and compliance settings for Lambda functions.

Controls execution limits and other settings to improve
the security posture of Lambda functions.

---

##### `s3`<sup>Optional</sup> <a name="s3" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.s3"></a>

```typescript
public readonly s3: S3Settings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.S3Settings

Security and compliance settings for S3 buckets.

Configures features like versioning and server access logging
to improve data protection and meet compliance requirements.

---

##### `stepFunctions`<sup>Optional</sup> <a name="stepFunctions" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Settings.property.stepFunctions"></a>

```typescript
public readonly stepFunctions: StepFunctionsSettings;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StepFunctionsSettings

Security and compliance settings for Step Functions state machines.

Controls settings like X-Ray tracing to improve
observability and debugging capabilities.

---

### StageMethodLogging <a name="StageMethodLogging" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const stageMethodLogging: aspects.SecurityCompliance.StageMethodLogging = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging.property.disabled">disabled</a></code> | <code>boolean</code> | Sets the setting to disabled. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging.property.loggingLevel">loggingLevel</a></code> | <code>aws-cdk-lib.aws_apigateway.MethodLoggingLevel</code> | The logging level to use for the stage method logging. This applies to all resources and methods in all stages. |

---

##### `disabled`<sup>Optional</sup> <a name="disabled" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging.property.disabled"></a>

```typescript
public readonly disabled: boolean;
```

- *Type:* boolean

Sets the setting to disabled.

This does not actually make an impact on
the setting itself, it just stops this aspect from making changes to
the specific setting.

---

##### `loggingLevel`<sup>Optional</sup> <a name="loggingLevel" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StageMethodLogging.property.loggingLevel"></a>

```typescript
public readonly loggingLevel: MethodLoggingLevel;
```

- *Type:* aws-cdk-lib.aws_apigateway.MethodLoggingLevel

The logging level to use for the stage method logging. This applies to all resources and methods in all stages.

Defaults to MethodLoggingLevel.ERROR if not specified.

---

### StepFunctionsSettings <a name="StepFunctionsSettings" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StepFunctionsSettings"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StepFunctionsSettings.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const stepFunctionsSettings: aspects.SecurityCompliance.StepFunctionsSettings = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StepFunctionsSettings.property.tracing">tracing</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting</code> | Enable or disable X-Ray tracing. |

---

##### `tracing`<sup>Optional</sup> <a name="tracing" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.StepFunctionsSettings.property.tracing"></a>

```typescript
public readonly tracing: DisableableSetting;
```

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.DisableableSetting

Enable or disable X-Ray tracing.

Resolves:
  - AwsSolutions-SF2

Defaults to true if not disabled.

---

### Suppressions <a name="Suppressions" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

const suppressions: aspects.SecurityCompliance.Suppressions = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.cdkCommonGrants">cdkCommonGrants</a></code> | <code>string</code> | Suppressions to add for CDK Nag on CDK generated policies. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.cdkGeneratedResources">cdkGeneratedResources</a></code> | <code>string</code> | Suppressions to add for CDK Nag on CDK generated resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.iamNoInlinePolicies">iamNoInlinePolicies</a></code> | <code>string</code> | Adds a stack suppression for `NIST.800.53.R5-IAMNoInlinePolicy`. CDK commonly uses inline policies when adding permissions. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.lambdaNoDlq">lambdaNoDlq</a></code> | <code>string</code> | Adds a stack suppression for `NIST.800.53.R5-LambdaDLQ`. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.lambdaNotInVpc">lambdaNotInVpc</a></code> | <code>string</code> | Adds a stack suppression for `NIST.800.53.R5-LambdaInsideVPC`. |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.s3BucketReplication">s3BucketReplication</a></code> | <code>string</code> | Adds a stack suppression for `NIST.800.53.R5-S3BucketReplicationEnabled`. |

---

##### `cdkCommonGrants`<sup>Optional</sup> <a name="cdkCommonGrants" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.cdkCommonGrants"></a>

```typescript
public readonly cdkCommonGrants: string;
```

- *Type:* string

Suppressions to add for CDK Nag on CDK generated policies.

If enabled
this will add a stack suppression for `AwsSolutions-IAM5` on the actions
that CDK commonly generates when using `.grant(...)` methods.

---

##### `cdkGeneratedResources`<sup>Optional</sup> <a name="cdkGeneratedResources" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.cdkGeneratedResources"></a>

```typescript
public readonly cdkGeneratedResources: string;
```

- *Type:* string

Suppressions to add for CDK Nag on CDK generated resources.

If enabled
this will suppress `AwsSolutions-IAM5` on the policies that are
created by CDK Generated Lambda functions, as well as other CDK generated
resources such as Log Groups and Step Functions that support CDK
generated custom resources. This only applies to resources that are
created by the underlying CDK.

- Policy suppression: AwsSolutions-IAM5
- Log Group suppression: NIST.800.53.R5-CloudWatchLogGroupEncrypted
- Step Function suppression: AwsSolutions-SF1

---

##### `iamNoInlinePolicies`<sup>Optional</sup> <a name="iamNoInlinePolicies" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.iamNoInlinePolicies"></a>

```typescript
public readonly iamNoInlinePolicies: string;
```

- *Type:* string

Adds a stack suppression for `NIST.800.53.R5-IAMNoInlinePolicy`. CDK commonly uses inline policies when adding permissions.

---

##### `lambdaNoDlq`<sup>Optional</sup> <a name="lambdaNoDlq" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.lambdaNoDlq"></a>

```typescript
public readonly lambdaNoDlq: string;
```

- *Type:* string

Adds a stack suppression for `NIST.800.53.R5-LambdaDLQ`.

---

##### `lambdaNotInVpc`<sup>Optional</sup> <a name="lambdaNotInVpc" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.lambdaNotInVpc"></a>

```typescript
public readonly lambdaNotInVpc: string;
```

- *Type:* string

Adds a stack suppression for `NIST.800.53.R5-LambdaInsideVPC`.

---

##### `s3BucketReplication`<sup>Optional</sup> <a name="s3BucketReplication" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Suppressions.property.s3BucketReplication"></a>

```typescript
public readonly s3BucketReplication: string;
```

- *Type:* string

Adds a stack suppression for `NIST.800.53.R5-S3BucketReplicationEnabled`.

---

### TableProps <a name="TableProps" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps"></a>

Information about the table to provision.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const tableProps: constructs.DynamoDbProvisionTable.TableProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.partitionKeyName">partitionKeyName</a></code> | <code>string</code> | Name of the partition key for the table. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.resource">resource</a></code> | <code>aws-cdk-lib.aws_dynamodb.ITable</code> | CDK representation of the table itself. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.encryption">encryption</a></code> | <code>aws-cdk-lib.aws_kms.IKey</code> | Optional existing encryption key associated with the table. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.sortKeyName">sortKeyName</a></code> | <code>string</code> | Name of the sort key for the table if applicable. |

---

##### `partitionKeyName`<sup>Required</sup> <a name="partitionKeyName" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.partitionKeyName"></a>

```typescript
public readonly partitionKeyName: string;
```

- *Type:* string

Name of the partition key for the table.

---

##### `resource`<sup>Required</sup> <a name="resource" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.resource"></a>

```typescript
public readonly resource: ITable;
```

- *Type:* aws-cdk-lib.aws_dynamodb.ITable

CDK representation of the table itself.

---

##### `encryption`<sup>Optional</sup> <a name="encryption" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.encryption"></a>

```typescript
public readonly encryption: IKey;
```

- *Type:* aws-cdk-lib.aws_kms.IKey

Optional existing encryption key associated with the table.

---

##### `sortKeyName`<sup>Optional</sup> <a name="sortKeyName" id="@cdklabs/cdk-proserve-lib.constructs.DynamoDbProvisionTable.TableProps.property.sortKeyName"></a>

```typescript
public readonly sortKeyName: string;
```

- *Type:* string

Name of the sort key for the table if applicable.

---

### VpcConfigurationProps <a name="VpcConfigurationProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps"></a>

VPC Configuration.

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const vpcConfigurationProps: constructs.Ec2ImagePipeline.VpcConfigurationProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.property.vpc">vpc</a></code> | <code>aws-cdk-lib.aws_ec2.IVpc</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.property.securityGroup">securityGroup</a></code> | <code>aws-cdk-lib.aws_ec2.ISecurityGroup</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.property.subnet">subnet</a></code> | <code>aws-cdk-lib.aws_ec2.ISubnet</code> | *No description.* |

---

##### `vpc`<sup>Required</sup> <a name="vpc" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.property.vpc"></a>

```typescript
public readonly vpc: IVpc;
```

- *Type:* aws-cdk-lib.aws_ec2.IVpc

---

##### `securityGroup`<sup>Optional</sup> <a name="securityGroup" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.property.securityGroup"></a>

```typescript
public readonly securityGroup: ISecurityGroup;
```

- *Type:* aws-cdk-lib.aws_ec2.ISecurityGroup

---

##### `subnet`<sup>Optional</sup> <a name="subnet" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.VpcConfigurationProps.property.subnet"></a>

```typescript
public readonly subnet: ISubnet;
```

- *Type:* aws-cdk-lib.aws_ec2.ISubnet

---

### WaitForCompletionProps <a name="WaitForCompletionProps" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const waitForCompletionProps: constructs.Ec2ImageBuilderStart.WaitForCompletionProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps.property.topic">topic</a></code> | <code>aws-cdk-lib.aws_sns.ITopic</code> | An SNS Topic that will signal when the pipeline is complete. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps.property.timeout">timeout</a></code> | <code>aws-cdk-lib.Duration</code> | The maximum amount of time to wait for the image build pipeline to complete. |

---

##### `topic`<sup>Required</sup> <a name="topic" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps.property.topic"></a>

```typescript
public readonly topic: ITopic;
```

- *Type:* aws-cdk-lib.aws_sns.ITopic

An SNS Topic that will signal when the pipeline is complete.

This is
typically configured on your EC2 Image Builder pipeline to trigger an
SNS notification when the pipeline completes.

---

##### `timeout`<sup>Optional</sup> <a name="timeout" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImageBuilderStart.WaitForCompletionProps.property.timeout"></a>

```typescript
public readonly timeout: Duration;
```

- *Type:* aws-cdk-lib.Duration
- *Default:* 12 hours

The maximum amount of time to wait for the image build pipeline to complete.

This is set to a maximum of 12 hours by default.

---

### WebApplicationFirewallLoggingConfig <a name="WebApplicationFirewallLoggingConfig" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const webApplicationFirewallLoggingConfig: constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.logGroupNameAffix">logGroupNameAffix</a></code> | <code>string</code> | Log Group name affix to be appended to aws-waf-logs-<affix>. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.encryptionKey">encryptionKey</a></code> | <code>aws-cdk-lib.aws_kms.Key</code> | KMS key to use for encryption of the log group. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.removalPolicy">removalPolicy</a></code> | <code>aws-cdk-lib.RemovalPolicy</code> | Removal policy for the log group. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.retention">retention</a></code> | <code>aws-cdk-lib.aws_logs.RetentionDays</code> | Retention period for the log group. |

---

##### `logGroupNameAffix`<sup>Required</sup> <a name="logGroupNameAffix" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.logGroupNameAffix"></a>

```typescript
public readonly logGroupNameAffix: string;
```

- *Type:* string

Log Group name affix to be appended to aws-waf-logs-<affix>.

---

##### `encryptionKey`<sup>Optional</sup> <a name="encryptionKey" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.encryptionKey"></a>

```typescript
public readonly encryptionKey: Key;
```

- *Type:* aws-cdk-lib.aws_kms.Key

KMS key to use for encryption of the log group.

---

##### `removalPolicy`<sup>Optional</sup> <a name="removalPolicy" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.removalPolicy"></a>

```typescript
public readonly removalPolicy: RemovalPolicy;
```

- *Type:* aws-cdk-lib.RemovalPolicy
- *Default:* DESTROY

Removal policy for the log group.

---

##### `retention`<sup>Optional</sup> <a name="retention" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig.property.retention"></a>

```typescript
public readonly retention: RetentionDays;
```

- *Type:* aws-cdk-lib.aws_logs.RetentionDays
- *Default:* ONE_MONTH

Retention period for the log group.

---

### WebApplicationFirewallProps <a name="WebApplicationFirewallProps" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps"></a>

#### Initializer <a name="Initializer" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.Initializer"></a>

```typescript
import { constructs } from '@cdklabs/cdk-proserve-lib'

const webApplicationFirewallProps: constructs.WebApplicationFirewallProps = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.awsManagedRuleGroups">awsManagedRuleGroups</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig \| @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup[]</code> | List of AWS Managed Rule Groups to use for the firewall. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.cloudWatchMetricsEnabled">cloudWatchMetricsEnabled</a></code> | <code>boolean</code> | Whether to enable CloudWatch metrics. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.logging">logging</a></code> | <code>@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig</code> | Logging configuration for the firewall. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.sampledRequestsEnabled">sampledRequestsEnabled</a></code> | <code>boolean</code> | Whether to enable sampled requests. |

---

##### `awsManagedRuleGroups`<sup>Optional</sup> <a name="awsManagedRuleGroups" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.awsManagedRuleGroups"></a>

```typescript
public readonly awsManagedRuleGroups: AwsManagedRuleGroupConfig | AwsManagedRuleGroup[];
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroupConfig | @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup[]
- *Default:* []

List of AWS Managed Rule Groups to use for the firewall.

---

##### `cloudWatchMetricsEnabled`<sup>Optional</sup> <a name="cloudWatchMetricsEnabled" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.cloudWatchMetricsEnabled"></a>

```typescript
public readonly cloudWatchMetricsEnabled: boolean;
```

- *Type:* boolean
- *Default:* false

Whether to enable CloudWatch metrics.

---

##### `logging`<sup>Optional</sup> <a name="logging" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.logging"></a>

```typescript
public readonly logging: WebApplicationFirewallLoggingConfig;
```

- *Type:* @cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.WebApplicationFirewallLoggingConfig

Logging configuration for the firewall.

---

##### `sampledRequestsEnabled`<sup>Optional</sup> <a name="sampledRequestsEnabled" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewallProps.property.sampledRequestsEnabled"></a>

```typescript
public readonly sampledRequestsEnabled: boolean;
```

- *Type:* boolean
- *Default:* false

Whether to enable sampled requests.

---

## Classes <a name="Classes" id="Classes"></a>

### ApplyRemovalPolicy <a name="ApplyRemovalPolicy" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy"></a>

- *Implements:* aws-cdk-lib.IAspect

Sets a user specified Removal Policy to all resources that the aspect applies to.

This Aspect is useful if you want to enforce a specified removal policy on
resources. For example, you could ensure that your removal policy is always
set to RETAIN or DESTROY.

*Example*

```typescript
import { App, Aspects, RemovalPolicy } from 'aws-cdk-lib';
import { ApplyRemovalPolicy } from '@cdklabs/cdk-proserve-lib/aspects';

const app = new App();

Aspects.of(app).add(
  new ApplyRemovalPolicy({ removalPolicy: RemovalPolicy.DESTROY })
);
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.ApplyRemovalPolicy(props: ApplyRemovalPolicyProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicyProps</code> | Configuration properties for removal policy. |

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicyProps

Configuration properties for removal policy.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy.visit">visit</a></code> | Visits a construct and applies the removal policy. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy.visit"></a>

```typescript
public visit(node: IConstruct): void
```

Visits a construct and applies the removal policy.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.ApplyRemovalPolicy.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

The construct being visited.

---




### AwsManagedPolicy <a name="AwsManagedPolicy" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy"></a>

AWS Managed Policy.




#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ADMINISTRATOR_ACCESS">ADMINISTRATOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ADMINISTRATOR_ACCESS_AMPLIFY">ADMINISTRATOR_ACCESS_AMPLIFY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK">ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_ASSISTANT_POLICY">AI_OPS_ASSISTANT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_CONSOLE_ADMIN_POLICY">AI_OPS_CONSOLE_ADMIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_OPERATOR_ACCESS">AI_OPS_OPERATOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_READ_ONLY_ACCESS">AI_OPS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_DEVICE_SETUP">ALEXA_FOR_BUSINESS_DEVICE_SETUP</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_FULL_ACCESS">ALEXA_FOR_BUSINESS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION">ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY">ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY">ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS">ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_API_GATEWAY_ADMINISTRATOR">AMAZON_API_GATEWAY_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS">AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_FLOW_FULL_ACCESS">AMAZON_APP_FLOW_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_FLOW_READ_ONLY_ACCESS">AMAZON_APP_FLOW_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_STREAM_FULL_ACCESS">AMAZON_APP_STREAM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_STREAM_READ_ONLY_ACCESS">AMAZON_APP_STREAM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ATHENA_FULL_ACCESS">AMAZON_ATHENA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AUGMENTED_AI_FULL_ACCESS">AMAZON_AUGMENTED_AI_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS">AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS">AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AURORA_DSQL_CONSOLE_FULL_ACCESS">AMAZON_AURORA_DSQL_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AURORA_DSQL_FULL_ACCESS">AMAZON_AURORA_DSQL_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AURORA_DSQL_READ_ONLY_ACCESS">AMAZON_AURORA_DSQL_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BEDROCK_FULL_ACCESS">AMAZON_BEDROCK_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BEDROCK_READ_ONLY">AMAZON_BEDROCK_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BEDROCK_STUDIO_PERMISSIONS_BOUNDARY">AMAZON_BEDROCK_STUDIO_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BRAKET_FULL_ACCESS">AMAZON_BRAKET_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BRAKET_JOBS_EXECUTION_POLICY">AMAZON_BRAKET_JOBS_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_FULL_ACCESS">AMAZON_CHIME_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_READ_ONLY">AMAZON_CHIME_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_SDK">AMAZON_CHIME_SDK</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_USER_MANAGEMENT">AMAZON_CHIME_USER_MANAGEMENT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_DIRECTORY_FULL_ACCESS">AMAZON_CLOUD_DIRECTORY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS">AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS">AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS">AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS">AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS">AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_CATALYST_FULL_ACCESS">AMAZON_CODE_CATALYST_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_CATALYST_READ_ONLY_ACCESS">AMAZON_CODE_CATALYST_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS">AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_PROFILER_FULL_ACCESS">AMAZON_CODE_GURU_PROFILER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS">AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS">AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS">AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_SECURITY_FULL_ACCESS">AMAZON_CODE_GURU_SECURITY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_SECURITY_SCAN_ACCESS">AMAZON_CODE_GURU_SECURITY_SCAN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES">AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_POWER_USER">AMAZON_COGNITO_POWER_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_READ_ONLY">AMAZON_COGNITO_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_UN_AUTHED_IDENTITIES_SESSION_POLICY">AMAZON_COGNITO_UN_AUTHED_IDENTITIES_SESSION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES">AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CONNECT_FULL_ACCESS">AMAZON_CONNECT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CONNECT_READ_ONLY_ACCESS">AMAZON_CONNECT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CONNECT_VOICE_ID_FULL_ACCESS">AMAZON_CONNECT_VOICE_ID_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY">AMAZON_DATA_ZONE_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_FULL_ACCESS">AMAZON_DATA_ZONE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_FULL_USER_ACCESS">AMAZON_DATA_ZONE_FULL_USER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_REDSHIFT_GLUE_PROVISIONING_POLICY">AMAZON_DATA_ZONE_REDSHIFT_GLUE_PROVISIONING_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_SAGE_MAKER_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY">AMAZON_DATA_ZONE_SAGE_MAKER_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_SAGE_MAKER_MANAGE_ACCESS_ROLE_POLICY">AMAZON_DATA_ZONE_SAGE_MAKER_MANAGE_ACCESS_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_SAGE_MAKER_PROVISIONING_ROLE_POLICY">AMAZON_DATA_ZONE_SAGE_MAKER_PROVISIONING_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_FULL_ACCESS">AMAZON_DETECTIVE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_INVESTIGATOR_ACCESS">AMAZON_DETECTIVE_INVESTIGATOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_MEMBER_ACCESS">AMAZON_DETECTIVE_MEMBER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_ORGANIZATIONS_ACCESS">AMAZON_DETECTIVE_ORGANIZATIONS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS">AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_FULL_ACCESS">AMAZON_DEV_OPS_GURU_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS">AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS">AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_CONSOLE_FULL_ACCESS">AMAZON_DOC_DB_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_ELASTIC_FULL_ACCESS">AMAZON_DOC_DB_ELASTIC_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_ELASTIC_READ_ONLY_ACCESS">AMAZON_DOC_DB_ELASTIC_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_FULL_ACCESS">AMAZON_DOC_DB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_READ_ONLY_ACCESS">AMAZON_DOC_DB_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DRSVPC_MANAGEMENT">AMAZON_DRSVPC_MANAGEMENT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DYNAMO_DB_FULL_ACCESS">AMAZON_DYNAMO_DB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE">AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DYNAMO_DB_READ_ONLY_ACCESS">AMAZON_DYNAMO_DB_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS">AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER">AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_PULL_ONLY">AMAZON_EC2_CONTAINER_REGISTRY_PULL_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY">AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_FULL_ACCESS">AMAZON_EC2_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_READ_ONLY_ACCESS">AMAZON_EC2_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD">AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ECS_FULL_ACCESS">AMAZON_ECS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ECS_INFRASTRUCTURE_ROLE_POLICY_FOR_VPC_LATTICE">AMAZON_ECS_INFRASTRUCTURE_ROLE_POLICY_FOR_VPC_LATTICE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_BLOCK_STORAGE_POLICY">AMAZON_EKS_BLOCK_STORAGE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_CLUSTER_POLICY">AMAZON_EKS_CLUSTER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_CNI_POLICY">AMAZON_EKS_CNI_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_COMPUTE_POLICY">AMAZON_EKS_COMPUTE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY">AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_LOAD_BALANCING_POLICY">AMAZON_EKS_LOAD_BALANCING_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY">AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_NETWORKING_POLICY">AMAZON_EKS_NETWORKING_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_SERVICE_POLICY">AMAZON_EKS_SERVICE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_WORKER_NODE_MINIMAL_POLICY">AMAZON_EKS_WORKER_NODE_MINIMAL_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_WORKER_NODE_POLICY">AMAZON_EKS_WORKER_NODE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKSVPC_RESOURCE_CONTROLLER">AMAZON_EKSVPC_RESOURCE_CONTROLLER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTI_CACHE_FULL_ACCESS">AMAZON_ELASTI_CACHE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS">AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS">AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER">AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY">AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS">AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS">AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS">AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS">AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS">AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEMS_UTILS">AMAZON_ELASTIC_FILE_SYSTEMS_UTILS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS">AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY">AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS">AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS">AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER">AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS">AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EMR_FULL_ACCESS_POLICY_V2">AMAZON_EMR_FULL_ACCESS_POLICY_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2">AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ES_COGNITO_ACCESS">AMAZON_ES_COGNITO_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ES_FULL_ACCESS">AMAZON_ES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ES_READ_ONLY_ACCESS">AMAZON_ES_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_FULL_ACCESS">AMAZON_EVENT_BRIDGE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS">AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS">AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS">AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS">AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS">AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS">AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS">AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS">AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_CONSOLE_FULL_ACCESS">AMAZON_F_SX_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS">AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_FULL_ACCESS">AMAZON_F_SX_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_READ_ONLY_ACCESS">AMAZON_F_SX_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_FORECAST_FULL_ACCESS">AMAZON_FORECAST_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY">AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_FREE_RTOS_FULL_ACCESS">AMAZON_FREE_RTOS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GLACIER_FULL_ACCESS">AMAZON_GLACIER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GLACIER_READ_ONLY_ACCESS">AMAZON_GLACIER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GUARD_DUTY_FULL_ACCESS">AMAZON_GUARD_DUTY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GUARD_DUTY_READ_ONLY_ACCESS">AMAZON_GUARD_DUTY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HEALTH_LAKE_FULL_ACCESS">AMAZON_HEALTH_LAKE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS">AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_FULL_ACCESS">AMAZON_HONEYCODE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_READ_ONLY_ACCESS">AMAZON_HONEYCODE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS">AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS">AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS">AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS">AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR_FULL_ACCESS">AMAZON_INSPECTOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR_READ_ONLY_ACCESS">AMAZON_INSPECTOR_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR2_FULL_ACCESS">AMAZON_INSPECTOR2_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR2_MANAGED_CIS_POLICY">AMAZON_INSPECTOR2_MANAGED_CIS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR2_READ_ONLY_ACCESS">AMAZON_INSPECTOR2_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KENDRA_FULL_ACCESS">AMAZON_KENDRA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KENDRA_READ_ONLY_ACCESS">AMAZON_KENDRA_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KEYSPACES_FULL_ACCESS">AMAZON_KEYSPACES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KEYSPACES_READ_ONLY_ACCESS">AMAZON_KEYSPACES_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KEYSPACES_READ_ONLY_ACCESS_V2">AMAZON_KEYSPACES_READ_ONLY_ACCESS_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_ANALYTICS_FULL_ACCESS">AMAZON_KINESIS_ANALYTICS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_ANALYTICS_READ_ONLY">AMAZON_KINESIS_ANALYTICS_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_FIREHOSE_FULL_ACCESS">AMAZON_KINESIS_FIREHOSE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS">AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_FULL_ACCESS">AMAZON_KINESIS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_READ_ONLY_ACCESS">AMAZON_KINESIS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS">AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS">AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LAUNCH_WIZARD_FULL_ACCESS_V2">AMAZON_LAUNCH_WIZARD_FULL_ACCESS_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LEX_FULL_ACCESS">AMAZON_LEX_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LEX_READ_ONLY">AMAZON_LEX_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LEX_RUN_BOTS_ONLY">AMAZON_LEX_RUN_BOTS_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS">AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS">AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_METRICS_FULL_ACCESS">AMAZON_LOOKOUT_METRICS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS">AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS">AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS">AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_FULL_ACCESS">AMAZON_LOOKOUT_VISION_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS">AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS">AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS">AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_FULL_ACCESS">AMAZON_MACHINE_LEARNING_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS">AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS">AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS">AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACIE_FULL_ACCESS">AMAZON_MACIE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACIE_READ_ONLY_ACCESS">AMAZON_MACIE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS">AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS">AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS">AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MCS_FULL_ACCESS">AMAZON_MCS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MCS_READ_ONLY_ACCESS">AMAZON_MCS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MECHANICAL_TURK_FULL_ACCESS">AMAZON_MECHANICAL_TURK_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MECHANICAL_TURK_READ_ONLY">AMAZON_MECHANICAL_TURK_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MEMORY_DB_FULL_ACCESS">AMAZON_MEMORY_DB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MEMORY_DB_READ_ONLY_ACCESS">AMAZON_MEMORY_DB_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS">AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_FULL_ACCESS">AMAZON_MOBILE_ANALYTICS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_NON_FINANCIAL_REPORT_ACCESS">AMAZON_MOBILE_ANALYTICS_NON_FINANCIAL_REPORT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS">AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MONITRON_FULL_ACCESS">AMAZON_MONITRON_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_API_FULL_ACCESS">AMAZON_MQ_API_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_API_READ_ONLY_ACCESS">AMAZON_MQ_API_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_FULL_ACCESS">AMAZON_MQ_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_READ_ONLY_ACCESS">AMAZON_MQ_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MSK_CONNECT_READ_ONLY_ACCESS">AMAZON_MSK_CONNECT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MSK_FULL_ACCESS">AMAZON_MSK_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MSK_READ_ONLY_ACCESS">AMAZON_MSK_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER">AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN">AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_NIMBLE_STUDIO_STUDIO_USER">AMAZON_NIMBLE_STUDIO_STUDIO_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OMICS_FULL_ACCESS">AMAZON_OMICS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OMICS_READ_ONLY_ACCESS">AMAZON_OMICS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ONE_ENTERPRISE_FULL_ACCESS">AMAZON_ONE_ENTERPRISE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ONE_ENTERPRISE_INSTALLER_ACCESS">AMAZON_ONE_ENTERPRISE_INSTALLER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ONE_ENTERPRISE_READ_ONLY_ACCESS">AMAZON_ONE_ENTERPRISE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_DIRECT_QUERY_GLUE_CREATE_ACCESS">AMAZON_OPEN_SEARCH_DIRECT_QUERY_GLUE_CREATE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_INGESTION_FULL_ACCESS">AMAZON_OPEN_SEARCH_INGESTION_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_INGESTION_READ_ONLY_ACCESS">AMAZON_OPEN_SEARCH_INGESTION_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS">AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS">AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS">AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_POLLY_FULL_ACCESS">AMAZON_POLLY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_POLLY_READ_ONLY_ACCESS">AMAZON_POLLY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS">AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_FULL_ACCESS">AMAZON_PROMETHEUS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_QUERY_ACCESS">AMAZON_PROMETHEUS_QUERY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS">AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_Q_DEVELOPER_ACCESS">AMAZON_Q_DEVELOPER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_Q_FULL_ACCESS">AMAZON_Q_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_QLDB_CONSOLE_FULL_ACCESS">AMAZON_QLDB_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_QLDB_FULL_ACCESS">AMAZON_QLDB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_QLDB_READ_ONLY">AMAZON_QLDB_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_CUSTOM_INSTANCE_PROFILE_ROLE_POLICY">AMAZON_RDS_CUSTOM_INSTANCE_PROFILE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_DATA_FULL_ACCESS">AMAZON_RDS_DATA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_FULL_ACCESS">AMAZON_RDS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_PERFORMANCE_INSIGHTS_FULL_ACCESS">AMAZON_RDS_PERFORMANCE_INSIGHTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY">AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_READ_ONLY_ACCESS">AMAZON_RDS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS">AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_DATA_FULL_ACCESS">AMAZON_REDSHIFT_DATA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_FULL_ACCESS">AMAZON_REDSHIFT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR">AMAZON_REDSHIFT_QUERY_EDITOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS">AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING">AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING">AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING">AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_READ_ONLY_ACCESS">AMAZON_REDSHIFT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS">AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REKOGNITION_FULL_ACCESS">AMAZON_REKOGNITION_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REKOGNITION_READ_ONLY_ACCESS">AMAZON_REKOGNITION_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS">AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS">AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS">AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_DOMAINS_FULL_ACCESS">AMAZON_ROUTE53_DOMAINS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS">AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_FULL_ACCESS">AMAZON_ROUTE53_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_PROFILES_FULL_ACCESS">AMAZON_ROUTE53_PROFILES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_PROFILES_READ_ONLY_ACCESS">AMAZON_ROUTE53_PROFILES_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_READ_ONLY_ACCESS">AMAZON_ROUTE53_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS">AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS">AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS">AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS">AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS">AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS">AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RESOLVER_FULL_ACCESS">AMAZON_ROUTE53_RESOLVER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS">AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_FULL_ACCESS">AMAZON_S3_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_OUTPOSTS_FULL_ACCESS">AMAZON_S3_OUTPOSTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS">AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_READ_ONLY_ACCESS">AMAZON_S3_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_TABLES_FULL_ACCESS">AMAZON_S3_TABLES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_TABLES_READ_ONLY_ACCESS">AMAZON_S3_TABLES_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY">AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_AI_SERVICES_ACCESS">AMAZON_SAGE_MAKER_CANVAS_AI_SERVICES_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_BEDROCK_ACCESS">AMAZON_SAGE_MAKER_CANVAS_BEDROCK_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_DATA_PREP_FULL_ACCESS">AMAZON_SAGE_MAKER_CANVAS_DATA_PREP_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_EMR_SERVERLESS_EXECUTION_ROLE_POLICY">AMAZON_SAGE_MAKER_CANVAS_EMR_SERVERLESS_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS">AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_SM_DATA_SCIENCE_ASSISTANT_ACCESS">AMAZON_SAGE_MAKER_CANVAS_SM_DATA_SCIENCE_ASSISTANT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CLUSTER_INSTANCE_ROLE_POLICY">AMAZON_SAGE_MAKER_CLUSTER_INSTANCE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS">AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_FULL_ACCESS">AMAZON_SAGE_MAKER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION">AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS">AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS">AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_MODEL_REGISTRY_FULL_ACCESS">AMAZON_SAGE_MAKER_MODEL_REGISTRY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_PARTNER_APPS_FULL_ACCESS">AMAZON_SAGE_MAKER_PARTNER_APPS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS">AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_READ_ONLY">AMAZON_SAGE_MAKER_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY">AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_TRAINING_PLAN_CREATE_ACCESS">AMAZON_SAGE_MAKER_TRAINING_PLAN_CREATE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SECURITY_LAKE_ADMINISTRATOR">AMAZON_SECURITY_LAKE_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY">AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SES_FULL_ACCESS">AMAZON_SES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SES_READ_ONLY_ACCESS">AMAZON_SES_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SNS_FULL_ACCESS">AMAZON_SNS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SNS_READ_ONLY_ACCESS">AMAZON_SNS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SQS_FULL_ACCESS">AMAZON_SQS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SQS_READ_ONLY_ACCESS">AMAZON_SQS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_AUTOMATION_APPROVER_ACCESS">AMAZON_SSM_AUTOMATION_APPROVER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_DIRECTORY_SERVICE_ACCESS">AMAZON_SSM_DIRECTORY_SERVICE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_FULL_ACCESS">AMAZON_SSM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY">AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_MANAGED_INSTANCE_CORE">AMAZON_SSM_MANAGED_INSTANCE_CORE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_PATCH_ASSOCIATION">AMAZON_SSM_PATCH_ASSOCIATION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_READ_ONLY_ACCESS">AMAZON_SSM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TEXTRACT_FULL_ACCESS">AMAZON_TEXTRACT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS">AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_FULL_ACCESS">AMAZON_TIMESTREAM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_INFLUX_DB_FULL_ACCESS">AMAZON_TIMESTREAM_INFLUX_DB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_READ_ONLY_ACCESS">AMAZON_TIMESTREAM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TRANSCRIBE_FULL_ACCESS">AMAZON_TRANSCRIBE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TRANSCRIBE_READ_ONLY_ACCESS">AMAZON_TRANSCRIBE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VERIFIED_PERMISSIONS_FULL_ACCESS">AMAZON_VERIFIED_PERMISSIONS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VERIFIED_PERMISSIONS_READ_ONLY_ACCESS">AMAZON_VERIFIED_PERMISSIONS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS">AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_FULL_ACCESS">AMAZON_VPC_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_NETWORK_ACCESS_ANALYZER_FULL_ACCESS_POLICY">AMAZON_VPC_NETWORK_ACCESS_ANALYZER_FULL_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_REACHABILITY_ANALYZER_FULL_ACCESS_POLICY">AMAZON_VPC_REACHABILITY_ANALYZER_FULL_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_REACHABILITY_ANALYZER_PATH_COMPONENT_READ_POLICY">AMAZON_VPC_REACHABILITY_ANALYZER_PATH_COMPONENT_READ_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_READ_ONLY_ACCESS">AMAZON_VPC_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_DOCS_FULL_ACCESS">AMAZON_WORK_DOCS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_DOCS_READ_ONLY_ACCESS">AMAZON_WORK_DOCS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_FULL_ACCESS">AMAZON_WORK_MAIL_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS">AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS">AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_READ_ONLY_ACCESS">AMAZON_WORK_MAIL_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_ADMIN">AMAZON_WORK_SPACES_ADMIN</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS">AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_POOL_SERVICE_ACCESS">AMAZON_WORK_SPACES_POOL_SERVICE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_SECURE_BROWSER_READ_ONLY">AMAZON_WORK_SPACES_SECURE_BROWSER_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS">AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_SERVICE_ACCESS">AMAZON_WORK_SPACES_SERVICE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_THIN_CLIENT_FULL_ACCESS">AMAZON_WORK_SPACES_THIN_CLIENT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_THIN_CLIENT_READ_ONLY_ACCESS">AMAZON_WORK_SPACES_THIN_CLIENT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_WEB_READ_ONLY">AMAZON_WORK_SPACES_WEB_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORKSPACES_PCA_ACCESS">AMAZON_WORKSPACES_PCA_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ZOCALO_FULL_ACCESS">AMAZON_ZOCALO_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ZOCALO_READ_ONLY_ACCESS">AMAZON_ZOCALO_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_CONSOLE_FULL_ACCESS">AUTO_SCALING_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS">AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_FULL_ACCESS">AUTO_SCALING_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_READ_ONLY_ACCESS">AUTO_SCALING_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_ACTIVITY_ACCESS">AWS_ACCOUNT_ACTIVITY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS">AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS">AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_USAGE_REPORT_ACCESS">AWS_ACCOUNT_USAGE_REPORT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_AGENTLESS_DISCOVERY_SERVICE">AWS_AGENTLESS_DISCOVERY_SERVICE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_FABRIC_FULL_ACCESS">AWS_APP_FABRIC_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_FABRIC_READ_ONLY_ACCESS">AWS_APP_FABRIC_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_ENVOY_ACCESS">AWS_APP_MESH_ENVOY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_FULL_ACCESS">AWS_APP_MESH_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_PREVIEW_ENVOY_ACCESS">AWS_APP_MESH_PREVIEW_ENVOY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_READ_ONLY">AWS_APP_MESH_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_RUNNER_FULL_ACCESS">AWS_APP_RUNNER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_RUNNER_READ_ONLY_ACCESS">AWS_APP_RUNNER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_SYNC_ADMINISTRATOR">AWS_APP_SYNC_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_SYNC_INVOKE_FULL_ACCESS">AWS_APP_SYNC_INVOKE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_SYNC_SCHEMA_AUTHOR">AWS_APP_SYNC_SCHEMA_AUTHOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_DISCOVERY_AGENT_ACCESS">AWS_APPLICATION_DISCOVERY_AGENT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS">AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS">AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY">AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_AGENT_POLICY">AWS_APPLICATION_MIGRATION_AGENT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_EC2_ACCESS">AWS_APPLICATION_MIGRATION_EC2_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_FULL_ACCESS">AWS_APPLICATION_MIGRATION_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS">AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_SERVICE_EC2_INSTANCE_POLICY">AWS_APPLICATION_MIGRATION_SERVICE_EC2_INSTANCE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_SSM_ACCESS">AWS_APPLICATION_MIGRATION_SSM_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY">AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ARTIFACT_AGREEMENTS_FULL_ACCESS">AWS_ARTIFACT_AGREEMENTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ARTIFACT_AGREEMENTS_READ_ONLY_ACCESS">AWS_ARTIFACT_AGREEMENTS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ARTIFACT_REPORTS_READ_ONLY_ACCESS">AWS_ARTIFACT_REPORTS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS">AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_AUDIT_ACCESS">AWS_BACKUP_AUDIT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_DATA_TRANSFER_ACCESS">AWS_BACKUP_DATA_TRANSFER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_FULL_ACCESS">AWS_BACKUP_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_OPERATOR_ACCESS">AWS_BACKUP_OPERATOR_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS">AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA">AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_INDEXING">AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_INDEXING</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_ITEM_RESTORES">AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_ITEM_RESTORES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP">AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE">AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BATCH_FULL_ACCESS">AWS_BATCH_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BILLING_CONDUCTOR_FULL_ACCESS">AWS_BILLING_CONDUCTOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS">AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BILLING_READ_ONLY_ACCESS">AWS_BILLING_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM">AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS">AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUDGETS_READ_ONLY_ACCESS">AWS_BUDGETS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUG_BUST_FULL_ACCESS">AWS_BUG_BUST_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUG_BUST_PLAYER_ACCESS">AWS_BUG_BUST_PLAYER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_FULL_ACCESS">AWS_CERTIFICATE_MANAGER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR">AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS">AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER">AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY">AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_USER">AWS_CERTIFICATE_MANAGER_PRIVATE_CA_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_READ_ONLY">AWS_CERTIFICATE_MANAGER_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_FULL_ACCESS">AWS_CLEAN_ROOMS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING">AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_ML_FULL_ACCESS">AWS_CLEAN_ROOMS_ML_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_ML_READ_ONLY_ACCESS">AWS_CLEAN_ROOMS_ML_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_READ_ONLY_ACCESS">AWS_CLEAN_ROOMS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_FORMATION_FULL_ACCESS">AWS_CLOUD_FORMATION_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_FORMATION_READ_ONLY_ACCESS">AWS_CLOUD_FORMATION_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_HSM_FULL_ACCESS">AWS_CLOUD_HSM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_HSM_READ_ONLY_ACCESS">AWS_CLOUD_HSM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS">AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_FULL_ACCESS">AWS_CLOUD_MAP_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_READ_ONLY_ACCESS">AWS_CLOUD_MAP_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS">AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_SHELL_FULL_ACCESS">AWS_CLOUD_SHELL_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_TRAIL_FULL_ACCESS">AWS_CLOUD_TRAIL_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_TRAIL_READ_ONLY_ACCESS">AWS_CLOUD_TRAIL_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_ADMINISTRATOR">AWS_CLOUD9_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_ENVIRONMENT_MEMBER">AWS_CLOUD9_ENVIRONMENT_MEMBER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_SSM_INSTANCE_PROFILE">AWS_CLOUD9_SSM_INSTANCE_PROFILE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_USER">AWS_CLOUD9_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_ARTIFACT_ADMIN_ACCESS">AWS_CODE_ARTIFACT_ADMIN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_ARTIFACT_READ_ONLY_ACCESS">AWS_CODE_ARTIFACT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_BUILD_ADMIN_ACCESS">AWS_CODE_BUILD_ADMIN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_BUILD_DEVELOPER_ACCESS">AWS_CODE_BUILD_DEVELOPER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_BUILD_READ_ONLY_ACCESS">AWS_CODE_BUILD_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_COMMIT_FULL_ACCESS">AWS_CODE_COMMIT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_COMMIT_POWER_USER">AWS_CODE_COMMIT_POWER_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_COMMIT_READ_ONLY">AWS_CODE_COMMIT_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_DEPLOYER_ACCESS">AWS_CODE_DEPLOY_DEPLOYER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_FULL_ACCESS">AWS_CODE_DEPLOY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_READ_ONLY_ACCESS">AWS_CODE_DEPLOY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_ROLE_FOR_ECS">AWS_CODE_DEPLOY_ROLE_FOR_ECS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED">AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_APPROVER_ACCESS">AWS_CODE_PIPELINE_APPROVER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS">AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_FULL_ACCESS">AWS_CODE_PIPELINE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_READ_ONLY_ACCESS">AWS_CODE_PIPELINE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_STAR_FULL_ACCESS">AWS_CODE_STAR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_COMPROMISED_KEY_QUARANTINE">AWS_COMPROMISED_KEY_QUARANTINE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_COMPROMISED_KEY_QUARANTINE_V2">AWS_COMPROMISED_KEY_QUARANTINE_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_COMPROMISED_KEY_QUARANTINE_V3">AWS_COMPROMISED_KEY_QUARANTINE_V3</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CONFIG_USER_ACCESS">AWS_CONFIG_USER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CONNECTOR">AWS_CONNECTOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_DATA_GRANT_OWNER_FULL_ACCESS">AWS_DATA_EXCHANGE_DATA_GRANT_OWNER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_DATA_GRANT_RECEIVER_FULL_ACCESS">AWS_DATA_EXCHANGE_DATA_GRANT_RECEIVER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_FULL_ACCESS">AWS_DATA_EXCHANGE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS">AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_READ_ONLY">AWS_DATA_EXCHANGE_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS">AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_PIPELINE_FULL_ACCESS">AWS_DATA_PIPELINE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_PIPELINE_POWER_USER">AWS_DATA_PIPELINE_POWER_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_SYNC_FULL_ACCESS">AWS_DATA_SYNC_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_SYNC_READ_ONLY_ACCESS">AWS_DATA_SYNC_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_FLEET_WORKER">AWS_DEADLINE_CLOUD_FLEET_WORKER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_FARMS">AWS_DEADLINE_CLOUD_USER_ACCESS_FARMS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_FLEETS">AWS_DEADLINE_CLOUD_USER_ACCESS_FLEETS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_JOBS">AWS_DEADLINE_CLOUD_USER_ACCESS_JOBS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_QUEUES">AWS_DEADLINE_CLOUD_USER_ACCESS_QUEUES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_WORKER_HOST">AWS_DEADLINE_CLOUD_WORKER_HOST</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY">AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS">AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY">AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS">AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_FULL_ACCESS">AWS_DEEP_RACER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY">AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DENY_ALL">AWS_DENY_ALL</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEVICE_FARM_FULL_ACCESS">AWS_DEVICE_FARM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECT_CONNECT_FULL_ACCESS">AWS_DIRECT_CONNECT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECT_CONNECT_READ_ONLY_ACCESS">AWS_DIRECT_CONNECT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_DATA_FULL_ACCESS">AWS_DIRECTORY_SERVICE_DATA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_DATA_READ_ONLY_ACCESS">AWS_DIRECTORY_SERVICE_DATA_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_FULL_ACCESS">AWS_DIRECTORY_SERVICE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS">AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY">AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_EC2_VSS_SNAPSHOT_POLICY">AWS_EC2_VSS_SNAPSHOT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE">AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY">AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER">AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_READ_ONLY">AWS_ELASTIC_BEANSTALK_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_WEB_TIER">AWS_ELASTIC_BEANSTALK_WEB_TIER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_WORKER_TIER">AWS_ELASTIC_BEANSTALK_WORKER_TIER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY">AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS">AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS_V2">AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY">AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_LAUNCH_ACTIONS_POLICY">AWS_ELASTIC_DISASTER_RECOVERY_LAUNCH_ACTIONS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS">AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS">AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY">AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS">AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY">AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS">AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY">AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_V2_FULL_ACCESS">AWS_ELEMENTAL_MEDIA_PACKAGE_V2_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_V2_READ_ONLY">AWS_ELEMENTAL_MEDIA_PACKAGE_V2_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS">AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY">AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS">AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY">AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ENTITY_RESOLUTION_CONSOLE_FULL_ACCESS">AWS_ENTITY_RESOLUTION_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ENTITY_RESOLUTION_CONSOLE_READ_ONLY_ACCESS">AWS_ENTITY_RESOLUTION_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FM_ADMIN_FULL_ACCESS">AWS_FM_ADMIN_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FM_ADMIN_READ_ONLY_ACCESS">AWS_FM_ADMIN_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FM_MEMBER_READ_ONLY_ACCESS">AWS_FM_MEMBER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FOR_WORD_PRESS_PLUGIN_POLICY">AWS_FOR_WORD_PRESS_PLUGIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_CONSOLE_FULL_ACCESS">AWS_GLUE_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS">AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY">AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS">AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS">AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY">AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SESSION_USER_RESTRICTED_POLICY">AWS_GLUE_SESSION_USER_RESTRICTED_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_ACCOUNT_ADMINISTRATOR">AWS_GRAFANA_ACCOUNT_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS">AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT">AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT_V2">AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GREENGRASS_FULL_ACCESS">AWS_GREENGRASS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GREENGRASS_READ_ONLY_ACCESS">AWS_GREENGRASS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GROUND_STATION_AGENT_INSTANCE_POLICY">AWS_GROUND_STATION_AGENT_INSTANCE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_HEALTH_FULL_ACCESS">AWS_HEALTH_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_HEALTH_IMAGING_FULL_ACCESS">AWS_HEALTH_IMAGING_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_HEALTH_IMAGING_READ_ONLY_ACCESS">AWS_HEALTH_IMAGING_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IAM_IDENTITY_CENTER_ALLOW_LIST_FOR_IDENTITY_CONTEXT">AWS_IAM_IDENTITY_CENTER_ALLOW_LIST_FOR_IDENTITY_CONTEXT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IDENTITY_SYNC_FULL_ACCESS">AWS_IDENTITY_SYNC_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IDENTITY_SYNC_READ_ONLY_ACCESS">AWS_IDENTITY_SYNC_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMAGE_BUILDER_FULL_ACCESS">AWS_IMAGE_BUILDER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMAGE_BUILDER_READ_ONLY_ACCESS">AWS_IMAGE_BUILDER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMPORT_EXPORT_FULL_ACCESS">AWS_IMPORT_EXPORT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMPORT_EXPORT_READ_ONLY_ACCESS">AWS_IMPORT_EXPORT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_INCIDENT_MANAGER_INCIDENT_ACCESS_SERVICE_ROLE_POLICY">AWS_INCIDENT_MANAGER_INCIDENT_ACCESS_SERVICE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_INCIDENT_MANAGER_RESOLVER_ACCESS">AWS_INCIDENT_MANAGER_RESOLVER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_ANALYTICS_FULL_ACCESS">AWS_IO_T_ANALYTICS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS">AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_CONFIG_ACCESS">AWS_IO_T_CONFIG_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_CONFIG_READ_ONLY_ACCESS">AWS_IO_T_CONFIG_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_DATA_ACCESS">AWS_IO_T_DATA_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS">AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS">AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_EVENTS_FULL_ACCESS">AWS_IO_T_EVENTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_EVENTS_READ_ONLY_ACCESS">AWS_IO_T_EVENTS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_FULL_ACCESS">AWS_IO_T_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS">AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_SITE_WISE_FULL_ACCESS">AWS_IO_T_SITE_WISE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS">AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_DATA_ACCESS">AWS_IO_T_WIRELESS_DATA_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_FULL_ACCESS">AWS_IO_T_WIRELESS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS">AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER">AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_LOGGING">AWS_IO_T_WIRELESS_LOGGING</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_READ_ONLY_ACCESS">AWS_IO_T_WIRELESS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T1_CLICK_FULL_ACCESS">AWS_IO_T1_CLICK_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T1_CLICK_READ_ONLY_ACCESS">AWS_IO_T1_CLICK_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IQ_FULL_ACCESS">AWS_IQ_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_KEY_MANAGEMENT_SERVICE_POWER_USER">AWS_KEY_MANAGEMENT_SERVICE_POWER_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER">AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAKE_FORMATION_DATA_ADMIN">AWS_LAKE_FORMATION_DATA_ADMIN</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_EXECUTE">AWS_LAMBDA_EXECUTE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_FULL_ACCESS">AWS_LAMBDA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_INVOCATION_DYNAMO_DB">AWS_LAMBDA_INVOCATION_DYNAMO_DB</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_READ_ONLY_ACCESS">AWS_LAMBDA_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_AMI_INGESTION">AWS_MARKETPLACE_AMI_INGESTION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_FULL_ACCESS">AWS_MARKETPLACE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_GET_ENTITLEMENTS">AWS_MARKETPLACE_GET_ENTITLEMENTS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS">AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS">AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_METERING_FULL_ACCESS">AWS_MARKETPLACE_METERING_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_METERING_REGISTER_USAGE">AWS_MARKETPLACE_METERING_REGISTER_USAGE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS">AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_READ_ONLY">AWS_MARKETPLACE_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_FULL_ACCESS">AWS_MARKETPLACE_SELLER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_OFFER_MANAGEMENT">AWS_MARKETPLACE_SELLER_OFFER_MANAGEMENT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS">AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY">AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_FULL_ACCESS">AWS_MIGRATION_HUB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS">AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY">AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN">AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_REFACTOR_SPACES_ENVIRONMENTS_WITHOUT_BRIDGES_FULL_ACCESS">AWS_MIGRATION_HUB_REFACTOR_SPACES_ENVIRONMENTS_WITHOUT_BRIDGES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS">AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_STRATEGY_COLLECTOR">AWS_MIGRATION_HUB_STRATEGY_COLLECTOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS">AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_NETWORK_MANAGER_FULL_ACCESS">AWS_NETWORK_MANAGER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_NETWORK_MANAGER_READ_ONLY_ACCESS">AWS_NETWORK_MANAGER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_CLOUD_WATCH_LOGS">AWS_OPS_WORKS_CLOUD_WATCH_LOGS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE">AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_FULL_ACCESS">AWS_OPS_WORKS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_INSTANCE_REGISTRATION">AWS_OPS_WORKS_INSTANCE_REGISTRATION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_REGISTER_CLI_EC2">AWS_OPS_WORKS_REGISTER_CLI_EC2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_REGISTER_CLI_ON_PREMISES">AWS_OPS_WORKS_REGISTER_CLI_ON_PREMISES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ORGANIZATIONS_FULL_ACCESS">AWS_ORGANIZATIONS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ORGANIZATIONS_READ_ONLY_ACCESS">AWS_ORGANIZATIONS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY">AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PANORAMA_FULL_ACCESS">AWS_PANORAMA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_FULL_ACCESS">AWS_PARTNER_CENTRAL_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_OPPORTUNITY_MANAGEMENT">AWS_PARTNER_CENTRAL_OPPORTUNITY_MANAGEMENT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_SANDBOX_FULL_ACCESS">AWS_PARTNER_CENTRAL_SANDBOX_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_SELLING_RESOURCE_SNAPSHOT_JOB_EXECUTION_ROLE_POLICY">AWS_PARTNER_CENTRAL_SELLING_RESOURCE_SNAPSHOT_JOB_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_LED_SUPPORT_READ_ONLY_ACCESS">AWS_PARTNER_LED_SUPPORT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRICE_LIST_SERVICE_FULL_ACCESS">AWS_PRICE_LIST_SERVICE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_AUDITOR">AWS_PRIVATE_CA_AUDITOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_FULL_ACCESS">AWS_PRIVATE_CA_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_PRIVILEGED_USER">AWS_PRIVATE_CA_PRIVILEGED_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_READ_ONLY">AWS_PRIVATE_CA_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_USER">AWS_PRIVATE_CA_USER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS">AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_MARKETPLACE_REQUESTS">AWS_PRIVATE_MARKETPLACE_REQUESTS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS">AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_DEVELOPER_ACCESS">AWS_PROTON_DEVELOPER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_FULL_ACCESS">AWS_PROTON_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_READ_ONLY_ACCESS">AWS_PROTON_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY">AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_CFGC_PACKS_PERMISSIONS_BOUNDARY">AWS_QUICK_SETUP_CFGC_PACKS_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_DEPLOYMENT_ROLE_POLICY">AWS_QUICK_SETUP_DEPLOYMENT_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_DEV_OPS_GURU_PERMISSIONS_BOUNDARY">AWS_QUICK_SETUP_DEV_OPS_GURU_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_DISTRIBUTOR_PERMISSIONS_BOUNDARY">AWS_QUICK_SETUP_DISTRIBUTOR_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_ENABLE_AREX_EXECUTION_POLICY">AWS_QUICK_SETUP_ENABLE_AREX_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_ENABLE_DHMC_EXECUTION_POLICY">AWS_QUICK_SETUP_ENABLE_DHMC_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_MANAGED_INSTANCE_PROFILE_EXECUTION_POLICY">AWS_QUICK_SETUP_MANAGED_INSTANCE_PROFILE_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_PATCH_POLICY_BASELINE_ACCESS">AWS_QUICK_SETUP_PATCH_POLICY_BASELINE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_PATCH_POLICY_DEPLOYMENT_ROLE_POLICY">AWS_QUICK_SETUP_PATCH_POLICY_DEPLOYMENT_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_PATCH_POLICY_PERMISSIONS_BOUNDARY">AWS_QUICK_SETUP_PATCH_POLICY_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SCHEDULER_PERMISSIONS_BOUNDARY">AWS_QUICK_SETUP_SCHEDULER_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_DEPLOYMENT_ROLE_POLICY">AWS_QUICK_SETUP_SSM_DEPLOYMENT_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_DEPLOYMENT_S3_BUCKET_ROLE_POLICY">AWS_QUICK_SETUP_SSM_DEPLOYMENT_S3_BUCKET_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_HOST_MGMT_PERMISSIONS_BOUNDARY">AWS_QUICK_SETUP_SSM_HOST_MGMT_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_LIFECYCLE_MANAGEMENT_EXECUTION_POLICY">AWS_QUICK_SETUP_SSM_LIFECYCLE_MANAGEMENT_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_MANAGE_RESOURCES_EXECUTION_POLICY">AWS_QUICK_SETUP_SSM_MANAGE_RESOURCES_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SIGHT_ASSET_BUNDLE_EXPORT_POLICY">AWS_QUICK_SIGHT_ASSET_BUNDLE_EXPORT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SIGHT_ASSET_BUNDLE_IMPORT_POLICY">AWS_QUICK_SIGHT_ASSET_BUNDLE_IMPORT_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS">AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_REFACTORING_TOOLKIT_FULL_ACCESS">AWS_REFACTORING_TOOLKIT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY">AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_REPOST_SPACE_SUPPORT_OPERATIONS_POLICY">AWS_REPOST_SPACE_SUPPORT_OPERATIONS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESILIENCE_HUB_ASSSESSMENT_EXECUTION_POLICY">AWS_RESILIENCE_HUB_ASSSESSMENT_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS">AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS">AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS">AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_EXPLORER_FULL_ACCESS">AWS_RESOURCE_EXPLORER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_EXPLORER_ORGANIZATIONS_ACCESS">AWS_RESOURCE_EXPLORER_ORGANIZATIONS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS">AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS">AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ROBO_MAKER_FULL_ACCESS">AWS_ROBO_MAKER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ROBO_MAKER_READ_ONLY_ACCESS">AWS_ROBO_MAKER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ROBO_MAKER_SERVICE_ROLE_POLICY">AWS_ROBO_MAKER_SERVICE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SAVINGS_PLANS_FULL_ACCESS">AWS_SAVINGS_PLANS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SAVINGS_PLANS_READ_ONLY_ACCESS">AWS_SAVINGS_PLANS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_HUB_FULL_ACCESS">AWS_SECURITY_HUB_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS">AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_HUB_READ_ONLY_ACCESS">AWS_SECURITY_HUB_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_INCIDENT_RESPONSE_CASE_FULL_ACCESS">AWS_SECURITY_INCIDENT_RESPONSE_CASE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_INCIDENT_RESPONSE_FULL_ACCESS">AWS_SECURITY_INCIDENT_RESPONSE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_INCIDENT_RESPONSE_READ_ONLY_ACCESS">AWS_SECURITY_INCIDENT_RESPONSE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS">AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS">AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS">AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS">AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS">AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS">AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_AUTOMATION_DIAGNOSIS_BUCKET_POLICY">AWS_SSM_AUTOMATION_DIAGNOSIS_BUCKET_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_DIAGNOSIS_AUTOMATION_ADMINISTRATION_ROLE_POLICY">AWS_SSM_DIAGNOSIS_AUTOMATION_ADMINISTRATION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_DIAGNOSIS_AUTOMATION_EXECUTION_ROLE_POLICY">AWS_SSM_DIAGNOSIS_AUTOMATION_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_DIAGNOSIS_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY">AWS_SSM_DIAGNOSIS_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_REMEDIATION_AUTOMATION_ADMINISTRATION_ROLE_POLICY">AWS_SSM_REMEDIATION_AUTOMATION_ADMINISTRATION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_REMEDIATION_AUTOMATION_EXECUTION_ROLE_POLICY">AWS_SSM_REMEDIATION_AUTOMATION_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_REMEDIATION_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY">AWS_SSM_REMEDIATION_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_DIRECTORY_ADMINISTRATOR">AWS_SSO_DIRECTORY_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_DIRECTORY_READ_ONLY">AWS_SSO_DIRECTORY_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_MASTER_ACCOUNT_ADMINISTRATOR">AWS_SSO_MASTER_ACCOUNT_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_MEMBER_ACCOUNT_ADMINISTRATOR">AWS_SSO_MEMBER_ACCOUNT_ADMINISTRATOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_READ_ONLY">AWS_SSO_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS">AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STEP_FUNCTIONS_FULL_ACCESS">AWS_STEP_FUNCTIONS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS">AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STORAGE_GATEWAY_FULL_ACCESS">AWS_STORAGE_GATEWAY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS">AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_ACCESS">AWS_SUPPORT_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_APP_FULL_ACCESS">AWS_SUPPORT_APP_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_APP_READ_ONLY_ACCESS">AWS_SUPPORT_APP_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_PLANS_FULL_ACCESS">AWS_SUPPORT_PLANS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_PLANS_READ_ONLY_ACCESS">AWS_SUPPORT_PLANS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_ENABLE_CONFIG_RECORDING_EXECUTION_POLICY">AWS_SYSTEMS_MANAGER_ENABLE_CONFIG_RECORDING_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_ENABLE_EXPLORER_EXECUTION_POLICY">AWS_SYSTEMS_MANAGER_ENABLE_EXPLORER_EXECUTION_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS">AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS">AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_ASSET_SERVER_POLICY">AWS_THINKBOX_ASSET_SERVER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY">AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY">AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY">AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY">AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY">AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY">AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY">AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRANSFER_CONSOLE_FULL_ACCESS">AWS_TRANSFER_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRANSFER_FULL_ACCESS">AWS_TRANSFER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRANSFER_READ_ONLY_ACCESS">AWS_TRANSFER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS">AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS">AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS">AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY">AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS">AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY">AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_CONSOLE_FULL_ACCESS">AWS_WAF_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_CONSOLE_READ_ONLY_ACCESS">AWS_WAF_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_FULL_ACCESS">AWS_WAF_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_READ_ONLY_ACCESS">AWS_WAF_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WICKR_FULL_ACCESS">AWS_WICKR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_X_RAY_DAEMON_WRITE_ACCESS">AWS_X_RAY_DAEMON_WRITE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION">AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_FULL_ACCESS">AWS_XRAY_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_READ_ONLY_ACCESS">AWS_XRAY_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_WRITE_ONLY_ACCESS">AWS_XRAY_WRITE_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_FRONT_FULL_ACCESS">CLOUD_FRONT_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_FRONT_READ_ONLY_ACCESS">CLOUD_FRONT_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_SEARCH_FULL_ACCESS">CLOUD_SEARCH_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_SEARCH_READ_ONLY_ACCESS">CLOUD_SEARCH_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_ACTIONS_EC2_ACCESS">CLOUD_WATCH_ACTIONS_EC2_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_AGENT_ADMIN_POLICY">CLOUD_WATCH_AGENT_ADMIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_AGENT_SERVER_POLICY">CLOUD_WATCH_AGENT_SERVER_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS">CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS">CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_SIGNALS_FULL_ACCESS">CLOUD_WATCH_APPLICATION_SIGNALS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_SIGNALS_READ_ONLY_ACCESS">CLOUD_WATCH_APPLICATION_SIGNALS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS">CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION">CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_EVENTS_FULL_ACCESS">CLOUD_WATCH_EVENTS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS">CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_FULL_ACCESS">CLOUD_WATCH_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_FULL_ACCESS_V2">CLOUD_WATCH_FULL_ACCESS_V2</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_INTERNET_MONITOR_FULL_ACCESS">CLOUD_WATCH_INTERNET_MONITOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_INTERNET_MONITOR_READ_ONLY_ACCESS">CLOUD_WATCH_INTERNET_MONITOR_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LAMBDA_APPLICATION_SIGNALS_EXECUTION_ROLE_POLICY">CLOUD_WATCH_LAMBDA_APPLICATION_SIGNALS_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY">CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION">CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LOGS_FULL_ACCESS">CLOUD_WATCH_LOGS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LOGS_READ_ONLY_ACCESS">CLOUD_WATCH_LOGS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_NETWORK_FLOW_MONITOR_AGENT_PUBLISH_POLICY">CLOUD_WATCH_NETWORK_FLOW_MONITOR_AGENT_PUBLISH_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_OPEN_SEARCH_DASHBOARD_ACCESS">CLOUD_WATCH_OPEN_SEARCH_DASHBOARD_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_OPEN_SEARCH_DASHBOARDS_FULL_ACCESS">CLOUD_WATCH_OPEN_SEARCH_DASHBOARDS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_READ_ONLY_ACCESS">CLOUD_WATCH_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_SYNTHETICS_FULL_ACCESS">CLOUD_WATCH_SYNTHETICS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS">CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPREHEND_FULL_ACCESS">COMPREHEND_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPREHEND_MEDICAL_FULL_ACCESS">COMPREHEND_MEDICAL_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPREHEND_READ_ONLY">COMPREHEND_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPUTE_OPTIMIZER_READ_ONLY_ACCESS">COMPUTE_OPTIMIZER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COST_OPTIMIZATION_HUB_ADMIN_ACCESS">COST_OPTIMIZATION_HUB_ADMIN_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COST_OPTIMIZATION_HUB_READ_ONLY_ACCESS">COST_OPTIMIZATION_HUB_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_FAST_LAUNCH_FULL_ACCESS">EC2_FAST_LAUNCH_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS">EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_INSTANCE_CONNECT">EC2_INSTANCE_CONNECT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER">EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS">EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELASTIC_LOAD_BALANCING_FULL_ACCESS">ELASTIC_LOAD_BALANCING_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELASTIC_LOAD_BALANCING_READ_ONLY">ELASTIC_LOAD_BALANCING_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS">ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_FULL_ACCESS">ELEMENTAL_ACTIVATIONS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES">ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS">ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS">ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS">ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS">ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GAME_LIFT_CONTAINER_FLEET_POLICY">GAME_LIFT_CONTAINER_FLEET_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GAME_LIFT_GAME_SERVER_GROUP_POLICY">GAME_LIFT_GAME_SERVER_GROUP_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GLOBAL_ACCELERATOR_FULL_ACCESS">GLOBAL_ACCELERATOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GLOBAL_ACCELERATOR_READ_ONLY_ACCESS">GLOBAL_ACCELERATOR_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS">GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS">GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_ACCESS_ADVISOR_READ_ONLY">IAM_ACCESS_ADVISOR_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_ACCESS_ANALYZER_FULL_ACCESS">IAM_ACCESS_ANALYZER_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS">IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_FULL_ACCESS">IAM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_READ_ONLY_ACCESS">IAM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS">IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_USER_CHANGE_PASSWORD">IAM_USER_CHANGE_PASSWORD</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_USER_SSH_KEYS">IAM_USER_SSH_KEYS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IVS_FULL_ACCESS">IVS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IVS_READ_ONLY_ACCESS">IVS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.MEDIA_CONNECT_GATEWAY_INSTANCE_ROLE_POLICY">MEDIA_CONNECT_GATEWAY_INSTANCE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_CONSOLE_FULL_ACCESS">NEPTUNE_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_FULL_ACCESS">NEPTUNE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_GRAPH_READ_ONLY_ACCESS">NEPTUNE_GRAPH_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_READ_ONLY_ACCESS">NEPTUNE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.OAM_FULL_ACCESS">OAM_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.OAM_READ_ONLY_ACCESS">OAM_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.PARTNER_CENTRAL_ACCOUNT_MANAGEMENT_USER_ROLE_ASSOCIATION">PARTNER_CENTRAL_ACCOUNT_MANAGEMENT_USER_ROLE_ASSOCIATION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.POWER_USER_ACCESS">POWER_USER_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.Q_BUSINESS_QUICKSIGHT_PLUGIN_POLICY">Q_BUSINESS_QUICKSIGHT_PLUGIN_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.READ_ONLY_ACCESS">READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.RESOURCE_GROUPS_AND_TAG_EDITOR_FULL_ACCESS">RESOURCE_GROUPS_AND_TAG_EDITOR_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.RESOURCE_GROUPS_AND_TAG_EDITOR_READ_ONLY_ACCESS">RESOURCE_GROUPS_AND_TAG_EDITOR_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.RESOURCE_GROUPS_TAGGING_API_TAG_UNTAG_SUPPORTED_RESOURCES">RESOURCE_GROUPS_TAGGING_API_TAG_UNTAG_SUPPORTED_RESOURCES</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ROSA_MANAGE_SUBSCRIPTION">ROSA_MANAGE_SUBSCRIPTION</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_FULL_ACCESS">SAGE_MAKER_STUDIO_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_PROJECT_ROLE_MACHINE_LEARNING_POLICY">SAGE_MAKER_STUDIO_PROJECT_ROLE_MACHINE_LEARNING_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_PERMISSIONS_BOUNDARY">SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_PERMISSIONS_BOUNDARY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_POLICY">SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SECRETS_MANAGER_READ_WRITE">SECRETS_MANAGER_READ_WRITE</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SECURITY_AUDIT">SECURITY_AUDIT</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVER_MIGRATION_CONNECTOR">SERVER_MIGRATION_CONNECTOR</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS">SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVICE_QUOTAS_FULL_ACCESS">SERVICE_QUOTAS_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVICE_QUOTAS_READ_ONLY_ACCESS">SERVICE_QUOTAS_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SIMPLE_WORKFLOW_FULL_ACCESS">SIMPLE_WORKFLOW_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.TRANSLATE_FULL_ACCESS">TRANSLATE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.TRANSLATE_READ_ONLY">TRANSLATE_READ_ONLY</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.VPC_LATTICE_FULL_ACCESS">VPC_LATTICE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.VPC_LATTICE_READ_ONLY_ACCESS">VPC_LATTICE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.VPC_LATTICE_SERVICES_INVOKE_ACCESS">VPC_LATTICE_SERVICES_INVOKE_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.WELL_ARCHITECTED_CONSOLE_FULL_ACCESS">WELL_ARCHITECTED_CONSOLE_FULL_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS">WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.WORK_LINK_SERVICE_ROLE_POLICY">WORK_LINK_SERVICE_ROLE_POLICY</a></code> | <code>string</code> | *No description.* |

---

##### `ADMINISTRATOR_ACCESS`<sup>Required</sup> <a name="ADMINISTRATOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ADMINISTRATOR_ACCESS"></a>

```typescript
public readonly ADMINISTRATOR_ACCESS: string;
```

- *Type:* string

---

##### `ADMINISTRATOR_ACCESS_AMPLIFY`<sup>Required</sup> <a name="ADMINISTRATOR_ACCESS_AMPLIFY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ADMINISTRATOR_ACCESS_AMPLIFY"></a>

```typescript
public readonly ADMINISTRATOR_ACCESS_AMPLIFY: string;
```

- *Type:* string

---

##### `ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK`<sup>Required</sup> <a name="ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK"></a>

```typescript
public readonly ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK: string;
```

- *Type:* string

---

##### `AI_OPS_ASSISTANT_POLICY`<sup>Required</sup> <a name="AI_OPS_ASSISTANT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_ASSISTANT_POLICY"></a>

```typescript
public readonly AI_OPS_ASSISTANT_POLICY: string;
```

- *Type:* string

---

##### `AI_OPS_CONSOLE_ADMIN_POLICY`<sup>Required</sup> <a name="AI_OPS_CONSOLE_ADMIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_CONSOLE_ADMIN_POLICY"></a>

```typescript
public readonly AI_OPS_CONSOLE_ADMIN_POLICY: string;
```

- *Type:* string

---

##### `AI_OPS_OPERATOR_ACCESS`<sup>Required</sup> <a name="AI_OPS_OPERATOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_OPERATOR_ACCESS"></a>

```typescript
public readonly AI_OPS_OPERATOR_ACCESS: string;
```

- *Type:* string

---

##### `AI_OPS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AI_OPS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AI_OPS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AI_OPS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `ALEXA_FOR_BUSINESS_DEVICE_SETUP`<sup>Required</sup> <a name="ALEXA_FOR_BUSINESS_DEVICE_SETUP" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_DEVICE_SETUP"></a>

```typescript
public readonly ALEXA_FOR_BUSINESS_DEVICE_SETUP: string;
```

- *Type:* string

---

##### `ALEXA_FOR_BUSINESS_FULL_ACCESS`<sup>Required</sup> <a name="ALEXA_FOR_BUSINESS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_FULL_ACCESS"></a>

```typescript
public readonly ALEXA_FOR_BUSINESS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION`<sup>Required</sup> <a name="ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION"></a>

```typescript
public readonly ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION: string;
```

- *Type:* string

---

##### `ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY`<sup>Required</sup> <a name="ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY"></a>

```typescript
public readonly ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY`<sup>Required</sup> <a name="ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY"></a>

```typescript
public readonly ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS"></a>

```typescript
public readonly ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_API_GATEWAY_ADMINISTRATOR`<sup>Required</sup> <a name="AMAZON_API_GATEWAY_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_API_GATEWAY_ADMINISTRATOR"></a>

```typescript
public readonly AMAZON_API_GATEWAY_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_APP_FLOW_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_APP_FLOW_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_FLOW_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_APP_FLOW_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_APP_FLOW_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_APP_FLOW_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_FLOW_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_APP_FLOW_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_APP_STREAM_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_APP_STREAM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_STREAM_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_APP_STREAM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_APP_STREAM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_APP_STREAM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_APP_STREAM_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_APP_STREAM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ATHENA_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ATHENA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ATHENA_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ATHENA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_AUGMENTED_AI_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_AUGMENTED_AI_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AUGMENTED_AI_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_AUGMENTED_AI_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS`<sup>Required</sup> <a name="AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS"></a>

```typescript
public readonly AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_AURORA_DSQL_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_AURORA_DSQL_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AURORA_DSQL_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_AURORA_DSQL_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_AURORA_DSQL_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_AURORA_DSQL_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AURORA_DSQL_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_AURORA_DSQL_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_AURORA_DSQL_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_AURORA_DSQL_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_AURORA_DSQL_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_AURORA_DSQL_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_BEDROCK_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_BEDROCK_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BEDROCK_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_BEDROCK_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_BEDROCK_READ_ONLY`<sup>Required</sup> <a name="AMAZON_BEDROCK_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BEDROCK_READ_ONLY"></a>

```typescript
public readonly AMAZON_BEDROCK_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_BEDROCK_STUDIO_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AMAZON_BEDROCK_STUDIO_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BEDROCK_STUDIO_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AMAZON_BEDROCK_STUDIO_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AMAZON_BRAKET_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_BRAKET_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BRAKET_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_BRAKET_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_BRAKET_JOBS_EXECUTION_POLICY`<sup>Required</sup> <a name="AMAZON_BRAKET_JOBS_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_BRAKET_JOBS_EXECUTION_POLICY"></a>

```typescript
public readonly AMAZON_BRAKET_JOBS_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_CHIME_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CHIME_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CHIME_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CHIME_READ_ONLY`<sup>Required</sup> <a name="AMAZON_CHIME_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_READ_ONLY"></a>

```typescript
public readonly AMAZON_CHIME_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_CHIME_SDK`<sup>Required</sup> <a name="AMAZON_CHIME_SDK" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_SDK"></a>

```typescript
public readonly AMAZON_CHIME_SDK: string;
```

- *Type:* string

---

##### `AMAZON_CHIME_USER_MANAGEMENT`<sup>Required</sup> <a name="AMAZON_CHIME_USER_MANAGEMENT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CHIME_USER_MANAGEMENT"></a>

```typescript
public readonly AMAZON_CHIME_USER_MANAGEMENT: string;
```

- *Type:* string

---

##### `AMAZON_CLOUD_DIRECTORY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CLOUD_DIRECTORY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_DIRECTORY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CLOUD_DIRECTORY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_CATALYST_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_CATALYST_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_CATALYST_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_CATALYST_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_CATALYST_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_CATALYST_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_CATALYST_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_CATALYST_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_PROFILER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_PROFILER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_PROFILER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_PROFILER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_SECURITY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_SECURITY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_SECURITY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_SECURITY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CODE_GURU_SECURITY_SCAN_ACCESS`<sup>Required</sup> <a name="AMAZON_CODE_GURU_SECURITY_SCAN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CODE_GURU_SECURITY_SCAN_ACCESS"></a>

```typescript
public readonly AMAZON_CODE_GURU_SECURITY_SCAN_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES`<sup>Required</sup> <a name="AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES"></a>

```typescript
public readonly AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES: string;
```

- *Type:* string

---

##### `AMAZON_COGNITO_POWER_USER`<sup>Required</sup> <a name="AMAZON_COGNITO_POWER_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_POWER_USER"></a>

```typescript
public readonly AMAZON_COGNITO_POWER_USER: string;
```

- *Type:* string

---

##### `AMAZON_COGNITO_READ_ONLY`<sup>Required</sup> <a name="AMAZON_COGNITO_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_READ_ONLY"></a>

```typescript
public readonly AMAZON_COGNITO_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_COGNITO_UN_AUTHED_IDENTITIES_SESSION_POLICY`<sup>Required</sup> <a name="AMAZON_COGNITO_UN_AUTHED_IDENTITIES_SESSION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_UN_AUTHED_IDENTITIES_SESSION_POLICY"></a>

```typescript
public readonly AMAZON_COGNITO_UN_AUTHED_IDENTITIES_SESSION_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES`<sup>Required</sup> <a name="AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES"></a>

```typescript
public readonly AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES: string;
```

- *Type:* string

---

##### `AMAZON_CONNECT_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CONNECT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CONNECT_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CONNECT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CONNECT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_CONNECT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CONNECT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_CONNECT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_CONNECT_VOICE_ID_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_CONNECT_VOICE_ID_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_CONNECT_VOICE_ID_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_CONNECT_VOICE_ID_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AMAZON_DATA_ZONE_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DATA_ZONE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_FULL_USER_ACCESS`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_FULL_USER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_FULL_USER_ACCESS"></a>

```typescript
public readonly AMAZON_DATA_ZONE_FULL_USER_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_REDSHIFT_GLUE_PROVISIONING_POLICY`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_REDSHIFT_GLUE_PROVISIONING_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_REDSHIFT_GLUE_PROVISIONING_POLICY"></a>

```typescript
public readonly AMAZON_DATA_ZONE_REDSHIFT_GLUE_PROVISIONING_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_SAGE_MAKER_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_SAGE_MAKER_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_SAGE_MAKER_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AMAZON_DATA_ZONE_SAGE_MAKER_ENVIRONMENT_ROLE_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_SAGE_MAKER_MANAGE_ACCESS_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_SAGE_MAKER_MANAGE_ACCESS_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_SAGE_MAKER_MANAGE_ACCESS_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_DATA_ZONE_SAGE_MAKER_MANAGE_ACCESS_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_DATA_ZONE_SAGE_MAKER_PROVISIONING_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_DATA_ZONE_SAGE_MAKER_PROVISIONING_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DATA_ZONE_SAGE_MAKER_PROVISIONING_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_DATA_ZONE_SAGE_MAKER_PROVISIONING_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_DETECTIVE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DETECTIVE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DETECTIVE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DETECTIVE_INVESTIGATOR_ACCESS`<sup>Required</sup> <a name="AMAZON_DETECTIVE_INVESTIGATOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_INVESTIGATOR_ACCESS"></a>

```typescript
public readonly AMAZON_DETECTIVE_INVESTIGATOR_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DETECTIVE_MEMBER_ACCESS`<sup>Required</sup> <a name="AMAZON_DETECTIVE_MEMBER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_MEMBER_ACCESS"></a>

```typescript
public readonly AMAZON_DETECTIVE_MEMBER_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DETECTIVE_ORGANIZATIONS_ACCESS`<sup>Required</sup> <a name="AMAZON_DETECTIVE_ORGANIZATIONS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DETECTIVE_ORGANIZATIONS_ACCESS"></a>

```typescript
public readonly AMAZON_DETECTIVE_ORGANIZATIONS_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DEV_OPS_GURU_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DEV_OPS_GURU_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DEV_OPS_GURU_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS`<sup>Required</sup> <a name="AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS"></a>

```typescript
public readonly AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DOC_DB_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DOC_DB_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DOC_DB_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DOC_DB_ELASTIC_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DOC_DB_ELASTIC_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_ELASTIC_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DOC_DB_ELASTIC_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DOC_DB_ELASTIC_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_DOC_DB_ELASTIC_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_ELASTIC_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_DOC_DB_ELASTIC_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DOC_DB_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DOC_DB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DOC_DB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DOC_DB_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_DOC_DB_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DOC_DB_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_DOC_DB_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DRSVPC_MANAGEMENT`<sup>Required</sup> <a name="AMAZON_DRSVPC_MANAGEMENT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DRSVPC_MANAGEMENT"></a>

```typescript
public readonly AMAZON_DRSVPC_MANAGEMENT: string;
```

- *Type:* string

---

##### `AMAZON_DYNAMO_DB_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_DYNAMO_DB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DYNAMO_DB_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_DYNAMO_DB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE`<sup>Required</sup> <a name="AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE"></a>

```typescript
public readonly AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE: string;
```

- *Type:* string

---

##### `AMAZON_DYNAMO_DB_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_DYNAMO_DB_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_DYNAMO_DB_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_DYNAMO_DB_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER`<sup>Required</sup> <a name="AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER"></a>

```typescript
public readonly AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER: string;
```

- *Type:* string

---

##### `AMAZON_EC2_CONTAINER_REGISTRY_PULL_ONLY`<sup>Required</sup> <a name="AMAZON_EC2_CONTAINER_REGISTRY_PULL_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_PULL_ONLY"></a>

```typescript
public readonly AMAZON_EC2_CONTAINER_REGISTRY_PULL_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY`<sup>Required</sup> <a name="AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY"></a>

```typescript
public readonly AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_EC2_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_EC2_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_EC2_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EC2_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_EC2_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_EC2_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD`<sup>Required</sup> <a name="AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD"></a>

```typescript
public readonly AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD: string;
```

- *Type:* string

---

##### `AMAZON_ECS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ECS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ECS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ECS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ECS_INFRASTRUCTURE_ROLE_POLICY_FOR_VPC_LATTICE`<sup>Required</sup> <a name="AMAZON_ECS_INFRASTRUCTURE_ROLE_POLICY_FOR_VPC_LATTICE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ECS_INFRASTRUCTURE_ROLE_POLICY_FOR_VPC_LATTICE"></a>

```typescript
public readonly AMAZON_ECS_INFRASTRUCTURE_ROLE_POLICY_FOR_VPC_LATTICE: string;
```

- *Type:* string

---

##### `AMAZON_EKS_BLOCK_STORAGE_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_BLOCK_STORAGE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_BLOCK_STORAGE_POLICY"></a>

```typescript
public readonly AMAZON_EKS_BLOCK_STORAGE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_CLUSTER_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_CLUSTER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_CLUSTER_POLICY"></a>

```typescript
public readonly AMAZON_EKS_CLUSTER_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_CNI_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_CNI_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_CNI_POLICY"></a>

```typescript
public readonly AMAZON_EKS_CNI_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_COMPUTE_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_COMPUTE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_COMPUTE_POLICY"></a>

```typescript
public readonly AMAZON_EKS_COMPUTE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_LOAD_BALANCING_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_LOAD_BALANCING_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_LOAD_BALANCING_POLICY"></a>

```typescript
public readonly AMAZON_EKS_LOAD_BALANCING_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY"></a>

```typescript
public readonly AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_NETWORKING_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_NETWORKING_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_NETWORKING_POLICY"></a>

```typescript
public readonly AMAZON_EKS_NETWORKING_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_SERVICE_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_SERVICE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_SERVICE_POLICY"></a>

```typescript
public readonly AMAZON_EKS_SERVICE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_WORKER_NODE_MINIMAL_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_WORKER_NODE_MINIMAL_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_WORKER_NODE_MINIMAL_POLICY"></a>

```typescript
public readonly AMAZON_EKS_WORKER_NODE_MINIMAL_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKS_WORKER_NODE_POLICY`<sup>Required</sup> <a name="AMAZON_EKS_WORKER_NODE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKS_WORKER_NODE_POLICY"></a>

```typescript
public readonly AMAZON_EKS_WORKER_NODE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_EKSVPC_RESOURCE_CONTROLLER`<sup>Required</sup> <a name="AMAZON_EKSVPC_RESOURCE_CONTROLLER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EKSVPC_RESOURCE_CONTROLLER"></a>

```typescript
public readonly AMAZON_EKSVPC_RESOURCE_CONTROLLER: string;
```

- *Type:* string

---

##### `AMAZON_ELASTI_CACHE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTI_CACHE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTI_CACHE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTI_CACHE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER`<sup>Required</sup> <a name="AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER"></a>

```typescript
public readonly AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY`<sup>Required</sup> <a name="AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY"></a>

```typescript
public readonly AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_FILE_SYSTEMS_UTILS`<sup>Required</sup> <a name="AMAZON_ELASTIC_FILE_SYSTEMS_UTILS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_FILE_SYSTEMS_UTILS"></a>

```typescript
public readonly AMAZON_ELASTIC_FILE_SYSTEMS_UTILS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY`<sup>Required</sup> <a name="AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY"></a>

```typescript
public readonly AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER`<sup>Required</sup> <a name="AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER"></a>

```typescript
public readonly AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER: string;
```

- *Type:* string

---

##### `AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EMR_FULL_ACCESS_POLICY_V2`<sup>Required</sup> <a name="AMAZON_EMR_FULL_ACCESS_POLICY_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EMR_FULL_ACCESS_POLICY_V2"></a>

```typescript
public readonly AMAZON_EMR_FULL_ACCESS_POLICY_V2: string;
```

- *Type:* string

---

##### `AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2`<sup>Required</sup> <a name="AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2"></a>

```typescript
public readonly AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2: string;
```

- *Type:* string

---

##### `AMAZON_ES_COGNITO_ACCESS`<sup>Required</sup> <a name="AMAZON_ES_COGNITO_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ES_COGNITO_ACCESS"></a>

```typescript
public readonly AMAZON_ES_COGNITO_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ES_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ES_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ES_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ES_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ES_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ES_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_F_SX_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_F_SX_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_F_SX_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_F_SX_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_F_SX_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_F_SX_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_F_SX_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_F_SX_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_F_SX_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_F_SX_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_FORECAST_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_FORECAST_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_FORECAST_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_FORECAST_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY`<sup>Required</sup> <a name="AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY"></a>

```typescript
public readonly AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_FREE_RTOS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_FREE_RTOS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_FREE_RTOS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_FREE_RTOS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_GLACIER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_GLACIER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GLACIER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_GLACIER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_GLACIER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_GLACIER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GLACIER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_GLACIER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_GUARD_DUTY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_GUARD_DUTY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GUARD_DUTY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_GUARD_DUTY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_GUARD_DUTY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_GUARD_DUTY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_GUARD_DUTY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_GUARD_DUTY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HEALTH_LAKE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_HEALTH_LAKE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HEALTH_LAKE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_HEALTH_LAKE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HONEYCODE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_HONEYCODE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_HONEYCODE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HONEYCODE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_HONEYCODE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_HONEYCODE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_INSPECTOR_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_INSPECTOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_INSPECTOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_INSPECTOR_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_INSPECTOR_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_INSPECTOR_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_INSPECTOR2_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_INSPECTOR2_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR2_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_INSPECTOR2_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_INSPECTOR2_MANAGED_CIS_POLICY`<sup>Required</sup> <a name="AMAZON_INSPECTOR2_MANAGED_CIS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR2_MANAGED_CIS_POLICY"></a>

```typescript
public readonly AMAZON_INSPECTOR2_MANAGED_CIS_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_INSPECTOR2_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_INSPECTOR2_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_INSPECTOR2_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_INSPECTOR2_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KENDRA_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_KENDRA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KENDRA_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_KENDRA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KENDRA_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_KENDRA_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KENDRA_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_KENDRA_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KEYSPACES_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_KEYSPACES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KEYSPACES_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_KEYSPACES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KEYSPACES_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_KEYSPACES_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KEYSPACES_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_KEYSPACES_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KEYSPACES_READ_ONLY_ACCESS_V2`<sup>Required</sup> <a name="AMAZON_KEYSPACES_READ_ONLY_ACCESS_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KEYSPACES_READ_ONLY_ACCESS_V2"></a>

```typescript
public readonly AMAZON_KEYSPACES_READ_ONLY_ACCESS_V2: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_ANALYTICS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_ANALYTICS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_ANALYTICS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_ANALYTICS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_ANALYTICS_READ_ONLY`<sup>Required</sup> <a name="AMAZON_KINESIS_ANALYTICS_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_ANALYTICS_READ_ONLY"></a>

```typescript
public readonly AMAZON_KINESIS_ANALYTICS_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_FIREHOSE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_FIREHOSE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_FIREHOSE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_FIREHOSE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LAUNCH_WIZARD_FULL_ACCESS_V2`<sup>Required</sup> <a name="AMAZON_LAUNCH_WIZARD_FULL_ACCESS_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LAUNCH_WIZARD_FULL_ACCESS_V2"></a>

```typescript
public readonly AMAZON_LAUNCH_WIZARD_FULL_ACCESS_V2: string;
```

- *Type:* string

---

##### `AMAZON_LEX_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_LEX_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LEX_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_LEX_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LEX_READ_ONLY`<sup>Required</sup> <a name="AMAZON_LEX_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LEX_READ_ONLY"></a>

```typescript
public readonly AMAZON_LEX_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_LEX_RUN_BOTS_ONLY`<sup>Required</sup> <a name="AMAZON_LEX_RUN_BOTS_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LEX_RUN_BOTS_ONLY"></a>

```typescript
public readonly AMAZON_LEX_RUN_BOTS_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_METRICS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_METRICS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_METRICS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_METRICS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_VISION_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_VISION_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_VISION_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS`<sup>Required</sup> <a name="AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS"></a>

```typescript
public readonly AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACHINE_LEARNING_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MACHINE_LEARNING_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MACHINE_LEARNING_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACIE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MACIE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACIE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MACIE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MACIE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MACIE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MACIE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MACIE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MCS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MCS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MCS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MCS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MCS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MCS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MCS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MCS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MECHANICAL_TURK_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MECHANICAL_TURK_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MECHANICAL_TURK_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MECHANICAL_TURK_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MECHANICAL_TURK_READ_ONLY`<sup>Required</sup> <a name="AMAZON_MECHANICAL_TURK_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MECHANICAL_TURK_READ_ONLY"></a>

```typescript
public readonly AMAZON_MECHANICAL_TURK_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_MEMORY_DB_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MEMORY_DB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MEMORY_DB_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MEMORY_DB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MEMORY_DB_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MEMORY_DB_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MEMORY_DB_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MEMORY_DB_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS`<sup>Required</sup> <a name="AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS"></a>

```typescript
public readonly AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MOBILE_ANALYTICS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MOBILE_ANALYTICS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MOBILE_ANALYTICS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MOBILE_ANALYTICS_NON_FINANCIAL_REPORT_ACCESS`<sup>Required</sup> <a name="AMAZON_MOBILE_ANALYTICS_NON_FINANCIAL_REPORT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_NON_FINANCIAL_REPORT_ACCESS"></a>

```typescript
public readonly AMAZON_MOBILE_ANALYTICS_NON_FINANCIAL_REPORT_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MONITRON_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MONITRON_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MONITRON_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MONITRON_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MQ_API_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MQ_API_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_API_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MQ_API_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MQ_API_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MQ_API_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_API_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MQ_API_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MQ_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MQ_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MQ_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MQ_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MQ_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MQ_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MQ_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MSK_CONNECT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MSK_CONNECT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MSK_CONNECT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MSK_CONNECT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MSK_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_MSK_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MSK_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_MSK_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_MSK_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_MSK_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_MSK_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_MSK_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER`<sup>Required</sup> <a name="AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER"></a>

```typescript
public readonly AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER: string;
```

- *Type:* string

---

##### `AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN`<sup>Required</sup> <a name="AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN"></a>

```typescript
public readonly AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN: string;
```

- *Type:* string

---

##### `AMAZON_NIMBLE_STUDIO_STUDIO_USER`<sup>Required</sup> <a name="AMAZON_NIMBLE_STUDIO_STUDIO_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_NIMBLE_STUDIO_STUDIO_USER"></a>

```typescript
public readonly AMAZON_NIMBLE_STUDIO_STUDIO_USER: string;
```

- *Type:* string

---

##### `AMAZON_OMICS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_OMICS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OMICS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_OMICS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OMICS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_OMICS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OMICS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_OMICS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ONE_ENTERPRISE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ONE_ENTERPRISE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ONE_ENTERPRISE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ONE_ENTERPRISE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ONE_ENTERPRISE_INSTALLER_ACCESS`<sup>Required</sup> <a name="AMAZON_ONE_ENTERPRISE_INSTALLER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ONE_ENTERPRISE_INSTALLER_ACCESS"></a>

```typescript
public readonly AMAZON_ONE_ENTERPRISE_INSTALLER_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ONE_ENTERPRISE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ONE_ENTERPRISE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ONE_ENTERPRISE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ONE_ENTERPRISE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OPEN_SEARCH_DIRECT_QUERY_GLUE_CREATE_ACCESS`<sup>Required</sup> <a name="AMAZON_OPEN_SEARCH_DIRECT_QUERY_GLUE_CREATE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_DIRECT_QUERY_GLUE_CREATE_ACCESS"></a>

```typescript
public readonly AMAZON_OPEN_SEARCH_DIRECT_QUERY_GLUE_CREATE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OPEN_SEARCH_INGESTION_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_OPEN_SEARCH_INGESTION_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_INGESTION_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_OPEN_SEARCH_INGESTION_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OPEN_SEARCH_INGESTION_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_OPEN_SEARCH_INGESTION_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_INGESTION_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_OPEN_SEARCH_INGESTION_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS`<sup>Required</sup> <a name="AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS"></a>

```typescript
public readonly AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_POLLY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_POLLY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_POLLY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_POLLY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_POLLY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_POLLY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_POLLY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_POLLY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_PROMETHEUS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_PROMETHEUS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_PROMETHEUS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_PROMETHEUS_QUERY_ACCESS`<sup>Required</sup> <a name="AMAZON_PROMETHEUS_QUERY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_QUERY_ACCESS"></a>

```typescript
public readonly AMAZON_PROMETHEUS_QUERY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS`<sup>Required</sup> <a name="AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS"></a>

```typescript
public readonly AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_Q_DEVELOPER_ACCESS`<sup>Required</sup> <a name="AMAZON_Q_DEVELOPER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_Q_DEVELOPER_ACCESS"></a>

```typescript
public readonly AMAZON_Q_DEVELOPER_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_Q_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_Q_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_Q_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_Q_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_QLDB_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_QLDB_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_QLDB_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_QLDB_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_QLDB_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_QLDB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_QLDB_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_QLDB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_QLDB_READ_ONLY`<sup>Required</sup> <a name="AMAZON_QLDB_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_QLDB_READ_ONLY"></a>

```typescript
public readonly AMAZON_QLDB_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_RDS_CUSTOM_INSTANCE_PROFILE_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_RDS_CUSTOM_INSTANCE_PROFILE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_CUSTOM_INSTANCE_PROFILE_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_RDS_CUSTOM_INSTANCE_PROFILE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_RDS_DATA_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_RDS_DATA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_DATA_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_RDS_DATA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_RDS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_RDS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_RDS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_RDS_PERFORMANCE_INSIGHTS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_RDS_PERFORMANCE_INSIGHTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_PERFORMANCE_INSIGHTS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_RDS_PERFORMANCE_INSIGHTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY`<sup>Required</sup> <a name="AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY"></a>

```typescript
public readonly AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_RDS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_RDS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_RDS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_RDS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_DATA_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_REDSHIFT_DATA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_DATA_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_REDSHIFT_DATA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_REDSHIFT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_REDSHIFT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_QUERY_EDITOR`<sup>Required</sup> <a name="AMAZON_REDSHIFT_QUERY_EDITOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR"></a>

```typescript
public readonly AMAZON_REDSHIFT_QUERY_EDITOR: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING`<sup>Required</sup> <a name="AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING"></a>

```typescript
public readonly AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING`<sup>Required</sup> <a name="AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING"></a>

```typescript
public readonly AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING`<sup>Required</sup> <a name="AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING"></a>

```typescript
public readonly AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING: string;
```

- *Type:* string

---

##### `AMAZON_REDSHIFT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_REDSHIFT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REDSHIFT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_REDSHIFT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REKOGNITION_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_REKOGNITION_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REKOGNITION_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_REKOGNITION_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_REKOGNITION_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_REKOGNITION_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_REKOGNITION_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_REKOGNITION_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_DOMAINS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_DOMAINS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_DOMAINS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_DOMAINS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_PROFILES_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_PROFILES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_PROFILES_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_PROFILES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_PROFILES_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_PROFILES_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_PROFILES_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_PROFILES_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RESOLVER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RESOLVER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RESOLVER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RESOLVER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_S3_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_S3_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_S3_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_S3_OUTPOSTS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_S3_OUTPOSTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_OUTPOSTS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_S3_OUTPOSTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_S3_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_S3_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_S3_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_S3_TABLES_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_S3_TABLES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_TABLES_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_S3_TABLES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_S3_TABLES_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_S3_TABLES_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_S3_TABLES_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_S3_TABLES_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CANVAS_AI_SERVICES_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CANVAS_AI_SERVICES_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_AI_SERVICES_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CANVAS_AI_SERVICES_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CANVAS_BEDROCK_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CANVAS_BEDROCK_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_BEDROCK_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CANVAS_BEDROCK_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CANVAS_DATA_PREP_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CANVAS_DATA_PREP_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_DATA_PREP_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CANVAS_DATA_PREP_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CANVAS_EMR_SERVERLESS_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CANVAS_EMR_SERVERLESS_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_EMR_SERVERLESS_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CANVAS_EMR_SERVERLESS_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CANVAS_SM_DATA_SCIENCE_ASSISTANT_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CANVAS_SM_DATA_SCIENCE_ASSISTANT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CANVAS_SM_DATA_SCIENCE_ASSISTANT_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CANVAS_SM_DATA_SCIENCE_ASSISTANT_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_CLUSTER_INSTANCE_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_CLUSTER_INSTANCE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_CLUSTER_INSTANCE_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_CLUSTER_INSTANCE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_MODEL_REGISTRY_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_MODEL_REGISTRY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_MODEL_REGISTRY_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_MODEL_REGISTRY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_PARTNER_APPS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_PARTNER_APPS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_PARTNER_APPS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_PARTNER_APPS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_READ_ONLY`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_READ_ONLY"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_SAGE_MAKER_TRAINING_PLAN_CREATE_ACCESS`<sup>Required</sup> <a name="AMAZON_SAGE_MAKER_TRAINING_PLAN_CREATE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SAGE_MAKER_TRAINING_PLAN_CREATE_ACCESS"></a>

```typescript
public readonly AMAZON_SAGE_MAKER_TRAINING_PLAN_CREATE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SECURITY_LAKE_ADMINISTRATOR`<sup>Required</sup> <a name="AMAZON_SECURITY_LAKE_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SECURITY_LAKE_ADMINISTRATOR"></a>

```typescript
public readonly AMAZON_SECURITY_LAKE_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AMAZON_SES_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SES_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SES_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_SES_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SES_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_SES_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SNS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SNS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SNS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SNS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SNS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_SNS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SNS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_SNS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SQS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SQS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SQS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SQS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SQS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_SQS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SQS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_SQS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SSM_AUTOMATION_APPROVER_ACCESS`<sup>Required</sup> <a name="AMAZON_SSM_AUTOMATION_APPROVER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_AUTOMATION_APPROVER_ACCESS"></a>

```typescript
public readonly AMAZON_SSM_AUTOMATION_APPROVER_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SSM_DIRECTORY_SERVICE_ACCESS`<sup>Required</sup> <a name="AMAZON_SSM_DIRECTORY_SERVICE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_DIRECTORY_SERVICE_ACCESS"></a>

```typescript
public readonly AMAZON_SSM_DIRECTORY_SERVICE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SSM_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_SSM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_SSM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY`<sup>Required</sup> <a name="AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY"></a>

```typescript
public readonly AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_SSM_MANAGED_INSTANCE_CORE`<sup>Required</sup> <a name="AMAZON_SSM_MANAGED_INSTANCE_CORE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_MANAGED_INSTANCE_CORE"></a>

```typescript
public readonly AMAZON_SSM_MANAGED_INSTANCE_CORE: string;
```

- *Type:* string

---

##### `AMAZON_SSM_PATCH_ASSOCIATION`<sup>Required</sup> <a name="AMAZON_SSM_PATCH_ASSOCIATION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_PATCH_ASSOCIATION"></a>

```typescript
public readonly AMAZON_SSM_PATCH_ASSOCIATION: string;
```

- *Type:* string

---

##### `AMAZON_SSM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_SSM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_SSM_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_SSM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TEXTRACT_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_TEXTRACT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TEXTRACT_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_TEXTRACT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TIMESTREAM_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_TIMESTREAM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_TIMESTREAM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TIMESTREAM_INFLUX_DB_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_TIMESTREAM_INFLUX_DB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_INFLUX_DB_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_TIMESTREAM_INFLUX_DB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TIMESTREAM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_TIMESTREAM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TIMESTREAM_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_TIMESTREAM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TRANSCRIBE_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_TRANSCRIBE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TRANSCRIBE_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_TRANSCRIBE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_TRANSCRIBE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_TRANSCRIBE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_TRANSCRIBE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_TRANSCRIBE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_VERIFIED_PERMISSIONS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_VERIFIED_PERMISSIONS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VERIFIED_PERMISSIONS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_VERIFIED_PERMISSIONS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_VERIFIED_PERMISSIONS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_VERIFIED_PERMISSIONS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VERIFIED_PERMISSIONS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_VERIFIED_PERMISSIONS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS`<sup>Required</sup> <a name="AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS"></a>

```typescript
public readonly AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS: string;
```

- *Type:* string

---

##### `AMAZON_VPC_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_VPC_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_VPC_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_VPC_NETWORK_ACCESS_ANALYZER_FULL_ACCESS_POLICY`<sup>Required</sup> <a name="AMAZON_VPC_NETWORK_ACCESS_ANALYZER_FULL_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_NETWORK_ACCESS_ANALYZER_FULL_ACCESS_POLICY"></a>

```typescript
public readonly AMAZON_VPC_NETWORK_ACCESS_ANALYZER_FULL_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_VPC_REACHABILITY_ANALYZER_FULL_ACCESS_POLICY`<sup>Required</sup> <a name="AMAZON_VPC_REACHABILITY_ANALYZER_FULL_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_REACHABILITY_ANALYZER_FULL_ACCESS_POLICY"></a>

```typescript
public readonly AMAZON_VPC_REACHABILITY_ANALYZER_FULL_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_VPC_REACHABILITY_ANALYZER_PATH_COMPONENT_READ_POLICY`<sup>Required</sup> <a name="AMAZON_VPC_REACHABILITY_ANALYZER_PATH_COMPONENT_READ_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_REACHABILITY_ANALYZER_PATH_COMPONENT_READ_POLICY"></a>

```typescript
public readonly AMAZON_VPC_REACHABILITY_ANALYZER_PATH_COMPONENT_READ_POLICY: string;
```

- *Type:* string

---

##### `AMAZON_VPC_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_VPC_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_VPC_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_VPC_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_DOCS_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_DOCS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_DOCS_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_DOCS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_DOCS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_DOCS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_DOCS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_DOCS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_MAIL_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_MAIL_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_MAIL_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_MAIL_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_MAIL_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_MAIL_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_MAIL_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_ADMIN`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_ADMIN" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_ADMIN"></a>

```typescript
public readonly AMAZON_WORK_SPACES_ADMIN: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_POOL_SERVICE_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_POOL_SERVICE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_POOL_SERVICE_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_SPACES_POOL_SERVICE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_SECURE_BROWSER_READ_ONLY`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_SECURE_BROWSER_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_SECURE_BROWSER_READ_ONLY"></a>

```typescript
public readonly AMAZON_WORK_SPACES_SECURE_BROWSER_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_SERVICE_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_SERVICE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_SERVICE_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_SPACES_SERVICE_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_THIN_CLIENT_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_THIN_CLIENT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_THIN_CLIENT_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_SPACES_THIN_CLIENT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_THIN_CLIENT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_THIN_CLIENT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_THIN_CLIENT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_WORK_SPACES_THIN_CLIENT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_WORK_SPACES_WEB_READ_ONLY`<sup>Required</sup> <a name="AMAZON_WORK_SPACES_WEB_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORK_SPACES_WEB_READ_ONLY"></a>

```typescript
public readonly AMAZON_WORK_SPACES_WEB_READ_ONLY: string;
```

- *Type:* string

---

##### `AMAZON_WORKSPACES_PCA_ACCESS`<sup>Required</sup> <a name="AMAZON_WORKSPACES_PCA_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_WORKSPACES_PCA_ACCESS"></a>

```typescript
public readonly AMAZON_WORKSPACES_PCA_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ZOCALO_FULL_ACCESS`<sup>Required</sup> <a name="AMAZON_ZOCALO_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ZOCALO_FULL_ACCESS"></a>

```typescript
public readonly AMAZON_ZOCALO_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AMAZON_ZOCALO_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AMAZON_ZOCALO_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AMAZON_ZOCALO_READ_ONLY_ACCESS"></a>

```typescript
public readonly AMAZON_ZOCALO_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AUTO_SCALING_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AUTO_SCALING_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AUTO_SCALING_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AUTO_SCALING_FULL_ACCESS`<sup>Required</sup> <a name="AUTO_SCALING_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_FULL_ACCESS"></a>

```typescript
public readonly AUTO_SCALING_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AUTO_SCALING_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AUTO_SCALING_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AUTO_SCALING_READ_ONLY_ACCESS"></a>

```typescript
public readonly AUTO_SCALING_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ACCOUNT_ACTIVITY_ACCESS`<sup>Required</sup> <a name="AWS_ACCOUNT_ACTIVITY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_ACTIVITY_ACCESS"></a>

```typescript
public readonly AWS_ACCOUNT_ACTIVITY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS"></a>

```typescript
public readonly AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ACCOUNT_USAGE_REPORT_ACCESS`<sup>Required</sup> <a name="AWS_ACCOUNT_USAGE_REPORT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ACCOUNT_USAGE_REPORT_ACCESS"></a>

```typescript
public readonly AWS_ACCOUNT_USAGE_REPORT_ACCESS: string;
```

- *Type:* string

---

##### `AWS_AGENTLESS_DISCOVERY_SERVICE`<sup>Required</sup> <a name="AWS_AGENTLESS_DISCOVERY_SERVICE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_AGENTLESS_DISCOVERY_SERVICE"></a>

```typescript
public readonly AWS_AGENTLESS_DISCOVERY_SERVICE: string;
```

- *Type:* string

---

##### `AWS_APP_FABRIC_FULL_ACCESS`<sup>Required</sup> <a name="AWS_APP_FABRIC_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_FABRIC_FULL_ACCESS"></a>

```typescript
public readonly AWS_APP_FABRIC_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_FABRIC_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_APP_FABRIC_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_FABRIC_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_APP_FABRIC_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_MESH_ENVOY_ACCESS`<sup>Required</sup> <a name="AWS_APP_MESH_ENVOY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_ENVOY_ACCESS"></a>

```typescript
public readonly AWS_APP_MESH_ENVOY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_MESH_FULL_ACCESS`<sup>Required</sup> <a name="AWS_APP_MESH_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_FULL_ACCESS"></a>

```typescript
public readonly AWS_APP_MESH_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_MESH_PREVIEW_ENVOY_ACCESS`<sup>Required</sup> <a name="AWS_APP_MESH_PREVIEW_ENVOY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_PREVIEW_ENVOY_ACCESS"></a>

```typescript
public readonly AWS_APP_MESH_PREVIEW_ENVOY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_MESH_READ_ONLY`<sup>Required</sup> <a name="AWS_APP_MESH_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_MESH_READ_ONLY"></a>

```typescript
public readonly AWS_APP_MESH_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_APP_RUNNER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_APP_RUNNER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_RUNNER_FULL_ACCESS"></a>

```typescript
public readonly AWS_APP_RUNNER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_RUNNER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_APP_RUNNER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_RUNNER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_APP_RUNNER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_SYNC_ADMINISTRATOR`<sup>Required</sup> <a name="AWS_APP_SYNC_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_SYNC_ADMINISTRATOR"></a>

```typescript
public readonly AWS_APP_SYNC_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AWS_APP_SYNC_INVOKE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_APP_SYNC_INVOKE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_SYNC_INVOKE_FULL_ACCESS"></a>

```typescript
public readonly AWS_APP_SYNC_INVOKE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APP_SYNC_SCHEMA_AUTHOR`<sup>Required</sup> <a name="AWS_APP_SYNC_SCHEMA_AUTHOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APP_SYNC_SCHEMA_AUTHOR"></a>

```typescript
public readonly AWS_APP_SYNC_SCHEMA_AUTHOR: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_DISCOVERY_AGENT_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_DISCOVERY_AGENT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_DISCOVERY_AGENT_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_DISCOVERY_AGENT_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_AGENT_POLICY`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_AGENT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_AGENT_POLICY"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_AGENT_POLICY: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_EC2_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_EC2_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_EC2_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_EC2_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_FULL_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_FULL_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_SERVICE_EC2_INSTANCE_POLICY`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_SERVICE_EC2_INSTANCE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_SERVICE_EC2_INSTANCE_POLICY"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_SERVICE_EC2_INSTANCE_POLICY: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_SSM_ACCESS`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_SSM_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_SSM_ACCESS"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_SSM_ACCESS: string;
```

- *Type:* string

---

##### `AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY`<sup>Required</sup> <a name="AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY"></a>

```typescript
public readonly AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY: string;
```

- *Type:* string

---

##### `AWS_ARTIFACT_AGREEMENTS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ARTIFACT_AGREEMENTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ARTIFACT_AGREEMENTS_FULL_ACCESS"></a>

```typescript
public readonly AWS_ARTIFACT_AGREEMENTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ARTIFACT_AGREEMENTS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ARTIFACT_AGREEMENTS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ARTIFACT_AGREEMENTS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ARTIFACT_AGREEMENTS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ARTIFACT_REPORTS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ARTIFACT_REPORTS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ARTIFACT_REPORTS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ARTIFACT_REPORTS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS`<sup>Required</sup> <a name="AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS"></a>

```typescript
public readonly AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BACKUP_AUDIT_ACCESS`<sup>Required</sup> <a name="AWS_BACKUP_AUDIT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_AUDIT_ACCESS"></a>

```typescript
public readonly AWS_BACKUP_AUDIT_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BACKUP_DATA_TRANSFER_ACCESS`<sup>Required</sup> <a name="AWS_BACKUP_DATA_TRANSFER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_DATA_TRANSFER_ACCESS"></a>

```typescript
public readonly AWS_BACKUP_DATA_TRANSFER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BACKUP_FULL_ACCESS`<sup>Required</sup> <a name="AWS_BACKUP_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_FULL_ACCESS"></a>

```typescript
public readonly AWS_BACKUP_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BACKUP_OPERATOR_ACCESS`<sup>Required</sup> <a name="AWS_BACKUP_OPERATOR_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_OPERATOR_ACCESS"></a>

```typescript
public readonly AWS_BACKUP_OPERATOR_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS`<sup>Required</sup> <a name="AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS"></a>

```typescript
public readonly AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA`<sup>Required</sup> <a name="AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA"></a>

```typescript
public readonly AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA: string;
```

- *Type:* string

---

##### `AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_INDEXING`<sup>Required</sup> <a name="AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_INDEXING" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_INDEXING"></a>

```typescript
public readonly AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_INDEXING: string;
```

- *Type:* string

---

##### `AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_ITEM_RESTORES`<sup>Required</sup> <a name="AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_ITEM_RESTORES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_ITEM_RESTORES"></a>

```typescript
public readonly AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_ITEM_RESTORES: string;
```

- *Type:* string

---

##### `AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP`<sup>Required</sup> <a name="AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP"></a>

```typescript
public readonly AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP: string;
```

- *Type:* string

---

##### `AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE`<sup>Required</sup> <a name="AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE"></a>

```typescript
public readonly AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE: string;
```

- *Type:* string

---

##### `AWS_BATCH_FULL_ACCESS`<sup>Required</sup> <a name="AWS_BATCH_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BATCH_FULL_ACCESS"></a>

```typescript
public readonly AWS_BATCH_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BILLING_CONDUCTOR_FULL_ACCESS`<sup>Required</sup> <a name="AWS_BILLING_CONDUCTOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BILLING_CONDUCTOR_FULL_ACCESS"></a>

```typescript
public readonly AWS_BILLING_CONDUCTOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BILLING_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_BILLING_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BILLING_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_BILLING_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM`<sup>Required</sup> <a name="AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM"></a>

```typescript
public readonly AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM: string;
```

- *Type:* string

---

##### `AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS`<sup>Required</sup> <a name="AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS"></a>

```typescript
public readonly AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BUDGETS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_BUDGETS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUDGETS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_BUDGETS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BUG_BUST_FULL_ACCESS`<sup>Required</sup> <a name="AWS_BUG_BUST_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUG_BUST_FULL_ACCESS"></a>

```typescript
public readonly AWS_BUG_BUST_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_BUG_BUST_PLAYER_ACCESS`<sup>Required</sup> <a name="AWS_BUG_BUST_PLAYER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_BUG_BUST_PLAYER_ACCESS"></a>

```typescript
public readonly AWS_BUG_BUST_PLAYER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_FULL_ACCESS"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_PRIVATE_CA_USER`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_PRIVATE_CA_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_PRIVATE_CA_USER"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_PRIVATE_CA_USER: string;
```

- *Type:* string

---

##### `AWS_CERTIFICATE_MANAGER_READ_ONLY`<sup>Required</sup> <a name="AWS_CERTIFICATE_MANAGER_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CERTIFICATE_MANAGER_READ_ONLY"></a>

```typescript
public readonly AWS_CERTIFICATE_MANAGER_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_CLEAN_ROOMS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLEAN_ROOMS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLEAN_ROOMS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING`<sup>Required</sup> <a name="AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING"></a>

```typescript
public readonly AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING: string;
```

- *Type:* string

---

##### `AWS_CLEAN_ROOMS_ML_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLEAN_ROOMS_ML_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_ML_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLEAN_ROOMS_ML_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLEAN_ROOMS_ML_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CLEAN_ROOMS_ML_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_ML_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CLEAN_ROOMS_ML_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLEAN_ROOMS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CLEAN_ROOMS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLEAN_ROOMS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CLEAN_ROOMS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_FORMATION_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_FORMATION_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_FORMATION_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_FORMATION_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_FORMATION_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_FORMATION_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_FORMATION_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_FORMATION_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_HSM_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_HSM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_HSM_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_HSM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_HSM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_HSM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_HSM_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_HSM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_MAP_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_MAP_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_MAP_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_MAP_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_MAP_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_MAP_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_SHELL_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_SHELL_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_SHELL_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_SHELL_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_TRAIL_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_TRAIL_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_TRAIL_FULL_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_TRAIL_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD_TRAIL_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CLOUD_TRAIL_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD_TRAIL_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CLOUD_TRAIL_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CLOUD9_ADMINISTRATOR`<sup>Required</sup> <a name="AWS_CLOUD9_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_ADMINISTRATOR"></a>

```typescript
public readonly AWS_CLOUD9_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AWS_CLOUD9_ENVIRONMENT_MEMBER`<sup>Required</sup> <a name="AWS_CLOUD9_ENVIRONMENT_MEMBER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_ENVIRONMENT_MEMBER"></a>

```typescript
public readonly AWS_CLOUD9_ENVIRONMENT_MEMBER: string;
```

- *Type:* string

---

##### `AWS_CLOUD9_SSM_INSTANCE_PROFILE`<sup>Required</sup> <a name="AWS_CLOUD9_SSM_INSTANCE_PROFILE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_SSM_INSTANCE_PROFILE"></a>

```typescript
public readonly AWS_CLOUD9_SSM_INSTANCE_PROFILE: string;
```

- *Type:* string

---

##### `AWS_CLOUD9_USER`<sup>Required</sup> <a name="AWS_CLOUD9_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CLOUD9_USER"></a>

```typescript
public readonly AWS_CLOUD9_USER: string;
```

- *Type:* string

---

##### `AWS_CODE_ARTIFACT_ADMIN_ACCESS`<sup>Required</sup> <a name="AWS_CODE_ARTIFACT_ADMIN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_ARTIFACT_ADMIN_ACCESS"></a>

```typescript
public readonly AWS_CODE_ARTIFACT_ADMIN_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_ARTIFACT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CODE_ARTIFACT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_ARTIFACT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CODE_ARTIFACT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_BUILD_ADMIN_ACCESS`<sup>Required</sup> <a name="AWS_CODE_BUILD_ADMIN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_BUILD_ADMIN_ACCESS"></a>

```typescript
public readonly AWS_CODE_BUILD_ADMIN_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_BUILD_DEVELOPER_ACCESS`<sup>Required</sup> <a name="AWS_CODE_BUILD_DEVELOPER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_BUILD_DEVELOPER_ACCESS"></a>

```typescript
public readonly AWS_CODE_BUILD_DEVELOPER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_BUILD_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CODE_BUILD_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_BUILD_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CODE_BUILD_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_COMMIT_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CODE_COMMIT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_COMMIT_FULL_ACCESS"></a>

```typescript
public readonly AWS_CODE_COMMIT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_COMMIT_POWER_USER`<sup>Required</sup> <a name="AWS_CODE_COMMIT_POWER_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_COMMIT_POWER_USER"></a>

```typescript
public readonly AWS_CODE_COMMIT_POWER_USER: string;
```

- *Type:* string

---

##### `AWS_CODE_COMMIT_READ_ONLY`<sup>Required</sup> <a name="AWS_CODE_COMMIT_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_COMMIT_READ_ONLY"></a>

```typescript
public readonly AWS_CODE_COMMIT_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_CODE_DEPLOY_DEPLOYER_ACCESS`<sup>Required</sup> <a name="AWS_CODE_DEPLOY_DEPLOYER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_DEPLOYER_ACCESS"></a>

```typescript
public readonly AWS_CODE_DEPLOY_DEPLOYER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_DEPLOY_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CODE_DEPLOY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_FULL_ACCESS"></a>

```typescript
public readonly AWS_CODE_DEPLOY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_DEPLOY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CODE_DEPLOY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CODE_DEPLOY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_DEPLOY_ROLE_FOR_ECS`<sup>Required</sup> <a name="AWS_CODE_DEPLOY_ROLE_FOR_ECS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_ROLE_FOR_ECS"></a>

```typescript
public readonly AWS_CODE_DEPLOY_ROLE_FOR_ECS: string;
```

- *Type:* string

---

##### `AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED`<sup>Required</sup> <a name="AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED"></a>

```typescript
public readonly AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED: string;
```

- *Type:* string

---

##### `AWS_CODE_PIPELINE_APPROVER_ACCESS`<sup>Required</sup> <a name="AWS_CODE_PIPELINE_APPROVER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_APPROVER_ACCESS"></a>

```typescript
public readonly AWS_CODE_PIPELINE_APPROVER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS`<sup>Required</sup> <a name="AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS"></a>

```typescript
public readonly AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_PIPELINE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CODE_PIPELINE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_FULL_ACCESS"></a>

```typescript
public readonly AWS_CODE_PIPELINE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_PIPELINE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_CODE_PIPELINE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_PIPELINE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_CODE_PIPELINE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CODE_STAR_FULL_ACCESS`<sup>Required</sup> <a name="AWS_CODE_STAR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CODE_STAR_FULL_ACCESS"></a>

```typescript
public readonly AWS_CODE_STAR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_COMPROMISED_KEY_QUARANTINE`<sup>Required</sup> <a name="AWS_COMPROMISED_KEY_QUARANTINE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_COMPROMISED_KEY_QUARANTINE"></a>

```typescript
public readonly AWS_COMPROMISED_KEY_QUARANTINE: string;
```

- *Type:* string

---

##### `AWS_COMPROMISED_KEY_QUARANTINE_V2`<sup>Required</sup> <a name="AWS_COMPROMISED_KEY_QUARANTINE_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_COMPROMISED_KEY_QUARANTINE_V2"></a>

```typescript
public readonly AWS_COMPROMISED_KEY_QUARANTINE_V2: string;
```

- *Type:* string

---

##### `AWS_COMPROMISED_KEY_QUARANTINE_V3`<sup>Required</sup> <a name="AWS_COMPROMISED_KEY_QUARANTINE_V3" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_COMPROMISED_KEY_QUARANTINE_V3"></a>

```typescript
public readonly AWS_COMPROMISED_KEY_QUARANTINE_V3: string;
```

- *Type:* string

---

##### `AWS_CONFIG_USER_ACCESS`<sup>Required</sup> <a name="AWS_CONFIG_USER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CONFIG_USER_ACCESS"></a>

```typescript
public readonly AWS_CONFIG_USER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_CONNECTOR`<sup>Required</sup> <a name="AWS_CONNECTOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_CONNECTOR"></a>

```typescript
public readonly AWS_CONNECTOR: string;
```

- *Type:* string

---

##### `AWS_DATA_EXCHANGE_DATA_GRANT_OWNER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_EXCHANGE_DATA_GRANT_OWNER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_DATA_GRANT_OWNER_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_EXCHANGE_DATA_GRANT_OWNER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_EXCHANGE_DATA_GRANT_RECEIVER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_EXCHANGE_DATA_GRANT_RECEIVER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_DATA_GRANT_RECEIVER_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_EXCHANGE_DATA_GRANT_RECEIVER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_EXCHANGE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_EXCHANGE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_EXCHANGE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_EXCHANGE_READ_ONLY`<sup>Required</sup> <a name="AWS_DATA_EXCHANGE_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_READ_ONLY"></a>

```typescript
public readonly AWS_DATA_EXCHANGE_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_PIPELINE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_PIPELINE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_PIPELINE_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_PIPELINE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_PIPELINE_POWER_USER`<sup>Required</sup> <a name="AWS_DATA_PIPELINE_POWER_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_PIPELINE_POWER_USER"></a>

```typescript
public readonly AWS_DATA_PIPELINE_POWER_USER: string;
```

- *Type:* string

---

##### `AWS_DATA_SYNC_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DATA_SYNC_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_SYNC_FULL_ACCESS"></a>

```typescript
public readonly AWS_DATA_SYNC_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DATA_SYNC_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_DATA_SYNC_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DATA_SYNC_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_DATA_SYNC_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DEADLINE_CLOUD_FLEET_WORKER`<sup>Required</sup> <a name="AWS_DEADLINE_CLOUD_FLEET_WORKER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_FLEET_WORKER"></a>

```typescript
public readonly AWS_DEADLINE_CLOUD_FLEET_WORKER: string;
```

- *Type:* string

---

##### `AWS_DEADLINE_CLOUD_USER_ACCESS_FARMS`<sup>Required</sup> <a name="AWS_DEADLINE_CLOUD_USER_ACCESS_FARMS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_FARMS"></a>

```typescript
public readonly AWS_DEADLINE_CLOUD_USER_ACCESS_FARMS: string;
```

- *Type:* string

---

##### `AWS_DEADLINE_CLOUD_USER_ACCESS_FLEETS`<sup>Required</sup> <a name="AWS_DEADLINE_CLOUD_USER_ACCESS_FLEETS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_FLEETS"></a>

```typescript
public readonly AWS_DEADLINE_CLOUD_USER_ACCESS_FLEETS: string;
```

- *Type:* string

---

##### `AWS_DEADLINE_CLOUD_USER_ACCESS_JOBS`<sup>Required</sup> <a name="AWS_DEADLINE_CLOUD_USER_ACCESS_JOBS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_JOBS"></a>

```typescript
public readonly AWS_DEADLINE_CLOUD_USER_ACCESS_JOBS: string;
```

- *Type:* string

---

##### `AWS_DEADLINE_CLOUD_USER_ACCESS_QUEUES`<sup>Required</sup> <a name="AWS_DEADLINE_CLOUD_USER_ACCESS_QUEUES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_USER_ACCESS_QUEUES"></a>

```typescript
public readonly AWS_DEADLINE_CLOUD_USER_ACCESS_QUEUES: string;
```

- *Type:* string

---

##### `AWS_DEADLINE_CLOUD_WORKER_HOST`<sup>Required</sup> <a name="AWS_DEADLINE_CLOUD_WORKER_HOST" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEADLINE_CLOUD_WORKER_HOST"></a>

```typescript
public readonly AWS_DEADLINE_CLOUD_WORKER_HOST: string;
```

- *Type:* string

---

##### `AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY`<sup>Required</sup> <a name="AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY"></a>

```typescript
public readonly AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS`<sup>Required</sup> <a name="AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS"></a>

```typescript
public readonly AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY`<sup>Required</sup> <a name="AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY"></a>

```typescript
public readonly AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS`<sup>Required</sup> <a name="AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS"></a>

```typescript
public readonly AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DEEP_RACER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DEEP_RACER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_FULL_ACCESS"></a>

```typescript
public readonly AWS_DEEP_RACER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY`<sup>Required</sup> <a name="AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY"></a>

```typescript
public readonly AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AWS_DENY_ALL`<sup>Required</sup> <a name="AWS_DENY_ALL" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DENY_ALL"></a>

```typescript
public readonly AWS_DENY_ALL: string;
```

- *Type:* string

---

##### `AWS_DEVICE_FARM_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DEVICE_FARM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DEVICE_FARM_FULL_ACCESS"></a>

```typescript
public readonly AWS_DEVICE_FARM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DIRECT_CONNECT_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DIRECT_CONNECT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECT_CONNECT_FULL_ACCESS"></a>

```typescript
public readonly AWS_DIRECT_CONNECT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DIRECT_CONNECT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_DIRECT_CONNECT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECT_CONNECT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_DIRECT_CONNECT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DIRECTORY_SERVICE_DATA_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DIRECTORY_SERVICE_DATA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_DATA_FULL_ACCESS"></a>

```typescript
public readonly AWS_DIRECTORY_SERVICE_DATA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DIRECTORY_SERVICE_DATA_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_DIRECTORY_SERVICE_DATA_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_DATA_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_DIRECTORY_SERVICE_DATA_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DIRECTORY_SERVICE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_DIRECTORY_SERVICE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_FULL_ACCESS"></a>

```typescript
public readonly AWS_DIRECTORY_SERVICE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY`<sup>Required</sup> <a name="AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY"></a>

```typescript
public readonly AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY: string;
```

- *Type:* string

---

##### `AWS_EC2_VSS_SNAPSHOT_POLICY`<sup>Required</sup> <a name="AWS_EC2_VSS_SNAPSHOT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_EC2_VSS_SNAPSHOT_POLICY"></a>

```typescript
public readonly AWS_EC2_VSS_SNAPSHOT_POLICY: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE`<sup>Required</sup> <a name="AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE"></a>

```typescript
public readonly AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY`<sup>Required</sup> <a name="AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY"></a>

```typescript
public readonly AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER`<sup>Required</sup> <a name="AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER"></a>

```typescript
public readonly AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_BEANSTALK_READ_ONLY`<sup>Required</sup> <a name="AWS_ELASTIC_BEANSTALK_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_READ_ONLY"></a>

```typescript
public readonly AWS_ELASTIC_BEANSTALK_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_BEANSTALK_WEB_TIER`<sup>Required</sup> <a name="AWS_ELASTIC_BEANSTALK_WEB_TIER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_WEB_TIER"></a>

```typescript
public readonly AWS_ELASTIC_BEANSTALK_WEB_TIER: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_BEANSTALK_WORKER_TIER`<sup>Required</sup> <a name="AWS_ELASTIC_BEANSTALK_WORKER_TIER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_BEANSTALK_WORKER_TIER"></a>

```typescript
public readonly AWS_ELASTIC_BEANSTALK_WORKER_TIER: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY`<sup>Required</sup> <a name="AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY"></a>

```typescript
public readonly AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS_V2`<sup>Required</sup> <a name="AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS_V2"></a>

```typescript
public readonly AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS_V2: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY`<sup>Required</sup> <a name="AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY"></a>

```typescript
public readonly AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_DISASTER_RECOVERY_LAUNCH_ACTIONS_POLICY`<sup>Required</sup> <a name="AWS_ELASTIC_DISASTER_RECOVERY_LAUNCH_ACTIONS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_LAUNCH_ACTIONS_POLICY"></a>

```typescript
public readonly AWS_ELASTIC_DISASTER_RECOVERY_LAUNCH_ACTIONS_POLICY: string;
```

- *Type:* string

---

##### `AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_PACKAGE_V2_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_PACKAGE_V2_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_V2_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_PACKAGE_V2_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_PACKAGE_V2_READ_ONLY`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_PACKAGE_V2_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_PACKAGE_V2_READ_ONLY"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_PACKAGE_V2_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY`<sup>Required</sup> <a name="AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY"></a>

```typescript
public readonly AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_ENTITY_RESOLUTION_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ENTITY_RESOLUTION_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ENTITY_RESOLUTION_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_ENTITY_RESOLUTION_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ENTITY_RESOLUTION_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ENTITY_RESOLUTION_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ENTITY_RESOLUTION_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ENTITY_RESOLUTION_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_FM_ADMIN_FULL_ACCESS`<sup>Required</sup> <a name="AWS_FM_ADMIN_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FM_ADMIN_FULL_ACCESS"></a>

```typescript
public readonly AWS_FM_ADMIN_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_FM_ADMIN_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_FM_ADMIN_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FM_ADMIN_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_FM_ADMIN_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_FM_MEMBER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_FM_MEMBER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FM_MEMBER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_FM_MEMBER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_FOR_WORD_PRESS_PLUGIN_POLICY`<sup>Required</sup> <a name="AWS_FOR_WORD_PRESS_PLUGIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_FOR_WORD_PRESS_PLUGIN_POLICY"></a>

```typescript
public readonly AWS_FOR_WORD_PRESS_PLUGIN_POLICY: string;
```

- *Type:* string

---

##### `AWS_GLUE_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_GLUE_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_GLUE_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS`<sup>Required</sup> <a name="AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS"></a>

```typescript
public readonly AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY`<sup>Required</sup> <a name="AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY"></a>

```typescript
public readonly AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS`<sup>Required</sup> <a name="AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS"></a>

```typescript
public readonly AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS`<sup>Required</sup> <a name="AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS"></a>

```typescript
public readonly AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY`<sup>Required</sup> <a name="AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY"></a>

```typescript
public readonly AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY: string;
```

- *Type:* string

---

##### `AWS_GLUE_SESSION_USER_RESTRICTED_POLICY`<sup>Required</sup> <a name="AWS_GLUE_SESSION_USER_RESTRICTED_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GLUE_SESSION_USER_RESTRICTED_POLICY"></a>

```typescript
public readonly AWS_GLUE_SESSION_USER_RESTRICTED_POLICY: string;
```

- *Type:* string

---

##### `AWS_GRAFANA_ACCOUNT_ADMINISTRATOR`<sup>Required</sup> <a name="AWS_GRAFANA_ACCOUNT_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_ACCOUNT_ADMINISTRATOR"></a>

```typescript
public readonly AWS_GRAFANA_ACCOUNT_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT`<sup>Required</sup> <a name="AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT"></a>

```typescript
public readonly AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT: string;
```

- *Type:* string

---

##### `AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT_V2`<sup>Required</sup> <a name="AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT_V2"></a>

```typescript
public readonly AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT_V2: string;
```

- *Type:* string

---

##### `AWS_GREENGRASS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_GREENGRASS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GREENGRASS_FULL_ACCESS"></a>

```typescript
public readonly AWS_GREENGRASS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GREENGRASS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_GREENGRASS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GREENGRASS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_GREENGRASS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_GROUND_STATION_AGENT_INSTANCE_POLICY`<sup>Required</sup> <a name="AWS_GROUND_STATION_AGENT_INSTANCE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_GROUND_STATION_AGENT_INSTANCE_POLICY"></a>

```typescript
public readonly AWS_GROUND_STATION_AGENT_INSTANCE_POLICY: string;
```

- *Type:* string

---

##### `AWS_HEALTH_FULL_ACCESS`<sup>Required</sup> <a name="AWS_HEALTH_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_HEALTH_FULL_ACCESS"></a>

```typescript
public readonly AWS_HEALTH_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_HEALTH_IMAGING_FULL_ACCESS`<sup>Required</sup> <a name="AWS_HEALTH_IMAGING_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_HEALTH_IMAGING_FULL_ACCESS"></a>

```typescript
public readonly AWS_HEALTH_IMAGING_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_HEALTH_IMAGING_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_HEALTH_IMAGING_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_HEALTH_IMAGING_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_HEALTH_IMAGING_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IAM_IDENTITY_CENTER_ALLOW_LIST_FOR_IDENTITY_CONTEXT`<sup>Required</sup> <a name="AWS_IAM_IDENTITY_CENTER_ALLOW_LIST_FOR_IDENTITY_CONTEXT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IAM_IDENTITY_CENTER_ALLOW_LIST_FOR_IDENTITY_CONTEXT"></a>

```typescript
public readonly AWS_IAM_IDENTITY_CENTER_ALLOW_LIST_FOR_IDENTITY_CONTEXT: string;
```

- *Type:* string

---

##### `AWS_IDENTITY_SYNC_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IDENTITY_SYNC_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IDENTITY_SYNC_FULL_ACCESS"></a>

```typescript
public readonly AWS_IDENTITY_SYNC_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IDENTITY_SYNC_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IDENTITY_SYNC_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IDENTITY_SYNC_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IDENTITY_SYNC_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IMAGE_BUILDER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IMAGE_BUILDER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMAGE_BUILDER_FULL_ACCESS"></a>

```typescript
public readonly AWS_IMAGE_BUILDER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IMAGE_BUILDER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IMAGE_BUILDER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMAGE_BUILDER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IMAGE_BUILDER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IMPORT_EXPORT_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IMPORT_EXPORT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMPORT_EXPORT_FULL_ACCESS"></a>

```typescript
public readonly AWS_IMPORT_EXPORT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IMPORT_EXPORT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IMPORT_EXPORT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IMPORT_EXPORT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IMPORT_EXPORT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_INCIDENT_MANAGER_INCIDENT_ACCESS_SERVICE_ROLE_POLICY`<sup>Required</sup> <a name="AWS_INCIDENT_MANAGER_INCIDENT_ACCESS_SERVICE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_INCIDENT_MANAGER_INCIDENT_ACCESS_SERVICE_ROLE_POLICY"></a>

```typescript
public readonly AWS_INCIDENT_MANAGER_INCIDENT_ACCESS_SERVICE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_INCIDENT_MANAGER_RESOLVER_ACCESS`<sup>Required</sup> <a name="AWS_INCIDENT_MANAGER_RESOLVER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_INCIDENT_MANAGER_RESOLVER_ACCESS"></a>

```typescript
public readonly AWS_INCIDENT_MANAGER_RESOLVER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_ANALYTICS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_ANALYTICS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_ANALYTICS_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_ANALYTICS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_CONFIG_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_CONFIG_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_CONFIG_ACCESS"></a>

```typescript
public readonly AWS_IO_T_CONFIG_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_CONFIG_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_CONFIG_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_CONFIG_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IO_T_CONFIG_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_DATA_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_DATA_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_DATA_ACCESS"></a>

```typescript
public readonly AWS_IO_T_DATA_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_EVENTS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_EVENTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_EVENTS_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_EVENTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_EVENTS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_EVENTS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_EVENTS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IO_T_EVENTS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_SITE_WISE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_SITE_WISE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_SITE_WISE_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_SITE_WISE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_WIRELESS_DATA_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_WIRELESS_DATA_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_DATA_ACCESS"></a>

```typescript
public readonly AWS_IO_T_WIRELESS_DATA_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_WIRELESS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_WIRELESS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T_WIRELESS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS"></a>

```typescript
public readonly AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER`<sup>Required</sup> <a name="AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER"></a>

```typescript
public readonly AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER: string;
```

- *Type:* string

---

##### `AWS_IO_T_WIRELESS_LOGGING`<sup>Required</sup> <a name="AWS_IO_T_WIRELESS_LOGGING" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_LOGGING"></a>

```typescript
public readonly AWS_IO_T_WIRELESS_LOGGING: string;
```

- *Type:* string

---

##### `AWS_IO_T_WIRELESS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IO_T_WIRELESS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T_WIRELESS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IO_T_WIRELESS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T1_CLICK_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IO_T1_CLICK_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T1_CLICK_FULL_ACCESS"></a>

```typescript
public readonly AWS_IO_T1_CLICK_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IO_T1_CLICK_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_IO_T1_CLICK_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IO_T1_CLICK_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_IO_T1_CLICK_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_IQ_FULL_ACCESS`<sup>Required</sup> <a name="AWS_IQ_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_IQ_FULL_ACCESS"></a>

```typescript
public readonly AWS_IQ_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_KEY_MANAGEMENT_SERVICE_POWER_USER`<sup>Required</sup> <a name="AWS_KEY_MANAGEMENT_SERVICE_POWER_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_KEY_MANAGEMENT_SERVICE_POWER_USER"></a>

```typescript
public readonly AWS_KEY_MANAGEMENT_SERVICE_POWER_USER: string;
```

- *Type:* string

---

##### `AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER`<sup>Required</sup> <a name="AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER"></a>

```typescript
public readonly AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER: string;
```

- *Type:* string

---

##### `AWS_LAKE_FORMATION_DATA_ADMIN`<sup>Required</sup> <a name="AWS_LAKE_FORMATION_DATA_ADMIN" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAKE_FORMATION_DATA_ADMIN"></a>

```typescript
public readonly AWS_LAKE_FORMATION_DATA_ADMIN: string;
```

- *Type:* string

---

##### `AWS_LAMBDA_EXECUTE`<sup>Required</sup> <a name="AWS_LAMBDA_EXECUTE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_EXECUTE"></a>

```typescript
public readonly AWS_LAMBDA_EXECUTE: string;
```

- *Type:* string

---

##### `AWS_LAMBDA_FULL_ACCESS`<sup>Required</sup> <a name="AWS_LAMBDA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_FULL_ACCESS"></a>

```typescript
public readonly AWS_LAMBDA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_LAMBDA_INVOCATION_DYNAMO_DB`<sup>Required</sup> <a name="AWS_LAMBDA_INVOCATION_DYNAMO_DB" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_INVOCATION_DYNAMO_DB"></a>

```typescript
public readonly AWS_LAMBDA_INVOCATION_DYNAMO_DB: string;
```

- *Type:* string

---

##### `AWS_LAMBDA_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_LAMBDA_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_LAMBDA_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_LAMBDA_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_AMI_INGESTION`<sup>Required</sup> <a name="AWS_MARKETPLACE_AMI_INGESTION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_AMI_INGESTION"></a>

```typescript
public readonly AWS_MARKETPLACE_AMI_INGESTION: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MARKETPLACE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_FULL_ACCESS"></a>

```typescript
public readonly AWS_MARKETPLACE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_GET_ENTITLEMENTS`<sup>Required</sup> <a name="AWS_MARKETPLACE_GET_ENTITLEMENTS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_GET_ENTITLEMENTS"></a>

```typescript
public readonly AWS_MARKETPLACE_GET_ENTITLEMENTS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS"></a>

```typescript
public readonly AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS`<sup>Required</sup> <a name="AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS"></a>

```typescript
public readonly AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_METERING_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MARKETPLACE_METERING_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_METERING_FULL_ACCESS"></a>

```typescript
public readonly AWS_MARKETPLACE_METERING_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_METERING_REGISTER_USAGE`<sup>Required</sup> <a name="AWS_MARKETPLACE_METERING_REGISTER_USAGE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_METERING_REGISTER_USAGE"></a>

```typescript
public readonly AWS_MARKETPLACE_METERING_REGISTER_USAGE: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS"></a>

```typescript
public readonly AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_READ_ONLY`<sup>Required</sup> <a name="AWS_MARKETPLACE_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_READ_ONLY"></a>

```typescript
public readonly AWS_MARKETPLACE_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_SELLER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MARKETPLACE_SELLER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_FULL_ACCESS"></a>

```typescript
public readonly AWS_MARKETPLACE_SELLER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_SELLER_OFFER_MANAGEMENT`<sup>Required</sup> <a name="AWS_MARKETPLACE_SELLER_OFFER_MANAGEMENT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_OFFER_MANAGEMENT"></a>

```typescript
public readonly AWS_MARKETPLACE_SELLER_OFFER_MANAGEMENT: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS"></a>

```typescript
public readonly AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY`<sup>Required</sup> <a name="AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY"></a>

```typescript
public readonly AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_FULL_ACCESS"></a>

```typescript
public readonly AWS_MIGRATION_HUB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY"></a>

```typescript
public readonly AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN"></a>

```typescript
public readonly AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_REFACTOR_SPACES_ENVIRONMENTS_WITHOUT_BRIDGES_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_REFACTOR_SPACES_ENVIRONMENTS_WITHOUT_BRIDGES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_REFACTOR_SPACES_ENVIRONMENTS_WITHOUT_BRIDGES_FULL_ACCESS"></a>

```typescript
public readonly AWS_MIGRATION_HUB_REFACTOR_SPACES_ENVIRONMENTS_WITHOUT_BRIDGES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS"></a>

```typescript
public readonly AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_STRATEGY_COLLECTOR`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_STRATEGY_COLLECTOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_STRATEGY_COLLECTOR"></a>

```typescript
public readonly AWS_MIGRATION_HUB_STRATEGY_COLLECTOR: string;
```

- *Type:* string

---

##### `AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_NETWORK_MANAGER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_NETWORK_MANAGER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_NETWORK_MANAGER_FULL_ACCESS"></a>

```typescript
public readonly AWS_NETWORK_MANAGER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_NETWORK_MANAGER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_NETWORK_MANAGER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_NETWORK_MANAGER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_NETWORK_MANAGER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_OPS_WORKS_CLOUD_WATCH_LOGS`<sup>Required</sup> <a name="AWS_OPS_WORKS_CLOUD_WATCH_LOGS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_CLOUD_WATCH_LOGS"></a>

```typescript
public readonly AWS_OPS_WORKS_CLOUD_WATCH_LOGS: string;
```

- *Type:* string

---

##### `AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE`<sup>Required</sup> <a name="AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE"></a>

```typescript
public readonly AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE: string;
```

- *Type:* string

---

##### `AWS_OPS_WORKS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_OPS_WORKS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_FULL_ACCESS"></a>

```typescript
public readonly AWS_OPS_WORKS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_OPS_WORKS_INSTANCE_REGISTRATION`<sup>Required</sup> <a name="AWS_OPS_WORKS_INSTANCE_REGISTRATION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_INSTANCE_REGISTRATION"></a>

```typescript
public readonly AWS_OPS_WORKS_INSTANCE_REGISTRATION: string;
```

- *Type:* string

---

##### `AWS_OPS_WORKS_REGISTER_CLI_EC2`<sup>Required</sup> <a name="AWS_OPS_WORKS_REGISTER_CLI_EC2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_REGISTER_CLI_EC2"></a>

```typescript
public readonly AWS_OPS_WORKS_REGISTER_CLI_EC2: string;
```

- *Type:* string

---

##### `AWS_OPS_WORKS_REGISTER_CLI_ON_PREMISES`<sup>Required</sup> <a name="AWS_OPS_WORKS_REGISTER_CLI_ON_PREMISES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OPS_WORKS_REGISTER_CLI_ON_PREMISES"></a>

```typescript
public readonly AWS_OPS_WORKS_REGISTER_CLI_ON_PREMISES: string;
```

- *Type:* string

---

##### `AWS_ORGANIZATIONS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ORGANIZATIONS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ORGANIZATIONS_FULL_ACCESS"></a>

```typescript
public readonly AWS_ORGANIZATIONS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ORGANIZATIONS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ORGANIZATIONS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ORGANIZATIONS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ORGANIZATIONS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY`<sup>Required</sup> <a name="AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY"></a>

```typescript
public readonly AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY: string;
```

- *Type:* string

---

##### `AWS_PANORAMA_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PANORAMA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PANORAMA_FULL_ACCESS"></a>

```typescript
public readonly AWS_PANORAMA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PARTNER_CENTRAL_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PARTNER_CENTRAL_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_FULL_ACCESS"></a>

```typescript
public readonly AWS_PARTNER_CENTRAL_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PARTNER_CENTRAL_OPPORTUNITY_MANAGEMENT`<sup>Required</sup> <a name="AWS_PARTNER_CENTRAL_OPPORTUNITY_MANAGEMENT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_OPPORTUNITY_MANAGEMENT"></a>

```typescript
public readonly AWS_PARTNER_CENTRAL_OPPORTUNITY_MANAGEMENT: string;
```

- *Type:* string

---

##### `AWS_PARTNER_CENTRAL_SANDBOX_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PARTNER_CENTRAL_SANDBOX_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_SANDBOX_FULL_ACCESS"></a>

```typescript
public readonly AWS_PARTNER_CENTRAL_SANDBOX_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PARTNER_CENTRAL_SELLING_RESOURCE_SNAPSHOT_JOB_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_PARTNER_CENTRAL_SELLING_RESOURCE_SNAPSHOT_JOB_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_CENTRAL_SELLING_RESOURCE_SNAPSHOT_JOB_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly AWS_PARTNER_CENTRAL_SELLING_RESOURCE_SNAPSHOT_JOB_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_PARTNER_LED_SUPPORT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_PARTNER_LED_SUPPORT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PARTNER_LED_SUPPORT_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_PARTNER_LED_SUPPORT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PRICE_LIST_SERVICE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PRICE_LIST_SERVICE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRICE_LIST_SERVICE_FULL_ACCESS"></a>

```typescript
public readonly AWS_PRICE_LIST_SERVICE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_CA_AUDITOR`<sup>Required</sup> <a name="AWS_PRIVATE_CA_AUDITOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_AUDITOR"></a>

```typescript
public readonly AWS_PRIVATE_CA_AUDITOR: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_CA_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PRIVATE_CA_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_FULL_ACCESS"></a>

```typescript
public readonly AWS_PRIVATE_CA_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_CA_PRIVILEGED_USER`<sup>Required</sup> <a name="AWS_PRIVATE_CA_PRIVILEGED_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_PRIVILEGED_USER"></a>

```typescript
public readonly AWS_PRIVATE_CA_PRIVILEGED_USER: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_CA_READ_ONLY`<sup>Required</sup> <a name="AWS_PRIVATE_CA_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_READ_ONLY"></a>

```typescript
public readonly AWS_PRIVATE_CA_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_CA_USER`<sup>Required</sup> <a name="AWS_PRIVATE_CA_USER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_CA_USER"></a>

```typescript
public readonly AWS_PRIVATE_CA_USER: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS"></a>

```typescript
public readonly AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PRIVATE_MARKETPLACE_REQUESTS`<sup>Required</sup> <a name="AWS_PRIVATE_MARKETPLACE_REQUESTS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PRIVATE_MARKETPLACE_REQUESTS"></a>

```typescript
public readonly AWS_PRIVATE_MARKETPLACE_REQUESTS: string;
```

- *Type:* string

---

##### `AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS`<sup>Required</sup> <a name="AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS"></a>

```typescript
public readonly AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PROTON_DEVELOPER_ACCESS`<sup>Required</sup> <a name="AWS_PROTON_DEVELOPER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_DEVELOPER_ACCESS"></a>

```typescript
public readonly AWS_PROTON_DEVELOPER_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PROTON_FULL_ACCESS`<sup>Required</sup> <a name="AWS_PROTON_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_FULL_ACCESS"></a>

```typescript
public readonly AWS_PROTON_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PROTON_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_PROTON_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PROTON_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_PROTON_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY`<sup>Required</sup> <a name="AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY"></a>

```typescript
public readonly AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_CFGC_PACKS_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_CFGC_PACKS_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_CFGC_PACKS_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AWS_QUICK_SETUP_CFGC_PACKS_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_DEPLOYMENT_ROLE_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_DEPLOYMENT_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_DEPLOYMENT_ROLE_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_DEPLOYMENT_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_DEV_OPS_GURU_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_DEV_OPS_GURU_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_DEV_OPS_GURU_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AWS_QUICK_SETUP_DEV_OPS_GURU_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_DISTRIBUTOR_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_DISTRIBUTOR_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_DISTRIBUTOR_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AWS_QUICK_SETUP_DISTRIBUTOR_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_ENABLE_AREX_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_ENABLE_AREX_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_ENABLE_AREX_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_ENABLE_AREX_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_ENABLE_DHMC_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_ENABLE_DHMC_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_ENABLE_DHMC_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_ENABLE_DHMC_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_MANAGED_INSTANCE_PROFILE_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_MANAGED_INSTANCE_PROFILE_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_MANAGED_INSTANCE_PROFILE_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_MANAGED_INSTANCE_PROFILE_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_PATCH_POLICY_BASELINE_ACCESS`<sup>Required</sup> <a name="AWS_QUICK_SETUP_PATCH_POLICY_BASELINE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_PATCH_POLICY_BASELINE_ACCESS"></a>

```typescript
public readonly AWS_QUICK_SETUP_PATCH_POLICY_BASELINE_ACCESS: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_PATCH_POLICY_DEPLOYMENT_ROLE_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_PATCH_POLICY_DEPLOYMENT_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_PATCH_POLICY_DEPLOYMENT_ROLE_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_PATCH_POLICY_DEPLOYMENT_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_PATCH_POLICY_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_PATCH_POLICY_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_PATCH_POLICY_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AWS_QUICK_SETUP_PATCH_POLICY_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_SCHEDULER_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_SCHEDULER_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SCHEDULER_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AWS_QUICK_SETUP_SCHEDULER_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_SSM_DEPLOYMENT_ROLE_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_SSM_DEPLOYMENT_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_DEPLOYMENT_ROLE_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_SSM_DEPLOYMENT_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_SSM_DEPLOYMENT_S3_BUCKET_ROLE_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_SSM_DEPLOYMENT_S3_BUCKET_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_DEPLOYMENT_S3_BUCKET_ROLE_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_SSM_DEPLOYMENT_S3_BUCKET_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_SSM_HOST_MGMT_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_SSM_HOST_MGMT_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_HOST_MGMT_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly AWS_QUICK_SETUP_SSM_HOST_MGMT_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_SSM_LIFECYCLE_MANAGEMENT_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_SSM_LIFECYCLE_MANAGEMENT_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_LIFECYCLE_MANAGEMENT_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_SSM_LIFECYCLE_MANAGEMENT_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SETUP_SSM_MANAGE_RESOURCES_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SETUP_SSM_MANAGE_RESOURCES_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SETUP_SSM_MANAGE_RESOURCES_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_QUICK_SETUP_SSM_MANAGE_RESOURCES_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SIGHT_ASSET_BUNDLE_EXPORT_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SIGHT_ASSET_BUNDLE_EXPORT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SIGHT_ASSET_BUNDLE_EXPORT_POLICY"></a>

```typescript
public readonly AWS_QUICK_SIGHT_ASSET_BUNDLE_EXPORT_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SIGHT_ASSET_BUNDLE_IMPORT_POLICY`<sup>Required</sup> <a name="AWS_QUICK_SIGHT_ASSET_BUNDLE_IMPORT_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SIGHT_ASSET_BUNDLE_IMPORT_POLICY"></a>

```typescript
public readonly AWS_QUICK_SIGHT_ASSET_BUNDLE_IMPORT_POLICY: string;
```

- *Type:* string

---

##### `AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS`<sup>Required</sup> <a name="AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS"></a>

```typescript
public readonly AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS: string;
```

- *Type:* string

---

##### `AWS_REFACTORING_TOOLKIT_FULL_ACCESS`<sup>Required</sup> <a name="AWS_REFACTORING_TOOLKIT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_REFACTORING_TOOLKIT_FULL_ACCESS"></a>

```typescript
public readonly AWS_REFACTORING_TOOLKIT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY`<sup>Required</sup> <a name="AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY"></a>

```typescript
public readonly AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY: string;
```

- *Type:* string

---

##### `AWS_REPOST_SPACE_SUPPORT_OPERATIONS_POLICY`<sup>Required</sup> <a name="AWS_REPOST_SPACE_SUPPORT_OPERATIONS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_REPOST_SPACE_SUPPORT_OPERATIONS_POLICY"></a>

```typescript
public readonly AWS_REPOST_SPACE_SUPPORT_OPERATIONS_POLICY: string;
```

- *Type:* string

---

##### `AWS_RESILIENCE_HUB_ASSSESSMENT_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_RESILIENCE_HUB_ASSSESSMENT_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESILIENCE_HUB_ASSSESSMENT_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_RESILIENCE_HUB_ASSSESSMENT_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_EXPLORER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_EXPLORER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_EXPLORER_FULL_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_EXPLORER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_EXPLORER_ORGANIZATIONS_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_EXPLORER_ORGANIZATIONS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_EXPLORER_ORGANIZATIONS_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_EXPLORER_ORGANIZATIONS_ACCESS: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ROBO_MAKER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_ROBO_MAKER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ROBO_MAKER_FULL_ACCESS"></a>

```typescript
public readonly AWS_ROBO_MAKER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ROBO_MAKER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_ROBO_MAKER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ROBO_MAKER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_ROBO_MAKER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_ROBO_MAKER_SERVICE_ROLE_POLICY`<sup>Required</sup> <a name="AWS_ROBO_MAKER_SERVICE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_ROBO_MAKER_SERVICE_ROLE_POLICY"></a>

```typescript
public readonly AWS_ROBO_MAKER_SERVICE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SAVINGS_PLANS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SAVINGS_PLANS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SAVINGS_PLANS_FULL_ACCESS"></a>

```typescript
public readonly AWS_SAVINGS_PLANS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SAVINGS_PLANS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SAVINGS_PLANS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SAVINGS_PLANS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SAVINGS_PLANS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SECURITY_HUB_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SECURITY_HUB_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_HUB_FULL_ACCESS"></a>

```typescript
public readonly AWS_SECURITY_HUB_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS`<sup>Required</sup> <a name="AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS"></a>

```typescript
public readonly AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SECURITY_HUB_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SECURITY_HUB_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_HUB_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SECURITY_HUB_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SECURITY_INCIDENT_RESPONSE_CASE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SECURITY_INCIDENT_RESPONSE_CASE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_INCIDENT_RESPONSE_CASE_FULL_ACCESS"></a>

```typescript
public readonly AWS_SECURITY_INCIDENT_RESPONSE_CASE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SECURITY_INCIDENT_RESPONSE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SECURITY_INCIDENT_RESPONSE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_INCIDENT_RESPONSE_FULL_ACCESS"></a>

```typescript
public readonly AWS_SECURITY_INCIDENT_RESPONSE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SECURITY_INCIDENT_RESPONSE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SECURITY_INCIDENT_RESPONSE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SECURITY_INCIDENT_RESPONSE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SECURITY_INCIDENT_RESPONSE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS"></a>

```typescript
public readonly AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS"></a>

```typescript
public readonly AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS"></a>

```typescript
public readonly AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SSM_AUTOMATION_DIAGNOSIS_BUCKET_POLICY`<sup>Required</sup> <a name="AWS_SSM_AUTOMATION_DIAGNOSIS_BUCKET_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_AUTOMATION_DIAGNOSIS_BUCKET_POLICY"></a>

```typescript
public readonly AWS_SSM_AUTOMATION_DIAGNOSIS_BUCKET_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSM_DIAGNOSIS_AUTOMATION_ADMINISTRATION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_SSM_DIAGNOSIS_AUTOMATION_ADMINISTRATION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_DIAGNOSIS_AUTOMATION_ADMINISTRATION_ROLE_POLICY"></a>

```typescript
public readonly AWS_SSM_DIAGNOSIS_AUTOMATION_ADMINISTRATION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSM_DIAGNOSIS_AUTOMATION_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_SSM_DIAGNOSIS_AUTOMATION_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_DIAGNOSIS_AUTOMATION_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly AWS_SSM_DIAGNOSIS_AUTOMATION_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSM_DIAGNOSIS_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_SSM_DIAGNOSIS_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_DIAGNOSIS_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY"></a>

```typescript
public readonly AWS_SSM_DIAGNOSIS_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSM_REMEDIATION_AUTOMATION_ADMINISTRATION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_SSM_REMEDIATION_AUTOMATION_ADMINISTRATION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_REMEDIATION_AUTOMATION_ADMINISTRATION_ROLE_POLICY"></a>

```typescript
public readonly AWS_SSM_REMEDIATION_AUTOMATION_ADMINISTRATION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSM_REMEDIATION_AUTOMATION_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_SSM_REMEDIATION_AUTOMATION_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_REMEDIATION_AUTOMATION_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly AWS_SSM_REMEDIATION_AUTOMATION_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSM_REMEDIATION_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY`<sup>Required</sup> <a name="AWS_SSM_REMEDIATION_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSM_REMEDIATION_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY"></a>

```typescript
public readonly AWS_SSM_REMEDIATION_AUTOMATION_OPERATIONAL_ACCOUNT_ADMINISTRATION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `AWS_SSO_DIRECTORY_ADMINISTRATOR`<sup>Required</sup> <a name="AWS_SSO_DIRECTORY_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_DIRECTORY_ADMINISTRATOR"></a>

```typescript
public readonly AWS_SSO_DIRECTORY_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AWS_SSO_DIRECTORY_READ_ONLY`<sup>Required</sup> <a name="AWS_SSO_DIRECTORY_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_DIRECTORY_READ_ONLY"></a>

```typescript
public readonly AWS_SSO_DIRECTORY_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_SSO_MASTER_ACCOUNT_ADMINISTRATOR`<sup>Required</sup> <a name="AWS_SSO_MASTER_ACCOUNT_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_MASTER_ACCOUNT_ADMINISTRATOR"></a>

```typescript
public readonly AWS_SSO_MASTER_ACCOUNT_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AWS_SSO_MEMBER_ACCOUNT_ADMINISTRATOR`<sup>Required</sup> <a name="AWS_SSO_MEMBER_ACCOUNT_ADMINISTRATOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_MEMBER_ACCOUNT_ADMINISTRATOR"></a>

```typescript
public readonly AWS_SSO_MEMBER_ACCOUNT_ADMINISTRATOR: string;
```

- *Type:* string

---

##### `AWS_SSO_READ_ONLY`<sup>Required</sup> <a name="AWS_SSO_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SSO_READ_ONLY"></a>

```typescript
public readonly AWS_SSO_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_STEP_FUNCTIONS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_STEP_FUNCTIONS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STEP_FUNCTIONS_FULL_ACCESS"></a>

```typescript
public readonly AWS_STEP_FUNCTIONS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_STORAGE_GATEWAY_FULL_ACCESS`<sup>Required</sup> <a name="AWS_STORAGE_GATEWAY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STORAGE_GATEWAY_FULL_ACCESS"></a>

```typescript
public readonly AWS_STORAGE_GATEWAY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SUPPORT_ACCESS`<sup>Required</sup> <a name="AWS_SUPPORT_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_ACCESS"></a>

```typescript
public readonly AWS_SUPPORT_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SUPPORT_APP_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SUPPORT_APP_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_APP_FULL_ACCESS"></a>

```typescript
public readonly AWS_SUPPORT_APP_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SUPPORT_APP_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SUPPORT_APP_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_APP_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SUPPORT_APP_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SUPPORT_PLANS_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SUPPORT_PLANS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_PLANS_FULL_ACCESS"></a>

```typescript
public readonly AWS_SUPPORT_PLANS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SUPPORT_PLANS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SUPPORT_PLANS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SUPPORT_PLANS_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SUPPORT_PLANS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SYSTEMS_MANAGER_ENABLE_CONFIG_RECORDING_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_SYSTEMS_MANAGER_ENABLE_CONFIG_RECORDING_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_ENABLE_CONFIG_RECORDING_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_SYSTEMS_MANAGER_ENABLE_CONFIG_RECORDING_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_SYSTEMS_MANAGER_ENABLE_EXPLORER_EXECUTION_POLICY`<sup>Required</sup> <a name="AWS_SYSTEMS_MANAGER_ENABLE_EXPLORER_EXECUTION_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_ENABLE_EXPLORER_EXECUTION_POLICY"></a>

```typescript
public readonly AWS_SYSTEMS_MANAGER_ENABLE_EXPLORER_EXECUTION_POLICY: string;
```

- *Type:* string

---

##### `AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS`<sup>Required</sup> <a name="AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS"></a>

```typescript
public readonly AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_ASSET_SERVER_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_ASSET_SERVER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_ASSET_SERVER_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_ASSET_SERVER_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY: string;
```

- *Type:* string

---

##### `AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY`<sup>Required</sup> <a name="AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY"></a>

```typescript
public readonly AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY: string;
```

- *Type:* string

---

##### `AWS_TRANSFER_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_TRANSFER_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRANSFER_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_TRANSFER_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_TRANSFER_FULL_ACCESS`<sup>Required</sup> <a name="AWS_TRANSFER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRANSFER_FULL_ACCESS"></a>

```typescript
public readonly AWS_TRANSFER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_TRANSFER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_TRANSFER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRANSFER_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_TRANSFER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS`<sup>Required</sup> <a name="AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS"></a>

```typescript
public readonly AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS`<sup>Required</sup> <a name="AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS"></a>

```typescript
public readonly AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY`<sup>Required</sup> <a name="AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY"></a>

```typescript
public readonly AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS`<sup>Required</sup> <a name="AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS"></a>

```typescript
public readonly AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY`<sup>Required</sup> <a name="AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY"></a>

```typescript
public readonly AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY: string;
```

- *Type:* string

---

##### `AWS_WAF_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="AWS_WAF_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly AWS_WAF_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_WAF_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_WAF_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_WAF_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_WAF_FULL_ACCESS`<sup>Required</sup> <a name="AWS_WAF_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_FULL_ACCESS"></a>

```typescript
public readonly AWS_WAF_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_WAF_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_WAF_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WAF_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_WAF_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_WICKR_FULL_ACCESS`<sup>Required</sup> <a name="AWS_WICKR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_WICKR_FULL_ACCESS"></a>

```typescript
public readonly AWS_WICKR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_X_RAY_DAEMON_WRITE_ACCESS`<sup>Required</sup> <a name="AWS_X_RAY_DAEMON_WRITE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_X_RAY_DAEMON_WRITE_ACCESS"></a>

```typescript
public readonly AWS_X_RAY_DAEMON_WRITE_ACCESS: string;
```

- *Type:* string

---

##### `AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION`<sup>Required</sup> <a name="AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION"></a>

```typescript
public readonly AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION: string;
```

- *Type:* string

---

##### `AWS_XRAY_FULL_ACCESS`<sup>Required</sup> <a name="AWS_XRAY_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_FULL_ACCESS"></a>

```typescript
public readonly AWS_XRAY_FULL_ACCESS: string;
```

- *Type:* string

---

##### `AWS_XRAY_READ_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_XRAY_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_READ_ONLY_ACCESS"></a>

```typescript
public readonly AWS_XRAY_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `AWS_XRAY_WRITE_ONLY_ACCESS`<sup>Required</sup> <a name="AWS_XRAY_WRITE_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.AWS_XRAY_WRITE_ONLY_ACCESS"></a>

```typescript
public readonly AWS_XRAY_WRITE_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_FRONT_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_FRONT_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_FRONT_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_FRONT_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_FRONT_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_FRONT_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_FRONT_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_FRONT_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_SEARCH_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_SEARCH_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_SEARCH_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_SEARCH_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_SEARCH_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_SEARCH_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_SEARCH_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_SEARCH_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_ACTIONS_EC2_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_ACTIONS_EC2_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_ACTIONS_EC2_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_ACTIONS_EC2_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_AGENT_ADMIN_POLICY`<sup>Required</sup> <a name="CLOUD_WATCH_AGENT_ADMIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_AGENT_ADMIN_POLICY"></a>

```typescript
public readonly CLOUD_WATCH_AGENT_ADMIN_POLICY: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_AGENT_SERVER_POLICY`<sup>Required</sup> <a name="CLOUD_WATCH_AGENT_SERVER_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_AGENT_SERVER_POLICY"></a>

```typescript
public readonly CLOUD_WATCH_AGENT_SERVER_POLICY: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_APPLICATION_SIGNALS_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_APPLICATION_SIGNALS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_SIGNALS_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_APPLICATION_SIGNALS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_APPLICATION_SIGNALS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_APPLICATION_SIGNALS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_APPLICATION_SIGNALS_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_APPLICATION_SIGNALS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION`<sup>Required</sup> <a name="CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION"></a>

```typescript
public readonly CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_EVENTS_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_EVENTS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_EVENTS_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_EVENTS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_FULL_ACCESS_V2`<sup>Required</sup> <a name="CLOUD_WATCH_FULL_ACCESS_V2" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_FULL_ACCESS_V2"></a>

```typescript
public readonly CLOUD_WATCH_FULL_ACCESS_V2: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_INTERNET_MONITOR_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_INTERNET_MONITOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_INTERNET_MONITOR_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_INTERNET_MONITOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_INTERNET_MONITOR_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_INTERNET_MONITOR_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_INTERNET_MONITOR_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_INTERNET_MONITOR_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_LAMBDA_APPLICATION_SIGNALS_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="CLOUD_WATCH_LAMBDA_APPLICATION_SIGNALS_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LAMBDA_APPLICATION_SIGNALS_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly CLOUD_WATCH_LAMBDA_APPLICATION_SIGNALS_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY`<sup>Required</sup> <a name="CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY"></a>

```typescript
public readonly CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION`<sup>Required</sup> <a name="CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION"></a>

```typescript
public readonly CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_LOGS_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_LOGS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LOGS_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_LOGS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_LOGS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_LOGS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_LOGS_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_LOGS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_NETWORK_FLOW_MONITOR_AGENT_PUBLISH_POLICY`<sup>Required</sup> <a name="CLOUD_WATCH_NETWORK_FLOW_MONITOR_AGENT_PUBLISH_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_NETWORK_FLOW_MONITOR_AGENT_PUBLISH_POLICY"></a>

```typescript
public readonly CLOUD_WATCH_NETWORK_FLOW_MONITOR_AGENT_PUBLISH_POLICY: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_OPEN_SEARCH_DASHBOARD_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_OPEN_SEARCH_DASHBOARD_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_OPEN_SEARCH_DASHBOARD_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_OPEN_SEARCH_DASHBOARD_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_OPEN_SEARCH_DASHBOARDS_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_OPEN_SEARCH_DASHBOARDS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_OPEN_SEARCH_DASHBOARDS_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_OPEN_SEARCH_DASHBOARDS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_SYNTHETICS_FULL_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_SYNTHETICS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_SYNTHETICS_FULL_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_SYNTHETICS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS"></a>

```typescript
public readonly CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `COMPREHEND_FULL_ACCESS`<sup>Required</sup> <a name="COMPREHEND_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPREHEND_FULL_ACCESS"></a>

```typescript
public readonly COMPREHEND_FULL_ACCESS: string;
```

- *Type:* string

---

##### `COMPREHEND_MEDICAL_FULL_ACCESS`<sup>Required</sup> <a name="COMPREHEND_MEDICAL_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPREHEND_MEDICAL_FULL_ACCESS"></a>

```typescript
public readonly COMPREHEND_MEDICAL_FULL_ACCESS: string;
```

- *Type:* string

---

##### `COMPREHEND_READ_ONLY`<sup>Required</sup> <a name="COMPREHEND_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPREHEND_READ_ONLY"></a>

```typescript
public readonly COMPREHEND_READ_ONLY: string;
```

- *Type:* string

---

##### `COMPUTE_OPTIMIZER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="COMPUTE_OPTIMIZER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COMPUTE_OPTIMIZER_READ_ONLY_ACCESS"></a>

```typescript
public readonly COMPUTE_OPTIMIZER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `COST_OPTIMIZATION_HUB_ADMIN_ACCESS`<sup>Required</sup> <a name="COST_OPTIMIZATION_HUB_ADMIN_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COST_OPTIMIZATION_HUB_ADMIN_ACCESS"></a>

```typescript
public readonly COST_OPTIMIZATION_HUB_ADMIN_ACCESS: string;
```

- *Type:* string

---

##### `COST_OPTIMIZATION_HUB_READ_ONLY_ACCESS`<sup>Required</sup> <a name="COST_OPTIMIZATION_HUB_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.COST_OPTIMIZATION_HUB_READ_ONLY_ACCESS"></a>

```typescript
public readonly COST_OPTIMIZATION_HUB_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `EC2_FAST_LAUNCH_FULL_ACCESS`<sup>Required</sup> <a name="EC2_FAST_LAUNCH_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_FAST_LAUNCH_FULL_ACCESS"></a>

```typescript
public readonly EC2_FAST_LAUNCH_FULL_ACCESS: string;
```

- *Type:* string

---

##### `EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS`<sup>Required</sup> <a name="EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS"></a>

```typescript
public readonly EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS: string;
```

- *Type:* string

---

##### `EC2_INSTANCE_CONNECT`<sup>Required</sup> <a name="EC2_INSTANCE_CONNECT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_INSTANCE_CONNECT"></a>

```typescript
public readonly EC2_INSTANCE_CONNECT: string;
```

- *Type:* string

---

##### `EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER`<sup>Required</sup> <a name="EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER"></a>

```typescript
public readonly EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER: string;
```

- *Type:* string

---

##### `EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS`<sup>Required</sup> <a name="EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS"></a>

```typescript
public readonly EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS: string;
```

- *Type:* string

---

##### `ELASTIC_LOAD_BALANCING_FULL_ACCESS`<sup>Required</sup> <a name="ELASTIC_LOAD_BALANCING_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELASTIC_LOAD_BALANCING_FULL_ACCESS"></a>

```typescript
public readonly ELASTIC_LOAD_BALANCING_FULL_ACCESS: string;
```

- *Type:* string

---

##### `ELASTIC_LOAD_BALANCING_READ_ONLY`<sup>Required</sup> <a name="ELASTIC_LOAD_BALANCING_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELASTIC_LOAD_BALANCING_READ_ONLY"></a>

```typescript
public readonly ELASTIC_LOAD_BALANCING_READ_ONLY: string;
```

- *Type:* string

---

##### `ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS`<sup>Required</sup> <a name="ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS"></a>

```typescript
public readonly ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS: string;
```

- *Type:* string

---

##### `ELEMENTAL_ACTIVATIONS_FULL_ACCESS`<sup>Required</sup> <a name="ELEMENTAL_ACTIVATIONS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_FULL_ACCESS"></a>

```typescript
public readonly ELEMENTAL_ACTIVATIONS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES`<sup>Required</sup> <a name="ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES"></a>

```typescript
public readonly ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES: string;
```

- *Type:* string

---

##### `ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS"></a>

```typescript
public readonly ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS`<sup>Required</sup> <a name="ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS"></a>

```typescript
public readonly ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS"></a>

```typescript
public readonly ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS`<sup>Required</sup> <a name="ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS"></a>

```typescript
public readonly ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `GAME_LIFT_CONTAINER_FLEET_POLICY`<sup>Required</sup> <a name="GAME_LIFT_CONTAINER_FLEET_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GAME_LIFT_CONTAINER_FLEET_POLICY"></a>

```typescript
public readonly GAME_LIFT_CONTAINER_FLEET_POLICY: string;
```

- *Type:* string

---

##### `GAME_LIFT_GAME_SERVER_GROUP_POLICY`<sup>Required</sup> <a name="GAME_LIFT_GAME_SERVER_GROUP_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GAME_LIFT_GAME_SERVER_GROUP_POLICY"></a>

```typescript
public readonly GAME_LIFT_GAME_SERVER_GROUP_POLICY: string;
```

- *Type:* string

---

##### `GLOBAL_ACCELERATOR_FULL_ACCESS`<sup>Required</sup> <a name="GLOBAL_ACCELERATOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GLOBAL_ACCELERATOR_FULL_ACCESS"></a>

```typescript
public readonly GLOBAL_ACCELERATOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `GLOBAL_ACCELERATOR_READ_ONLY_ACCESS`<sup>Required</sup> <a name="GLOBAL_ACCELERATOR_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GLOBAL_ACCELERATOR_READ_ONLY_ACCESS"></a>

```typescript
public readonly GLOBAL_ACCELERATOR_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `IAM_ACCESS_ADVISOR_READ_ONLY`<sup>Required</sup> <a name="IAM_ACCESS_ADVISOR_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_ACCESS_ADVISOR_READ_ONLY"></a>

```typescript
public readonly IAM_ACCESS_ADVISOR_READ_ONLY: string;
```

- *Type:* string

---

##### `IAM_ACCESS_ANALYZER_FULL_ACCESS`<sup>Required</sup> <a name="IAM_ACCESS_ANALYZER_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_ACCESS_ANALYZER_FULL_ACCESS"></a>

```typescript
public readonly IAM_ACCESS_ANALYZER_FULL_ACCESS: string;
```

- *Type:* string

---

##### `IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS`<sup>Required</sup> <a name="IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS"></a>

```typescript
public readonly IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `IAM_FULL_ACCESS`<sup>Required</sup> <a name="IAM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_FULL_ACCESS"></a>

```typescript
public readonly IAM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `IAM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="IAM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_READ_ONLY_ACCESS"></a>

```typescript
public readonly IAM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS`<sup>Required</sup> <a name="IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS"></a>

```typescript
public readonly IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS: string;
```

- *Type:* string

---

##### `IAM_USER_CHANGE_PASSWORD`<sup>Required</sup> <a name="IAM_USER_CHANGE_PASSWORD" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_USER_CHANGE_PASSWORD"></a>

```typescript
public readonly IAM_USER_CHANGE_PASSWORD: string;
```

- *Type:* string

---

##### `IAM_USER_SSH_KEYS`<sup>Required</sup> <a name="IAM_USER_SSH_KEYS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IAM_USER_SSH_KEYS"></a>

```typescript
public readonly IAM_USER_SSH_KEYS: string;
```

- *Type:* string

---

##### `IVS_FULL_ACCESS`<sup>Required</sup> <a name="IVS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IVS_FULL_ACCESS"></a>

```typescript
public readonly IVS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `IVS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="IVS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.IVS_READ_ONLY_ACCESS"></a>

```typescript
public readonly IVS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `MEDIA_CONNECT_GATEWAY_INSTANCE_ROLE_POLICY`<sup>Required</sup> <a name="MEDIA_CONNECT_GATEWAY_INSTANCE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.MEDIA_CONNECT_GATEWAY_INSTANCE_ROLE_POLICY"></a>

```typescript
public readonly MEDIA_CONNECT_GATEWAY_INSTANCE_ROLE_POLICY: string;
```

- *Type:* string

---

##### `NEPTUNE_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="NEPTUNE_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly NEPTUNE_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `NEPTUNE_FULL_ACCESS`<sup>Required</sup> <a name="NEPTUNE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_FULL_ACCESS"></a>

```typescript
public readonly NEPTUNE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `NEPTUNE_GRAPH_READ_ONLY_ACCESS`<sup>Required</sup> <a name="NEPTUNE_GRAPH_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_GRAPH_READ_ONLY_ACCESS"></a>

```typescript
public readonly NEPTUNE_GRAPH_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `NEPTUNE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="NEPTUNE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.NEPTUNE_READ_ONLY_ACCESS"></a>

```typescript
public readonly NEPTUNE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `OAM_FULL_ACCESS`<sup>Required</sup> <a name="OAM_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.OAM_FULL_ACCESS"></a>

```typescript
public readonly OAM_FULL_ACCESS: string;
```

- *Type:* string

---

##### `OAM_READ_ONLY_ACCESS`<sup>Required</sup> <a name="OAM_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.OAM_READ_ONLY_ACCESS"></a>

```typescript
public readonly OAM_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `PARTNER_CENTRAL_ACCOUNT_MANAGEMENT_USER_ROLE_ASSOCIATION`<sup>Required</sup> <a name="PARTNER_CENTRAL_ACCOUNT_MANAGEMENT_USER_ROLE_ASSOCIATION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.PARTNER_CENTRAL_ACCOUNT_MANAGEMENT_USER_ROLE_ASSOCIATION"></a>

```typescript
public readonly PARTNER_CENTRAL_ACCOUNT_MANAGEMENT_USER_ROLE_ASSOCIATION: string;
```

- *Type:* string

---

##### `POWER_USER_ACCESS`<sup>Required</sup> <a name="POWER_USER_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.POWER_USER_ACCESS"></a>

```typescript
public readonly POWER_USER_ACCESS: string;
```

- *Type:* string

---

##### `Q_BUSINESS_QUICKSIGHT_PLUGIN_POLICY`<sup>Required</sup> <a name="Q_BUSINESS_QUICKSIGHT_PLUGIN_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.Q_BUSINESS_QUICKSIGHT_PLUGIN_POLICY"></a>

```typescript
public readonly Q_BUSINESS_QUICKSIGHT_PLUGIN_POLICY: string;
```

- *Type:* string

---

##### `READ_ONLY_ACCESS`<sup>Required</sup> <a name="READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.READ_ONLY_ACCESS"></a>

```typescript
public readonly READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `RESOURCE_GROUPS_AND_TAG_EDITOR_FULL_ACCESS`<sup>Required</sup> <a name="RESOURCE_GROUPS_AND_TAG_EDITOR_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.RESOURCE_GROUPS_AND_TAG_EDITOR_FULL_ACCESS"></a>

```typescript
public readonly RESOURCE_GROUPS_AND_TAG_EDITOR_FULL_ACCESS: string;
```

- *Type:* string

---

##### `RESOURCE_GROUPS_AND_TAG_EDITOR_READ_ONLY_ACCESS`<sup>Required</sup> <a name="RESOURCE_GROUPS_AND_TAG_EDITOR_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.RESOURCE_GROUPS_AND_TAG_EDITOR_READ_ONLY_ACCESS"></a>

```typescript
public readonly RESOURCE_GROUPS_AND_TAG_EDITOR_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `RESOURCE_GROUPS_TAGGING_API_TAG_UNTAG_SUPPORTED_RESOURCES`<sup>Required</sup> <a name="RESOURCE_GROUPS_TAGGING_API_TAG_UNTAG_SUPPORTED_RESOURCES" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.RESOURCE_GROUPS_TAGGING_API_TAG_UNTAG_SUPPORTED_RESOURCES"></a>

```typescript
public readonly RESOURCE_GROUPS_TAGGING_API_TAG_UNTAG_SUPPORTED_RESOURCES: string;
```

- *Type:* string

---

##### `ROSA_MANAGE_SUBSCRIPTION`<sup>Required</sup> <a name="ROSA_MANAGE_SUBSCRIPTION" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.ROSA_MANAGE_SUBSCRIPTION"></a>

```typescript
public readonly ROSA_MANAGE_SUBSCRIPTION: string;
```

- *Type:* string

---

##### `SAGE_MAKER_STUDIO_FULL_ACCESS`<sup>Required</sup> <a name="SAGE_MAKER_STUDIO_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_FULL_ACCESS"></a>

```typescript
public readonly SAGE_MAKER_STUDIO_FULL_ACCESS: string;
```

- *Type:* string

---

##### `SAGE_MAKER_STUDIO_PROJECT_ROLE_MACHINE_LEARNING_POLICY`<sup>Required</sup> <a name="SAGE_MAKER_STUDIO_PROJECT_ROLE_MACHINE_LEARNING_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_PROJECT_ROLE_MACHINE_LEARNING_POLICY"></a>

```typescript
public readonly SAGE_MAKER_STUDIO_PROJECT_ROLE_MACHINE_LEARNING_POLICY: string;
```

- *Type:* string

---

##### `SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_PERMISSIONS_BOUNDARY`<sup>Required</sup> <a name="SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_PERMISSIONS_BOUNDARY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_PERMISSIONS_BOUNDARY"></a>

```typescript
public readonly SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_PERMISSIONS_BOUNDARY: string;
```

- *Type:* string

---

##### `SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_POLICY`<sup>Required</sup> <a name="SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_POLICY"></a>

```typescript
public readonly SAGE_MAKER_STUDIO_PROJECT_USER_ROLE_POLICY: string;
```

- *Type:* string

---

##### `SECRETS_MANAGER_READ_WRITE`<sup>Required</sup> <a name="SECRETS_MANAGER_READ_WRITE" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SECRETS_MANAGER_READ_WRITE"></a>

```typescript
public readonly SECRETS_MANAGER_READ_WRITE: string;
```

- *Type:* string

---

##### `SECURITY_AUDIT`<sup>Required</sup> <a name="SECURITY_AUDIT" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SECURITY_AUDIT"></a>

```typescript
public readonly SECURITY_AUDIT: string;
```

- *Type:* string

---

##### `SERVER_MIGRATION_CONNECTOR`<sup>Required</sup> <a name="SERVER_MIGRATION_CONNECTOR" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVER_MIGRATION_CONNECTOR"></a>

```typescript
public readonly SERVER_MIGRATION_CONNECTOR: string;
```

- *Type:* string

---

##### `SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `SERVICE_QUOTAS_FULL_ACCESS`<sup>Required</sup> <a name="SERVICE_QUOTAS_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVICE_QUOTAS_FULL_ACCESS"></a>

```typescript
public readonly SERVICE_QUOTAS_FULL_ACCESS: string;
```

- *Type:* string

---

##### `SERVICE_QUOTAS_READ_ONLY_ACCESS`<sup>Required</sup> <a name="SERVICE_QUOTAS_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SERVICE_QUOTAS_READ_ONLY_ACCESS"></a>

```typescript
public readonly SERVICE_QUOTAS_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `SIMPLE_WORKFLOW_FULL_ACCESS`<sup>Required</sup> <a name="SIMPLE_WORKFLOW_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.SIMPLE_WORKFLOW_FULL_ACCESS"></a>

```typescript
public readonly SIMPLE_WORKFLOW_FULL_ACCESS: string;
```

- *Type:* string

---

##### `TRANSLATE_FULL_ACCESS`<sup>Required</sup> <a name="TRANSLATE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.TRANSLATE_FULL_ACCESS"></a>

```typescript
public readonly TRANSLATE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `TRANSLATE_READ_ONLY`<sup>Required</sup> <a name="TRANSLATE_READ_ONLY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.TRANSLATE_READ_ONLY"></a>

```typescript
public readonly TRANSLATE_READ_ONLY: string;
```

- *Type:* string

---

##### `VPC_LATTICE_FULL_ACCESS`<sup>Required</sup> <a name="VPC_LATTICE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.VPC_LATTICE_FULL_ACCESS"></a>

```typescript
public readonly VPC_LATTICE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `VPC_LATTICE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="VPC_LATTICE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.VPC_LATTICE_READ_ONLY_ACCESS"></a>

```typescript
public readonly VPC_LATTICE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `VPC_LATTICE_SERVICES_INVOKE_ACCESS`<sup>Required</sup> <a name="VPC_LATTICE_SERVICES_INVOKE_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.VPC_LATTICE_SERVICES_INVOKE_ACCESS"></a>

```typescript
public readonly VPC_LATTICE_SERVICES_INVOKE_ACCESS: string;
```

- *Type:* string

---

##### `WELL_ARCHITECTED_CONSOLE_FULL_ACCESS`<sup>Required</sup> <a name="WELL_ARCHITECTED_CONSOLE_FULL_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.WELL_ARCHITECTED_CONSOLE_FULL_ACCESS"></a>

```typescript
public readonly WELL_ARCHITECTED_CONSOLE_FULL_ACCESS: string;
```

- *Type:* string

---

##### `WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS`<sup>Required</sup> <a name="WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS"></a>

```typescript
public readonly WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS: string;
```

- *Type:* string

---

##### `WORK_LINK_SERVICE_ROLE_POLICY`<sup>Required</sup> <a name="WORK_LINK_SERVICE_ROLE_POLICY" id="@cdklabs/cdk-proserve-lib.types.AwsManagedPolicy.property.WORK_LINK_SERVICE_ROLE_POLICY"></a>

```typescript
public readonly WORK_LINK_SERVICE_ROLE_POLICY: string;
```

- *Type:* string

---

### CreateLambdaLogGroup <a name="CreateLambdaLogGroup" id="@cdklabs/cdk-proserve-lib.aspects.CreateLambdaLogGroup"></a>

- *Implements:* aws-cdk-lib.IAspect

Ensures that Lambda log groups are created for all Lambda functions that the aspect applies to.

*Example*

```typescript
import { App, Aspects } from 'aws-cdk-lib';
import { CreateLambdaLogGroup } from '@cdklabs/cdk-proserve-lib/aspects';

const app = new App();

Aspects.of(app).add(new CreateLambdaLogGroup());
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.CreateLambdaLogGroup.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.CreateLambdaLogGroup()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.CreateLambdaLogGroup.visit">visit</a></code> | Visits a construct and creates a log group if the construct is a Lambda function. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.CreateLambdaLogGroup.visit"></a>

```typescript
public visit(node: IConstruct): void
```

Visits a construct and creates a log group if the construct is a Lambda function.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.CreateLambdaLogGroup.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

The construct being visited.

---




### Ec2AutomatedShutdown <a name="Ec2AutomatedShutdown" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown"></a>

- *Implements:* aws-cdk-lib.IAspect

Automatically shut down EC2 instances when an alarm is triggered based off of a provided metric.

🚩 If you are applying this Aspect to multiple EC2 instances, you
will need to configure the CDK context variable flag
`@aws-cdk/aws-cloudwatch-actions:changeLambdaPermissionLogicalIdForLambdaAction`
set to `true`. If this is not configured, applying this Aspect to multiple
EC2 instances will result in a CDK synth error.

Allows for cost optimization and the reduction of resources not being
actively used. When the EC2 alarm is triggered for a given EC2 instance, it
will automatically trigger a Lambda function to shutdown the instance.

*Example*

```typescript
import { App, Aspects, Duration, Stack } from 'aws-cdk-lib';
import { ComparisonOperator, Stats } from 'aws-cdk-lib/aws-cloudwatch';
import { Instance } from 'aws-cdk-lib/aws-ec2';
import { Ec2AutomatedShutdown } from './src/aspects/ec2-automated-shutdown';

const app = new App({
    context: {
        '@aws-cdk/aws-cloudwatch-actions:changeLambdaPermissionLogicalIdForLambdaAction':
            true
    }
});
const stack = new Stack(app, 'MyStack');

// Create your EC2 instance(s)
const instance = new Instance(stack, 'MyInstance', {
    // instance properties
});

// Apply the aspect to automatically shut down the EC2 instance when underutilized
Aspects.of(stack).add(new Ec2AutomatedShutdown());

// Or with custom configuration
Aspects.of(stack).add(
    new Ec2AutomatedShutdown({
        alarmConfig: {
            metricName: Ec2AutomatedShutdown.Ec2MetricName.NETWORK_IN,
            period: Duration.minutes(5),
            statistic: Stats.AVERAGE,
            threshold: 100, // 100 bytes
            evaluationPeriods: 6,
            datapointsToAlarm: 5,
            comparisonOperator: ComparisonOperator.LESS_THAN_THRESHOLD
        }
    })
);
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.Ec2AutomatedShutdown(props?: Ec2AutomatedShutdownProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps</code> | *No description.* |

---

##### `props`<sup>Optional</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdownProps

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.visit">visit</a></code> | All aspects can visit an IConstruct. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.visit"></a>

```typescript
public visit(node: IConstruct): void
```

All aspects can visit an IConstruct.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

---




### Ec2InstanceType <a name="Ec2InstanceType" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType"></a>

EC2 Instance Type.




#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_2XLARGE">A1_2XLARGE</a></code> | <code>string</code> | a1.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_4XLARGE">A1_4XLARGE</a></code> | <code>string</code> | a1.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_LARGE">A1_LARGE</a></code> | <code>string</code> | a1.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_MEDIUM">A1_MEDIUM</a></code> | <code>string</code> | a1.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_METAL">A1_METAL</a></code> | <code>string</code> | a1.metal vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_XLARGE">A1_XLARGE</a></code> | <code>string</code> | a1.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C1_MEDIUM">C1_MEDIUM</a></code> | <code>string</code> | c1.medium vCPUs: 2 Memory: 1740 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C1_XLARGE">C1_XLARGE</a></code> | <code>string</code> | c1.xlarge vCPUs: 8 Memory: 7168 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_2XLARGE">C3_2XLARGE</a></code> | <code>string</code> | c3.2xlarge vCPUs: 8 Memory: 15360 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_4XLARGE">C3_4XLARGE</a></code> | <code>string</code> | c3.4xlarge vCPUs: 16 Memory: 30720 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_8XLARGE">C3_8XLARGE</a></code> | <code>string</code> | c3.8xlarge vCPUs: 32 Memory: 61440 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_LARGE">C3_LARGE</a></code> | <code>string</code> | c3.large vCPUs: 2 Memory: 3840 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_XLARGE">C3_XLARGE</a></code> | <code>string</code> | c3.xlarge vCPUs: 4 Memory: 7680 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_2XLARGE">C4_2XLARGE</a></code> | <code>string</code> | c4.2xlarge vCPUs: 8 Memory: 15360 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_4XLARGE">C4_4XLARGE</a></code> | <code>string</code> | c4.4xlarge vCPUs: 16 Memory: 30720 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_8XLARGE">C4_8XLARGE</a></code> | <code>string</code> | c4.8xlarge vCPUs: 36 Memory: 61440 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_LARGE">C4_LARGE</a></code> | <code>string</code> | c4.large vCPUs: 2 Memory: 3840 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_XLARGE">C4_XLARGE</a></code> | <code>string</code> | c4.xlarge vCPUs: 4 Memory: 7680 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_12XLARGE">C5_12XLARGE</a></code> | <code>string</code> | c5.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_18XLARGE">C5_18XLARGE</a></code> | <code>string</code> | c5.18xlarge vCPUs: 72 Memory: 147456 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_24XLARGE">C5_24XLARGE</a></code> | <code>string</code> | c5.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_2XLARGE">C5_2XLARGE</a></code> | <code>string</code> | c5.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_4XLARGE">C5_4XLARGE</a></code> | <code>string</code> | c5.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_9XLARGE">C5_9XLARGE</a></code> | <code>string</code> | c5.9xlarge vCPUs: 36 Memory: 73728 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_LARGE">C5_LARGE</a></code> | <code>string</code> | c5.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_METAL">C5_METAL</a></code> | <code>string</code> | c5.metal vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_XLARGE">C5_XLARGE</a></code> | <code>string</code> | c5.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_12XLARGE">C5A_12XLARGE</a></code> | <code>string</code> | c5a.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_16XLARGE">C5A_16XLARGE</a></code> | <code>string</code> | c5a.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_24XLARGE">C5A_24XLARGE</a></code> | <code>string</code> | c5a.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_2XLARGE">C5A_2XLARGE</a></code> | <code>string</code> | c5a.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_4XLARGE">C5A_4XLARGE</a></code> | <code>string</code> | c5a.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_8XLARGE">C5A_8XLARGE</a></code> | <code>string</code> | c5a.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_LARGE">C5A_LARGE</a></code> | <code>string</code> | c5a.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_XLARGE">C5A_XLARGE</a></code> | <code>string</code> | c5a.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_12XLARGE">C5AD_12XLARGE</a></code> | <code>string</code> | c5ad.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_16XLARGE">C5AD_16XLARGE</a></code> | <code>string</code> | c5ad.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_24XLARGE">C5AD_24XLARGE</a></code> | <code>string</code> | c5ad.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_2XLARGE">C5AD_2XLARGE</a></code> | <code>string</code> | c5ad.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_4XLARGE">C5AD_4XLARGE</a></code> | <code>string</code> | c5ad.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_8XLARGE">C5AD_8XLARGE</a></code> | <code>string</code> | c5ad.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_LARGE">C5AD_LARGE</a></code> | <code>string</code> | c5ad.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_XLARGE">C5AD_XLARGE</a></code> | <code>string</code> | c5ad.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_12XLARGE">C5D_12XLARGE</a></code> | <code>string</code> | c5d.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_18XLARGE">C5D_18XLARGE</a></code> | <code>string</code> | c5d.18xlarge vCPUs: 72 Memory: 147456 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_24XLARGE">C5D_24XLARGE</a></code> | <code>string</code> | c5d.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_2XLARGE">C5D_2XLARGE</a></code> | <code>string</code> | c5d.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_4XLARGE">C5D_4XLARGE</a></code> | <code>string</code> | c5d.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_9XLARGE">C5D_9XLARGE</a></code> | <code>string</code> | c5d.9xlarge vCPUs: 36 Memory: 73728 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_LARGE">C5D_LARGE</a></code> | <code>string</code> | c5d.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_METAL">C5D_METAL</a></code> | <code>string</code> | c5d.metal vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_XLARGE">C5D_XLARGE</a></code> | <code>string</code> | c5d.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_18XLARGE">C5N_18XLARGE</a></code> | <code>string</code> | c5n.18xlarge vCPUs: 72 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_2XLARGE">C5N_2XLARGE</a></code> | <code>string</code> | c5n.2xlarge vCPUs: 8 Memory: 21504 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_4XLARGE">C5N_4XLARGE</a></code> | <code>string</code> | c5n.4xlarge vCPUs: 16 Memory: 43008 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_9XLARGE">C5N_9XLARGE</a></code> | <code>string</code> | c5n.9xlarge vCPUs: 36 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_LARGE">C5N_LARGE</a></code> | <code>string</code> | c5n.large vCPUs: 2 Memory: 5376 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_METAL">C5N_METAL</a></code> | <code>string</code> | c5n.metal vCPUs: 72 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_XLARGE">C5N_XLARGE</a></code> | <code>string</code> | c5n.xlarge vCPUs: 4 Memory: 10752 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_12XLARGE">C6A_12XLARGE</a></code> | <code>string</code> | c6a.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_16XLARGE">C6A_16XLARGE</a></code> | <code>string</code> | c6a.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_24XLARGE">C6A_24XLARGE</a></code> | <code>string</code> | c6a.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_2XLARGE">C6A_2XLARGE</a></code> | <code>string</code> | c6a.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_32XLARGE">C6A_32XLARGE</a></code> | <code>string</code> | c6a.32xlarge vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_48XLARGE">C6A_48XLARGE</a></code> | <code>string</code> | c6a.48xlarge vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_4XLARGE">C6A_4XLARGE</a></code> | <code>string</code> | c6a.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_8XLARGE">C6A_8XLARGE</a></code> | <code>string</code> | c6a.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_LARGE">C6A_LARGE</a></code> | <code>string</code> | c6a.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_METAL">C6A_METAL</a></code> | <code>string</code> | c6a.metal vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_XLARGE">C6A_XLARGE</a></code> | <code>string</code> | c6a.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_12XLARGE">C6G_12XLARGE</a></code> | <code>string</code> | c6g.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_16XLARGE">C6G_16XLARGE</a></code> | <code>string</code> | c6g.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_2XLARGE">C6G_2XLARGE</a></code> | <code>string</code> | c6g.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_4XLARGE">C6G_4XLARGE</a></code> | <code>string</code> | c6g.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_8XLARGE">C6G_8XLARGE</a></code> | <code>string</code> | c6g.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_LARGE">C6G_LARGE</a></code> | <code>string</code> | c6g.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_MEDIUM">C6G_MEDIUM</a></code> | <code>string</code> | c6g.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_METAL">C6G_METAL</a></code> | <code>string</code> | c6g.metal vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_XLARGE">C6G_XLARGE</a></code> | <code>string</code> | c6g.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_12XLARGE">C6GD_12XLARGE</a></code> | <code>string</code> | c6gd.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_16XLARGE">C6GD_16XLARGE</a></code> | <code>string</code> | c6gd.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_2XLARGE">C6GD_2XLARGE</a></code> | <code>string</code> | c6gd.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_4XLARGE">C6GD_4XLARGE</a></code> | <code>string</code> | c6gd.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_8XLARGE">C6GD_8XLARGE</a></code> | <code>string</code> | c6gd.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_LARGE">C6GD_LARGE</a></code> | <code>string</code> | c6gd.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_MEDIUM">C6GD_MEDIUM</a></code> | <code>string</code> | c6gd.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_METAL">C6GD_METAL</a></code> | <code>string</code> | c6gd.metal vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_XLARGE">C6GD_XLARGE</a></code> | <code>string</code> | c6gd.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_12XLARGE">C6GN_12XLARGE</a></code> | <code>string</code> | c6gn.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_16XLARGE">C6GN_16XLARGE</a></code> | <code>string</code> | c6gn.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_2XLARGE">C6GN_2XLARGE</a></code> | <code>string</code> | c6gn.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_4XLARGE">C6GN_4XLARGE</a></code> | <code>string</code> | c6gn.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_8XLARGE">C6GN_8XLARGE</a></code> | <code>string</code> | c6gn.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_LARGE">C6GN_LARGE</a></code> | <code>string</code> | c6gn.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_MEDIUM">C6GN_MEDIUM</a></code> | <code>string</code> | c6gn.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_XLARGE">C6GN_XLARGE</a></code> | <code>string</code> | c6gn.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_12XLARGE">C6I_12XLARGE</a></code> | <code>string</code> | c6i.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_16XLARGE">C6I_16XLARGE</a></code> | <code>string</code> | c6i.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_24XLARGE">C6I_24XLARGE</a></code> | <code>string</code> | c6i.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_2XLARGE">C6I_2XLARGE</a></code> | <code>string</code> | c6i.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_32XLARGE">C6I_32XLARGE</a></code> | <code>string</code> | c6i.32xlarge vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_4XLARGE">C6I_4XLARGE</a></code> | <code>string</code> | c6i.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_8XLARGE">C6I_8XLARGE</a></code> | <code>string</code> | c6i.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_LARGE">C6I_LARGE</a></code> | <code>string</code> | c6i.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_METAL">C6I_METAL</a></code> | <code>string</code> | c6i.metal vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_XLARGE">C6I_XLARGE</a></code> | <code>string</code> | c6i.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_12XLARGE">C6ID_12XLARGE</a></code> | <code>string</code> | c6id.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_16XLARGE">C6ID_16XLARGE</a></code> | <code>string</code> | c6id.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_24XLARGE">C6ID_24XLARGE</a></code> | <code>string</code> | c6id.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_2XLARGE">C6ID_2XLARGE</a></code> | <code>string</code> | c6id.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_32XLARGE">C6ID_32XLARGE</a></code> | <code>string</code> | c6id.32xlarge vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_4XLARGE">C6ID_4XLARGE</a></code> | <code>string</code> | c6id.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_8XLARGE">C6ID_8XLARGE</a></code> | <code>string</code> | c6id.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_LARGE">C6ID_LARGE</a></code> | <code>string</code> | c6id.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_METAL">C6ID_METAL</a></code> | <code>string</code> | c6id.metal vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_XLARGE">C6ID_XLARGE</a></code> | <code>string</code> | c6id.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_12XLARGE">C6IN_12XLARGE</a></code> | <code>string</code> | c6in.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_16XLARGE">C6IN_16XLARGE</a></code> | <code>string</code> | c6in.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_24XLARGE">C6IN_24XLARGE</a></code> | <code>string</code> | c6in.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_2XLARGE">C6IN_2XLARGE</a></code> | <code>string</code> | c6in.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_32XLARGE">C6IN_32XLARGE</a></code> | <code>string</code> | c6in.32xlarge vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_4XLARGE">C6IN_4XLARGE</a></code> | <code>string</code> | c6in.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_8XLARGE">C6IN_8XLARGE</a></code> | <code>string</code> | c6in.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_LARGE">C6IN_LARGE</a></code> | <code>string</code> | c6in.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_METAL">C6IN_METAL</a></code> | <code>string</code> | c6in.metal vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_XLARGE">C6IN_XLARGE</a></code> | <code>string</code> | c6in.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_12XLARGE">C7A_12XLARGE</a></code> | <code>string</code> | c7a.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_16XLARGE">C7A_16XLARGE</a></code> | <code>string</code> | c7a.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_24XLARGE">C7A_24XLARGE</a></code> | <code>string</code> | c7a.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_2XLARGE">C7A_2XLARGE</a></code> | <code>string</code> | c7a.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_32XLARGE">C7A_32XLARGE</a></code> | <code>string</code> | c7a.32xlarge vCPUs: 128 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_48XLARGE">C7A_48XLARGE</a></code> | <code>string</code> | c7a.48xlarge vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_4XLARGE">C7A_4XLARGE</a></code> | <code>string</code> | c7a.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_8XLARGE">C7A_8XLARGE</a></code> | <code>string</code> | c7a.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_LARGE">C7A_LARGE</a></code> | <code>string</code> | c7a.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_MEDIUM">C7A_MEDIUM</a></code> | <code>string</code> | c7a.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_METAL_48XL">C7A_METAL_48XL</a></code> | <code>string</code> | c7a.metal-48xl vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_XLARGE">C7A_XLARGE</a></code> | <code>string</code> | c7a.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_12XLARGE">C7G_12XLARGE</a></code> | <code>string</code> | c7g.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_16XLARGE">C7G_16XLARGE</a></code> | <code>string</code> | c7g.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_2XLARGE">C7G_2XLARGE</a></code> | <code>string</code> | c7g.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_4XLARGE">C7G_4XLARGE</a></code> | <code>string</code> | c7g.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_8XLARGE">C7G_8XLARGE</a></code> | <code>string</code> | c7g.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_LARGE">C7G_LARGE</a></code> | <code>string</code> | c7g.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_MEDIUM">C7G_MEDIUM</a></code> | <code>string</code> | c7g.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_METAL">C7G_METAL</a></code> | <code>string</code> | c7g.metal vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_XLARGE">C7G_XLARGE</a></code> | <code>string</code> | c7g.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_12XLARGE">C7GD_12XLARGE</a></code> | <code>string</code> | c7gd.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_16XLARGE">C7GD_16XLARGE</a></code> | <code>string</code> | c7gd.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_2XLARGE">C7GD_2XLARGE</a></code> | <code>string</code> | c7gd.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_4XLARGE">C7GD_4XLARGE</a></code> | <code>string</code> | c7gd.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_8XLARGE">C7GD_8XLARGE</a></code> | <code>string</code> | c7gd.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_LARGE">C7GD_LARGE</a></code> | <code>string</code> | c7gd.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_MEDIUM">C7GD_MEDIUM</a></code> | <code>string</code> | c7gd.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_METAL">C7GD_METAL</a></code> | <code>string</code> | c7gd.metal vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_XLARGE">C7GD_XLARGE</a></code> | <code>string</code> | c7gd.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_12XLARGE">C7GN_12XLARGE</a></code> | <code>string</code> | c7gn.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_16XLARGE">C7GN_16XLARGE</a></code> | <code>string</code> | c7gn.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_2XLARGE">C7GN_2XLARGE</a></code> | <code>string</code> | c7gn.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_4XLARGE">C7GN_4XLARGE</a></code> | <code>string</code> | c7gn.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_8XLARGE">C7GN_8XLARGE</a></code> | <code>string</code> | c7gn.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_LARGE">C7GN_LARGE</a></code> | <code>string</code> | c7gn.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_MEDIUM">C7GN_MEDIUM</a></code> | <code>string</code> | c7gn.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_METAL">C7GN_METAL</a></code> | <code>string</code> | c7gn.metal vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_XLARGE">C7GN_XLARGE</a></code> | <code>string</code> | c7gn.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_12XLARGE">C7I_12XLARGE</a></code> | <code>string</code> | c7i.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_16XLARGE">C7I_16XLARGE</a></code> | <code>string</code> | c7i.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_24XLARGE">C7I_24XLARGE</a></code> | <code>string</code> | c7i.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_2XLARGE">C7I_2XLARGE</a></code> | <code>string</code> | c7i.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_48XLARGE">C7I_48XLARGE</a></code> | <code>string</code> | c7i.48xlarge vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_4XLARGE">C7I_4XLARGE</a></code> | <code>string</code> | c7i.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_8XLARGE">C7I_8XLARGE</a></code> | <code>string</code> | c7i.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_12XLARGE">C7I_FLEX_12XLARGE</a></code> | <code>string</code> | c7i-flex.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_16XLARGE">C7I_FLEX_16XLARGE</a></code> | <code>string</code> | c7i-flex.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_2XLARGE">C7I_FLEX_2XLARGE</a></code> | <code>string</code> | c7i-flex.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_4XLARGE">C7I_FLEX_4XLARGE</a></code> | <code>string</code> | c7i-flex.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_8XLARGE">C7I_FLEX_8XLARGE</a></code> | <code>string</code> | c7i-flex.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_LARGE">C7I_FLEX_LARGE</a></code> | <code>string</code> | c7i-flex.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_XLARGE">C7I_FLEX_XLARGE</a></code> | <code>string</code> | c7i-flex.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_LARGE">C7I_LARGE</a></code> | <code>string</code> | c7i.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_METAL_24XL">C7I_METAL_24XL</a></code> | <code>string</code> | c7i.metal-24xl vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_METAL_48XL">C7I_METAL_48XL</a></code> | <code>string</code> | c7i.metal-48xl vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_XLARGE">C7I_XLARGE</a></code> | <code>string</code> | c7i.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_12XLARGE">C8G_12XLARGE</a></code> | <code>string</code> | c8g.12xlarge vCPUs: 48 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_16XLARGE">C8G_16XLARGE</a></code> | <code>string</code> | c8g.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_24XLARGE">C8G_24XLARGE</a></code> | <code>string</code> | c8g.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_2XLARGE">C8G_2XLARGE</a></code> | <code>string</code> | c8g.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_48XLARGE">C8G_48XLARGE</a></code> | <code>string</code> | c8g.48xlarge vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_4XLARGE">C8G_4XLARGE</a></code> | <code>string</code> | c8g.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_8XLARGE">C8G_8XLARGE</a></code> | <code>string</code> | c8g.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_LARGE">C8G_LARGE</a></code> | <code>string</code> | c8g.large vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_MEDIUM">C8G_MEDIUM</a></code> | <code>string</code> | c8g.medium vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_METAL_24XL">C8G_METAL_24XL</a></code> | <code>string</code> | c8g.metal-24xl vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_METAL_48XL">C8G_METAL_48XL</a></code> | <code>string</code> | c8g.metal-48xl vCPUs: 192 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_XLARGE">C8G_XLARGE</a></code> | <code>string</code> | c8g.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_2XLARGE">D2_2XLARGE</a></code> | <code>string</code> | d2.2xlarge vCPUs: 8 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_4XLARGE">D2_4XLARGE</a></code> | <code>string</code> | d2.4xlarge vCPUs: 16 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_8XLARGE">D2_8XLARGE</a></code> | <code>string</code> | d2.8xlarge vCPUs: 36 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_XLARGE">D2_XLARGE</a></code> | <code>string</code> | d2.xlarge vCPUs: 4 Memory: 31232 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_2XLARGE">D3_2XLARGE</a></code> | <code>string</code> | d3.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_4XLARGE">D3_4XLARGE</a></code> | <code>string</code> | d3.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_8XLARGE">D3_8XLARGE</a></code> | <code>string</code> | d3.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_XLARGE">D3_XLARGE</a></code> | <code>string</code> | d3.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_12XLARGE">D3EN_12XLARGE</a></code> | <code>string</code> | d3en.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_2XLARGE">D3EN_2XLARGE</a></code> | <code>string</code> | d3en.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_4XLARGE">D3EN_4XLARGE</a></code> | <code>string</code> | d3en.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_6XLARGE">D3EN_6XLARGE</a></code> | <code>string</code> | d3en.6xlarge vCPUs: 24 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_8XLARGE">D3EN_8XLARGE</a></code> | <code>string</code> | d3en.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_XLARGE">D3EN_XLARGE</a></code> | <code>string</code> | d3en.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.DL1_24XLARGE">DL1_24XLARGE</a></code> | <code>string</code> | dl1.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F1_16XLARGE">F1_16XLARGE</a></code> | <code>string</code> | f1.16xlarge vCPUs: 64 Memory: 999424 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F1_2XLARGE">F1_2XLARGE</a></code> | <code>string</code> | f1.2xlarge vCPUs: 8 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F1_4XLARGE">F1_4XLARGE</a></code> | <code>string</code> | f1.4xlarge vCPUs: 16 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F2_12XLARGE">F2_12XLARGE</a></code> | <code>string</code> | f2.12xlarge vCPUs: 48 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F2_48XLARGE">F2_48XLARGE</a></code> | <code>string</code> | f2.48xlarge vCPUs: 192 Memory: 2097152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F2_6XLARGE">F2_6XLARGE</a></code> | <code>string</code> | f2.6xlarge vCPUs: 24 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_16XLARGE">G4AD_16XLARGE</a></code> | <code>string</code> | g4ad.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_2XLARGE">G4AD_2XLARGE</a></code> | <code>string</code> | g4ad.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_4XLARGE">G4AD_4XLARGE</a></code> | <code>string</code> | g4ad.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_8XLARGE">G4AD_8XLARGE</a></code> | <code>string</code> | g4ad.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_XLARGE">G4AD_XLARGE</a></code> | <code>string</code> | g4ad.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_12XLARGE">G4DN_12XLARGE</a></code> | <code>string</code> | g4dn.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_16XLARGE">G4DN_16XLARGE</a></code> | <code>string</code> | g4dn.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_2XLARGE">G4DN_2XLARGE</a></code> | <code>string</code> | g4dn.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_4XLARGE">G4DN_4XLARGE</a></code> | <code>string</code> | g4dn.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_8XLARGE">G4DN_8XLARGE</a></code> | <code>string</code> | g4dn.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_METAL">G4DN_METAL</a></code> | <code>string</code> | g4dn.metal vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_XLARGE">G4DN_XLARGE</a></code> | <code>string</code> | g4dn.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_12XLARGE">G5_12XLARGE</a></code> | <code>string</code> | g5.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_16XLARGE">G5_16XLARGE</a></code> | <code>string</code> | g5.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_24XLARGE">G5_24XLARGE</a></code> | <code>string</code> | g5.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_2XLARGE">G5_2XLARGE</a></code> | <code>string</code> | g5.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_48XLARGE">G5_48XLARGE</a></code> | <code>string</code> | g5.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_4XLARGE">G5_4XLARGE</a></code> | <code>string</code> | g5.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_8XLARGE">G5_8XLARGE</a></code> | <code>string</code> | g5.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_XLARGE">G5_XLARGE</a></code> | <code>string</code> | g5.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_16XLARGE">G5G_16XLARGE</a></code> | <code>string</code> | g5g.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_2XLARGE">G5G_2XLARGE</a></code> | <code>string</code> | g5g.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_4XLARGE">G5G_4XLARGE</a></code> | <code>string</code> | g5g.4xlarge vCPUs: 16 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_8XLARGE">G5G_8XLARGE</a></code> | <code>string</code> | g5g.8xlarge vCPUs: 32 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_METAL">G5G_METAL</a></code> | <code>string</code> | g5g.metal vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_XLARGE">G5G_XLARGE</a></code> | <code>string</code> | g5g.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_12XLARGE">G6_12XLARGE</a></code> | <code>string</code> | g6.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_16XLARGE">G6_16XLARGE</a></code> | <code>string</code> | g6.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_24XLARGE">G6_24XLARGE</a></code> | <code>string</code> | g6.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_2XLARGE">G6_2XLARGE</a></code> | <code>string</code> | g6.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_48XLARGE">G6_48XLARGE</a></code> | <code>string</code> | g6.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_4XLARGE">G6_4XLARGE</a></code> | <code>string</code> | g6.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_8XLARGE">G6_8XLARGE</a></code> | <code>string</code> | g6.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_XLARGE">G6_XLARGE</a></code> | <code>string</code> | g6.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_12XLARGE">G6E_12XLARGE</a></code> | <code>string</code> | g6e.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_16XLARGE">G6E_16XLARGE</a></code> | <code>string</code> | g6e.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_24XLARGE">G6E_24XLARGE</a></code> | <code>string</code> | g6e.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_2XLARGE">G6E_2XLARGE</a></code> | <code>string</code> | g6e.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_48XLARGE">G6E_48XLARGE</a></code> | <code>string</code> | g6e.48xlarge vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_4XLARGE">G6E_4XLARGE</a></code> | <code>string</code> | g6e.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_8XLARGE">G6E_8XLARGE</a></code> | <code>string</code> | g6e.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_XLARGE">G6E_XLARGE</a></code> | <code>string</code> | g6e.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.GR6_4XLARGE">GR6_4XLARGE</a></code> | <code>string</code> | gr6.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.GR6_8XLARGE">GR6_8XLARGE</a></code> | <code>string</code> | gr6.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_16XLARGE">H1_16XLARGE</a></code> | <code>string</code> | h1.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_2XLARGE">H1_2XLARGE</a></code> | <code>string</code> | h1.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_4XLARGE">H1_4XLARGE</a></code> | <code>string</code> | h1.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_8XLARGE">H1_8XLARGE</a></code> | <code>string</code> | h1.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.HPC7G_16XLARGE">HPC7G_16XLARGE</a></code> | <code>string</code> | hpc7g.16xlarge vCPUs: 64 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.HPC7G_4XLARGE">HPC7G_4XLARGE</a></code> | <code>string</code> | hpc7g.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.HPC7G_8XLARGE">HPC7G_8XLARGE</a></code> | <code>string</code> | hpc7g.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_2XLARGE">I2_2XLARGE</a></code> | <code>string</code> | i2.2xlarge vCPUs: 8 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_4XLARGE">I2_4XLARGE</a></code> | <code>string</code> | i2.4xlarge vCPUs: 16 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_8XLARGE">I2_8XLARGE</a></code> | <code>string</code> | i2.8xlarge vCPUs: 32 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_XLARGE">I2_XLARGE</a></code> | <code>string</code> | i2.xlarge vCPUs: 4 Memory: 31232 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_16XLARGE">I3_16XLARGE</a></code> | <code>string</code> | i3.16xlarge vCPUs: 64 Memory: 499712 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_2XLARGE">I3_2XLARGE</a></code> | <code>string</code> | i3.2xlarge vCPUs: 8 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_4XLARGE">I3_4XLARGE</a></code> | <code>string</code> | i3.4xlarge vCPUs: 16 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_8XLARGE">I3_8XLARGE</a></code> | <code>string</code> | i3.8xlarge vCPUs: 32 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_LARGE">I3_LARGE</a></code> | <code>string</code> | i3.large vCPUs: 2 Memory: 15616 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_METAL">I3_METAL</a></code> | <code>string</code> | i3.metal vCPUs: 72 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_XLARGE">I3_XLARGE</a></code> | <code>string</code> | i3.xlarge vCPUs: 4 Memory: 31232 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_12XLARGE">I3EN_12XLARGE</a></code> | <code>string</code> | i3en.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_24XLARGE">I3EN_24XLARGE</a></code> | <code>string</code> | i3en.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_2XLARGE">I3EN_2XLARGE</a></code> | <code>string</code> | i3en.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_3XLARGE">I3EN_3XLARGE</a></code> | <code>string</code> | i3en.3xlarge vCPUs: 12 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_6XLARGE">I3EN_6XLARGE</a></code> | <code>string</code> | i3en.6xlarge vCPUs: 24 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_LARGE">I3EN_LARGE</a></code> | <code>string</code> | i3en.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_METAL">I3EN_METAL</a></code> | <code>string</code> | i3en.metal vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_XLARGE">I3EN_XLARGE</a></code> | <code>string</code> | i3en.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_16XLARGE">I4G_16XLARGE</a></code> | <code>string</code> | i4g.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_2XLARGE">I4G_2XLARGE</a></code> | <code>string</code> | i4g.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_4XLARGE">I4G_4XLARGE</a></code> | <code>string</code> | i4g.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_8XLARGE">I4G_8XLARGE</a></code> | <code>string</code> | i4g.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_LARGE">I4G_LARGE</a></code> | <code>string</code> | i4g.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_XLARGE">I4G_XLARGE</a></code> | <code>string</code> | i4g.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_12XLARGE">I4I_12XLARGE</a></code> | <code>string</code> | i4i.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_16XLARGE">I4I_16XLARGE</a></code> | <code>string</code> | i4i.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_24XLARGE">I4I_24XLARGE</a></code> | <code>string</code> | i4i.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_2XLARGE">I4I_2XLARGE</a></code> | <code>string</code> | i4i.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_32XLARGE">I4I_32XLARGE</a></code> | <code>string</code> | i4i.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_4XLARGE">I4I_4XLARGE</a></code> | <code>string</code> | i4i.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_8XLARGE">I4I_8XLARGE</a></code> | <code>string</code> | i4i.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_LARGE">I4I_LARGE</a></code> | <code>string</code> | i4i.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_METAL">I4I_METAL</a></code> | <code>string</code> | i4i.metal vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_XLARGE">I4I_XLARGE</a></code> | <code>string</code> | i4i.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_12XLARGE">I7IE_12XLARGE</a></code> | <code>string</code> | i7ie.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_18XLARGE">I7IE_18XLARGE</a></code> | <code>string</code> | i7ie.18xlarge vCPUs: 72 Memory: 589824 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_24XLARGE">I7IE_24XLARGE</a></code> | <code>string</code> | i7ie.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_2XLARGE">I7IE_2XLARGE</a></code> | <code>string</code> | i7ie.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_3XLARGE">I7IE_3XLARGE</a></code> | <code>string</code> | i7ie.3xlarge vCPUs: 12 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_48XLARGE">I7IE_48XLARGE</a></code> | <code>string</code> | i7ie.48xlarge vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_6XLARGE">I7IE_6XLARGE</a></code> | <code>string</code> | i7ie.6xlarge vCPUs: 24 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_LARGE">I7IE_LARGE</a></code> | <code>string</code> | i7ie.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_XLARGE">I7IE_XLARGE</a></code> | <code>string</code> | i7ie.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_12XLARGE">I8G_12XLARGE</a></code> | <code>string</code> | i8g.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_16XLARGE">I8G_16XLARGE</a></code> | <code>string</code> | i8g.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_24XLARGE">I8G_24XLARGE</a></code> | <code>string</code> | i8g.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_2XLARGE">I8G_2XLARGE</a></code> | <code>string</code> | i8g.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_4XLARGE">I8G_4XLARGE</a></code> | <code>string</code> | i8g.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_8XLARGE">I8G_8XLARGE</a></code> | <code>string</code> | i8g.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_LARGE">I8G_LARGE</a></code> | <code>string</code> | i8g.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_METAL_24XL">I8G_METAL_24XL</a></code> | <code>string</code> | i8g.metal-24xl vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_XLARGE">I8G_XLARGE</a></code> | <code>string</code> | i8g.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_16XLARGE">IM4GN_16XLARGE</a></code> | <code>string</code> | im4gn.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_2XLARGE">IM4GN_2XLARGE</a></code> | <code>string</code> | im4gn.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_4XLARGE">IM4GN_4XLARGE</a></code> | <code>string</code> | im4gn.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_8XLARGE">IM4GN_8XLARGE</a></code> | <code>string</code> | im4gn.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_LARGE">IM4GN_LARGE</a></code> | <code>string</code> | im4gn.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_XLARGE">IM4GN_XLARGE</a></code> | <code>string</code> | im4gn.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_24XLARGE">INF1_24XLARGE</a></code> | <code>string</code> | inf1.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_2XLARGE">INF1_2XLARGE</a></code> | <code>string</code> | inf1.2xlarge vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_6XLARGE">INF1_6XLARGE</a></code> | <code>string</code> | inf1.6xlarge vCPUs: 24 Memory: 49152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_XLARGE">INF1_XLARGE</a></code> | <code>string</code> | inf1.xlarge vCPUs: 4 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_24XLARGE">INF2_24XLARGE</a></code> | <code>string</code> | inf2.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_48XLARGE">INF2_48XLARGE</a></code> | <code>string</code> | inf2.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_8XLARGE">INF2_8XLARGE</a></code> | <code>string</code> | inf2.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_XLARGE">INF2_XLARGE</a></code> | <code>string</code> | inf2.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_2XLARGE">IS4GEN_2XLARGE</a></code> | <code>string</code> | is4gen.2xlarge vCPUs: 8 Memory: 49152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_4XLARGE">IS4GEN_4XLARGE</a></code> | <code>string</code> | is4gen.4xlarge vCPUs: 16 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_8XLARGE">IS4GEN_8XLARGE</a></code> | <code>string</code> | is4gen.8xlarge vCPUs: 32 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_LARGE">IS4GEN_LARGE</a></code> | <code>string</code> | is4gen.large vCPUs: 2 Memory: 12288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_MEDIUM">IS4GEN_MEDIUM</a></code> | <code>string</code> | is4gen.medium vCPUs: 1 Memory: 6144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_XLARGE">IS4GEN_XLARGE</a></code> | <code>string</code> | is4gen.xlarge vCPUs: 4 Memory: 24576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_LARGE">M1_LARGE</a></code> | <code>string</code> | m1.large vCPUs: 2 Memory: 7680 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_MEDIUM">M1_MEDIUM</a></code> | <code>string</code> | m1.medium vCPUs: 1 Memory: 3788 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_SMALL">M1_SMALL</a></code> | <code>string</code> | m1.small vCPUs: 1 Memory: 1740 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_XLARGE">M1_XLARGE</a></code> | <code>string</code> | m1.xlarge vCPUs: 4 Memory: 15360 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M2_2XLARGE">M2_2XLARGE</a></code> | <code>string</code> | m2.2xlarge vCPUs: 4 Memory: 35020 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M2_4XLARGE">M2_4XLARGE</a></code> | <code>string</code> | m2.4xlarge vCPUs: 8 Memory: 70041 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M2_XLARGE">M2_XLARGE</a></code> | <code>string</code> | m2.xlarge vCPUs: 2 Memory: 17510 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_2XLARGE">M3_2XLARGE</a></code> | <code>string</code> | m3.2xlarge vCPUs: 8 Memory: 30720 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_LARGE">M3_LARGE</a></code> | <code>string</code> | m3.large vCPUs: 2 Memory: 7680 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_MEDIUM">M3_MEDIUM</a></code> | <code>string</code> | m3.medium vCPUs: 1 Memory: 3840 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_XLARGE">M3_XLARGE</a></code> | <code>string</code> | m3.xlarge vCPUs: 4 Memory: 15360 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_10XLARGE">M4_10XLARGE</a></code> | <code>string</code> | m4.10xlarge vCPUs: 40 Memory: 163840 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_16XLARGE">M4_16XLARGE</a></code> | <code>string</code> | m4.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_2XLARGE">M4_2XLARGE</a></code> | <code>string</code> | m4.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_4XLARGE">M4_4XLARGE</a></code> | <code>string</code> | m4.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_LARGE">M4_LARGE</a></code> | <code>string</code> | m4.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_XLARGE">M4_XLARGE</a></code> | <code>string</code> | m4.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_12XLARGE">M5_12XLARGE</a></code> | <code>string</code> | m5.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_16XLARGE">M5_16XLARGE</a></code> | <code>string</code> | m5.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_24XLARGE">M5_24XLARGE</a></code> | <code>string</code> | m5.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_2XLARGE">M5_2XLARGE</a></code> | <code>string</code> | m5.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_4XLARGE">M5_4XLARGE</a></code> | <code>string</code> | m5.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_8XLARGE">M5_8XLARGE</a></code> | <code>string</code> | m5.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_LARGE">M5_LARGE</a></code> | <code>string</code> | m5.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_METAL">M5_METAL</a></code> | <code>string</code> | m5.metal vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_XLARGE">M5_XLARGE</a></code> | <code>string</code> | m5.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_12XLARGE">M5A_12XLARGE</a></code> | <code>string</code> | m5a.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_16XLARGE">M5A_16XLARGE</a></code> | <code>string</code> | m5a.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_24XLARGE">M5A_24XLARGE</a></code> | <code>string</code> | m5a.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_2XLARGE">M5A_2XLARGE</a></code> | <code>string</code> | m5a.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_4XLARGE">M5A_4XLARGE</a></code> | <code>string</code> | m5a.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_8XLARGE">M5A_8XLARGE</a></code> | <code>string</code> | m5a.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_LARGE">M5A_LARGE</a></code> | <code>string</code> | m5a.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_XLARGE">M5A_XLARGE</a></code> | <code>string</code> | m5a.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_12XLARGE">M5AD_12XLARGE</a></code> | <code>string</code> | m5ad.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_16XLARGE">M5AD_16XLARGE</a></code> | <code>string</code> | m5ad.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_24XLARGE">M5AD_24XLARGE</a></code> | <code>string</code> | m5ad.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_2XLARGE">M5AD_2XLARGE</a></code> | <code>string</code> | m5ad.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_4XLARGE">M5AD_4XLARGE</a></code> | <code>string</code> | m5ad.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_8XLARGE">M5AD_8XLARGE</a></code> | <code>string</code> | m5ad.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_LARGE">M5AD_LARGE</a></code> | <code>string</code> | m5ad.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_XLARGE">M5AD_XLARGE</a></code> | <code>string</code> | m5ad.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_12XLARGE">M5D_12XLARGE</a></code> | <code>string</code> | m5d.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_16XLARGE">M5D_16XLARGE</a></code> | <code>string</code> | m5d.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_24XLARGE">M5D_24XLARGE</a></code> | <code>string</code> | m5d.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_2XLARGE">M5D_2XLARGE</a></code> | <code>string</code> | m5d.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_4XLARGE">M5D_4XLARGE</a></code> | <code>string</code> | m5d.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_8XLARGE">M5D_8XLARGE</a></code> | <code>string</code> | m5d.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_LARGE">M5D_LARGE</a></code> | <code>string</code> | m5d.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_METAL">M5D_METAL</a></code> | <code>string</code> | m5d.metal vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_XLARGE">M5D_XLARGE</a></code> | <code>string</code> | m5d.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_12XLARGE">M5DN_12XLARGE</a></code> | <code>string</code> | m5dn.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_16XLARGE">M5DN_16XLARGE</a></code> | <code>string</code> | m5dn.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_24XLARGE">M5DN_24XLARGE</a></code> | <code>string</code> | m5dn.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_2XLARGE">M5DN_2XLARGE</a></code> | <code>string</code> | m5dn.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_4XLARGE">M5DN_4XLARGE</a></code> | <code>string</code> | m5dn.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_8XLARGE">M5DN_8XLARGE</a></code> | <code>string</code> | m5dn.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_LARGE">M5DN_LARGE</a></code> | <code>string</code> | m5dn.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_METAL">M5DN_METAL</a></code> | <code>string</code> | m5dn.metal vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_XLARGE">M5DN_XLARGE</a></code> | <code>string</code> | m5dn.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_12XLARGE">M5N_12XLARGE</a></code> | <code>string</code> | m5n.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_16XLARGE">M5N_16XLARGE</a></code> | <code>string</code> | m5n.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_24XLARGE">M5N_24XLARGE</a></code> | <code>string</code> | m5n.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_2XLARGE">M5N_2XLARGE</a></code> | <code>string</code> | m5n.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_4XLARGE">M5N_4XLARGE</a></code> | <code>string</code> | m5n.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_8XLARGE">M5N_8XLARGE</a></code> | <code>string</code> | m5n.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_LARGE">M5N_LARGE</a></code> | <code>string</code> | m5n.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_METAL">M5N_METAL</a></code> | <code>string</code> | m5n.metal vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_XLARGE">M5N_XLARGE</a></code> | <code>string</code> | m5n.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_12XLARGE">M5ZN_12XLARGE</a></code> | <code>string</code> | m5zn.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_2XLARGE">M5ZN_2XLARGE</a></code> | <code>string</code> | m5zn.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_3XLARGE">M5ZN_3XLARGE</a></code> | <code>string</code> | m5zn.3xlarge vCPUs: 12 Memory: 49152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_6XLARGE">M5ZN_6XLARGE</a></code> | <code>string</code> | m5zn.6xlarge vCPUs: 24 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_LARGE">M5ZN_LARGE</a></code> | <code>string</code> | m5zn.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_METAL">M5ZN_METAL</a></code> | <code>string</code> | m5zn.metal vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_XLARGE">M5ZN_XLARGE</a></code> | <code>string</code> | m5zn.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_12XLARGE">M6A_12XLARGE</a></code> | <code>string</code> | m6a.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_16XLARGE">M6A_16XLARGE</a></code> | <code>string</code> | m6a.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_24XLARGE">M6A_24XLARGE</a></code> | <code>string</code> | m6a.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_2XLARGE">M6A_2XLARGE</a></code> | <code>string</code> | m6a.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_32XLARGE">M6A_32XLARGE</a></code> | <code>string</code> | m6a.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_48XLARGE">M6A_48XLARGE</a></code> | <code>string</code> | m6a.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_4XLARGE">M6A_4XLARGE</a></code> | <code>string</code> | m6a.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_8XLARGE">M6A_8XLARGE</a></code> | <code>string</code> | m6a.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_LARGE">M6A_LARGE</a></code> | <code>string</code> | m6a.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_METAL">M6A_METAL</a></code> | <code>string</code> | m6a.metal vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_XLARGE">M6A_XLARGE</a></code> | <code>string</code> | m6a.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_12XLARGE">M6G_12XLARGE</a></code> | <code>string</code> | m6g.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_16XLARGE">M6G_16XLARGE</a></code> | <code>string</code> | m6g.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_2XLARGE">M6G_2XLARGE</a></code> | <code>string</code> | m6g.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_4XLARGE">M6G_4XLARGE</a></code> | <code>string</code> | m6g.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_8XLARGE">M6G_8XLARGE</a></code> | <code>string</code> | m6g.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_LARGE">M6G_LARGE</a></code> | <code>string</code> | m6g.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_MEDIUM">M6G_MEDIUM</a></code> | <code>string</code> | m6g.medium vCPUs: 1 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_METAL">M6G_METAL</a></code> | <code>string</code> | m6g.metal vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_XLARGE">M6G_XLARGE</a></code> | <code>string</code> | m6g.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_12XLARGE">M6GD_12XLARGE</a></code> | <code>string</code> | m6gd.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_16XLARGE">M6GD_16XLARGE</a></code> | <code>string</code> | m6gd.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_2XLARGE">M6GD_2XLARGE</a></code> | <code>string</code> | m6gd.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_4XLARGE">M6GD_4XLARGE</a></code> | <code>string</code> | m6gd.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_8XLARGE">M6GD_8XLARGE</a></code> | <code>string</code> | m6gd.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_LARGE">M6GD_LARGE</a></code> | <code>string</code> | m6gd.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_MEDIUM">M6GD_MEDIUM</a></code> | <code>string</code> | m6gd.medium vCPUs: 1 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_METAL">M6GD_METAL</a></code> | <code>string</code> | m6gd.metal vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_XLARGE">M6GD_XLARGE</a></code> | <code>string</code> | m6gd.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_12XLARGE">M6I_12XLARGE</a></code> | <code>string</code> | m6i.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_16XLARGE">M6I_16XLARGE</a></code> | <code>string</code> | m6i.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_24XLARGE">M6I_24XLARGE</a></code> | <code>string</code> | m6i.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_2XLARGE">M6I_2XLARGE</a></code> | <code>string</code> | m6i.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_32XLARGE">M6I_32XLARGE</a></code> | <code>string</code> | m6i.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_4XLARGE">M6I_4XLARGE</a></code> | <code>string</code> | m6i.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_8XLARGE">M6I_8XLARGE</a></code> | <code>string</code> | m6i.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_LARGE">M6I_LARGE</a></code> | <code>string</code> | m6i.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_METAL">M6I_METAL</a></code> | <code>string</code> | m6i.metal vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_XLARGE">M6I_XLARGE</a></code> | <code>string</code> | m6i.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_12XLARGE">M6ID_12XLARGE</a></code> | <code>string</code> | m6id.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_16XLARGE">M6ID_16XLARGE</a></code> | <code>string</code> | m6id.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_24XLARGE">M6ID_24XLARGE</a></code> | <code>string</code> | m6id.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_2XLARGE">M6ID_2XLARGE</a></code> | <code>string</code> | m6id.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_32XLARGE">M6ID_32XLARGE</a></code> | <code>string</code> | m6id.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_4XLARGE">M6ID_4XLARGE</a></code> | <code>string</code> | m6id.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_8XLARGE">M6ID_8XLARGE</a></code> | <code>string</code> | m6id.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_LARGE">M6ID_LARGE</a></code> | <code>string</code> | m6id.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_METAL">M6ID_METAL</a></code> | <code>string</code> | m6id.metal vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_XLARGE">M6ID_XLARGE</a></code> | <code>string</code> | m6id.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_12XLARGE">M6IDN_12XLARGE</a></code> | <code>string</code> | m6idn.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_16XLARGE">M6IDN_16XLARGE</a></code> | <code>string</code> | m6idn.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_24XLARGE">M6IDN_24XLARGE</a></code> | <code>string</code> | m6idn.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_2XLARGE">M6IDN_2XLARGE</a></code> | <code>string</code> | m6idn.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_32XLARGE">M6IDN_32XLARGE</a></code> | <code>string</code> | m6idn.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_4XLARGE">M6IDN_4XLARGE</a></code> | <code>string</code> | m6idn.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_8XLARGE">M6IDN_8XLARGE</a></code> | <code>string</code> | m6idn.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_LARGE">M6IDN_LARGE</a></code> | <code>string</code> | m6idn.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_METAL">M6IDN_METAL</a></code> | <code>string</code> | m6idn.metal vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_XLARGE">M6IDN_XLARGE</a></code> | <code>string</code> | m6idn.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_12XLARGE">M6IN_12XLARGE</a></code> | <code>string</code> | m6in.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_16XLARGE">M6IN_16XLARGE</a></code> | <code>string</code> | m6in.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_24XLARGE">M6IN_24XLARGE</a></code> | <code>string</code> | m6in.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_2XLARGE">M6IN_2XLARGE</a></code> | <code>string</code> | m6in.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_32XLARGE">M6IN_32XLARGE</a></code> | <code>string</code> | m6in.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_4XLARGE">M6IN_4XLARGE</a></code> | <code>string</code> | m6in.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_8XLARGE">M6IN_8XLARGE</a></code> | <code>string</code> | m6in.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_LARGE">M6IN_LARGE</a></code> | <code>string</code> | m6in.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_METAL">M6IN_METAL</a></code> | <code>string</code> | m6in.metal vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_XLARGE">M6IN_XLARGE</a></code> | <code>string</code> | m6in.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_12XLARGE">M7A_12XLARGE</a></code> | <code>string</code> | m7a.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_16XLARGE">M7A_16XLARGE</a></code> | <code>string</code> | m7a.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_24XLARGE">M7A_24XLARGE</a></code> | <code>string</code> | m7a.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_2XLARGE">M7A_2XLARGE</a></code> | <code>string</code> | m7a.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_32XLARGE">M7A_32XLARGE</a></code> | <code>string</code> | m7a.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_48XLARGE">M7A_48XLARGE</a></code> | <code>string</code> | m7a.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_4XLARGE">M7A_4XLARGE</a></code> | <code>string</code> | m7a.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_8XLARGE">M7A_8XLARGE</a></code> | <code>string</code> | m7a.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_LARGE">M7A_LARGE</a></code> | <code>string</code> | m7a.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_MEDIUM">M7A_MEDIUM</a></code> | <code>string</code> | m7a.medium vCPUs: 1 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_METAL_48XL">M7A_METAL_48XL</a></code> | <code>string</code> | m7a.metal-48xl vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_XLARGE">M7A_XLARGE</a></code> | <code>string</code> | m7a.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_12XLARGE">M7G_12XLARGE</a></code> | <code>string</code> | m7g.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_16XLARGE">M7G_16XLARGE</a></code> | <code>string</code> | m7g.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_2XLARGE">M7G_2XLARGE</a></code> | <code>string</code> | m7g.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_4XLARGE">M7G_4XLARGE</a></code> | <code>string</code> | m7g.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_8XLARGE">M7G_8XLARGE</a></code> | <code>string</code> | m7g.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_LARGE">M7G_LARGE</a></code> | <code>string</code> | m7g.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_MEDIUM">M7G_MEDIUM</a></code> | <code>string</code> | m7g.medium vCPUs: 1 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_METAL">M7G_METAL</a></code> | <code>string</code> | m7g.metal vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_XLARGE">M7G_XLARGE</a></code> | <code>string</code> | m7g.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_12XLARGE">M7GD_12XLARGE</a></code> | <code>string</code> | m7gd.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_16XLARGE">M7GD_16XLARGE</a></code> | <code>string</code> | m7gd.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_2XLARGE">M7GD_2XLARGE</a></code> | <code>string</code> | m7gd.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_4XLARGE">M7GD_4XLARGE</a></code> | <code>string</code> | m7gd.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_8XLARGE">M7GD_8XLARGE</a></code> | <code>string</code> | m7gd.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_LARGE">M7GD_LARGE</a></code> | <code>string</code> | m7gd.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_MEDIUM">M7GD_MEDIUM</a></code> | <code>string</code> | m7gd.medium vCPUs: 1 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_METAL">M7GD_METAL</a></code> | <code>string</code> | m7gd.metal vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_XLARGE">M7GD_XLARGE</a></code> | <code>string</code> | m7gd.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_12XLARGE">M7I_12XLARGE</a></code> | <code>string</code> | m7i.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_16XLARGE">M7I_16XLARGE</a></code> | <code>string</code> | m7i.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_24XLARGE">M7I_24XLARGE</a></code> | <code>string</code> | m7i.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_2XLARGE">M7I_2XLARGE</a></code> | <code>string</code> | m7i.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_48XLARGE">M7I_48XLARGE</a></code> | <code>string</code> | m7i.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_4XLARGE">M7I_4XLARGE</a></code> | <code>string</code> | m7i.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_8XLARGE">M7I_8XLARGE</a></code> | <code>string</code> | m7i.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_12XLARGE">M7I_FLEX_12XLARGE</a></code> | <code>string</code> | m7i-flex.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_16XLARGE">M7I_FLEX_16XLARGE</a></code> | <code>string</code> | m7i-flex.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_2XLARGE">M7I_FLEX_2XLARGE</a></code> | <code>string</code> | m7i-flex.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_4XLARGE">M7I_FLEX_4XLARGE</a></code> | <code>string</code> | m7i-flex.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_8XLARGE">M7I_FLEX_8XLARGE</a></code> | <code>string</code> | m7i-flex.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_LARGE">M7I_FLEX_LARGE</a></code> | <code>string</code> | m7i-flex.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_XLARGE">M7I_FLEX_XLARGE</a></code> | <code>string</code> | m7i-flex.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_LARGE">M7I_LARGE</a></code> | <code>string</code> | m7i.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_METAL_24XL">M7I_METAL_24XL</a></code> | <code>string</code> | m7i.metal-24xl vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_METAL_48XL">M7I_METAL_48XL</a></code> | <code>string</code> | m7i.metal-48xl vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_XLARGE">M7I_XLARGE</a></code> | <code>string</code> | m7i.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_12XLARGE">M8G_12XLARGE</a></code> | <code>string</code> | m8g.12xlarge vCPUs: 48 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_16XLARGE">M8G_16XLARGE</a></code> | <code>string</code> | m8g.16xlarge vCPUs: 64 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_24XLARGE">M8G_24XLARGE</a></code> | <code>string</code> | m8g.24xlarge vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_2XLARGE">M8G_2XLARGE</a></code> | <code>string</code> | m8g.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_48XLARGE">M8G_48XLARGE</a></code> | <code>string</code> | m8g.48xlarge vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_4XLARGE">M8G_4XLARGE</a></code> | <code>string</code> | m8g.4xlarge vCPUs: 16 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_8XLARGE">M8G_8XLARGE</a></code> | <code>string</code> | m8g.8xlarge vCPUs: 32 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_LARGE">M8G_LARGE</a></code> | <code>string</code> | m8g.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_MEDIUM">M8G_MEDIUM</a></code> | <code>string</code> | m8g.medium vCPUs: 1 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_METAL_24XL">M8G_METAL_24XL</a></code> | <code>string</code> | m8g.metal-24xl vCPUs: 96 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_METAL_48XL">M8G_METAL_48XL</a></code> | <code>string</code> | m8g.metal-48xl vCPUs: 192 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_XLARGE">M8G_XLARGE</a></code> | <code>string</code> | m8g.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC1_METAL">MAC1_METAL</a></code> | <code>string</code> | mac1.metal vCPUs: 12 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_M1ULTRA_METAL">MAC2_M1ULTRA_METAL</a></code> | <code>string</code> | mac2-m1ultra.metal vCPUs: 20 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_M2_METAL">MAC2_M2_METAL</a></code> | <code>string</code> | mac2-m2.metal vCPUs: 8 Memory: 24576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_M2PRO_METAL">MAC2_M2PRO_METAL</a></code> | <code>string</code> | mac2-m2pro.metal vCPUs: 12 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_METAL">MAC2_METAL</a></code> | <code>string</code> | mac2.metal vCPUs: 8 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P2_16XLARGE">P2_16XLARGE</a></code> | <code>string</code> | p2.16xlarge vCPUs: 64 Memory: 749568 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P2_8XLARGE">P2_8XLARGE</a></code> | <code>string</code> | p2.8xlarge vCPUs: 32 Memory: 499712 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P2_XLARGE">P2_XLARGE</a></code> | <code>string</code> | p2.xlarge vCPUs: 4 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3_16XLARGE">P3_16XLARGE</a></code> | <code>string</code> | p3.16xlarge vCPUs: 64 Memory: 499712 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3_2XLARGE">P3_2XLARGE</a></code> | <code>string</code> | p3.2xlarge vCPUs: 8 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3_8XLARGE">P3_8XLARGE</a></code> | <code>string</code> | p3.8xlarge vCPUs: 32 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3DN_24XLARGE">P3DN_24XLARGE</a></code> | <code>string</code> | p3dn.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P4D_24XLARGE">P4D_24XLARGE</a></code> | <code>string</code> | p4d.24xlarge vCPUs: 96 Memory: 1179648 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P5_48XLARGE">P5_48XLARGE</a></code> | <code>string</code> | p5.48xlarge vCPUs: 192 Memory: 2097152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_2XLARGE">R3_2XLARGE</a></code> | <code>string</code> | r3.2xlarge vCPUs: 8 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_4XLARGE">R3_4XLARGE</a></code> | <code>string</code> | r3.4xlarge vCPUs: 16 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_8XLARGE">R3_8XLARGE</a></code> | <code>string</code> | r3.8xlarge vCPUs: 32 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_LARGE">R3_LARGE</a></code> | <code>string</code> | r3.large vCPUs: 2 Memory: 15360 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_XLARGE">R3_XLARGE</a></code> | <code>string</code> | r3.xlarge vCPUs: 4 Memory: 31232 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_16XLARGE">R4_16XLARGE</a></code> | <code>string</code> | r4.16xlarge vCPUs: 64 Memory: 499712 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_2XLARGE">R4_2XLARGE</a></code> | <code>string</code> | r4.2xlarge vCPUs: 8 Memory: 62464 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_4XLARGE">R4_4XLARGE</a></code> | <code>string</code> | r4.4xlarge vCPUs: 16 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_8XLARGE">R4_8XLARGE</a></code> | <code>string</code> | r4.8xlarge vCPUs: 32 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_LARGE">R4_LARGE</a></code> | <code>string</code> | r4.large vCPUs: 2 Memory: 15616 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_XLARGE">R4_XLARGE</a></code> | <code>string</code> | r4.xlarge vCPUs: 4 Memory: 31232 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_12XLARGE">R5_12XLARGE</a></code> | <code>string</code> | r5.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_16XLARGE">R5_16XLARGE</a></code> | <code>string</code> | r5.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_24XLARGE">R5_24XLARGE</a></code> | <code>string</code> | r5.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_2XLARGE">R5_2XLARGE</a></code> | <code>string</code> | r5.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_4XLARGE">R5_4XLARGE</a></code> | <code>string</code> | r5.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_8XLARGE">R5_8XLARGE</a></code> | <code>string</code> | r5.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_LARGE">R5_LARGE</a></code> | <code>string</code> | r5.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_METAL">R5_METAL</a></code> | <code>string</code> | r5.metal vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_XLARGE">R5_XLARGE</a></code> | <code>string</code> | r5.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_12XLARGE">R5A_12XLARGE</a></code> | <code>string</code> | r5a.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_16XLARGE">R5A_16XLARGE</a></code> | <code>string</code> | r5a.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_24XLARGE">R5A_24XLARGE</a></code> | <code>string</code> | r5a.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_2XLARGE">R5A_2XLARGE</a></code> | <code>string</code> | r5a.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_4XLARGE">R5A_4XLARGE</a></code> | <code>string</code> | r5a.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_8XLARGE">R5A_8XLARGE</a></code> | <code>string</code> | r5a.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_LARGE">R5A_LARGE</a></code> | <code>string</code> | r5a.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_XLARGE">R5A_XLARGE</a></code> | <code>string</code> | r5a.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_12XLARGE">R5AD_12XLARGE</a></code> | <code>string</code> | r5ad.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_16XLARGE">R5AD_16XLARGE</a></code> | <code>string</code> | r5ad.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_24XLARGE">R5AD_24XLARGE</a></code> | <code>string</code> | r5ad.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_2XLARGE">R5AD_2XLARGE</a></code> | <code>string</code> | r5ad.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_4XLARGE">R5AD_4XLARGE</a></code> | <code>string</code> | r5ad.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_8XLARGE">R5AD_8XLARGE</a></code> | <code>string</code> | r5ad.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_LARGE">R5AD_LARGE</a></code> | <code>string</code> | r5ad.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_XLARGE">R5AD_XLARGE</a></code> | <code>string</code> | r5ad.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_12XLARGE">R5B_12XLARGE</a></code> | <code>string</code> | r5b.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_16XLARGE">R5B_16XLARGE</a></code> | <code>string</code> | r5b.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_24XLARGE">R5B_24XLARGE</a></code> | <code>string</code> | r5b.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_2XLARGE">R5B_2XLARGE</a></code> | <code>string</code> | r5b.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_4XLARGE">R5B_4XLARGE</a></code> | <code>string</code> | r5b.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_8XLARGE">R5B_8XLARGE</a></code> | <code>string</code> | r5b.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_LARGE">R5B_LARGE</a></code> | <code>string</code> | r5b.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_METAL">R5B_METAL</a></code> | <code>string</code> | r5b.metal vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_XLARGE">R5B_XLARGE</a></code> | <code>string</code> | r5b.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_12XLARGE">R5D_12XLARGE</a></code> | <code>string</code> | r5d.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_16XLARGE">R5D_16XLARGE</a></code> | <code>string</code> | r5d.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_24XLARGE">R5D_24XLARGE</a></code> | <code>string</code> | r5d.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_2XLARGE">R5D_2XLARGE</a></code> | <code>string</code> | r5d.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_4XLARGE">R5D_4XLARGE</a></code> | <code>string</code> | r5d.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_8XLARGE">R5D_8XLARGE</a></code> | <code>string</code> | r5d.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_LARGE">R5D_LARGE</a></code> | <code>string</code> | r5d.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_METAL">R5D_METAL</a></code> | <code>string</code> | r5d.metal vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_XLARGE">R5D_XLARGE</a></code> | <code>string</code> | r5d.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_12XLARGE">R5DN_12XLARGE</a></code> | <code>string</code> | r5dn.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_16XLARGE">R5DN_16XLARGE</a></code> | <code>string</code> | r5dn.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_24XLARGE">R5DN_24XLARGE</a></code> | <code>string</code> | r5dn.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_2XLARGE">R5DN_2XLARGE</a></code> | <code>string</code> | r5dn.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_4XLARGE">R5DN_4XLARGE</a></code> | <code>string</code> | r5dn.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_8XLARGE">R5DN_8XLARGE</a></code> | <code>string</code> | r5dn.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_LARGE">R5DN_LARGE</a></code> | <code>string</code> | r5dn.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_METAL">R5DN_METAL</a></code> | <code>string</code> | r5dn.metal vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_XLARGE">R5DN_XLARGE</a></code> | <code>string</code> | r5dn.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_12XLARGE">R5N_12XLARGE</a></code> | <code>string</code> | r5n.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_16XLARGE">R5N_16XLARGE</a></code> | <code>string</code> | r5n.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_24XLARGE">R5N_24XLARGE</a></code> | <code>string</code> | r5n.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_2XLARGE">R5N_2XLARGE</a></code> | <code>string</code> | r5n.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_4XLARGE">R5N_4XLARGE</a></code> | <code>string</code> | r5n.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_8XLARGE">R5N_8XLARGE</a></code> | <code>string</code> | r5n.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_LARGE">R5N_LARGE</a></code> | <code>string</code> | r5n.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_METAL">R5N_METAL</a></code> | <code>string</code> | r5n.metal vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_XLARGE">R5N_XLARGE</a></code> | <code>string</code> | r5n.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_12XLARGE">R6A_12XLARGE</a></code> | <code>string</code> | r6a.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_16XLARGE">R6A_16XLARGE</a></code> | <code>string</code> | r6a.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_24XLARGE">R6A_24XLARGE</a></code> | <code>string</code> | r6a.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_2XLARGE">R6A_2XLARGE</a></code> | <code>string</code> | r6a.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_32XLARGE">R6A_32XLARGE</a></code> | <code>string</code> | r6a.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_48XLARGE">R6A_48XLARGE</a></code> | <code>string</code> | r6a.48xlarge vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_4XLARGE">R6A_4XLARGE</a></code> | <code>string</code> | r6a.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_8XLARGE">R6A_8XLARGE</a></code> | <code>string</code> | r6a.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_LARGE">R6A_LARGE</a></code> | <code>string</code> | r6a.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_METAL">R6A_METAL</a></code> | <code>string</code> | r6a.metal vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_XLARGE">R6A_XLARGE</a></code> | <code>string</code> | r6a.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_12XLARGE">R6G_12XLARGE</a></code> | <code>string</code> | r6g.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_16XLARGE">R6G_16XLARGE</a></code> | <code>string</code> | r6g.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_2XLARGE">R6G_2XLARGE</a></code> | <code>string</code> | r6g.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_4XLARGE">R6G_4XLARGE</a></code> | <code>string</code> | r6g.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_8XLARGE">R6G_8XLARGE</a></code> | <code>string</code> | r6g.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_LARGE">R6G_LARGE</a></code> | <code>string</code> | r6g.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_MEDIUM">R6G_MEDIUM</a></code> | <code>string</code> | r6g.medium vCPUs: 1 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_METAL">R6G_METAL</a></code> | <code>string</code> | r6g.metal vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_XLARGE">R6G_XLARGE</a></code> | <code>string</code> | r6g.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_12XLARGE">R6GD_12XLARGE</a></code> | <code>string</code> | r6gd.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_16XLARGE">R6GD_16XLARGE</a></code> | <code>string</code> | r6gd.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_2XLARGE">R6GD_2XLARGE</a></code> | <code>string</code> | r6gd.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_4XLARGE">R6GD_4XLARGE</a></code> | <code>string</code> | r6gd.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_8XLARGE">R6GD_8XLARGE</a></code> | <code>string</code> | r6gd.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_LARGE">R6GD_LARGE</a></code> | <code>string</code> | r6gd.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_MEDIUM">R6GD_MEDIUM</a></code> | <code>string</code> | r6gd.medium vCPUs: 1 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_METAL">R6GD_METAL</a></code> | <code>string</code> | r6gd.metal vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_XLARGE">R6GD_XLARGE</a></code> | <code>string</code> | r6gd.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_12XLARGE">R6I_12XLARGE</a></code> | <code>string</code> | r6i.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_16XLARGE">R6I_16XLARGE</a></code> | <code>string</code> | r6i.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_24XLARGE">R6I_24XLARGE</a></code> | <code>string</code> | r6i.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_2XLARGE">R6I_2XLARGE</a></code> | <code>string</code> | r6i.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_32XLARGE">R6I_32XLARGE</a></code> | <code>string</code> | r6i.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_4XLARGE">R6I_4XLARGE</a></code> | <code>string</code> | r6i.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_8XLARGE">R6I_8XLARGE</a></code> | <code>string</code> | r6i.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_LARGE">R6I_LARGE</a></code> | <code>string</code> | r6i.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_METAL">R6I_METAL</a></code> | <code>string</code> | r6i.metal vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_XLARGE">R6I_XLARGE</a></code> | <code>string</code> | r6i.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_12XLARGE">R6ID_12XLARGE</a></code> | <code>string</code> | r6id.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_16XLARGE">R6ID_16XLARGE</a></code> | <code>string</code> | r6id.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_24XLARGE">R6ID_24XLARGE</a></code> | <code>string</code> | r6id.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_2XLARGE">R6ID_2XLARGE</a></code> | <code>string</code> | r6id.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_32XLARGE">R6ID_32XLARGE</a></code> | <code>string</code> | r6id.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_4XLARGE">R6ID_4XLARGE</a></code> | <code>string</code> | r6id.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_8XLARGE">R6ID_8XLARGE</a></code> | <code>string</code> | r6id.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_LARGE">R6ID_LARGE</a></code> | <code>string</code> | r6id.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_METAL">R6ID_METAL</a></code> | <code>string</code> | r6id.metal vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_XLARGE">R6ID_XLARGE</a></code> | <code>string</code> | r6id.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_12XLARGE">R6IDN_12XLARGE</a></code> | <code>string</code> | r6idn.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_16XLARGE">R6IDN_16XLARGE</a></code> | <code>string</code> | r6idn.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_24XLARGE">R6IDN_24XLARGE</a></code> | <code>string</code> | r6idn.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_2XLARGE">R6IDN_2XLARGE</a></code> | <code>string</code> | r6idn.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_32XLARGE">R6IDN_32XLARGE</a></code> | <code>string</code> | r6idn.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_4XLARGE">R6IDN_4XLARGE</a></code> | <code>string</code> | r6idn.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_8XLARGE">R6IDN_8XLARGE</a></code> | <code>string</code> | r6idn.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_LARGE">R6IDN_LARGE</a></code> | <code>string</code> | r6idn.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_METAL">R6IDN_METAL</a></code> | <code>string</code> | r6idn.metal vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_XLARGE">R6IDN_XLARGE</a></code> | <code>string</code> | r6idn.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_12XLARGE">R6IN_12XLARGE</a></code> | <code>string</code> | r6in.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_16XLARGE">R6IN_16XLARGE</a></code> | <code>string</code> | r6in.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_24XLARGE">R6IN_24XLARGE</a></code> | <code>string</code> | r6in.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_2XLARGE">R6IN_2XLARGE</a></code> | <code>string</code> | r6in.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_32XLARGE">R6IN_32XLARGE</a></code> | <code>string</code> | r6in.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_4XLARGE">R6IN_4XLARGE</a></code> | <code>string</code> | r6in.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_8XLARGE">R6IN_8XLARGE</a></code> | <code>string</code> | r6in.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_LARGE">R6IN_LARGE</a></code> | <code>string</code> | r6in.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_METAL">R6IN_METAL</a></code> | <code>string</code> | r6in.metal vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_XLARGE">R6IN_XLARGE</a></code> | <code>string</code> | r6in.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_12XLARGE">R7A_12XLARGE</a></code> | <code>string</code> | r7a.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_16XLARGE">R7A_16XLARGE</a></code> | <code>string</code> | r7a.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_24XLARGE">R7A_24XLARGE</a></code> | <code>string</code> | r7a.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_2XLARGE">R7A_2XLARGE</a></code> | <code>string</code> | r7a.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_32XLARGE">R7A_32XLARGE</a></code> | <code>string</code> | r7a.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_48XLARGE">R7A_48XLARGE</a></code> | <code>string</code> | r7a.48xlarge vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_4XLARGE">R7A_4XLARGE</a></code> | <code>string</code> | r7a.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_8XLARGE">R7A_8XLARGE</a></code> | <code>string</code> | r7a.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_LARGE">R7A_LARGE</a></code> | <code>string</code> | r7a.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_MEDIUM">R7A_MEDIUM</a></code> | <code>string</code> | r7a.medium vCPUs: 1 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_METAL_48XL">R7A_METAL_48XL</a></code> | <code>string</code> | r7a.metal-48xl vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_XLARGE">R7A_XLARGE</a></code> | <code>string</code> | r7a.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_12XLARGE">R7G_12XLARGE</a></code> | <code>string</code> | r7g.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_16XLARGE">R7G_16XLARGE</a></code> | <code>string</code> | r7g.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_2XLARGE">R7G_2XLARGE</a></code> | <code>string</code> | r7g.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_4XLARGE">R7G_4XLARGE</a></code> | <code>string</code> | r7g.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_8XLARGE">R7G_8XLARGE</a></code> | <code>string</code> | r7g.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_LARGE">R7G_LARGE</a></code> | <code>string</code> | r7g.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_MEDIUM">R7G_MEDIUM</a></code> | <code>string</code> | r7g.medium vCPUs: 1 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_METAL">R7G_METAL</a></code> | <code>string</code> | r7g.metal vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_XLARGE">R7G_XLARGE</a></code> | <code>string</code> | r7g.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_12XLARGE">R7GD_12XLARGE</a></code> | <code>string</code> | r7gd.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_16XLARGE">R7GD_16XLARGE</a></code> | <code>string</code> | r7gd.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_2XLARGE">R7GD_2XLARGE</a></code> | <code>string</code> | r7gd.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_4XLARGE">R7GD_4XLARGE</a></code> | <code>string</code> | r7gd.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_8XLARGE">R7GD_8XLARGE</a></code> | <code>string</code> | r7gd.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_LARGE">R7GD_LARGE</a></code> | <code>string</code> | r7gd.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_MEDIUM">R7GD_MEDIUM</a></code> | <code>string</code> | r7gd.medium vCPUs: 1 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_METAL">R7GD_METAL</a></code> | <code>string</code> | r7gd.metal vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_XLARGE">R7GD_XLARGE</a></code> | <code>string</code> | r7gd.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_12XLARGE">R7I_12XLARGE</a></code> | <code>string</code> | r7i.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_16XLARGE">R7I_16XLARGE</a></code> | <code>string</code> | r7i.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_24XLARGE">R7I_24XLARGE</a></code> | <code>string</code> | r7i.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_2XLARGE">R7I_2XLARGE</a></code> | <code>string</code> | r7i.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_48XLARGE">R7I_48XLARGE</a></code> | <code>string</code> | r7i.48xlarge vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_4XLARGE">R7I_4XLARGE</a></code> | <code>string</code> | r7i.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_8XLARGE">R7I_8XLARGE</a></code> | <code>string</code> | r7i.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_LARGE">R7I_LARGE</a></code> | <code>string</code> | r7i.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_METAL_24XL">R7I_METAL_24XL</a></code> | <code>string</code> | r7i.metal-24xl vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_METAL_48XL">R7I_METAL_48XL</a></code> | <code>string</code> | r7i.metal-48xl vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_XLARGE">R7I_XLARGE</a></code> | <code>string</code> | r7i.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_12XLARGE">R7IZ_12XLARGE</a></code> | <code>string</code> | r7iz.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_16XLARGE">R7IZ_16XLARGE</a></code> | <code>string</code> | r7iz.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_2XLARGE">R7IZ_2XLARGE</a></code> | <code>string</code> | r7iz.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_32XLARGE">R7IZ_32XLARGE</a></code> | <code>string</code> | r7iz.32xlarge vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_4XLARGE">R7IZ_4XLARGE</a></code> | <code>string</code> | r7iz.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_8XLARGE">R7IZ_8XLARGE</a></code> | <code>string</code> | r7iz.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_LARGE">R7IZ_LARGE</a></code> | <code>string</code> | r7iz.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_METAL_16XL">R7IZ_METAL_16XL</a></code> | <code>string</code> | r7iz.metal-16xl vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_METAL_32XL">R7IZ_METAL_32XL</a></code> | <code>string</code> | r7iz.metal-32xl vCPUs: 128 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_XLARGE">R7IZ_XLARGE</a></code> | <code>string</code> | r7iz.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_12XLARGE">R8G_12XLARGE</a></code> | <code>string</code> | r8g.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_16XLARGE">R8G_16XLARGE</a></code> | <code>string</code> | r8g.16xlarge vCPUs: 64 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_24XLARGE">R8G_24XLARGE</a></code> | <code>string</code> | r8g.24xlarge vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_2XLARGE">R8G_2XLARGE</a></code> | <code>string</code> | r8g.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_48XLARGE">R8G_48XLARGE</a></code> | <code>string</code> | r8g.48xlarge vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_4XLARGE">R8G_4XLARGE</a></code> | <code>string</code> | r8g.4xlarge vCPUs: 16 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_8XLARGE">R8G_8XLARGE</a></code> | <code>string</code> | r8g.8xlarge vCPUs: 32 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_LARGE">R8G_LARGE</a></code> | <code>string</code> | r8g.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_MEDIUM">R8G_MEDIUM</a></code> | <code>string</code> | r8g.medium vCPUs: 1 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_METAL_24XL">R8G_METAL_24XL</a></code> | <code>string</code> | r8g.metal-24xl vCPUs: 96 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_METAL_48XL">R8G_METAL_48XL</a></code> | <code>string</code> | r8g.metal-48xl vCPUs: 192 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_XLARGE">R8G_XLARGE</a></code> | <code>string</code> | r8g.xlarge vCPUs: 4 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T1_MICRO">T1_MICRO</a></code> | <code>string</code> | t1.micro vCPUs: 1 Memory: 627 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_2XLARGE">T2_2XLARGE</a></code> | <code>string</code> | t2.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_LARGE">T2_LARGE</a></code> | <code>string</code> | t2.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_MEDIUM">T2_MEDIUM</a></code> | <code>string</code> | t2.medium vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_MICRO">T2_MICRO</a></code> | <code>string</code> | t2.micro vCPUs: 1 Memory: 1024 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_NANO">T2_NANO</a></code> | <code>string</code> | t2.nano vCPUs: 1 Memory: 512 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_SMALL">T2_SMALL</a></code> | <code>string</code> | t2.small vCPUs: 1 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_XLARGE">T2_XLARGE</a></code> | <code>string</code> | t2.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_2XLARGE">T3_2XLARGE</a></code> | <code>string</code> | t3.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_LARGE">T3_LARGE</a></code> | <code>string</code> | t3.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_MEDIUM">T3_MEDIUM</a></code> | <code>string</code> | t3.medium vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_MICRO">T3_MICRO</a></code> | <code>string</code> | t3.micro vCPUs: 2 Memory: 1024 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_NANO">T3_NANO</a></code> | <code>string</code> | t3.nano vCPUs: 2 Memory: 512 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_SMALL">T3_SMALL</a></code> | <code>string</code> | t3.small vCPUs: 2 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_XLARGE">T3_XLARGE</a></code> | <code>string</code> | t3.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_2XLARGE">T3A_2XLARGE</a></code> | <code>string</code> | t3a.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_LARGE">T3A_LARGE</a></code> | <code>string</code> | t3a.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_MEDIUM">T3A_MEDIUM</a></code> | <code>string</code> | t3a.medium vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_MICRO">T3A_MICRO</a></code> | <code>string</code> | t3a.micro vCPUs: 2 Memory: 1024 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_NANO">T3A_NANO</a></code> | <code>string</code> | t3a.nano vCPUs: 2 Memory: 512 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_SMALL">T3A_SMALL</a></code> | <code>string</code> | t3a.small vCPUs: 2 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_XLARGE">T3A_XLARGE</a></code> | <code>string</code> | t3a.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_2XLARGE">T4G_2XLARGE</a></code> | <code>string</code> | t4g.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_LARGE">T4G_LARGE</a></code> | <code>string</code> | t4g.large vCPUs: 2 Memory: 8192 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_MEDIUM">T4G_MEDIUM</a></code> | <code>string</code> | t4g.medium vCPUs: 2 Memory: 4096 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_MICRO">T4G_MICRO</a></code> | <code>string</code> | t4g.micro vCPUs: 2 Memory: 1024 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_NANO">T4G_NANO</a></code> | <code>string</code> | t4g.nano vCPUs: 2 Memory: 512 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_SMALL">T4G_SMALL</a></code> | <code>string</code> | t4g.small vCPUs: 2 Memory: 2048 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_XLARGE">T4G_XLARGE</a></code> | <code>string</code> | t4g.xlarge vCPUs: 4 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.TRN1_2XLARGE">TRN1_2XLARGE</a></code> | <code>string</code> | trn1.2xlarge vCPUs: 8 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.TRN1_32XLARGE">TRN1_32XLARGE</a></code> | <code>string</code> | trn1.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.TRN1N_32XLARGE">TRN1N_32XLARGE</a></code> | <code>string</code> | trn1n.32xlarge vCPUs: 128 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_12TB1_112XLARGE">U_12TB1_112XLARGE</a></code> | <code>string</code> | u-12tb1.112xlarge vCPUs: 448 Memory: 12582912 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_18TB1_112XLARGE">U_18TB1_112XLARGE</a></code> | <code>string</code> | u-18tb1.112xlarge vCPUs: 448 Memory: 18874368 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_24TB1_112XLARGE">U_24TB1_112XLARGE</a></code> | <code>string</code> | u-24tb1.112xlarge vCPUs: 448 Memory: 25165824 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_3TB1_56XLARGE">U_3TB1_56XLARGE</a></code> | <code>string</code> | u-3tb1.56xlarge vCPUs: 224 Memory: 3145728 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_6TB1_112XLARGE">U_6TB1_112XLARGE</a></code> | <code>string</code> | u-6tb1.112xlarge vCPUs: 448 Memory: 6291456 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_6TB1_56XLARGE">U_6TB1_56XLARGE</a></code> | <code>string</code> | u-6tb1.56xlarge vCPUs: 224 Memory: 6291456 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_9TB1_112XLARGE">U_9TB1_112XLARGE</a></code> | <code>string</code> | u-9tb1.112xlarge vCPUs: 448 Memory: 9437184 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7I_12TB_224XLARGE">U7I_12TB_224XLARGE</a></code> | <code>string</code> | u7i-12tb.224xlarge vCPUs: 896 Memory: 12582912 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7I_6TB_112XLARGE">U7I_6TB_112XLARGE</a></code> | <code>string</code> | u7i-6tb.112xlarge vCPUs: 448 Memory: 6291456 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7I_8TB_112XLARGE">U7I_8TB_112XLARGE</a></code> | <code>string</code> | u7i-8tb.112xlarge vCPUs: 448 Memory: 8388608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7IN_16TB_224XLARGE">U7IN_16TB_224XLARGE</a></code> | <code>string</code> | u7in-16tb.224xlarge vCPUs: 896 Memory: 16777216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7IN_24TB_224XLARGE">U7IN_24TB_224XLARGE</a></code> | <code>string</code> | u7in-24tb.224xlarge vCPUs: 896 Memory: 25165824 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7IN_32TB_224XLARGE">U7IN_32TB_224XLARGE</a></code> | <code>string</code> | u7in-32tb.224xlarge vCPUs: 896 Memory: 33554432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.VT1_24XLARGE">VT1_24XLARGE</a></code> | <code>string</code> | vt1.24xlarge vCPUs: 96 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.VT1_3XLARGE">VT1_3XLARGE</a></code> | <code>string</code> | vt1.3xlarge vCPUs: 12 Memory: 24576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.VT1_6XLARGE">VT1_6XLARGE</a></code> | <code>string</code> | vt1.6xlarge vCPUs: 24 Memory: 49152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1_16XLARGE">X1_16XLARGE</a></code> | <code>string</code> | x1.16xlarge vCPUs: 64 Memory: 999424 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1_32XLARGE">X1_32XLARGE</a></code> | <code>string</code> | x1.32xlarge vCPUs: 128 Memory: 1998848 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_16XLARGE">X1E_16XLARGE</a></code> | <code>string</code> | x1e.16xlarge vCPUs: 64 Memory: 1998848 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_2XLARGE">X1E_2XLARGE</a></code> | <code>string</code> | x1e.2xlarge vCPUs: 8 Memory: 249856 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_32XLARGE">X1E_32XLARGE</a></code> | <code>string</code> | x1e.32xlarge vCPUs: 128 Memory: 3997696 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_4XLARGE">X1E_4XLARGE</a></code> | <code>string</code> | x1e.4xlarge vCPUs: 16 Memory: 499712 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_8XLARGE">X1E_8XLARGE</a></code> | <code>string</code> | x1e.8xlarge vCPUs: 32 Memory: 999424 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_XLARGE">X1E_XLARGE</a></code> | <code>string</code> | x1e.xlarge vCPUs: 4 Memory: 124928 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_12XLARGE">X2GD_12XLARGE</a></code> | <code>string</code> | x2gd.12xlarge vCPUs: 48 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_16XLARGE">X2GD_16XLARGE</a></code> | <code>string</code> | x2gd.16xlarge vCPUs: 64 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_2XLARGE">X2GD_2XLARGE</a></code> | <code>string</code> | x2gd.2xlarge vCPUs: 8 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_4XLARGE">X2GD_4XLARGE</a></code> | <code>string</code> | x2gd.4xlarge vCPUs: 16 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_8XLARGE">X2GD_8XLARGE</a></code> | <code>string</code> | x2gd.8xlarge vCPUs: 32 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_LARGE">X2GD_LARGE</a></code> | <code>string</code> | x2gd.large vCPUs: 2 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_MEDIUM">X2GD_MEDIUM</a></code> | <code>string</code> | x2gd.medium vCPUs: 1 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_METAL">X2GD_METAL</a></code> | <code>string</code> | x2gd.metal vCPUs: 64 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_XLARGE">X2GD_XLARGE</a></code> | <code>string</code> | x2gd.xlarge vCPUs: 4 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_16XLARGE">X2IDN_16XLARGE</a></code> | <code>string</code> | x2idn.16xlarge vCPUs: 64 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_24XLARGE">X2IDN_24XLARGE</a></code> | <code>string</code> | x2idn.24xlarge vCPUs: 96 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_32XLARGE">X2IDN_32XLARGE</a></code> | <code>string</code> | x2idn.32xlarge vCPUs: 128 Memory: 2097152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_METAL">X2IDN_METAL</a></code> | <code>string</code> | x2idn.metal vCPUs: 128 Memory: 2097152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_16XLARGE">X2IEDN_16XLARGE</a></code> | <code>string</code> | x2iedn.16xlarge vCPUs: 64 Memory: 2097152 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_24XLARGE">X2IEDN_24XLARGE</a></code> | <code>string</code> | x2iedn.24xlarge vCPUs: 96 Memory: 3145728 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_2XLARGE">X2IEDN_2XLARGE</a></code> | <code>string</code> | x2iedn.2xlarge vCPUs: 8 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_32XLARGE">X2IEDN_32XLARGE</a></code> | <code>string</code> | x2iedn.32xlarge vCPUs: 128 Memory: 4194304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_4XLARGE">X2IEDN_4XLARGE</a></code> | <code>string</code> | x2iedn.4xlarge vCPUs: 16 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_8XLARGE">X2IEDN_8XLARGE</a></code> | <code>string</code> | x2iedn.8xlarge vCPUs: 32 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_METAL">X2IEDN_METAL</a></code> | <code>string</code> | x2iedn.metal vCPUs: 128 Memory: 4194304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_XLARGE">X2IEDN_XLARGE</a></code> | <code>string</code> | x2iedn.xlarge vCPUs: 4 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_12XLARGE">X2IEZN_12XLARGE</a></code> | <code>string</code> | x2iezn.12xlarge vCPUs: 48 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_2XLARGE">X2IEZN_2XLARGE</a></code> | <code>string</code> | x2iezn.2xlarge vCPUs: 8 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_4XLARGE">X2IEZN_4XLARGE</a></code> | <code>string</code> | x2iezn.4xlarge vCPUs: 16 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_6XLARGE">X2IEZN_6XLARGE</a></code> | <code>string</code> | x2iezn.6xlarge vCPUs: 24 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_8XLARGE">X2IEZN_8XLARGE</a></code> | <code>string</code> | x2iezn.8xlarge vCPUs: 32 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_METAL">X2IEZN_METAL</a></code> | <code>string</code> | x2iezn.metal vCPUs: 48 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_12XLARGE">X8G_12XLARGE</a></code> | <code>string</code> | x8g.12xlarge vCPUs: 48 Memory: 786432 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_16XLARGE">X8G_16XLARGE</a></code> | <code>string</code> | x8g.16xlarge vCPUs: 64 Memory: 1048576 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_24XLARGE">X8G_24XLARGE</a></code> | <code>string</code> | x8g.24xlarge vCPUs: 96 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_2XLARGE">X8G_2XLARGE</a></code> | <code>string</code> | x8g.2xlarge vCPUs: 8 Memory: 131072 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_48XLARGE">X8G_48XLARGE</a></code> | <code>string</code> | x8g.48xlarge vCPUs: 192 Memory: 3145728 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_4XLARGE">X8G_4XLARGE</a></code> | <code>string</code> | x8g.4xlarge vCPUs: 16 Memory: 262144 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_8XLARGE">X8G_8XLARGE</a></code> | <code>string</code> | x8g.8xlarge vCPUs: 32 Memory: 524288 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_LARGE">X8G_LARGE</a></code> | <code>string</code> | x8g.large vCPUs: 2 Memory: 32768 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_MEDIUM">X8G_MEDIUM</a></code> | <code>string</code> | x8g.medium vCPUs: 1 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_METAL_24XL">X8G_METAL_24XL</a></code> | <code>string</code> | x8g.metal-24xl vCPUs: 96 Memory: 1572864 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_METAL_48XL">X8G_METAL_48XL</a></code> | <code>string</code> | x8g.metal-48xl vCPUs: 192 Memory: 3145728 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_XLARGE">X8G_XLARGE</a></code> | <code>string</code> | x8g.xlarge vCPUs: 4 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_12XLARGE">Z1D_12XLARGE</a></code> | <code>string</code> | z1d.12xlarge vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_2XLARGE">Z1D_2XLARGE</a></code> | <code>string</code> | z1d.2xlarge vCPUs: 8 Memory: 65536 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_3XLARGE">Z1D_3XLARGE</a></code> | <code>string</code> | z1d.3xlarge vCPUs: 12 Memory: 98304 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_6XLARGE">Z1D_6XLARGE</a></code> | <code>string</code> | z1d.6xlarge vCPUs: 24 Memory: 196608 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_LARGE">Z1D_LARGE</a></code> | <code>string</code> | z1d.large vCPUs: 2 Memory: 16384 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_METAL">Z1D_METAL</a></code> | <code>string</code> | z1d.metal vCPUs: 48 Memory: 393216 MiB. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_XLARGE">Z1D_XLARGE</a></code> | <code>string</code> | z1d.xlarge vCPUs: 4 Memory: 32768 MiB. |

---

##### `A1_2XLARGE`<sup>Required</sup> <a name="A1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_2XLARGE"></a>

```typescript
public readonly A1_2XLARGE: string;
```

- *Type:* string

a1.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `A1_4XLARGE`<sup>Required</sup> <a name="A1_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_4XLARGE"></a>

```typescript
public readonly A1_4XLARGE: string;
```

- *Type:* string

a1.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `A1_LARGE`<sup>Required</sup> <a name="A1_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_LARGE"></a>

```typescript
public readonly A1_LARGE: string;
```

- *Type:* string

a1.large vCPUs: 2 Memory: 4096 MiB.

---

##### `A1_MEDIUM`<sup>Required</sup> <a name="A1_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_MEDIUM"></a>

```typescript
public readonly A1_MEDIUM: string;
```

- *Type:* string

a1.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `A1_METAL`<sup>Required</sup> <a name="A1_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_METAL"></a>

```typescript
public readonly A1_METAL: string;
```

- *Type:* string

a1.metal vCPUs: 16 Memory: 32768 MiB.

---

##### `A1_XLARGE`<sup>Required</sup> <a name="A1_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.A1_XLARGE"></a>

```typescript
public readonly A1_XLARGE: string;
```

- *Type:* string

a1.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C1_MEDIUM`<sup>Required</sup> <a name="C1_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C1_MEDIUM"></a>

```typescript
public readonly C1_MEDIUM: string;
```

- *Type:* string

c1.medium vCPUs: 2 Memory: 1740 MiB.

---

##### `C1_XLARGE`<sup>Required</sup> <a name="C1_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C1_XLARGE"></a>

```typescript
public readonly C1_XLARGE: string;
```

- *Type:* string

c1.xlarge vCPUs: 8 Memory: 7168 MiB.

---

##### `C3_2XLARGE`<sup>Required</sup> <a name="C3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_2XLARGE"></a>

```typescript
public readonly C3_2XLARGE: string;
```

- *Type:* string

c3.2xlarge vCPUs: 8 Memory: 15360 MiB.

---

##### `C3_4XLARGE`<sup>Required</sup> <a name="C3_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_4XLARGE"></a>

```typescript
public readonly C3_4XLARGE: string;
```

- *Type:* string

c3.4xlarge vCPUs: 16 Memory: 30720 MiB.

---

##### `C3_8XLARGE`<sup>Required</sup> <a name="C3_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_8XLARGE"></a>

```typescript
public readonly C3_8XLARGE: string;
```

- *Type:* string

c3.8xlarge vCPUs: 32 Memory: 61440 MiB.

---

##### `C3_LARGE`<sup>Required</sup> <a name="C3_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_LARGE"></a>

```typescript
public readonly C3_LARGE: string;
```

- *Type:* string

c3.large vCPUs: 2 Memory: 3840 MiB.

---

##### `C3_XLARGE`<sup>Required</sup> <a name="C3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C3_XLARGE"></a>

```typescript
public readonly C3_XLARGE: string;
```

- *Type:* string

c3.xlarge vCPUs: 4 Memory: 7680 MiB.

---

##### `C4_2XLARGE`<sup>Required</sup> <a name="C4_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_2XLARGE"></a>

```typescript
public readonly C4_2XLARGE: string;
```

- *Type:* string

c4.2xlarge vCPUs: 8 Memory: 15360 MiB.

---

##### `C4_4XLARGE`<sup>Required</sup> <a name="C4_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_4XLARGE"></a>

```typescript
public readonly C4_4XLARGE: string;
```

- *Type:* string

c4.4xlarge vCPUs: 16 Memory: 30720 MiB.

---

##### `C4_8XLARGE`<sup>Required</sup> <a name="C4_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_8XLARGE"></a>

```typescript
public readonly C4_8XLARGE: string;
```

- *Type:* string

c4.8xlarge vCPUs: 36 Memory: 61440 MiB.

---

##### `C4_LARGE`<sup>Required</sup> <a name="C4_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_LARGE"></a>

```typescript
public readonly C4_LARGE: string;
```

- *Type:* string

c4.large vCPUs: 2 Memory: 3840 MiB.

---

##### `C4_XLARGE`<sup>Required</sup> <a name="C4_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C4_XLARGE"></a>

```typescript
public readonly C4_XLARGE: string;
```

- *Type:* string

c4.xlarge vCPUs: 4 Memory: 7680 MiB.

---

##### `C5_12XLARGE`<sup>Required</sup> <a name="C5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_12XLARGE"></a>

```typescript
public readonly C5_12XLARGE: string;
```

- *Type:* string

c5.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C5_18XLARGE`<sup>Required</sup> <a name="C5_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_18XLARGE"></a>

```typescript
public readonly C5_18XLARGE: string;
```

- *Type:* string

c5.18xlarge vCPUs: 72 Memory: 147456 MiB.

---

##### `C5_24XLARGE`<sup>Required</sup> <a name="C5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_24XLARGE"></a>

```typescript
public readonly C5_24XLARGE: string;
```

- *Type:* string

c5.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C5_2XLARGE`<sup>Required</sup> <a name="C5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_2XLARGE"></a>

```typescript
public readonly C5_2XLARGE: string;
```

- *Type:* string

c5.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C5_4XLARGE`<sup>Required</sup> <a name="C5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_4XLARGE"></a>

```typescript
public readonly C5_4XLARGE: string;
```

- *Type:* string

c5.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C5_9XLARGE`<sup>Required</sup> <a name="C5_9XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_9XLARGE"></a>

```typescript
public readonly C5_9XLARGE: string;
```

- *Type:* string

c5.9xlarge vCPUs: 36 Memory: 73728 MiB.

---

##### `C5_LARGE`<sup>Required</sup> <a name="C5_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_LARGE"></a>

```typescript
public readonly C5_LARGE: string;
```

- *Type:* string

c5.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C5_METAL`<sup>Required</sup> <a name="C5_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_METAL"></a>

```typescript
public readonly C5_METAL: string;
```

- *Type:* string

c5.metal vCPUs: 96 Memory: 196608 MiB.

---

##### `C5_XLARGE`<sup>Required</sup> <a name="C5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5_XLARGE"></a>

```typescript
public readonly C5_XLARGE: string;
```

- *Type:* string

c5.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C5A_12XLARGE`<sup>Required</sup> <a name="C5A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_12XLARGE"></a>

```typescript
public readonly C5A_12XLARGE: string;
```

- *Type:* string

c5a.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C5A_16XLARGE`<sup>Required</sup> <a name="C5A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_16XLARGE"></a>

```typescript
public readonly C5A_16XLARGE: string;
```

- *Type:* string

c5a.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C5A_24XLARGE`<sup>Required</sup> <a name="C5A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_24XLARGE"></a>

```typescript
public readonly C5A_24XLARGE: string;
```

- *Type:* string

c5a.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C5A_2XLARGE`<sup>Required</sup> <a name="C5A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_2XLARGE"></a>

```typescript
public readonly C5A_2XLARGE: string;
```

- *Type:* string

c5a.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C5A_4XLARGE`<sup>Required</sup> <a name="C5A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_4XLARGE"></a>

```typescript
public readonly C5A_4XLARGE: string;
```

- *Type:* string

c5a.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C5A_8XLARGE`<sup>Required</sup> <a name="C5A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_8XLARGE"></a>

```typescript
public readonly C5A_8XLARGE: string;
```

- *Type:* string

c5a.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C5A_LARGE`<sup>Required</sup> <a name="C5A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_LARGE"></a>

```typescript
public readonly C5A_LARGE: string;
```

- *Type:* string

c5a.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C5A_XLARGE`<sup>Required</sup> <a name="C5A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5A_XLARGE"></a>

```typescript
public readonly C5A_XLARGE: string;
```

- *Type:* string

c5a.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C5AD_12XLARGE`<sup>Required</sup> <a name="C5AD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_12XLARGE"></a>

```typescript
public readonly C5AD_12XLARGE: string;
```

- *Type:* string

c5ad.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C5AD_16XLARGE`<sup>Required</sup> <a name="C5AD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_16XLARGE"></a>

```typescript
public readonly C5AD_16XLARGE: string;
```

- *Type:* string

c5ad.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C5AD_24XLARGE`<sup>Required</sup> <a name="C5AD_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_24XLARGE"></a>

```typescript
public readonly C5AD_24XLARGE: string;
```

- *Type:* string

c5ad.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C5AD_2XLARGE`<sup>Required</sup> <a name="C5AD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_2XLARGE"></a>

```typescript
public readonly C5AD_2XLARGE: string;
```

- *Type:* string

c5ad.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C5AD_4XLARGE`<sup>Required</sup> <a name="C5AD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_4XLARGE"></a>

```typescript
public readonly C5AD_4XLARGE: string;
```

- *Type:* string

c5ad.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C5AD_8XLARGE`<sup>Required</sup> <a name="C5AD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_8XLARGE"></a>

```typescript
public readonly C5AD_8XLARGE: string;
```

- *Type:* string

c5ad.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C5AD_LARGE`<sup>Required</sup> <a name="C5AD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_LARGE"></a>

```typescript
public readonly C5AD_LARGE: string;
```

- *Type:* string

c5ad.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C5AD_XLARGE`<sup>Required</sup> <a name="C5AD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5AD_XLARGE"></a>

```typescript
public readonly C5AD_XLARGE: string;
```

- *Type:* string

c5ad.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C5D_12XLARGE`<sup>Required</sup> <a name="C5D_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_12XLARGE"></a>

```typescript
public readonly C5D_12XLARGE: string;
```

- *Type:* string

c5d.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C5D_18XLARGE`<sup>Required</sup> <a name="C5D_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_18XLARGE"></a>

```typescript
public readonly C5D_18XLARGE: string;
```

- *Type:* string

c5d.18xlarge vCPUs: 72 Memory: 147456 MiB.

---

##### `C5D_24XLARGE`<sup>Required</sup> <a name="C5D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_24XLARGE"></a>

```typescript
public readonly C5D_24XLARGE: string;
```

- *Type:* string

c5d.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C5D_2XLARGE`<sup>Required</sup> <a name="C5D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_2XLARGE"></a>

```typescript
public readonly C5D_2XLARGE: string;
```

- *Type:* string

c5d.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C5D_4XLARGE`<sup>Required</sup> <a name="C5D_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_4XLARGE"></a>

```typescript
public readonly C5D_4XLARGE: string;
```

- *Type:* string

c5d.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C5D_9XLARGE`<sup>Required</sup> <a name="C5D_9XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_9XLARGE"></a>

```typescript
public readonly C5D_9XLARGE: string;
```

- *Type:* string

c5d.9xlarge vCPUs: 36 Memory: 73728 MiB.

---

##### `C5D_LARGE`<sup>Required</sup> <a name="C5D_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_LARGE"></a>

```typescript
public readonly C5D_LARGE: string;
```

- *Type:* string

c5d.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C5D_METAL`<sup>Required</sup> <a name="C5D_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_METAL"></a>

```typescript
public readonly C5D_METAL: string;
```

- *Type:* string

c5d.metal vCPUs: 96 Memory: 196608 MiB.

---

##### `C5D_XLARGE`<sup>Required</sup> <a name="C5D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5D_XLARGE"></a>

```typescript
public readonly C5D_XLARGE: string;
```

- *Type:* string

c5d.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C5N_18XLARGE`<sup>Required</sup> <a name="C5N_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_18XLARGE"></a>

```typescript
public readonly C5N_18XLARGE: string;
```

- *Type:* string

c5n.18xlarge vCPUs: 72 Memory: 196608 MiB.

---

##### `C5N_2XLARGE`<sup>Required</sup> <a name="C5N_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_2XLARGE"></a>

```typescript
public readonly C5N_2XLARGE: string;
```

- *Type:* string

c5n.2xlarge vCPUs: 8 Memory: 21504 MiB.

---

##### `C5N_4XLARGE`<sup>Required</sup> <a name="C5N_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_4XLARGE"></a>

```typescript
public readonly C5N_4XLARGE: string;
```

- *Type:* string

c5n.4xlarge vCPUs: 16 Memory: 43008 MiB.

---

##### `C5N_9XLARGE`<sup>Required</sup> <a name="C5N_9XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_9XLARGE"></a>

```typescript
public readonly C5N_9XLARGE: string;
```

- *Type:* string

c5n.9xlarge vCPUs: 36 Memory: 98304 MiB.

---

##### `C5N_LARGE`<sup>Required</sup> <a name="C5N_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_LARGE"></a>

```typescript
public readonly C5N_LARGE: string;
```

- *Type:* string

c5n.large vCPUs: 2 Memory: 5376 MiB.

---

##### `C5N_METAL`<sup>Required</sup> <a name="C5N_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_METAL"></a>

```typescript
public readonly C5N_METAL: string;
```

- *Type:* string

c5n.metal vCPUs: 72 Memory: 196608 MiB.

---

##### `C5N_XLARGE`<sup>Required</sup> <a name="C5N_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C5N_XLARGE"></a>

```typescript
public readonly C5N_XLARGE: string;
```

- *Type:* string

c5n.xlarge vCPUs: 4 Memory: 10752 MiB.

---

##### `C6A_12XLARGE`<sup>Required</sup> <a name="C6A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_12XLARGE"></a>

```typescript
public readonly C6A_12XLARGE: string;
```

- *Type:* string

c6a.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6A_16XLARGE`<sup>Required</sup> <a name="C6A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_16XLARGE"></a>

```typescript
public readonly C6A_16XLARGE: string;
```

- *Type:* string

c6a.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6A_24XLARGE`<sup>Required</sup> <a name="C6A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_24XLARGE"></a>

```typescript
public readonly C6A_24XLARGE: string;
```

- *Type:* string

c6a.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C6A_2XLARGE`<sup>Required</sup> <a name="C6A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_2XLARGE"></a>

```typescript
public readonly C6A_2XLARGE: string;
```

- *Type:* string

c6a.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6A_32XLARGE`<sup>Required</sup> <a name="C6A_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_32XLARGE"></a>

```typescript
public readonly C6A_32XLARGE: string;
```

- *Type:* string

c6a.32xlarge vCPUs: 128 Memory: 262144 MiB.

---

##### `C6A_48XLARGE`<sup>Required</sup> <a name="C6A_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_48XLARGE"></a>

```typescript
public readonly C6A_48XLARGE: string;
```

- *Type:* string

c6a.48xlarge vCPUs: 192 Memory: 393216 MiB.

---

##### `C6A_4XLARGE`<sup>Required</sup> <a name="C6A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_4XLARGE"></a>

```typescript
public readonly C6A_4XLARGE: string;
```

- *Type:* string

c6a.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6A_8XLARGE`<sup>Required</sup> <a name="C6A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_8XLARGE"></a>

```typescript
public readonly C6A_8XLARGE: string;
```

- *Type:* string

c6a.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6A_LARGE`<sup>Required</sup> <a name="C6A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_LARGE"></a>

```typescript
public readonly C6A_LARGE: string;
```

- *Type:* string

c6a.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6A_METAL`<sup>Required</sup> <a name="C6A_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_METAL"></a>

```typescript
public readonly C6A_METAL: string;
```

- *Type:* string

c6a.metal vCPUs: 192 Memory: 393216 MiB.

---

##### `C6A_XLARGE`<sup>Required</sup> <a name="C6A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6A_XLARGE"></a>

```typescript
public readonly C6A_XLARGE: string;
```

- *Type:* string

c6a.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C6G_12XLARGE`<sup>Required</sup> <a name="C6G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_12XLARGE"></a>

```typescript
public readonly C6G_12XLARGE: string;
```

- *Type:* string

c6g.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6G_16XLARGE`<sup>Required</sup> <a name="C6G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_16XLARGE"></a>

```typescript
public readonly C6G_16XLARGE: string;
```

- *Type:* string

c6g.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6G_2XLARGE`<sup>Required</sup> <a name="C6G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_2XLARGE"></a>

```typescript
public readonly C6G_2XLARGE: string;
```

- *Type:* string

c6g.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6G_4XLARGE`<sup>Required</sup> <a name="C6G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_4XLARGE"></a>

```typescript
public readonly C6G_4XLARGE: string;
```

- *Type:* string

c6g.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6G_8XLARGE`<sup>Required</sup> <a name="C6G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_8XLARGE"></a>

```typescript
public readonly C6G_8XLARGE: string;
```

- *Type:* string

c6g.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6G_LARGE`<sup>Required</sup> <a name="C6G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_LARGE"></a>

```typescript
public readonly C6G_LARGE: string;
```

- *Type:* string

c6g.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6G_MEDIUM`<sup>Required</sup> <a name="C6G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_MEDIUM"></a>

```typescript
public readonly C6G_MEDIUM: string;
```

- *Type:* string

c6g.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C6G_METAL`<sup>Required</sup> <a name="C6G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_METAL"></a>

```typescript
public readonly C6G_METAL: string;
```

- *Type:* string

c6g.metal vCPUs: 64 Memory: 131072 MiB.

---

##### `C6G_XLARGE`<sup>Required</sup> <a name="C6G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6G_XLARGE"></a>

```typescript
public readonly C6G_XLARGE: string;
```

- *Type:* string

c6g.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C6GD_12XLARGE`<sup>Required</sup> <a name="C6GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_12XLARGE"></a>

```typescript
public readonly C6GD_12XLARGE: string;
```

- *Type:* string

c6gd.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6GD_16XLARGE`<sup>Required</sup> <a name="C6GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_16XLARGE"></a>

```typescript
public readonly C6GD_16XLARGE: string;
```

- *Type:* string

c6gd.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6GD_2XLARGE`<sup>Required</sup> <a name="C6GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_2XLARGE"></a>

```typescript
public readonly C6GD_2XLARGE: string;
```

- *Type:* string

c6gd.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6GD_4XLARGE`<sup>Required</sup> <a name="C6GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_4XLARGE"></a>

```typescript
public readonly C6GD_4XLARGE: string;
```

- *Type:* string

c6gd.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6GD_8XLARGE`<sup>Required</sup> <a name="C6GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_8XLARGE"></a>

```typescript
public readonly C6GD_8XLARGE: string;
```

- *Type:* string

c6gd.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6GD_LARGE`<sup>Required</sup> <a name="C6GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_LARGE"></a>

```typescript
public readonly C6GD_LARGE: string;
```

- *Type:* string

c6gd.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6GD_MEDIUM`<sup>Required</sup> <a name="C6GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_MEDIUM"></a>

```typescript
public readonly C6GD_MEDIUM: string;
```

- *Type:* string

c6gd.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C6GD_METAL`<sup>Required</sup> <a name="C6GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_METAL"></a>

```typescript
public readonly C6GD_METAL: string;
```

- *Type:* string

c6gd.metal vCPUs: 64 Memory: 131072 MiB.

---

##### `C6GD_XLARGE`<sup>Required</sup> <a name="C6GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GD_XLARGE"></a>

```typescript
public readonly C6GD_XLARGE: string;
```

- *Type:* string

c6gd.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C6GN_12XLARGE`<sup>Required</sup> <a name="C6GN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_12XLARGE"></a>

```typescript
public readonly C6GN_12XLARGE: string;
```

- *Type:* string

c6gn.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6GN_16XLARGE`<sup>Required</sup> <a name="C6GN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_16XLARGE"></a>

```typescript
public readonly C6GN_16XLARGE: string;
```

- *Type:* string

c6gn.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6GN_2XLARGE`<sup>Required</sup> <a name="C6GN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_2XLARGE"></a>

```typescript
public readonly C6GN_2XLARGE: string;
```

- *Type:* string

c6gn.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6GN_4XLARGE`<sup>Required</sup> <a name="C6GN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_4XLARGE"></a>

```typescript
public readonly C6GN_4XLARGE: string;
```

- *Type:* string

c6gn.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6GN_8XLARGE`<sup>Required</sup> <a name="C6GN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_8XLARGE"></a>

```typescript
public readonly C6GN_8XLARGE: string;
```

- *Type:* string

c6gn.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6GN_LARGE`<sup>Required</sup> <a name="C6GN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_LARGE"></a>

```typescript
public readonly C6GN_LARGE: string;
```

- *Type:* string

c6gn.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6GN_MEDIUM`<sup>Required</sup> <a name="C6GN_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_MEDIUM"></a>

```typescript
public readonly C6GN_MEDIUM: string;
```

- *Type:* string

c6gn.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C6GN_XLARGE`<sup>Required</sup> <a name="C6GN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6GN_XLARGE"></a>

```typescript
public readonly C6GN_XLARGE: string;
```

- *Type:* string

c6gn.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C6I_12XLARGE`<sup>Required</sup> <a name="C6I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_12XLARGE"></a>

```typescript
public readonly C6I_12XLARGE: string;
```

- *Type:* string

c6i.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6I_16XLARGE`<sup>Required</sup> <a name="C6I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_16XLARGE"></a>

```typescript
public readonly C6I_16XLARGE: string;
```

- *Type:* string

c6i.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6I_24XLARGE`<sup>Required</sup> <a name="C6I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_24XLARGE"></a>

```typescript
public readonly C6I_24XLARGE: string;
```

- *Type:* string

c6i.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C6I_2XLARGE`<sup>Required</sup> <a name="C6I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_2XLARGE"></a>

```typescript
public readonly C6I_2XLARGE: string;
```

- *Type:* string

c6i.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6I_32XLARGE`<sup>Required</sup> <a name="C6I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_32XLARGE"></a>

```typescript
public readonly C6I_32XLARGE: string;
```

- *Type:* string

c6i.32xlarge vCPUs: 128 Memory: 262144 MiB.

---

##### `C6I_4XLARGE`<sup>Required</sup> <a name="C6I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_4XLARGE"></a>

```typescript
public readonly C6I_4XLARGE: string;
```

- *Type:* string

c6i.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6I_8XLARGE`<sup>Required</sup> <a name="C6I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_8XLARGE"></a>

```typescript
public readonly C6I_8XLARGE: string;
```

- *Type:* string

c6i.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6I_LARGE`<sup>Required</sup> <a name="C6I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_LARGE"></a>

```typescript
public readonly C6I_LARGE: string;
```

- *Type:* string

c6i.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6I_METAL`<sup>Required</sup> <a name="C6I_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_METAL"></a>

```typescript
public readonly C6I_METAL: string;
```

- *Type:* string

c6i.metal vCPUs: 128 Memory: 262144 MiB.

---

##### `C6I_XLARGE`<sup>Required</sup> <a name="C6I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6I_XLARGE"></a>

```typescript
public readonly C6I_XLARGE: string;
```

- *Type:* string

c6i.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C6ID_12XLARGE`<sup>Required</sup> <a name="C6ID_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_12XLARGE"></a>

```typescript
public readonly C6ID_12XLARGE: string;
```

- *Type:* string

c6id.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6ID_16XLARGE`<sup>Required</sup> <a name="C6ID_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_16XLARGE"></a>

```typescript
public readonly C6ID_16XLARGE: string;
```

- *Type:* string

c6id.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6ID_24XLARGE`<sup>Required</sup> <a name="C6ID_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_24XLARGE"></a>

```typescript
public readonly C6ID_24XLARGE: string;
```

- *Type:* string

c6id.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C6ID_2XLARGE`<sup>Required</sup> <a name="C6ID_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_2XLARGE"></a>

```typescript
public readonly C6ID_2XLARGE: string;
```

- *Type:* string

c6id.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6ID_32XLARGE`<sup>Required</sup> <a name="C6ID_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_32XLARGE"></a>

```typescript
public readonly C6ID_32XLARGE: string;
```

- *Type:* string

c6id.32xlarge vCPUs: 128 Memory: 262144 MiB.

---

##### `C6ID_4XLARGE`<sup>Required</sup> <a name="C6ID_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_4XLARGE"></a>

```typescript
public readonly C6ID_4XLARGE: string;
```

- *Type:* string

c6id.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6ID_8XLARGE`<sup>Required</sup> <a name="C6ID_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_8XLARGE"></a>

```typescript
public readonly C6ID_8XLARGE: string;
```

- *Type:* string

c6id.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6ID_LARGE`<sup>Required</sup> <a name="C6ID_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_LARGE"></a>

```typescript
public readonly C6ID_LARGE: string;
```

- *Type:* string

c6id.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6ID_METAL`<sup>Required</sup> <a name="C6ID_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_METAL"></a>

```typescript
public readonly C6ID_METAL: string;
```

- *Type:* string

c6id.metal vCPUs: 128 Memory: 262144 MiB.

---

##### `C6ID_XLARGE`<sup>Required</sup> <a name="C6ID_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6ID_XLARGE"></a>

```typescript
public readonly C6ID_XLARGE: string;
```

- *Type:* string

c6id.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C6IN_12XLARGE`<sup>Required</sup> <a name="C6IN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_12XLARGE"></a>

```typescript
public readonly C6IN_12XLARGE: string;
```

- *Type:* string

c6in.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C6IN_16XLARGE`<sup>Required</sup> <a name="C6IN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_16XLARGE"></a>

```typescript
public readonly C6IN_16XLARGE: string;
```

- *Type:* string

c6in.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C6IN_24XLARGE`<sup>Required</sup> <a name="C6IN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_24XLARGE"></a>

```typescript
public readonly C6IN_24XLARGE: string;
```

- *Type:* string

c6in.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C6IN_2XLARGE`<sup>Required</sup> <a name="C6IN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_2XLARGE"></a>

```typescript
public readonly C6IN_2XLARGE: string;
```

- *Type:* string

c6in.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C6IN_32XLARGE`<sup>Required</sup> <a name="C6IN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_32XLARGE"></a>

```typescript
public readonly C6IN_32XLARGE: string;
```

- *Type:* string

c6in.32xlarge vCPUs: 128 Memory: 262144 MiB.

---

##### `C6IN_4XLARGE`<sup>Required</sup> <a name="C6IN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_4XLARGE"></a>

```typescript
public readonly C6IN_4XLARGE: string;
```

- *Type:* string

c6in.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C6IN_8XLARGE`<sup>Required</sup> <a name="C6IN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_8XLARGE"></a>

```typescript
public readonly C6IN_8XLARGE: string;
```

- *Type:* string

c6in.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C6IN_LARGE`<sup>Required</sup> <a name="C6IN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_LARGE"></a>

```typescript
public readonly C6IN_LARGE: string;
```

- *Type:* string

c6in.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C6IN_METAL`<sup>Required</sup> <a name="C6IN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_METAL"></a>

```typescript
public readonly C6IN_METAL: string;
```

- *Type:* string

c6in.metal vCPUs: 128 Memory: 262144 MiB.

---

##### `C6IN_XLARGE`<sup>Required</sup> <a name="C6IN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C6IN_XLARGE"></a>

```typescript
public readonly C6IN_XLARGE: string;
```

- *Type:* string

c6in.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C7A_12XLARGE`<sup>Required</sup> <a name="C7A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_12XLARGE"></a>

```typescript
public readonly C7A_12XLARGE: string;
```

- *Type:* string

c7a.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C7A_16XLARGE`<sup>Required</sup> <a name="C7A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_16XLARGE"></a>

```typescript
public readonly C7A_16XLARGE: string;
```

- *Type:* string

c7a.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C7A_24XLARGE`<sup>Required</sup> <a name="C7A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_24XLARGE"></a>

```typescript
public readonly C7A_24XLARGE: string;
```

- *Type:* string

c7a.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C7A_2XLARGE`<sup>Required</sup> <a name="C7A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_2XLARGE"></a>

```typescript
public readonly C7A_2XLARGE: string;
```

- *Type:* string

c7a.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C7A_32XLARGE`<sup>Required</sup> <a name="C7A_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_32XLARGE"></a>

```typescript
public readonly C7A_32XLARGE: string;
```

- *Type:* string

c7a.32xlarge vCPUs: 128 Memory: 262144 MiB.

---

##### `C7A_48XLARGE`<sup>Required</sup> <a name="C7A_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_48XLARGE"></a>

```typescript
public readonly C7A_48XLARGE: string;
```

- *Type:* string

c7a.48xlarge vCPUs: 192 Memory: 393216 MiB.

---

##### `C7A_4XLARGE`<sup>Required</sup> <a name="C7A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_4XLARGE"></a>

```typescript
public readonly C7A_4XLARGE: string;
```

- *Type:* string

c7a.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C7A_8XLARGE`<sup>Required</sup> <a name="C7A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_8XLARGE"></a>

```typescript
public readonly C7A_8XLARGE: string;
```

- *Type:* string

c7a.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C7A_LARGE`<sup>Required</sup> <a name="C7A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_LARGE"></a>

```typescript
public readonly C7A_LARGE: string;
```

- *Type:* string

c7a.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C7A_MEDIUM`<sup>Required</sup> <a name="C7A_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_MEDIUM"></a>

```typescript
public readonly C7A_MEDIUM: string;
```

- *Type:* string

c7a.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C7A_METAL_48XL`<sup>Required</sup> <a name="C7A_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_METAL_48XL"></a>

```typescript
public readonly C7A_METAL_48XL: string;
```

- *Type:* string

c7a.metal-48xl vCPUs: 192 Memory: 393216 MiB.

---

##### `C7A_XLARGE`<sup>Required</sup> <a name="C7A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7A_XLARGE"></a>

```typescript
public readonly C7A_XLARGE: string;
```

- *Type:* string

c7a.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C7G_12XLARGE`<sup>Required</sup> <a name="C7G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_12XLARGE"></a>

```typescript
public readonly C7G_12XLARGE: string;
```

- *Type:* string

c7g.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C7G_16XLARGE`<sup>Required</sup> <a name="C7G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_16XLARGE"></a>

```typescript
public readonly C7G_16XLARGE: string;
```

- *Type:* string

c7g.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C7G_2XLARGE`<sup>Required</sup> <a name="C7G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_2XLARGE"></a>

```typescript
public readonly C7G_2XLARGE: string;
```

- *Type:* string

c7g.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C7G_4XLARGE`<sup>Required</sup> <a name="C7G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_4XLARGE"></a>

```typescript
public readonly C7G_4XLARGE: string;
```

- *Type:* string

c7g.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C7G_8XLARGE`<sup>Required</sup> <a name="C7G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_8XLARGE"></a>

```typescript
public readonly C7G_8XLARGE: string;
```

- *Type:* string

c7g.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C7G_LARGE`<sup>Required</sup> <a name="C7G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_LARGE"></a>

```typescript
public readonly C7G_LARGE: string;
```

- *Type:* string

c7g.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C7G_MEDIUM`<sup>Required</sup> <a name="C7G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_MEDIUM"></a>

```typescript
public readonly C7G_MEDIUM: string;
```

- *Type:* string

c7g.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C7G_METAL`<sup>Required</sup> <a name="C7G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_METAL"></a>

```typescript
public readonly C7G_METAL: string;
```

- *Type:* string

c7g.metal vCPUs: 64 Memory: 131072 MiB.

---

##### `C7G_XLARGE`<sup>Required</sup> <a name="C7G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7G_XLARGE"></a>

```typescript
public readonly C7G_XLARGE: string;
```

- *Type:* string

c7g.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C7GD_12XLARGE`<sup>Required</sup> <a name="C7GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_12XLARGE"></a>

```typescript
public readonly C7GD_12XLARGE: string;
```

- *Type:* string

c7gd.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C7GD_16XLARGE`<sup>Required</sup> <a name="C7GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_16XLARGE"></a>

```typescript
public readonly C7GD_16XLARGE: string;
```

- *Type:* string

c7gd.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C7GD_2XLARGE`<sup>Required</sup> <a name="C7GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_2XLARGE"></a>

```typescript
public readonly C7GD_2XLARGE: string;
```

- *Type:* string

c7gd.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C7GD_4XLARGE`<sup>Required</sup> <a name="C7GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_4XLARGE"></a>

```typescript
public readonly C7GD_4XLARGE: string;
```

- *Type:* string

c7gd.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C7GD_8XLARGE`<sup>Required</sup> <a name="C7GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_8XLARGE"></a>

```typescript
public readonly C7GD_8XLARGE: string;
```

- *Type:* string

c7gd.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C7GD_LARGE`<sup>Required</sup> <a name="C7GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_LARGE"></a>

```typescript
public readonly C7GD_LARGE: string;
```

- *Type:* string

c7gd.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C7GD_MEDIUM`<sup>Required</sup> <a name="C7GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_MEDIUM"></a>

```typescript
public readonly C7GD_MEDIUM: string;
```

- *Type:* string

c7gd.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C7GD_METAL`<sup>Required</sup> <a name="C7GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_METAL"></a>

```typescript
public readonly C7GD_METAL: string;
```

- *Type:* string

c7gd.metal vCPUs: 64 Memory: 131072 MiB.

---

##### `C7GD_XLARGE`<sup>Required</sup> <a name="C7GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GD_XLARGE"></a>

```typescript
public readonly C7GD_XLARGE: string;
```

- *Type:* string

c7gd.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C7GN_12XLARGE`<sup>Required</sup> <a name="C7GN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_12XLARGE"></a>

```typescript
public readonly C7GN_12XLARGE: string;
```

- *Type:* string

c7gn.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C7GN_16XLARGE`<sup>Required</sup> <a name="C7GN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_16XLARGE"></a>

```typescript
public readonly C7GN_16XLARGE: string;
```

- *Type:* string

c7gn.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C7GN_2XLARGE`<sup>Required</sup> <a name="C7GN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_2XLARGE"></a>

```typescript
public readonly C7GN_2XLARGE: string;
```

- *Type:* string

c7gn.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C7GN_4XLARGE`<sup>Required</sup> <a name="C7GN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_4XLARGE"></a>

```typescript
public readonly C7GN_4XLARGE: string;
```

- *Type:* string

c7gn.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C7GN_8XLARGE`<sup>Required</sup> <a name="C7GN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_8XLARGE"></a>

```typescript
public readonly C7GN_8XLARGE: string;
```

- *Type:* string

c7gn.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C7GN_LARGE`<sup>Required</sup> <a name="C7GN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_LARGE"></a>

```typescript
public readonly C7GN_LARGE: string;
```

- *Type:* string

c7gn.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C7GN_MEDIUM`<sup>Required</sup> <a name="C7GN_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_MEDIUM"></a>

```typescript
public readonly C7GN_MEDIUM: string;
```

- *Type:* string

c7gn.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C7GN_METAL`<sup>Required</sup> <a name="C7GN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_METAL"></a>

```typescript
public readonly C7GN_METAL: string;
```

- *Type:* string

c7gn.metal vCPUs: 64 Memory: 131072 MiB.

---

##### `C7GN_XLARGE`<sup>Required</sup> <a name="C7GN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7GN_XLARGE"></a>

```typescript
public readonly C7GN_XLARGE: string;
```

- *Type:* string

c7gn.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C7I_12XLARGE`<sup>Required</sup> <a name="C7I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_12XLARGE"></a>

```typescript
public readonly C7I_12XLARGE: string;
```

- *Type:* string

c7i.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C7I_16XLARGE`<sup>Required</sup> <a name="C7I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_16XLARGE"></a>

```typescript
public readonly C7I_16XLARGE: string;
```

- *Type:* string

c7i.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C7I_24XLARGE`<sup>Required</sup> <a name="C7I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_24XLARGE"></a>

```typescript
public readonly C7I_24XLARGE: string;
```

- *Type:* string

c7i.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C7I_2XLARGE`<sup>Required</sup> <a name="C7I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_2XLARGE"></a>

```typescript
public readonly C7I_2XLARGE: string;
```

- *Type:* string

c7i.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C7I_48XLARGE`<sup>Required</sup> <a name="C7I_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_48XLARGE"></a>

```typescript
public readonly C7I_48XLARGE: string;
```

- *Type:* string

c7i.48xlarge vCPUs: 192 Memory: 393216 MiB.

---

##### `C7I_4XLARGE`<sup>Required</sup> <a name="C7I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_4XLARGE"></a>

```typescript
public readonly C7I_4XLARGE: string;
```

- *Type:* string

c7i.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C7I_8XLARGE`<sup>Required</sup> <a name="C7I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_8XLARGE"></a>

```typescript
public readonly C7I_8XLARGE: string;
```

- *Type:* string

c7i.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C7I_FLEX_12XLARGE`<sup>Required</sup> <a name="C7I_FLEX_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_12XLARGE"></a>

```typescript
public readonly C7I_FLEX_12XLARGE: string;
```

- *Type:* string

c7i-flex.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C7I_FLEX_16XLARGE`<sup>Required</sup> <a name="C7I_FLEX_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_16XLARGE"></a>

```typescript
public readonly C7I_FLEX_16XLARGE: string;
```

- *Type:* string

c7i-flex.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C7I_FLEX_2XLARGE`<sup>Required</sup> <a name="C7I_FLEX_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_2XLARGE"></a>

```typescript
public readonly C7I_FLEX_2XLARGE: string;
```

- *Type:* string

c7i-flex.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C7I_FLEX_4XLARGE`<sup>Required</sup> <a name="C7I_FLEX_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_4XLARGE"></a>

```typescript
public readonly C7I_FLEX_4XLARGE: string;
```

- *Type:* string

c7i-flex.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C7I_FLEX_8XLARGE`<sup>Required</sup> <a name="C7I_FLEX_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_8XLARGE"></a>

```typescript
public readonly C7I_FLEX_8XLARGE: string;
```

- *Type:* string

c7i-flex.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C7I_FLEX_LARGE`<sup>Required</sup> <a name="C7I_FLEX_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_LARGE"></a>

```typescript
public readonly C7I_FLEX_LARGE: string;
```

- *Type:* string

c7i-flex.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C7I_FLEX_XLARGE`<sup>Required</sup> <a name="C7I_FLEX_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_FLEX_XLARGE"></a>

```typescript
public readonly C7I_FLEX_XLARGE: string;
```

- *Type:* string

c7i-flex.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C7I_LARGE`<sup>Required</sup> <a name="C7I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_LARGE"></a>

```typescript
public readonly C7I_LARGE: string;
```

- *Type:* string

c7i.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C7I_METAL_24XL`<sup>Required</sup> <a name="C7I_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_METAL_24XL"></a>

```typescript
public readonly C7I_METAL_24XL: string;
```

- *Type:* string

c7i.metal-24xl vCPUs: 96 Memory: 196608 MiB.

---

##### `C7I_METAL_48XL`<sup>Required</sup> <a name="C7I_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_METAL_48XL"></a>

```typescript
public readonly C7I_METAL_48XL: string;
```

- *Type:* string

c7i.metal-48xl vCPUs: 192 Memory: 393216 MiB.

---

##### `C7I_XLARGE`<sup>Required</sup> <a name="C7I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C7I_XLARGE"></a>

```typescript
public readonly C7I_XLARGE: string;
```

- *Type:* string

c7i.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `C8G_12XLARGE`<sup>Required</sup> <a name="C8G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_12XLARGE"></a>

```typescript
public readonly C8G_12XLARGE: string;
```

- *Type:* string

c8g.12xlarge vCPUs: 48 Memory: 98304 MiB.

---

##### `C8G_16XLARGE`<sup>Required</sup> <a name="C8G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_16XLARGE"></a>

```typescript
public readonly C8G_16XLARGE: string;
```

- *Type:* string

c8g.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `C8G_24XLARGE`<sup>Required</sup> <a name="C8G_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_24XLARGE"></a>

```typescript
public readonly C8G_24XLARGE: string;
```

- *Type:* string

c8g.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `C8G_2XLARGE`<sup>Required</sup> <a name="C8G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_2XLARGE"></a>

```typescript
public readonly C8G_2XLARGE: string;
```

- *Type:* string

c8g.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `C8G_48XLARGE`<sup>Required</sup> <a name="C8G_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_48XLARGE"></a>

```typescript
public readonly C8G_48XLARGE: string;
```

- *Type:* string

c8g.48xlarge vCPUs: 192 Memory: 393216 MiB.

---

##### `C8G_4XLARGE`<sup>Required</sup> <a name="C8G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_4XLARGE"></a>

```typescript
public readonly C8G_4XLARGE: string;
```

- *Type:* string

c8g.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `C8G_8XLARGE`<sup>Required</sup> <a name="C8G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_8XLARGE"></a>

```typescript
public readonly C8G_8XLARGE: string;
```

- *Type:* string

c8g.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `C8G_LARGE`<sup>Required</sup> <a name="C8G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_LARGE"></a>

```typescript
public readonly C8G_LARGE: string;
```

- *Type:* string

c8g.large vCPUs: 2 Memory: 4096 MiB.

---

##### `C8G_MEDIUM`<sup>Required</sup> <a name="C8G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_MEDIUM"></a>

```typescript
public readonly C8G_MEDIUM: string;
```

- *Type:* string

c8g.medium vCPUs: 1 Memory: 2048 MiB.

---

##### `C8G_METAL_24XL`<sup>Required</sup> <a name="C8G_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_METAL_24XL"></a>

```typescript
public readonly C8G_METAL_24XL: string;
```

- *Type:* string

c8g.metal-24xl vCPUs: 96 Memory: 196608 MiB.

---

##### `C8G_METAL_48XL`<sup>Required</sup> <a name="C8G_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_METAL_48XL"></a>

```typescript
public readonly C8G_METAL_48XL: string;
```

- *Type:* string

c8g.metal-48xl vCPUs: 192 Memory: 393216 MiB.

---

##### `C8G_XLARGE`<sup>Required</sup> <a name="C8G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.C8G_XLARGE"></a>

```typescript
public readonly C8G_XLARGE: string;
```

- *Type:* string

c8g.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `D2_2XLARGE`<sup>Required</sup> <a name="D2_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_2XLARGE"></a>

```typescript
public readonly D2_2XLARGE: string;
```

- *Type:* string

d2.2xlarge vCPUs: 8 Memory: 62464 MiB.

---

##### `D2_4XLARGE`<sup>Required</sup> <a name="D2_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_4XLARGE"></a>

```typescript
public readonly D2_4XLARGE: string;
```

- *Type:* string

d2.4xlarge vCPUs: 16 Memory: 124928 MiB.

---

##### `D2_8XLARGE`<sup>Required</sup> <a name="D2_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_8XLARGE"></a>

```typescript
public readonly D2_8XLARGE: string;
```

- *Type:* string

d2.8xlarge vCPUs: 36 Memory: 249856 MiB.

---

##### `D2_XLARGE`<sup>Required</sup> <a name="D2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D2_XLARGE"></a>

```typescript
public readonly D2_XLARGE: string;
```

- *Type:* string

d2.xlarge vCPUs: 4 Memory: 31232 MiB.

---

##### `D3_2XLARGE`<sup>Required</sup> <a name="D3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_2XLARGE"></a>

```typescript
public readonly D3_2XLARGE: string;
```

- *Type:* string

d3.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `D3_4XLARGE`<sup>Required</sup> <a name="D3_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_4XLARGE"></a>

```typescript
public readonly D3_4XLARGE: string;
```

- *Type:* string

d3.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `D3_8XLARGE`<sup>Required</sup> <a name="D3_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_8XLARGE"></a>

```typescript
public readonly D3_8XLARGE: string;
```

- *Type:* string

d3.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `D3_XLARGE`<sup>Required</sup> <a name="D3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3_XLARGE"></a>

```typescript
public readonly D3_XLARGE: string;
```

- *Type:* string

d3.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `D3EN_12XLARGE`<sup>Required</sup> <a name="D3EN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_12XLARGE"></a>

```typescript
public readonly D3EN_12XLARGE: string;
```

- *Type:* string

d3en.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `D3EN_2XLARGE`<sup>Required</sup> <a name="D3EN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_2XLARGE"></a>

```typescript
public readonly D3EN_2XLARGE: string;
```

- *Type:* string

d3en.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `D3EN_4XLARGE`<sup>Required</sup> <a name="D3EN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_4XLARGE"></a>

```typescript
public readonly D3EN_4XLARGE: string;
```

- *Type:* string

d3en.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `D3EN_6XLARGE`<sup>Required</sup> <a name="D3EN_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_6XLARGE"></a>

```typescript
public readonly D3EN_6XLARGE: string;
```

- *Type:* string

d3en.6xlarge vCPUs: 24 Memory: 98304 MiB.

---

##### `D3EN_8XLARGE`<sup>Required</sup> <a name="D3EN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_8XLARGE"></a>

```typescript
public readonly D3EN_8XLARGE: string;
```

- *Type:* string

d3en.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `D3EN_XLARGE`<sup>Required</sup> <a name="D3EN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.D3EN_XLARGE"></a>

```typescript
public readonly D3EN_XLARGE: string;
```

- *Type:* string

d3en.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `DL1_24XLARGE`<sup>Required</sup> <a name="DL1_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.DL1_24XLARGE"></a>

```typescript
public readonly DL1_24XLARGE: string;
```

- *Type:* string

dl1.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `F1_16XLARGE`<sup>Required</sup> <a name="F1_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F1_16XLARGE"></a>

```typescript
public readonly F1_16XLARGE: string;
```

- *Type:* string

f1.16xlarge vCPUs: 64 Memory: 999424 MiB.

---

##### `F1_2XLARGE`<sup>Required</sup> <a name="F1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F1_2XLARGE"></a>

```typescript
public readonly F1_2XLARGE: string;
```

- *Type:* string

f1.2xlarge vCPUs: 8 Memory: 124928 MiB.

---

##### `F1_4XLARGE`<sup>Required</sup> <a name="F1_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F1_4XLARGE"></a>

```typescript
public readonly F1_4XLARGE: string;
```

- *Type:* string

f1.4xlarge vCPUs: 16 Memory: 249856 MiB.

---

##### `F2_12XLARGE`<sup>Required</sup> <a name="F2_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F2_12XLARGE"></a>

```typescript
public readonly F2_12XLARGE: string;
```

- *Type:* string

f2.12xlarge vCPUs: 48 Memory: 524288 MiB.

---

##### `F2_48XLARGE`<sup>Required</sup> <a name="F2_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F2_48XLARGE"></a>

```typescript
public readonly F2_48XLARGE: string;
```

- *Type:* string

f2.48xlarge vCPUs: 192 Memory: 2097152 MiB.

---

##### `F2_6XLARGE`<sup>Required</sup> <a name="F2_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.F2_6XLARGE"></a>

```typescript
public readonly F2_6XLARGE: string;
```

- *Type:* string

f2.6xlarge vCPUs: 24 Memory: 262144 MiB.

---

##### `G4AD_16XLARGE`<sup>Required</sup> <a name="G4AD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_16XLARGE"></a>

```typescript
public readonly G4AD_16XLARGE: string;
```

- *Type:* string

g4ad.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `G4AD_2XLARGE`<sup>Required</sup> <a name="G4AD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_2XLARGE"></a>

```typescript
public readonly G4AD_2XLARGE: string;
```

- *Type:* string

g4ad.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `G4AD_4XLARGE`<sup>Required</sup> <a name="G4AD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_4XLARGE"></a>

```typescript
public readonly G4AD_4XLARGE: string;
```

- *Type:* string

g4ad.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `G4AD_8XLARGE`<sup>Required</sup> <a name="G4AD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_8XLARGE"></a>

```typescript
public readonly G4AD_8XLARGE: string;
```

- *Type:* string

g4ad.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `G4AD_XLARGE`<sup>Required</sup> <a name="G4AD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4AD_XLARGE"></a>

```typescript
public readonly G4AD_XLARGE: string;
```

- *Type:* string

g4ad.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `G4DN_12XLARGE`<sup>Required</sup> <a name="G4DN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_12XLARGE"></a>

```typescript
public readonly G4DN_12XLARGE: string;
```

- *Type:* string

g4dn.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `G4DN_16XLARGE`<sup>Required</sup> <a name="G4DN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_16XLARGE"></a>

```typescript
public readonly G4DN_16XLARGE: string;
```

- *Type:* string

g4dn.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `G4DN_2XLARGE`<sup>Required</sup> <a name="G4DN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_2XLARGE"></a>

```typescript
public readonly G4DN_2XLARGE: string;
```

- *Type:* string

g4dn.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `G4DN_4XLARGE`<sup>Required</sup> <a name="G4DN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_4XLARGE"></a>

```typescript
public readonly G4DN_4XLARGE: string;
```

- *Type:* string

g4dn.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `G4DN_8XLARGE`<sup>Required</sup> <a name="G4DN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_8XLARGE"></a>

```typescript
public readonly G4DN_8XLARGE: string;
```

- *Type:* string

g4dn.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `G4DN_METAL`<sup>Required</sup> <a name="G4DN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_METAL"></a>

```typescript
public readonly G4DN_METAL: string;
```

- *Type:* string

g4dn.metal vCPUs: 96 Memory: 393216 MiB.

---

##### `G4DN_XLARGE`<sup>Required</sup> <a name="G4DN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G4DN_XLARGE"></a>

```typescript
public readonly G4DN_XLARGE: string;
```

- *Type:* string

g4dn.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `G5_12XLARGE`<sup>Required</sup> <a name="G5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_12XLARGE"></a>

```typescript
public readonly G5_12XLARGE: string;
```

- *Type:* string

g5.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `G5_16XLARGE`<sup>Required</sup> <a name="G5_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_16XLARGE"></a>

```typescript
public readonly G5_16XLARGE: string;
```

- *Type:* string

g5.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `G5_24XLARGE`<sup>Required</sup> <a name="G5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_24XLARGE"></a>

```typescript
public readonly G5_24XLARGE: string;
```

- *Type:* string

g5.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `G5_2XLARGE`<sup>Required</sup> <a name="G5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_2XLARGE"></a>

```typescript
public readonly G5_2XLARGE: string;
```

- *Type:* string

g5.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `G5_48XLARGE`<sup>Required</sup> <a name="G5_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_48XLARGE"></a>

```typescript
public readonly G5_48XLARGE: string;
```

- *Type:* string

g5.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `G5_4XLARGE`<sup>Required</sup> <a name="G5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_4XLARGE"></a>

```typescript
public readonly G5_4XLARGE: string;
```

- *Type:* string

g5.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `G5_8XLARGE`<sup>Required</sup> <a name="G5_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_8XLARGE"></a>

```typescript
public readonly G5_8XLARGE: string;
```

- *Type:* string

g5.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `G5_XLARGE`<sup>Required</sup> <a name="G5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5_XLARGE"></a>

```typescript
public readonly G5_XLARGE: string;
```

- *Type:* string

g5.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `G5G_16XLARGE`<sup>Required</sup> <a name="G5G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_16XLARGE"></a>

```typescript
public readonly G5G_16XLARGE: string;
```

- *Type:* string

g5g.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `G5G_2XLARGE`<sup>Required</sup> <a name="G5G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_2XLARGE"></a>

```typescript
public readonly G5G_2XLARGE: string;
```

- *Type:* string

g5g.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `G5G_4XLARGE`<sup>Required</sup> <a name="G5G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_4XLARGE"></a>

```typescript
public readonly G5G_4XLARGE: string;
```

- *Type:* string

g5g.4xlarge vCPUs: 16 Memory: 32768 MiB.

---

##### `G5G_8XLARGE`<sup>Required</sup> <a name="G5G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_8XLARGE"></a>

```typescript
public readonly G5G_8XLARGE: string;
```

- *Type:* string

g5g.8xlarge vCPUs: 32 Memory: 65536 MiB.

---

##### `G5G_METAL`<sup>Required</sup> <a name="G5G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_METAL"></a>

```typescript
public readonly G5G_METAL: string;
```

- *Type:* string

g5g.metal vCPUs: 64 Memory: 131072 MiB.

---

##### `G5G_XLARGE`<sup>Required</sup> <a name="G5G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G5G_XLARGE"></a>

```typescript
public readonly G5G_XLARGE: string;
```

- *Type:* string

g5g.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `G6_12XLARGE`<sup>Required</sup> <a name="G6_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_12XLARGE"></a>

```typescript
public readonly G6_12XLARGE: string;
```

- *Type:* string

g6.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `G6_16XLARGE`<sup>Required</sup> <a name="G6_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_16XLARGE"></a>

```typescript
public readonly G6_16XLARGE: string;
```

- *Type:* string

g6.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `G6_24XLARGE`<sup>Required</sup> <a name="G6_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_24XLARGE"></a>

```typescript
public readonly G6_24XLARGE: string;
```

- *Type:* string

g6.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `G6_2XLARGE`<sup>Required</sup> <a name="G6_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_2XLARGE"></a>

```typescript
public readonly G6_2XLARGE: string;
```

- *Type:* string

g6.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `G6_48XLARGE`<sup>Required</sup> <a name="G6_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_48XLARGE"></a>

```typescript
public readonly G6_48XLARGE: string;
```

- *Type:* string

g6.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `G6_4XLARGE`<sup>Required</sup> <a name="G6_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_4XLARGE"></a>

```typescript
public readonly G6_4XLARGE: string;
```

- *Type:* string

g6.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `G6_8XLARGE`<sup>Required</sup> <a name="G6_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_8XLARGE"></a>

```typescript
public readonly G6_8XLARGE: string;
```

- *Type:* string

g6.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `G6_XLARGE`<sup>Required</sup> <a name="G6_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6_XLARGE"></a>

```typescript
public readonly G6_XLARGE: string;
```

- *Type:* string

g6.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `G6E_12XLARGE`<sup>Required</sup> <a name="G6E_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_12XLARGE"></a>

```typescript
public readonly G6E_12XLARGE: string;
```

- *Type:* string

g6e.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `G6E_16XLARGE`<sup>Required</sup> <a name="G6E_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_16XLARGE"></a>

```typescript
public readonly G6E_16XLARGE: string;
```

- *Type:* string

g6e.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `G6E_24XLARGE`<sup>Required</sup> <a name="G6E_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_24XLARGE"></a>

```typescript
public readonly G6E_24XLARGE: string;
```

- *Type:* string

g6e.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `G6E_2XLARGE`<sup>Required</sup> <a name="G6E_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_2XLARGE"></a>

```typescript
public readonly G6E_2XLARGE: string;
```

- *Type:* string

g6e.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `G6E_48XLARGE`<sup>Required</sup> <a name="G6E_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_48XLARGE"></a>

```typescript
public readonly G6E_48XLARGE: string;
```

- *Type:* string

g6e.48xlarge vCPUs: 192 Memory: 1572864 MiB.

---

##### `G6E_4XLARGE`<sup>Required</sup> <a name="G6E_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_4XLARGE"></a>

```typescript
public readonly G6E_4XLARGE: string;
```

- *Type:* string

g6e.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `G6E_8XLARGE`<sup>Required</sup> <a name="G6E_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_8XLARGE"></a>

```typescript
public readonly G6E_8XLARGE: string;
```

- *Type:* string

g6e.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `G6E_XLARGE`<sup>Required</sup> <a name="G6E_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.G6E_XLARGE"></a>

```typescript
public readonly G6E_XLARGE: string;
```

- *Type:* string

g6e.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `GR6_4XLARGE`<sup>Required</sup> <a name="GR6_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.GR6_4XLARGE"></a>

```typescript
public readonly GR6_4XLARGE: string;
```

- *Type:* string

gr6.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `GR6_8XLARGE`<sup>Required</sup> <a name="GR6_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.GR6_8XLARGE"></a>

```typescript
public readonly GR6_8XLARGE: string;
```

- *Type:* string

gr6.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `H1_16XLARGE`<sup>Required</sup> <a name="H1_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_16XLARGE"></a>

```typescript
public readonly H1_16XLARGE: string;
```

- *Type:* string

h1.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `H1_2XLARGE`<sup>Required</sup> <a name="H1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_2XLARGE"></a>

```typescript
public readonly H1_2XLARGE: string;
```

- *Type:* string

h1.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `H1_4XLARGE`<sup>Required</sup> <a name="H1_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_4XLARGE"></a>

```typescript
public readonly H1_4XLARGE: string;
```

- *Type:* string

h1.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `H1_8XLARGE`<sup>Required</sup> <a name="H1_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.H1_8XLARGE"></a>

```typescript
public readonly H1_8XLARGE: string;
```

- *Type:* string

h1.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `HPC7G_16XLARGE`<sup>Required</sup> <a name="HPC7G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.HPC7G_16XLARGE"></a>

```typescript
public readonly HPC7G_16XLARGE: string;
```

- *Type:* string

hpc7g.16xlarge vCPUs: 64 Memory: 131072 MiB.

---

##### `HPC7G_4XLARGE`<sup>Required</sup> <a name="HPC7G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.HPC7G_4XLARGE"></a>

```typescript
public readonly HPC7G_4XLARGE: string;
```

- *Type:* string

hpc7g.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `HPC7G_8XLARGE`<sup>Required</sup> <a name="HPC7G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.HPC7G_8XLARGE"></a>

```typescript
public readonly HPC7G_8XLARGE: string;
```

- *Type:* string

hpc7g.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `I2_2XLARGE`<sup>Required</sup> <a name="I2_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_2XLARGE"></a>

```typescript
public readonly I2_2XLARGE: string;
```

- *Type:* string

i2.2xlarge vCPUs: 8 Memory: 62464 MiB.

---

##### `I2_4XLARGE`<sup>Required</sup> <a name="I2_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_4XLARGE"></a>

```typescript
public readonly I2_4XLARGE: string;
```

- *Type:* string

i2.4xlarge vCPUs: 16 Memory: 124928 MiB.

---

##### `I2_8XLARGE`<sup>Required</sup> <a name="I2_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_8XLARGE"></a>

```typescript
public readonly I2_8XLARGE: string;
```

- *Type:* string

i2.8xlarge vCPUs: 32 Memory: 249856 MiB.

---

##### `I2_XLARGE`<sup>Required</sup> <a name="I2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I2_XLARGE"></a>

```typescript
public readonly I2_XLARGE: string;
```

- *Type:* string

i2.xlarge vCPUs: 4 Memory: 31232 MiB.

---

##### `I3_16XLARGE`<sup>Required</sup> <a name="I3_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_16XLARGE"></a>

```typescript
public readonly I3_16XLARGE: string;
```

- *Type:* string

i3.16xlarge vCPUs: 64 Memory: 499712 MiB.

---

##### `I3_2XLARGE`<sup>Required</sup> <a name="I3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_2XLARGE"></a>

```typescript
public readonly I3_2XLARGE: string;
```

- *Type:* string

i3.2xlarge vCPUs: 8 Memory: 62464 MiB.

---

##### `I3_4XLARGE`<sup>Required</sup> <a name="I3_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_4XLARGE"></a>

```typescript
public readonly I3_4XLARGE: string;
```

- *Type:* string

i3.4xlarge vCPUs: 16 Memory: 124928 MiB.

---

##### `I3_8XLARGE`<sup>Required</sup> <a name="I3_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_8XLARGE"></a>

```typescript
public readonly I3_8XLARGE: string;
```

- *Type:* string

i3.8xlarge vCPUs: 32 Memory: 249856 MiB.

---

##### `I3_LARGE`<sup>Required</sup> <a name="I3_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_LARGE"></a>

```typescript
public readonly I3_LARGE: string;
```

- *Type:* string

i3.large vCPUs: 2 Memory: 15616 MiB.

---

##### `I3_METAL`<sup>Required</sup> <a name="I3_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_METAL"></a>

```typescript
public readonly I3_METAL: string;
```

- *Type:* string

i3.metal vCPUs: 72 Memory: 524288 MiB.

---

##### `I3_XLARGE`<sup>Required</sup> <a name="I3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3_XLARGE"></a>

```typescript
public readonly I3_XLARGE: string;
```

- *Type:* string

i3.xlarge vCPUs: 4 Memory: 31232 MiB.

---

##### `I3EN_12XLARGE`<sup>Required</sup> <a name="I3EN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_12XLARGE"></a>

```typescript
public readonly I3EN_12XLARGE: string;
```

- *Type:* string

i3en.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `I3EN_24XLARGE`<sup>Required</sup> <a name="I3EN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_24XLARGE"></a>

```typescript
public readonly I3EN_24XLARGE: string;
```

- *Type:* string

i3en.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `I3EN_2XLARGE`<sup>Required</sup> <a name="I3EN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_2XLARGE"></a>

```typescript
public readonly I3EN_2XLARGE: string;
```

- *Type:* string

i3en.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `I3EN_3XLARGE`<sup>Required</sup> <a name="I3EN_3XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_3XLARGE"></a>

```typescript
public readonly I3EN_3XLARGE: string;
```

- *Type:* string

i3en.3xlarge vCPUs: 12 Memory: 98304 MiB.

---

##### `I3EN_6XLARGE`<sup>Required</sup> <a name="I3EN_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_6XLARGE"></a>

```typescript
public readonly I3EN_6XLARGE: string;
```

- *Type:* string

i3en.6xlarge vCPUs: 24 Memory: 196608 MiB.

---

##### `I3EN_LARGE`<sup>Required</sup> <a name="I3EN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_LARGE"></a>

```typescript
public readonly I3EN_LARGE: string;
```

- *Type:* string

i3en.large vCPUs: 2 Memory: 16384 MiB.

---

##### `I3EN_METAL`<sup>Required</sup> <a name="I3EN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_METAL"></a>

```typescript
public readonly I3EN_METAL: string;
```

- *Type:* string

i3en.metal vCPUs: 96 Memory: 786432 MiB.

---

##### `I3EN_XLARGE`<sup>Required</sup> <a name="I3EN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I3EN_XLARGE"></a>

```typescript
public readonly I3EN_XLARGE: string;
```

- *Type:* string

i3en.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `I4G_16XLARGE`<sup>Required</sup> <a name="I4G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_16XLARGE"></a>

```typescript
public readonly I4G_16XLARGE: string;
```

- *Type:* string

i4g.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `I4G_2XLARGE`<sup>Required</sup> <a name="I4G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_2XLARGE"></a>

```typescript
public readonly I4G_2XLARGE: string;
```

- *Type:* string

i4g.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `I4G_4XLARGE`<sup>Required</sup> <a name="I4G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_4XLARGE"></a>

```typescript
public readonly I4G_4XLARGE: string;
```

- *Type:* string

i4g.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `I4G_8XLARGE`<sup>Required</sup> <a name="I4G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_8XLARGE"></a>

```typescript
public readonly I4G_8XLARGE: string;
```

- *Type:* string

i4g.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `I4G_LARGE`<sup>Required</sup> <a name="I4G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_LARGE"></a>

```typescript
public readonly I4G_LARGE: string;
```

- *Type:* string

i4g.large vCPUs: 2 Memory: 16384 MiB.

---

##### `I4G_XLARGE`<sup>Required</sup> <a name="I4G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4G_XLARGE"></a>

```typescript
public readonly I4G_XLARGE: string;
```

- *Type:* string

i4g.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `I4I_12XLARGE`<sup>Required</sup> <a name="I4I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_12XLARGE"></a>

```typescript
public readonly I4I_12XLARGE: string;
```

- *Type:* string

i4i.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `I4I_16XLARGE`<sup>Required</sup> <a name="I4I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_16XLARGE"></a>

```typescript
public readonly I4I_16XLARGE: string;
```

- *Type:* string

i4i.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `I4I_24XLARGE`<sup>Required</sup> <a name="I4I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_24XLARGE"></a>

```typescript
public readonly I4I_24XLARGE: string;
```

- *Type:* string

i4i.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `I4I_2XLARGE`<sup>Required</sup> <a name="I4I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_2XLARGE"></a>

```typescript
public readonly I4I_2XLARGE: string;
```

- *Type:* string

i4i.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `I4I_32XLARGE`<sup>Required</sup> <a name="I4I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_32XLARGE"></a>

```typescript
public readonly I4I_32XLARGE: string;
```

- *Type:* string

i4i.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `I4I_4XLARGE`<sup>Required</sup> <a name="I4I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_4XLARGE"></a>

```typescript
public readonly I4I_4XLARGE: string;
```

- *Type:* string

i4i.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `I4I_8XLARGE`<sup>Required</sup> <a name="I4I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_8XLARGE"></a>

```typescript
public readonly I4I_8XLARGE: string;
```

- *Type:* string

i4i.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `I4I_LARGE`<sup>Required</sup> <a name="I4I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_LARGE"></a>

```typescript
public readonly I4I_LARGE: string;
```

- *Type:* string

i4i.large vCPUs: 2 Memory: 16384 MiB.

---

##### `I4I_METAL`<sup>Required</sup> <a name="I4I_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_METAL"></a>

```typescript
public readonly I4I_METAL: string;
```

- *Type:* string

i4i.metal vCPUs: 128 Memory: 1048576 MiB.

---

##### `I4I_XLARGE`<sup>Required</sup> <a name="I4I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I4I_XLARGE"></a>

```typescript
public readonly I4I_XLARGE: string;
```

- *Type:* string

i4i.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `I7IE_12XLARGE`<sup>Required</sup> <a name="I7IE_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_12XLARGE"></a>

```typescript
public readonly I7IE_12XLARGE: string;
```

- *Type:* string

i7ie.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `I7IE_18XLARGE`<sup>Required</sup> <a name="I7IE_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_18XLARGE"></a>

```typescript
public readonly I7IE_18XLARGE: string;
```

- *Type:* string

i7ie.18xlarge vCPUs: 72 Memory: 589824 MiB.

---

##### `I7IE_24XLARGE`<sup>Required</sup> <a name="I7IE_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_24XLARGE"></a>

```typescript
public readonly I7IE_24XLARGE: string;
```

- *Type:* string

i7ie.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `I7IE_2XLARGE`<sup>Required</sup> <a name="I7IE_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_2XLARGE"></a>

```typescript
public readonly I7IE_2XLARGE: string;
```

- *Type:* string

i7ie.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `I7IE_3XLARGE`<sup>Required</sup> <a name="I7IE_3XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_3XLARGE"></a>

```typescript
public readonly I7IE_3XLARGE: string;
```

- *Type:* string

i7ie.3xlarge vCPUs: 12 Memory: 98304 MiB.

---

##### `I7IE_48XLARGE`<sup>Required</sup> <a name="I7IE_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_48XLARGE"></a>

```typescript
public readonly I7IE_48XLARGE: string;
```

- *Type:* string

i7ie.48xlarge vCPUs: 192 Memory: 1572864 MiB.

---

##### `I7IE_6XLARGE`<sup>Required</sup> <a name="I7IE_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_6XLARGE"></a>

```typescript
public readonly I7IE_6XLARGE: string;
```

- *Type:* string

i7ie.6xlarge vCPUs: 24 Memory: 196608 MiB.

---

##### `I7IE_LARGE`<sup>Required</sup> <a name="I7IE_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_LARGE"></a>

```typescript
public readonly I7IE_LARGE: string;
```

- *Type:* string

i7ie.large vCPUs: 2 Memory: 16384 MiB.

---

##### `I7IE_XLARGE`<sup>Required</sup> <a name="I7IE_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I7IE_XLARGE"></a>

```typescript
public readonly I7IE_XLARGE: string;
```

- *Type:* string

i7ie.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `I8G_12XLARGE`<sup>Required</sup> <a name="I8G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_12XLARGE"></a>

```typescript
public readonly I8G_12XLARGE: string;
```

- *Type:* string

i8g.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `I8G_16XLARGE`<sup>Required</sup> <a name="I8G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_16XLARGE"></a>

```typescript
public readonly I8G_16XLARGE: string;
```

- *Type:* string

i8g.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `I8G_24XLARGE`<sup>Required</sup> <a name="I8G_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_24XLARGE"></a>

```typescript
public readonly I8G_24XLARGE: string;
```

- *Type:* string

i8g.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `I8G_2XLARGE`<sup>Required</sup> <a name="I8G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_2XLARGE"></a>

```typescript
public readonly I8G_2XLARGE: string;
```

- *Type:* string

i8g.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `I8G_4XLARGE`<sup>Required</sup> <a name="I8G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_4XLARGE"></a>

```typescript
public readonly I8G_4XLARGE: string;
```

- *Type:* string

i8g.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `I8G_8XLARGE`<sup>Required</sup> <a name="I8G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_8XLARGE"></a>

```typescript
public readonly I8G_8XLARGE: string;
```

- *Type:* string

i8g.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `I8G_LARGE`<sup>Required</sup> <a name="I8G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_LARGE"></a>

```typescript
public readonly I8G_LARGE: string;
```

- *Type:* string

i8g.large vCPUs: 2 Memory: 16384 MiB.

---

##### `I8G_METAL_24XL`<sup>Required</sup> <a name="I8G_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_METAL_24XL"></a>

```typescript
public readonly I8G_METAL_24XL: string;
```

- *Type:* string

i8g.metal-24xl vCPUs: 96 Memory: 786432 MiB.

---

##### `I8G_XLARGE`<sup>Required</sup> <a name="I8G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.I8G_XLARGE"></a>

```typescript
public readonly I8G_XLARGE: string;
```

- *Type:* string

i8g.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `IM4GN_16XLARGE`<sup>Required</sup> <a name="IM4GN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_16XLARGE"></a>

```typescript
public readonly IM4GN_16XLARGE: string;
```

- *Type:* string

im4gn.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `IM4GN_2XLARGE`<sup>Required</sup> <a name="IM4GN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_2XLARGE"></a>

```typescript
public readonly IM4GN_2XLARGE: string;
```

- *Type:* string

im4gn.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `IM4GN_4XLARGE`<sup>Required</sup> <a name="IM4GN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_4XLARGE"></a>

```typescript
public readonly IM4GN_4XLARGE: string;
```

- *Type:* string

im4gn.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `IM4GN_8XLARGE`<sup>Required</sup> <a name="IM4GN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_8XLARGE"></a>

```typescript
public readonly IM4GN_8XLARGE: string;
```

- *Type:* string

im4gn.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `IM4GN_LARGE`<sup>Required</sup> <a name="IM4GN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_LARGE"></a>

```typescript
public readonly IM4GN_LARGE: string;
```

- *Type:* string

im4gn.large vCPUs: 2 Memory: 8192 MiB.

---

##### `IM4GN_XLARGE`<sup>Required</sup> <a name="IM4GN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IM4GN_XLARGE"></a>

```typescript
public readonly IM4GN_XLARGE: string;
```

- *Type:* string

im4gn.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `INF1_24XLARGE`<sup>Required</sup> <a name="INF1_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_24XLARGE"></a>

```typescript
public readonly INF1_24XLARGE: string;
```

- *Type:* string

inf1.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `INF1_2XLARGE`<sup>Required</sup> <a name="INF1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_2XLARGE"></a>

```typescript
public readonly INF1_2XLARGE: string;
```

- *Type:* string

inf1.2xlarge vCPUs: 8 Memory: 16384 MiB.

---

##### `INF1_6XLARGE`<sup>Required</sup> <a name="INF1_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_6XLARGE"></a>

```typescript
public readonly INF1_6XLARGE: string;
```

- *Type:* string

inf1.6xlarge vCPUs: 24 Memory: 49152 MiB.

---

##### `INF1_XLARGE`<sup>Required</sup> <a name="INF1_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF1_XLARGE"></a>

```typescript
public readonly INF1_XLARGE: string;
```

- *Type:* string

inf1.xlarge vCPUs: 4 Memory: 8192 MiB.

---

##### `INF2_24XLARGE`<sup>Required</sup> <a name="INF2_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_24XLARGE"></a>

```typescript
public readonly INF2_24XLARGE: string;
```

- *Type:* string

inf2.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `INF2_48XLARGE`<sup>Required</sup> <a name="INF2_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_48XLARGE"></a>

```typescript
public readonly INF2_48XLARGE: string;
```

- *Type:* string

inf2.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `INF2_8XLARGE`<sup>Required</sup> <a name="INF2_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_8XLARGE"></a>

```typescript
public readonly INF2_8XLARGE: string;
```

- *Type:* string

inf2.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `INF2_XLARGE`<sup>Required</sup> <a name="INF2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.INF2_XLARGE"></a>

```typescript
public readonly INF2_XLARGE: string;
```

- *Type:* string

inf2.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `IS4GEN_2XLARGE`<sup>Required</sup> <a name="IS4GEN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_2XLARGE"></a>

```typescript
public readonly IS4GEN_2XLARGE: string;
```

- *Type:* string

is4gen.2xlarge vCPUs: 8 Memory: 49152 MiB.

---

##### `IS4GEN_4XLARGE`<sup>Required</sup> <a name="IS4GEN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_4XLARGE"></a>

```typescript
public readonly IS4GEN_4XLARGE: string;
```

- *Type:* string

is4gen.4xlarge vCPUs: 16 Memory: 98304 MiB.

---

##### `IS4GEN_8XLARGE`<sup>Required</sup> <a name="IS4GEN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_8XLARGE"></a>

```typescript
public readonly IS4GEN_8XLARGE: string;
```

- *Type:* string

is4gen.8xlarge vCPUs: 32 Memory: 196608 MiB.

---

##### `IS4GEN_LARGE`<sup>Required</sup> <a name="IS4GEN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_LARGE"></a>

```typescript
public readonly IS4GEN_LARGE: string;
```

- *Type:* string

is4gen.large vCPUs: 2 Memory: 12288 MiB.

---

##### `IS4GEN_MEDIUM`<sup>Required</sup> <a name="IS4GEN_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_MEDIUM"></a>

```typescript
public readonly IS4GEN_MEDIUM: string;
```

- *Type:* string

is4gen.medium vCPUs: 1 Memory: 6144 MiB.

---

##### `IS4GEN_XLARGE`<sup>Required</sup> <a name="IS4GEN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.IS4GEN_XLARGE"></a>

```typescript
public readonly IS4GEN_XLARGE: string;
```

- *Type:* string

is4gen.xlarge vCPUs: 4 Memory: 24576 MiB.

---

##### `M1_LARGE`<sup>Required</sup> <a name="M1_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_LARGE"></a>

```typescript
public readonly M1_LARGE: string;
```

- *Type:* string

m1.large vCPUs: 2 Memory: 7680 MiB.

---

##### `M1_MEDIUM`<sup>Required</sup> <a name="M1_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_MEDIUM"></a>

```typescript
public readonly M1_MEDIUM: string;
```

- *Type:* string

m1.medium vCPUs: 1 Memory: 3788 MiB.

---

##### `M1_SMALL`<sup>Required</sup> <a name="M1_SMALL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_SMALL"></a>

```typescript
public readonly M1_SMALL: string;
```

- *Type:* string

m1.small vCPUs: 1 Memory: 1740 MiB.

---

##### `M1_XLARGE`<sup>Required</sup> <a name="M1_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M1_XLARGE"></a>

```typescript
public readonly M1_XLARGE: string;
```

- *Type:* string

m1.xlarge vCPUs: 4 Memory: 15360 MiB.

---

##### `M2_2XLARGE`<sup>Required</sup> <a name="M2_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M2_2XLARGE"></a>

```typescript
public readonly M2_2XLARGE: string;
```

- *Type:* string

m2.2xlarge vCPUs: 4 Memory: 35020 MiB.

---

##### `M2_4XLARGE`<sup>Required</sup> <a name="M2_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M2_4XLARGE"></a>

```typescript
public readonly M2_4XLARGE: string;
```

- *Type:* string

m2.4xlarge vCPUs: 8 Memory: 70041 MiB.

---

##### `M2_XLARGE`<sup>Required</sup> <a name="M2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M2_XLARGE"></a>

```typescript
public readonly M2_XLARGE: string;
```

- *Type:* string

m2.xlarge vCPUs: 2 Memory: 17510 MiB.

---

##### `M3_2XLARGE`<sup>Required</sup> <a name="M3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_2XLARGE"></a>

```typescript
public readonly M3_2XLARGE: string;
```

- *Type:* string

m3.2xlarge vCPUs: 8 Memory: 30720 MiB.

---

##### `M3_LARGE`<sup>Required</sup> <a name="M3_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_LARGE"></a>

```typescript
public readonly M3_LARGE: string;
```

- *Type:* string

m3.large vCPUs: 2 Memory: 7680 MiB.

---

##### `M3_MEDIUM`<sup>Required</sup> <a name="M3_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_MEDIUM"></a>

```typescript
public readonly M3_MEDIUM: string;
```

- *Type:* string

m3.medium vCPUs: 1 Memory: 3840 MiB.

---

##### `M3_XLARGE`<sup>Required</sup> <a name="M3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M3_XLARGE"></a>

```typescript
public readonly M3_XLARGE: string;
```

- *Type:* string

m3.xlarge vCPUs: 4 Memory: 15360 MiB.

---

##### `M4_10XLARGE`<sup>Required</sup> <a name="M4_10XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_10XLARGE"></a>

```typescript
public readonly M4_10XLARGE: string;
```

- *Type:* string

m4.10xlarge vCPUs: 40 Memory: 163840 MiB.

---

##### `M4_16XLARGE`<sup>Required</sup> <a name="M4_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_16XLARGE"></a>

```typescript
public readonly M4_16XLARGE: string;
```

- *Type:* string

m4.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M4_2XLARGE`<sup>Required</sup> <a name="M4_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_2XLARGE"></a>

```typescript
public readonly M4_2XLARGE: string;
```

- *Type:* string

m4.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M4_4XLARGE`<sup>Required</sup> <a name="M4_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_4XLARGE"></a>

```typescript
public readonly M4_4XLARGE: string;
```

- *Type:* string

m4.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M4_LARGE`<sup>Required</sup> <a name="M4_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_LARGE"></a>

```typescript
public readonly M4_LARGE: string;
```

- *Type:* string

m4.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M4_XLARGE`<sup>Required</sup> <a name="M4_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M4_XLARGE"></a>

```typescript
public readonly M4_XLARGE: string;
```

- *Type:* string

m4.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5_12XLARGE`<sup>Required</sup> <a name="M5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_12XLARGE"></a>

```typescript
public readonly M5_12XLARGE: string;
```

- *Type:* string

m5.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5_16XLARGE`<sup>Required</sup> <a name="M5_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_16XLARGE"></a>

```typescript
public readonly M5_16XLARGE: string;
```

- *Type:* string

m5.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M5_24XLARGE`<sup>Required</sup> <a name="M5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_24XLARGE"></a>

```typescript
public readonly M5_24XLARGE: string;
```

- *Type:* string

m5.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M5_2XLARGE`<sup>Required</sup> <a name="M5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_2XLARGE"></a>

```typescript
public readonly M5_2XLARGE: string;
```

- *Type:* string

m5.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5_4XLARGE`<sup>Required</sup> <a name="M5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_4XLARGE"></a>

```typescript
public readonly M5_4XLARGE: string;
```

- *Type:* string

m5.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M5_8XLARGE`<sup>Required</sup> <a name="M5_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_8XLARGE"></a>

```typescript
public readonly M5_8XLARGE: string;
```

- *Type:* string

m5.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M5_LARGE`<sup>Required</sup> <a name="M5_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_LARGE"></a>

```typescript
public readonly M5_LARGE: string;
```

- *Type:* string

m5.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5_METAL`<sup>Required</sup> <a name="M5_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_METAL"></a>

```typescript
public readonly M5_METAL: string;
```

- *Type:* string

m5.metal vCPUs: 96 Memory: 393216 MiB.

---

##### `M5_XLARGE`<sup>Required</sup> <a name="M5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5_XLARGE"></a>

```typescript
public readonly M5_XLARGE: string;
```

- *Type:* string

m5.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5A_12XLARGE`<sup>Required</sup> <a name="M5A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_12XLARGE"></a>

```typescript
public readonly M5A_12XLARGE: string;
```

- *Type:* string

m5a.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5A_16XLARGE`<sup>Required</sup> <a name="M5A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_16XLARGE"></a>

```typescript
public readonly M5A_16XLARGE: string;
```

- *Type:* string

m5a.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M5A_24XLARGE`<sup>Required</sup> <a name="M5A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_24XLARGE"></a>

```typescript
public readonly M5A_24XLARGE: string;
```

- *Type:* string

m5a.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M5A_2XLARGE`<sup>Required</sup> <a name="M5A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_2XLARGE"></a>

```typescript
public readonly M5A_2XLARGE: string;
```

- *Type:* string

m5a.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5A_4XLARGE`<sup>Required</sup> <a name="M5A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_4XLARGE"></a>

```typescript
public readonly M5A_4XLARGE: string;
```

- *Type:* string

m5a.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M5A_8XLARGE`<sup>Required</sup> <a name="M5A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_8XLARGE"></a>

```typescript
public readonly M5A_8XLARGE: string;
```

- *Type:* string

m5a.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M5A_LARGE`<sup>Required</sup> <a name="M5A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_LARGE"></a>

```typescript
public readonly M5A_LARGE: string;
```

- *Type:* string

m5a.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5A_XLARGE`<sup>Required</sup> <a name="M5A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5A_XLARGE"></a>

```typescript
public readonly M5A_XLARGE: string;
```

- *Type:* string

m5a.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5AD_12XLARGE`<sup>Required</sup> <a name="M5AD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_12XLARGE"></a>

```typescript
public readonly M5AD_12XLARGE: string;
```

- *Type:* string

m5ad.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5AD_16XLARGE`<sup>Required</sup> <a name="M5AD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_16XLARGE"></a>

```typescript
public readonly M5AD_16XLARGE: string;
```

- *Type:* string

m5ad.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M5AD_24XLARGE`<sup>Required</sup> <a name="M5AD_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_24XLARGE"></a>

```typescript
public readonly M5AD_24XLARGE: string;
```

- *Type:* string

m5ad.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M5AD_2XLARGE`<sup>Required</sup> <a name="M5AD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_2XLARGE"></a>

```typescript
public readonly M5AD_2XLARGE: string;
```

- *Type:* string

m5ad.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5AD_4XLARGE`<sup>Required</sup> <a name="M5AD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_4XLARGE"></a>

```typescript
public readonly M5AD_4XLARGE: string;
```

- *Type:* string

m5ad.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M5AD_8XLARGE`<sup>Required</sup> <a name="M5AD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_8XLARGE"></a>

```typescript
public readonly M5AD_8XLARGE: string;
```

- *Type:* string

m5ad.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M5AD_LARGE`<sup>Required</sup> <a name="M5AD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_LARGE"></a>

```typescript
public readonly M5AD_LARGE: string;
```

- *Type:* string

m5ad.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5AD_XLARGE`<sup>Required</sup> <a name="M5AD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5AD_XLARGE"></a>

```typescript
public readonly M5AD_XLARGE: string;
```

- *Type:* string

m5ad.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5D_12XLARGE`<sup>Required</sup> <a name="M5D_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_12XLARGE"></a>

```typescript
public readonly M5D_12XLARGE: string;
```

- *Type:* string

m5d.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5D_16XLARGE`<sup>Required</sup> <a name="M5D_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_16XLARGE"></a>

```typescript
public readonly M5D_16XLARGE: string;
```

- *Type:* string

m5d.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M5D_24XLARGE`<sup>Required</sup> <a name="M5D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_24XLARGE"></a>

```typescript
public readonly M5D_24XLARGE: string;
```

- *Type:* string

m5d.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M5D_2XLARGE`<sup>Required</sup> <a name="M5D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_2XLARGE"></a>

```typescript
public readonly M5D_2XLARGE: string;
```

- *Type:* string

m5d.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5D_4XLARGE`<sup>Required</sup> <a name="M5D_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_4XLARGE"></a>

```typescript
public readonly M5D_4XLARGE: string;
```

- *Type:* string

m5d.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M5D_8XLARGE`<sup>Required</sup> <a name="M5D_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_8XLARGE"></a>

```typescript
public readonly M5D_8XLARGE: string;
```

- *Type:* string

m5d.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M5D_LARGE`<sup>Required</sup> <a name="M5D_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_LARGE"></a>

```typescript
public readonly M5D_LARGE: string;
```

- *Type:* string

m5d.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5D_METAL`<sup>Required</sup> <a name="M5D_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_METAL"></a>

```typescript
public readonly M5D_METAL: string;
```

- *Type:* string

m5d.metal vCPUs: 96 Memory: 393216 MiB.

---

##### `M5D_XLARGE`<sup>Required</sup> <a name="M5D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5D_XLARGE"></a>

```typescript
public readonly M5D_XLARGE: string;
```

- *Type:* string

m5d.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5DN_12XLARGE`<sup>Required</sup> <a name="M5DN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_12XLARGE"></a>

```typescript
public readonly M5DN_12XLARGE: string;
```

- *Type:* string

m5dn.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5DN_16XLARGE`<sup>Required</sup> <a name="M5DN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_16XLARGE"></a>

```typescript
public readonly M5DN_16XLARGE: string;
```

- *Type:* string

m5dn.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M5DN_24XLARGE`<sup>Required</sup> <a name="M5DN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_24XLARGE"></a>

```typescript
public readonly M5DN_24XLARGE: string;
```

- *Type:* string

m5dn.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M5DN_2XLARGE`<sup>Required</sup> <a name="M5DN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_2XLARGE"></a>

```typescript
public readonly M5DN_2XLARGE: string;
```

- *Type:* string

m5dn.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5DN_4XLARGE`<sup>Required</sup> <a name="M5DN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_4XLARGE"></a>

```typescript
public readonly M5DN_4XLARGE: string;
```

- *Type:* string

m5dn.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M5DN_8XLARGE`<sup>Required</sup> <a name="M5DN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_8XLARGE"></a>

```typescript
public readonly M5DN_8XLARGE: string;
```

- *Type:* string

m5dn.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M5DN_LARGE`<sup>Required</sup> <a name="M5DN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_LARGE"></a>

```typescript
public readonly M5DN_LARGE: string;
```

- *Type:* string

m5dn.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5DN_METAL`<sup>Required</sup> <a name="M5DN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_METAL"></a>

```typescript
public readonly M5DN_METAL: string;
```

- *Type:* string

m5dn.metal vCPUs: 96 Memory: 393216 MiB.

---

##### `M5DN_XLARGE`<sup>Required</sup> <a name="M5DN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5DN_XLARGE"></a>

```typescript
public readonly M5DN_XLARGE: string;
```

- *Type:* string

m5dn.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5N_12XLARGE`<sup>Required</sup> <a name="M5N_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_12XLARGE"></a>

```typescript
public readonly M5N_12XLARGE: string;
```

- *Type:* string

m5n.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5N_16XLARGE`<sup>Required</sup> <a name="M5N_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_16XLARGE"></a>

```typescript
public readonly M5N_16XLARGE: string;
```

- *Type:* string

m5n.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M5N_24XLARGE`<sup>Required</sup> <a name="M5N_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_24XLARGE"></a>

```typescript
public readonly M5N_24XLARGE: string;
```

- *Type:* string

m5n.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M5N_2XLARGE`<sup>Required</sup> <a name="M5N_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_2XLARGE"></a>

```typescript
public readonly M5N_2XLARGE: string;
```

- *Type:* string

m5n.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5N_4XLARGE`<sup>Required</sup> <a name="M5N_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_4XLARGE"></a>

```typescript
public readonly M5N_4XLARGE: string;
```

- *Type:* string

m5n.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M5N_8XLARGE`<sup>Required</sup> <a name="M5N_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_8XLARGE"></a>

```typescript
public readonly M5N_8XLARGE: string;
```

- *Type:* string

m5n.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M5N_LARGE`<sup>Required</sup> <a name="M5N_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_LARGE"></a>

```typescript
public readonly M5N_LARGE: string;
```

- *Type:* string

m5n.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5N_METAL`<sup>Required</sup> <a name="M5N_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_METAL"></a>

```typescript
public readonly M5N_METAL: string;
```

- *Type:* string

m5n.metal vCPUs: 96 Memory: 393216 MiB.

---

##### `M5N_XLARGE`<sup>Required</sup> <a name="M5N_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5N_XLARGE"></a>

```typescript
public readonly M5N_XLARGE: string;
```

- *Type:* string

m5n.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M5ZN_12XLARGE`<sup>Required</sup> <a name="M5ZN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_12XLARGE"></a>

```typescript
public readonly M5ZN_12XLARGE: string;
```

- *Type:* string

m5zn.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M5ZN_2XLARGE`<sup>Required</sup> <a name="M5ZN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_2XLARGE"></a>

```typescript
public readonly M5ZN_2XLARGE: string;
```

- *Type:* string

m5zn.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M5ZN_3XLARGE`<sup>Required</sup> <a name="M5ZN_3XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_3XLARGE"></a>

```typescript
public readonly M5ZN_3XLARGE: string;
```

- *Type:* string

m5zn.3xlarge vCPUs: 12 Memory: 49152 MiB.

---

##### `M5ZN_6XLARGE`<sup>Required</sup> <a name="M5ZN_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_6XLARGE"></a>

```typescript
public readonly M5ZN_6XLARGE: string;
```

- *Type:* string

m5zn.6xlarge vCPUs: 24 Memory: 98304 MiB.

---

##### `M5ZN_LARGE`<sup>Required</sup> <a name="M5ZN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_LARGE"></a>

```typescript
public readonly M5ZN_LARGE: string;
```

- *Type:* string

m5zn.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M5ZN_METAL`<sup>Required</sup> <a name="M5ZN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_METAL"></a>

```typescript
public readonly M5ZN_METAL: string;
```

- *Type:* string

m5zn.metal vCPUs: 48 Memory: 196608 MiB.

---

##### `M5ZN_XLARGE`<sup>Required</sup> <a name="M5ZN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M5ZN_XLARGE"></a>

```typescript
public readonly M5ZN_XLARGE: string;
```

- *Type:* string

m5zn.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6A_12XLARGE`<sup>Required</sup> <a name="M6A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_12XLARGE"></a>

```typescript
public readonly M6A_12XLARGE: string;
```

- *Type:* string

m6a.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6A_16XLARGE`<sup>Required</sup> <a name="M6A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_16XLARGE"></a>

```typescript
public readonly M6A_16XLARGE: string;
```

- *Type:* string

m6a.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6A_24XLARGE`<sup>Required</sup> <a name="M6A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_24XLARGE"></a>

```typescript
public readonly M6A_24XLARGE: string;
```

- *Type:* string

m6a.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M6A_2XLARGE`<sup>Required</sup> <a name="M6A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_2XLARGE"></a>

```typescript
public readonly M6A_2XLARGE: string;
```

- *Type:* string

m6a.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6A_32XLARGE`<sup>Required</sup> <a name="M6A_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_32XLARGE"></a>

```typescript
public readonly M6A_32XLARGE: string;
```

- *Type:* string

m6a.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `M6A_48XLARGE`<sup>Required</sup> <a name="M6A_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_48XLARGE"></a>

```typescript
public readonly M6A_48XLARGE: string;
```

- *Type:* string

m6a.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `M6A_4XLARGE`<sup>Required</sup> <a name="M6A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_4XLARGE"></a>

```typescript
public readonly M6A_4XLARGE: string;
```

- *Type:* string

m6a.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6A_8XLARGE`<sup>Required</sup> <a name="M6A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_8XLARGE"></a>

```typescript
public readonly M6A_8XLARGE: string;
```

- *Type:* string

m6a.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6A_LARGE`<sup>Required</sup> <a name="M6A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_LARGE"></a>

```typescript
public readonly M6A_LARGE: string;
```

- *Type:* string

m6a.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6A_METAL`<sup>Required</sup> <a name="M6A_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_METAL"></a>

```typescript
public readonly M6A_METAL: string;
```

- *Type:* string

m6a.metal vCPUs: 192 Memory: 786432 MiB.

---

##### `M6A_XLARGE`<sup>Required</sup> <a name="M6A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6A_XLARGE"></a>

```typescript
public readonly M6A_XLARGE: string;
```

- *Type:* string

m6a.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6G_12XLARGE`<sup>Required</sup> <a name="M6G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_12XLARGE"></a>

```typescript
public readonly M6G_12XLARGE: string;
```

- *Type:* string

m6g.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6G_16XLARGE`<sup>Required</sup> <a name="M6G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_16XLARGE"></a>

```typescript
public readonly M6G_16XLARGE: string;
```

- *Type:* string

m6g.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6G_2XLARGE`<sup>Required</sup> <a name="M6G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_2XLARGE"></a>

```typescript
public readonly M6G_2XLARGE: string;
```

- *Type:* string

m6g.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6G_4XLARGE`<sup>Required</sup> <a name="M6G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_4XLARGE"></a>

```typescript
public readonly M6G_4XLARGE: string;
```

- *Type:* string

m6g.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6G_8XLARGE`<sup>Required</sup> <a name="M6G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_8XLARGE"></a>

```typescript
public readonly M6G_8XLARGE: string;
```

- *Type:* string

m6g.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6G_LARGE`<sup>Required</sup> <a name="M6G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_LARGE"></a>

```typescript
public readonly M6G_LARGE: string;
```

- *Type:* string

m6g.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6G_MEDIUM`<sup>Required</sup> <a name="M6G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_MEDIUM"></a>

```typescript
public readonly M6G_MEDIUM: string;
```

- *Type:* string

m6g.medium vCPUs: 1 Memory: 4096 MiB.

---

##### `M6G_METAL`<sup>Required</sup> <a name="M6G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_METAL"></a>

```typescript
public readonly M6G_METAL: string;
```

- *Type:* string

m6g.metal vCPUs: 64 Memory: 262144 MiB.

---

##### `M6G_XLARGE`<sup>Required</sup> <a name="M6G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6G_XLARGE"></a>

```typescript
public readonly M6G_XLARGE: string;
```

- *Type:* string

m6g.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6GD_12XLARGE`<sup>Required</sup> <a name="M6GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_12XLARGE"></a>

```typescript
public readonly M6GD_12XLARGE: string;
```

- *Type:* string

m6gd.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6GD_16XLARGE`<sup>Required</sup> <a name="M6GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_16XLARGE"></a>

```typescript
public readonly M6GD_16XLARGE: string;
```

- *Type:* string

m6gd.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6GD_2XLARGE`<sup>Required</sup> <a name="M6GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_2XLARGE"></a>

```typescript
public readonly M6GD_2XLARGE: string;
```

- *Type:* string

m6gd.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6GD_4XLARGE`<sup>Required</sup> <a name="M6GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_4XLARGE"></a>

```typescript
public readonly M6GD_4XLARGE: string;
```

- *Type:* string

m6gd.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6GD_8XLARGE`<sup>Required</sup> <a name="M6GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_8XLARGE"></a>

```typescript
public readonly M6GD_8XLARGE: string;
```

- *Type:* string

m6gd.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6GD_LARGE`<sup>Required</sup> <a name="M6GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_LARGE"></a>

```typescript
public readonly M6GD_LARGE: string;
```

- *Type:* string

m6gd.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6GD_MEDIUM`<sup>Required</sup> <a name="M6GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_MEDIUM"></a>

```typescript
public readonly M6GD_MEDIUM: string;
```

- *Type:* string

m6gd.medium vCPUs: 1 Memory: 4096 MiB.

---

##### `M6GD_METAL`<sup>Required</sup> <a name="M6GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_METAL"></a>

```typescript
public readonly M6GD_METAL: string;
```

- *Type:* string

m6gd.metal vCPUs: 64 Memory: 262144 MiB.

---

##### `M6GD_XLARGE`<sup>Required</sup> <a name="M6GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6GD_XLARGE"></a>

```typescript
public readonly M6GD_XLARGE: string;
```

- *Type:* string

m6gd.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6I_12XLARGE`<sup>Required</sup> <a name="M6I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_12XLARGE"></a>

```typescript
public readonly M6I_12XLARGE: string;
```

- *Type:* string

m6i.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6I_16XLARGE`<sup>Required</sup> <a name="M6I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_16XLARGE"></a>

```typescript
public readonly M6I_16XLARGE: string;
```

- *Type:* string

m6i.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6I_24XLARGE`<sup>Required</sup> <a name="M6I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_24XLARGE"></a>

```typescript
public readonly M6I_24XLARGE: string;
```

- *Type:* string

m6i.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M6I_2XLARGE`<sup>Required</sup> <a name="M6I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_2XLARGE"></a>

```typescript
public readonly M6I_2XLARGE: string;
```

- *Type:* string

m6i.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6I_32XLARGE`<sup>Required</sup> <a name="M6I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_32XLARGE"></a>

```typescript
public readonly M6I_32XLARGE: string;
```

- *Type:* string

m6i.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `M6I_4XLARGE`<sup>Required</sup> <a name="M6I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_4XLARGE"></a>

```typescript
public readonly M6I_4XLARGE: string;
```

- *Type:* string

m6i.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6I_8XLARGE`<sup>Required</sup> <a name="M6I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_8XLARGE"></a>

```typescript
public readonly M6I_8XLARGE: string;
```

- *Type:* string

m6i.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6I_LARGE`<sup>Required</sup> <a name="M6I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_LARGE"></a>

```typescript
public readonly M6I_LARGE: string;
```

- *Type:* string

m6i.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6I_METAL`<sup>Required</sup> <a name="M6I_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_METAL"></a>

```typescript
public readonly M6I_METAL: string;
```

- *Type:* string

m6i.metal vCPUs: 128 Memory: 524288 MiB.

---

##### `M6I_XLARGE`<sup>Required</sup> <a name="M6I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6I_XLARGE"></a>

```typescript
public readonly M6I_XLARGE: string;
```

- *Type:* string

m6i.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6ID_12XLARGE`<sup>Required</sup> <a name="M6ID_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_12XLARGE"></a>

```typescript
public readonly M6ID_12XLARGE: string;
```

- *Type:* string

m6id.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6ID_16XLARGE`<sup>Required</sup> <a name="M6ID_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_16XLARGE"></a>

```typescript
public readonly M6ID_16XLARGE: string;
```

- *Type:* string

m6id.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6ID_24XLARGE`<sup>Required</sup> <a name="M6ID_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_24XLARGE"></a>

```typescript
public readonly M6ID_24XLARGE: string;
```

- *Type:* string

m6id.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M6ID_2XLARGE`<sup>Required</sup> <a name="M6ID_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_2XLARGE"></a>

```typescript
public readonly M6ID_2XLARGE: string;
```

- *Type:* string

m6id.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6ID_32XLARGE`<sup>Required</sup> <a name="M6ID_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_32XLARGE"></a>

```typescript
public readonly M6ID_32XLARGE: string;
```

- *Type:* string

m6id.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `M6ID_4XLARGE`<sup>Required</sup> <a name="M6ID_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_4XLARGE"></a>

```typescript
public readonly M6ID_4XLARGE: string;
```

- *Type:* string

m6id.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6ID_8XLARGE`<sup>Required</sup> <a name="M6ID_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_8XLARGE"></a>

```typescript
public readonly M6ID_8XLARGE: string;
```

- *Type:* string

m6id.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6ID_LARGE`<sup>Required</sup> <a name="M6ID_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_LARGE"></a>

```typescript
public readonly M6ID_LARGE: string;
```

- *Type:* string

m6id.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6ID_METAL`<sup>Required</sup> <a name="M6ID_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_METAL"></a>

```typescript
public readonly M6ID_METAL: string;
```

- *Type:* string

m6id.metal vCPUs: 128 Memory: 524288 MiB.

---

##### `M6ID_XLARGE`<sup>Required</sup> <a name="M6ID_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6ID_XLARGE"></a>

```typescript
public readonly M6ID_XLARGE: string;
```

- *Type:* string

m6id.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6IDN_12XLARGE`<sup>Required</sup> <a name="M6IDN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_12XLARGE"></a>

```typescript
public readonly M6IDN_12XLARGE: string;
```

- *Type:* string

m6idn.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6IDN_16XLARGE`<sup>Required</sup> <a name="M6IDN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_16XLARGE"></a>

```typescript
public readonly M6IDN_16XLARGE: string;
```

- *Type:* string

m6idn.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6IDN_24XLARGE`<sup>Required</sup> <a name="M6IDN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_24XLARGE"></a>

```typescript
public readonly M6IDN_24XLARGE: string;
```

- *Type:* string

m6idn.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M6IDN_2XLARGE`<sup>Required</sup> <a name="M6IDN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_2XLARGE"></a>

```typescript
public readonly M6IDN_2XLARGE: string;
```

- *Type:* string

m6idn.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6IDN_32XLARGE`<sup>Required</sup> <a name="M6IDN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_32XLARGE"></a>

```typescript
public readonly M6IDN_32XLARGE: string;
```

- *Type:* string

m6idn.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `M6IDN_4XLARGE`<sup>Required</sup> <a name="M6IDN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_4XLARGE"></a>

```typescript
public readonly M6IDN_4XLARGE: string;
```

- *Type:* string

m6idn.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6IDN_8XLARGE`<sup>Required</sup> <a name="M6IDN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_8XLARGE"></a>

```typescript
public readonly M6IDN_8XLARGE: string;
```

- *Type:* string

m6idn.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6IDN_LARGE`<sup>Required</sup> <a name="M6IDN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_LARGE"></a>

```typescript
public readonly M6IDN_LARGE: string;
```

- *Type:* string

m6idn.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6IDN_METAL`<sup>Required</sup> <a name="M6IDN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_METAL"></a>

```typescript
public readonly M6IDN_METAL: string;
```

- *Type:* string

m6idn.metal vCPUs: 128 Memory: 524288 MiB.

---

##### `M6IDN_XLARGE`<sup>Required</sup> <a name="M6IDN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IDN_XLARGE"></a>

```typescript
public readonly M6IDN_XLARGE: string;
```

- *Type:* string

m6idn.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M6IN_12XLARGE`<sup>Required</sup> <a name="M6IN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_12XLARGE"></a>

```typescript
public readonly M6IN_12XLARGE: string;
```

- *Type:* string

m6in.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M6IN_16XLARGE`<sup>Required</sup> <a name="M6IN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_16XLARGE"></a>

```typescript
public readonly M6IN_16XLARGE: string;
```

- *Type:* string

m6in.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M6IN_24XLARGE`<sup>Required</sup> <a name="M6IN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_24XLARGE"></a>

```typescript
public readonly M6IN_24XLARGE: string;
```

- *Type:* string

m6in.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M6IN_2XLARGE`<sup>Required</sup> <a name="M6IN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_2XLARGE"></a>

```typescript
public readonly M6IN_2XLARGE: string;
```

- *Type:* string

m6in.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M6IN_32XLARGE`<sup>Required</sup> <a name="M6IN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_32XLARGE"></a>

```typescript
public readonly M6IN_32XLARGE: string;
```

- *Type:* string

m6in.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `M6IN_4XLARGE`<sup>Required</sup> <a name="M6IN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_4XLARGE"></a>

```typescript
public readonly M6IN_4XLARGE: string;
```

- *Type:* string

m6in.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M6IN_8XLARGE`<sup>Required</sup> <a name="M6IN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_8XLARGE"></a>

```typescript
public readonly M6IN_8XLARGE: string;
```

- *Type:* string

m6in.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M6IN_LARGE`<sup>Required</sup> <a name="M6IN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_LARGE"></a>

```typescript
public readonly M6IN_LARGE: string;
```

- *Type:* string

m6in.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M6IN_METAL`<sup>Required</sup> <a name="M6IN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_METAL"></a>

```typescript
public readonly M6IN_METAL: string;
```

- *Type:* string

m6in.metal vCPUs: 128 Memory: 524288 MiB.

---

##### `M6IN_XLARGE`<sup>Required</sup> <a name="M6IN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M6IN_XLARGE"></a>

```typescript
public readonly M6IN_XLARGE: string;
```

- *Type:* string

m6in.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M7A_12XLARGE`<sup>Required</sup> <a name="M7A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_12XLARGE"></a>

```typescript
public readonly M7A_12XLARGE: string;
```

- *Type:* string

m7a.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M7A_16XLARGE`<sup>Required</sup> <a name="M7A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_16XLARGE"></a>

```typescript
public readonly M7A_16XLARGE: string;
```

- *Type:* string

m7a.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M7A_24XLARGE`<sup>Required</sup> <a name="M7A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_24XLARGE"></a>

```typescript
public readonly M7A_24XLARGE: string;
```

- *Type:* string

m7a.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M7A_2XLARGE`<sup>Required</sup> <a name="M7A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_2XLARGE"></a>

```typescript
public readonly M7A_2XLARGE: string;
```

- *Type:* string

m7a.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M7A_32XLARGE`<sup>Required</sup> <a name="M7A_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_32XLARGE"></a>

```typescript
public readonly M7A_32XLARGE: string;
```

- *Type:* string

m7a.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `M7A_48XLARGE`<sup>Required</sup> <a name="M7A_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_48XLARGE"></a>

```typescript
public readonly M7A_48XLARGE: string;
```

- *Type:* string

m7a.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `M7A_4XLARGE`<sup>Required</sup> <a name="M7A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_4XLARGE"></a>

```typescript
public readonly M7A_4XLARGE: string;
```

- *Type:* string

m7a.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M7A_8XLARGE`<sup>Required</sup> <a name="M7A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_8XLARGE"></a>

```typescript
public readonly M7A_8XLARGE: string;
```

- *Type:* string

m7a.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M7A_LARGE`<sup>Required</sup> <a name="M7A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_LARGE"></a>

```typescript
public readonly M7A_LARGE: string;
```

- *Type:* string

m7a.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M7A_MEDIUM`<sup>Required</sup> <a name="M7A_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_MEDIUM"></a>

```typescript
public readonly M7A_MEDIUM: string;
```

- *Type:* string

m7a.medium vCPUs: 1 Memory: 4096 MiB.

---

##### `M7A_METAL_48XL`<sup>Required</sup> <a name="M7A_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_METAL_48XL"></a>

```typescript
public readonly M7A_METAL_48XL: string;
```

- *Type:* string

m7a.metal-48xl vCPUs: 192 Memory: 786432 MiB.

---

##### `M7A_XLARGE`<sup>Required</sup> <a name="M7A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7A_XLARGE"></a>

```typescript
public readonly M7A_XLARGE: string;
```

- *Type:* string

m7a.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M7G_12XLARGE`<sup>Required</sup> <a name="M7G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_12XLARGE"></a>

```typescript
public readonly M7G_12XLARGE: string;
```

- *Type:* string

m7g.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M7G_16XLARGE`<sup>Required</sup> <a name="M7G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_16XLARGE"></a>

```typescript
public readonly M7G_16XLARGE: string;
```

- *Type:* string

m7g.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M7G_2XLARGE`<sup>Required</sup> <a name="M7G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_2XLARGE"></a>

```typescript
public readonly M7G_2XLARGE: string;
```

- *Type:* string

m7g.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M7G_4XLARGE`<sup>Required</sup> <a name="M7G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_4XLARGE"></a>

```typescript
public readonly M7G_4XLARGE: string;
```

- *Type:* string

m7g.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M7G_8XLARGE`<sup>Required</sup> <a name="M7G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_8XLARGE"></a>

```typescript
public readonly M7G_8XLARGE: string;
```

- *Type:* string

m7g.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M7G_LARGE`<sup>Required</sup> <a name="M7G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_LARGE"></a>

```typescript
public readonly M7G_LARGE: string;
```

- *Type:* string

m7g.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M7G_MEDIUM`<sup>Required</sup> <a name="M7G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_MEDIUM"></a>

```typescript
public readonly M7G_MEDIUM: string;
```

- *Type:* string

m7g.medium vCPUs: 1 Memory: 4096 MiB.

---

##### `M7G_METAL`<sup>Required</sup> <a name="M7G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_METAL"></a>

```typescript
public readonly M7G_METAL: string;
```

- *Type:* string

m7g.metal vCPUs: 64 Memory: 262144 MiB.

---

##### `M7G_XLARGE`<sup>Required</sup> <a name="M7G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7G_XLARGE"></a>

```typescript
public readonly M7G_XLARGE: string;
```

- *Type:* string

m7g.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M7GD_12XLARGE`<sup>Required</sup> <a name="M7GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_12XLARGE"></a>

```typescript
public readonly M7GD_12XLARGE: string;
```

- *Type:* string

m7gd.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M7GD_16XLARGE`<sup>Required</sup> <a name="M7GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_16XLARGE"></a>

```typescript
public readonly M7GD_16XLARGE: string;
```

- *Type:* string

m7gd.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M7GD_2XLARGE`<sup>Required</sup> <a name="M7GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_2XLARGE"></a>

```typescript
public readonly M7GD_2XLARGE: string;
```

- *Type:* string

m7gd.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M7GD_4XLARGE`<sup>Required</sup> <a name="M7GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_4XLARGE"></a>

```typescript
public readonly M7GD_4XLARGE: string;
```

- *Type:* string

m7gd.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M7GD_8XLARGE`<sup>Required</sup> <a name="M7GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_8XLARGE"></a>

```typescript
public readonly M7GD_8XLARGE: string;
```

- *Type:* string

m7gd.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M7GD_LARGE`<sup>Required</sup> <a name="M7GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_LARGE"></a>

```typescript
public readonly M7GD_LARGE: string;
```

- *Type:* string

m7gd.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M7GD_MEDIUM`<sup>Required</sup> <a name="M7GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_MEDIUM"></a>

```typescript
public readonly M7GD_MEDIUM: string;
```

- *Type:* string

m7gd.medium vCPUs: 1 Memory: 4096 MiB.

---

##### `M7GD_METAL`<sup>Required</sup> <a name="M7GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_METAL"></a>

```typescript
public readonly M7GD_METAL: string;
```

- *Type:* string

m7gd.metal vCPUs: 64 Memory: 262144 MiB.

---

##### `M7GD_XLARGE`<sup>Required</sup> <a name="M7GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7GD_XLARGE"></a>

```typescript
public readonly M7GD_XLARGE: string;
```

- *Type:* string

m7gd.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M7I_12XLARGE`<sup>Required</sup> <a name="M7I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_12XLARGE"></a>

```typescript
public readonly M7I_12XLARGE: string;
```

- *Type:* string

m7i.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M7I_16XLARGE`<sup>Required</sup> <a name="M7I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_16XLARGE"></a>

```typescript
public readonly M7I_16XLARGE: string;
```

- *Type:* string

m7i.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M7I_24XLARGE`<sup>Required</sup> <a name="M7I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_24XLARGE"></a>

```typescript
public readonly M7I_24XLARGE: string;
```

- *Type:* string

m7i.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M7I_2XLARGE`<sup>Required</sup> <a name="M7I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_2XLARGE"></a>

```typescript
public readonly M7I_2XLARGE: string;
```

- *Type:* string

m7i.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M7I_48XLARGE`<sup>Required</sup> <a name="M7I_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_48XLARGE"></a>

```typescript
public readonly M7I_48XLARGE: string;
```

- *Type:* string

m7i.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `M7I_4XLARGE`<sup>Required</sup> <a name="M7I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_4XLARGE"></a>

```typescript
public readonly M7I_4XLARGE: string;
```

- *Type:* string

m7i.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M7I_8XLARGE`<sup>Required</sup> <a name="M7I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_8XLARGE"></a>

```typescript
public readonly M7I_8XLARGE: string;
```

- *Type:* string

m7i.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M7I_FLEX_12XLARGE`<sup>Required</sup> <a name="M7I_FLEX_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_12XLARGE"></a>

```typescript
public readonly M7I_FLEX_12XLARGE: string;
```

- *Type:* string

m7i-flex.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M7I_FLEX_16XLARGE`<sup>Required</sup> <a name="M7I_FLEX_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_16XLARGE"></a>

```typescript
public readonly M7I_FLEX_16XLARGE: string;
```

- *Type:* string

m7i-flex.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M7I_FLEX_2XLARGE`<sup>Required</sup> <a name="M7I_FLEX_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_2XLARGE"></a>

```typescript
public readonly M7I_FLEX_2XLARGE: string;
```

- *Type:* string

m7i-flex.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M7I_FLEX_4XLARGE`<sup>Required</sup> <a name="M7I_FLEX_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_4XLARGE"></a>

```typescript
public readonly M7I_FLEX_4XLARGE: string;
```

- *Type:* string

m7i-flex.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M7I_FLEX_8XLARGE`<sup>Required</sup> <a name="M7I_FLEX_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_8XLARGE"></a>

```typescript
public readonly M7I_FLEX_8XLARGE: string;
```

- *Type:* string

m7i-flex.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M7I_FLEX_LARGE`<sup>Required</sup> <a name="M7I_FLEX_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_LARGE"></a>

```typescript
public readonly M7I_FLEX_LARGE: string;
```

- *Type:* string

m7i-flex.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M7I_FLEX_XLARGE`<sup>Required</sup> <a name="M7I_FLEX_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_FLEX_XLARGE"></a>

```typescript
public readonly M7I_FLEX_XLARGE: string;
```

- *Type:* string

m7i-flex.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M7I_LARGE`<sup>Required</sup> <a name="M7I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_LARGE"></a>

```typescript
public readonly M7I_LARGE: string;
```

- *Type:* string

m7i.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M7I_METAL_24XL`<sup>Required</sup> <a name="M7I_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_METAL_24XL"></a>

```typescript
public readonly M7I_METAL_24XL: string;
```

- *Type:* string

m7i.metal-24xl vCPUs: 96 Memory: 393216 MiB.

---

##### `M7I_METAL_48XL`<sup>Required</sup> <a name="M7I_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_METAL_48XL"></a>

```typescript
public readonly M7I_METAL_48XL: string;
```

- *Type:* string

m7i.metal-48xl vCPUs: 192 Memory: 786432 MiB.

---

##### `M7I_XLARGE`<sup>Required</sup> <a name="M7I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M7I_XLARGE"></a>

```typescript
public readonly M7I_XLARGE: string;
```

- *Type:* string

m7i.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `M8G_12XLARGE`<sup>Required</sup> <a name="M8G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_12XLARGE"></a>

```typescript
public readonly M8G_12XLARGE: string;
```

- *Type:* string

m8g.12xlarge vCPUs: 48 Memory: 196608 MiB.

---

##### `M8G_16XLARGE`<sup>Required</sup> <a name="M8G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_16XLARGE"></a>

```typescript
public readonly M8G_16XLARGE: string;
```

- *Type:* string

m8g.16xlarge vCPUs: 64 Memory: 262144 MiB.

---

##### `M8G_24XLARGE`<sup>Required</sup> <a name="M8G_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_24XLARGE"></a>

```typescript
public readonly M8G_24XLARGE: string;
```

- *Type:* string

m8g.24xlarge vCPUs: 96 Memory: 393216 MiB.

---

##### `M8G_2XLARGE`<sup>Required</sup> <a name="M8G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_2XLARGE"></a>

```typescript
public readonly M8G_2XLARGE: string;
```

- *Type:* string

m8g.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `M8G_48XLARGE`<sup>Required</sup> <a name="M8G_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_48XLARGE"></a>

```typescript
public readonly M8G_48XLARGE: string;
```

- *Type:* string

m8g.48xlarge vCPUs: 192 Memory: 786432 MiB.

---

##### `M8G_4XLARGE`<sup>Required</sup> <a name="M8G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_4XLARGE"></a>

```typescript
public readonly M8G_4XLARGE: string;
```

- *Type:* string

m8g.4xlarge vCPUs: 16 Memory: 65536 MiB.

---

##### `M8G_8XLARGE`<sup>Required</sup> <a name="M8G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_8XLARGE"></a>

```typescript
public readonly M8G_8XLARGE: string;
```

- *Type:* string

m8g.8xlarge vCPUs: 32 Memory: 131072 MiB.

---

##### `M8G_LARGE`<sup>Required</sup> <a name="M8G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_LARGE"></a>

```typescript
public readonly M8G_LARGE: string;
```

- *Type:* string

m8g.large vCPUs: 2 Memory: 8192 MiB.

---

##### `M8G_MEDIUM`<sup>Required</sup> <a name="M8G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_MEDIUM"></a>

```typescript
public readonly M8G_MEDIUM: string;
```

- *Type:* string

m8g.medium vCPUs: 1 Memory: 4096 MiB.

---

##### `M8G_METAL_24XL`<sup>Required</sup> <a name="M8G_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_METAL_24XL"></a>

```typescript
public readonly M8G_METAL_24XL: string;
```

- *Type:* string

m8g.metal-24xl vCPUs: 96 Memory: 393216 MiB.

---

##### `M8G_METAL_48XL`<sup>Required</sup> <a name="M8G_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_METAL_48XL"></a>

```typescript
public readonly M8G_METAL_48XL: string;
```

- *Type:* string

m8g.metal-48xl vCPUs: 192 Memory: 786432 MiB.

---

##### `M8G_XLARGE`<sup>Required</sup> <a name="M8G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.M8G_XLARGE"></a>

```typescript
public readonly M8G_XLARGE: string;
```

- *Type:* string

m8g.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `MAC1_METAL`<sup>Required</sup> <a name="MAC1_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC1_METAL"></a>

```typescript
public readonly MAC1_METAL: string;
```

- *Type:* string

mac1.metal vCPUs: 12 Memory: 32768 MiB.

---

##### `MAC2_M1ULTRA_METAL`<sup>Required</sup> <a name="MAC2_M1ULTRA_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_M1ULTRA_METAL"></a>

```typescript
public readonly MAC2_M1ULTRA_METAL: string;
```

- *Type:* string

mac2-m1ultra.metal vCPUs: 20 Memory: 131072 MiB.

---

##### `MAC2_M2_METAL`<sup>Required</sup> <a name="MAC2_M2_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_M2_METAL"></a>

```typescript
public readonly MAC2_M2_METAL: string;
```

- *Type:* string

mac2-m2.metal vCPUs: 8 Memory: 24576 MiB.

---

##### `MAC2_M2PRO_METAL`<sup>Required</sup> <a name="MAC2_M2PRO_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_M2PRO_METAL"></a>

```typescript
public readonly MAC2_M2PRO_METAL: string;
```

- *Type:* string

mac2-m2pro.metal vCPUs: 12 Memory: 32768 MiB.

---

##### `MAC2_METAL`<sup>Required</sup> <a name="MAC2_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.MAC2_METAL"></a>

```typescript
public readonly MAC2_METAL: string;
```

- *Type:* string

mac2.metal vCPUs: 8 Memory: 16384 MiB.

---

##### `P2_16XLARGE`<sup>Required</sup> <a name="P2_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P2_16XLARGE"></a>

```typescript
public readonly P2_16XLARGE: string;
```

- *Type:* string

p2.16xlarge vCPUs: 64 Memory: 749568 MiB.

---

##### `P2_8XLARGE`<sup>Required</sup> <a name="P2_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P2_8XLARGE"></a>

```typescript
public readonly P2_8XLARGE: string;
```

- *Type:* string

p2.8xlarge vCPUs: 32 Memory: 499712 MiB.

---

##### `P2_XLARGE`<sup>Required</sup> <a name="P2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P2_XLARGE"></a>

```typescript
public readonly P2_XLARGE: string;
```

- *Type:* string

p2.xlarge vCPUs: 4 Memory: 62464 MiB.

---

##### `P3_16XLARGE`<sup>Required</sup> <a name="P3_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3_16XLARGE"></a>

```typescript
public readonly P3_16XLARGE: string;
```

- *Type:* string

p3.16xlarge vCPUs: 64 Memory: 499712 MiB.

---

##### `P3_2XLARGE`<sup>Required</sup> <a name="P3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3_2XLARGE"></a>

```typescript
public readonly P3_2XLARGE: string;
```

- *Type:* string

p3.2xlarge vCPUs: 8 Memory: 62464 MiB.

---

##### `P3_8XLARGE`<sup>Required</sup> <a name="P3_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3_8XLARGE"></a>

```typescript
public readonly P3_8XLARGE: string;
```

- *Type:* string

p3.8xlarge vCPUs: 32 Memory: 249856 MiB.

---

##### `P3DN_24XLARGE`<sup>Required</sup> <a name="P3DN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P3DN_24XLARGE"></a>

```typescript
public readonly P3DN_24XLARGE: string;
```

- *Type:* string

p3dn.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `P4D_24XLARGE`<sup>Required</sup> <a name="P4D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P4D_24XLARGE"></a>

```typescript
public readonly P4D_24XLARGE: string;
```

- *Type:* string

p4d.24xlarge vCPUs: 96 Memory: 1179648 MiB.

---

##### `P5_48XLARGE`<sup>Required</sup> <a name="P5_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.P5_48XLARGE"></a>

```typescript
public readonly P5_48XLARGE: string;
```

- *Type:* string

p5.48xlarge vCPUs: 192 Memory: 2097152 MiB.

---

##### `R3_2XLARGE`<sup>Required</sup> <a name="R3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_2XLARGE"></a>

```typescript
public readonly R3_2XLARGE: string;
```

- *Type:* string

r3.2xlarge vCPUs: 8 Memory: 62464 MiB.

---

##### `R3_4XLARGE`<sup>Required</sup> <a name="R3_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_4XLARGE"></a>

```typescript
public readonly R3_4XLARGE: string;
```

- *Type:* string

r3.4xlarge vCPUs: 16 Memory: 124928 MiB.

---

##### `R3_8XLARGE`<sup>Required</sup> <a name="R3_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_8XLARGE"></a>

```typescript
public readonly R3_8XLARGE: string;
```

- *Type:* string

r3.8xlarge vCPUs: 32 Memory: 249856 MiB.

---

##### `R3_LARGE`<sup>Required</sup> <a name="R3_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_LARGE"></a>

```typescript
public readonly R3_LARGE: string;
```

- *Type:* string

r3.large vCPUs: 2 Memory: 15360 MiB.

---

##### `R3_XLARGE`<sup>Required</sup> <a name="R3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R3_XLARGE"></a>

```typescript
public readonly R3_XLARGE: string;
```

- *Type:* string

r3.xlarge vCPUs: 4 Memory: 31232 MiB.

---

##### `R4_16XLARGE`<sup>Required</sup> <a name="R4_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_16XLARGE"></a>

```typescript
public readonly R4_16XLARGE: string;
```

- *Type:* string

r4.16xlarge vCPUs: 64 Memory: 499712 MiB.

---

##### `R4_2XLARGE`<sup>Required</sup> <a name="R4_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_2XLARGE"></a>

```typescript
public readonly R4_2XLARGE: string;
```

- *Type:* string

r4.2xlarge vCPUs: 8 Memory: 62464 MiB.

---

##### `R4_4XLARGE`<sup>Required</sup> <a name="R4_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_4XLARGE"></a>

```typescript
public readonly R4_4XLARGE: string;
```

- *Type:* string

r4.4xlarge vCPUs: 16 Memory: 124928 MiB.

---

##### `R4_8XLARGE`<sup>Required</sup> <a name="R4_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_8XLARGE"></a>

```typescript
public readonly R4_8XLARGE: string;
```

- *Type:* string

r4.8xlarge vCPUs: 32 Memory: 249856 MiB.

---

##### `R4_LARGE`<sup>Required</sup> <a name="R4_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_LARGE"></a>

```typescript
public readonly R4_LARGE: string;
```

- *Type:* string

r4.large vCPUs: 2 Memory: 15616 MiB.

---

##### `R4_XLARGE`<sup>Required</sup> <a name="R4_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R4_XLARGE"></a>

```typescript
public readonly R4_XLARGE: string;
```

- *Type:* string

r4.xlarge vCPUs: 4 Memory: 31232 MiB.

---

##### `R5_12XLARGE`<sup>Required</sup> <a name="R5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_12XLARGE"></a>

```typescript
public readonly R5_12XLARGE: string;
```

- *Type:* string

r5.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5_16XLARGE`<sup>Required</sup> <a name="R5_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_16XLARGE"></a>

```typescript
public readonly R5_16XLARGE: string;
```

- *Type:* string

r5.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5_24XLARGE`<sup>Required</sup> <a name="R5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_24XLARGE"></a>

```typescript
public readonly R5_24XLARGE: string;
```

- *Type:* string

r5.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5_2XLARGE`<sup>Required</sup> <a name="R5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_2XLARGE"></a>

```typescript
public readonly R5_2XLARGE: string;
```

- *Type:* string

r5.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5_4XLARGE`<sup>Required</sup> <a name="R5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_4XLARGE"></a>

```typescript
public readonly R5_4XLARGE: string;
```

- *Type:* string

r5.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5_8XLARGE`<sup>Required</sup> <a name="R5_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_8XLARGE"></a>

```typescript
public readonly R5_8XLARGE: string;
```

- *Type:* string

r5.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5_LARGE`<sup>Required</sup> <a name="R5_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_LARGE"></a>

```typescript
public readonly R5_LARGE: string;
```

- *Type:* string

r5.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5_METAL`<sup>Required</sup> <a name="R5_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_METAL"></a>

```typescript
public readonly R5_METAL: string;
```

- *Type:* string

r5.metal vCPUs: 96 Memory: 786432 MiB.

---

##### `R5_XLARGE`<sup>Required</sup> <a name="R5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5_XLARGE"></a>

```typescript
public readonly R5_XLARGE: string;
```

- *Type:* string

r5.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R5A_12XLARGE`<sup>Required</sup> <a name="R5A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_12XLARGE"></a>

```typescript
public readonly R5A_12XLARGE: string;
```

- *Type:* string

r5a.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5A_16XLARGE`<sup>Required</sup> <a name="R5A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_16XLARGE"></a>

```typescript
public readonly R5A_16XLARGE: string;
```

- *Type:* string

r5a.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5A_24XLARGE`<sup>Required</sup> <a name="R5A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_24XLARGE"></a>

```typescript
public readonly R5A_24XLARGE: string;
```

- *Type:* string

r5a.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5A_2XLARGE`<sup>Required</sup> <a name="R5A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_2XLARGE"></a>

```typescript
public readonly R5A_2XLARGE: string;
```

- *Type:* string

r5a.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5A_4XLARGE`<sup>Required</sup> <a name="R5A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_4XLARGE"></a>

```typescript
public readonly R5A_4XLARGE: string;
```

- *Type:* string

r5a.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5A_8XLARGE`<sup>Required</sup> <a name="R5A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_8XLARGE"></a>

```typescript
public readonly R5A_8XLARGE: string;
```

- *Type:* string

r5a.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5A_LARGE`<sup>Required</sup> <a name="R5A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_LARGE"></a>

```typescript
public readonly R5A_LARGE: string;
```

- *Type:* string

r5a.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5A_XLARGE`<sup>Required</sup> <a name="R5A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5A_XLARGE"></a>

```typescript
public readonly R5A_XLARGE: string;
```

- *Type:* string

r5a.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R5AD_12XLARGE`<sup>Required</sup> <a name="R5AD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_12XLARGE"></a>

```typescript
public readonly R5AD_12XLARGE: string;
```

- *Type:* string

r5ad.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5AD_16XLARGE`<sup>Required</sup> <a name="R5AD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_16XLARGE"></a>

```typescript
public readonly R5AD_16XLARGE: string;
```

- *Type:* string

r5ad.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5AD_24XLARGE`<sup>Required</sup> <a name="R5AD_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_24XLARGE"></a>

```typescript
public readonly R5AD_24XLARGE: string;
```

- *Type:* string

r5ad.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5AD_2XLARGE`<sup>Required</sup> <a name="R5AD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_2XLARGE"></a>

```typescript
public readonly R5AD_2XLARGE: string;
```

- *Type:* string

r5ad.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5AD_4XLARGE`<sup>Required</sup> <a name="R5AD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_4XLARGE"></a>

```typescript
public readonly R5AD_4XLARGE: string;
```

- *Type:* string

r5ad.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5AD_8XLARGE`<sup>Required</sup> <a name="R5AD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_8XLARGE"></a>

```typescript
public readonly R5AD_8XLARGE: string;
```

- *Type:* string

r5ad.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5AD_LARGE`<sup>Required</sup> <a name="R5AD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_LARGE"></a>

```typescript
public readonly R5AD_LARGE: string;
```

- *Type:* string

r5ad.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5AD_XLARGE`<sup>Required</sup> <a name="R5AD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5AD_XLARGE"></a>

```typescript
public readonly R5AD_XLARGE: string;
```

- *Type:* string

r5ad.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R5B_12XLARGE`<sup>Required</sup> <a name="R5B_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_12XLARGE"></a>

```typescript
public readonly R5B_12XLARGE: string;
```

- *Type:* string

r5b.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5B_16XLARGE`<sup>Required</sup> <a name="R5B_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_16XLARGE"></a>

```typescript
public readonly R5B_16XLARGE: string;
```

- *Type:* string

r5b.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5B_24XLARGE`<sup>Required</sup> <a name="R5B_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_24XLARGE"></a>

```typescript
public readonly R5B_24XLARGE: string;
```

- *Type:* string

r5b.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5B_2XLARGE`<sup>Required</sup> <a name="R5B_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_2XLARGE"></a>

```typescript
public readonly R5B_2XLARGE: string;
```

- *Type:* string

r5b.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5B_4XLARGE`<sup>Required</sup> <a name="R5B_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_4XLARGE"></a>

```typescript
public readonly R5B_4XLARGE: string;
```

- *Type:* string

r5b.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5B_8XLARGE`<sup>Required</sup> <a name="R5B_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_8XLARGE"></a>

```typescript
public readonly R5B_8XLARGE: string;
```

- *Type:* string

r5b.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5B_LARGE`<sup>Required</sup> <a name="R5B_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_LARGE"></a>

```typescript
public readonly R5B_LARGE: string;
```

- *Type:* string

r5b.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5B_METAL`<sup>Required</sup> <a name="R5B_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_METAL"></a>

```typescript
public readonly R5B_METAL: string;
```

- *Type:* string

r5b.metal vCPUs: 96 Memory: 786432 MiB.

---

##### `R5B_XLARGE`<sup>Required</sup> <a name="R5B_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5B_XLARGE"></a>

```typescript
public readonly R5B_XLARGE: string;
```

- *Type:* string

r5b.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R5D_12XLARGE`<sup>Required</sup> <a name="R5D_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_12XLARGE"></a>

```typescript
public readonly R5D_12XLARGE: string;
```

- *Type:* string

r5d.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5D_16XLARGE`<sup>Required</sup> <a name="R5D_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_16XLARGE"></a>

```typescript
public readonly R5D_16XLARGE: string;
```

- *Type:* string

r5d.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5D_24XLARGE`<sup>Required</sup> <a name="R5D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_24XLARGE"></a>

```typescript
public readonly R5D_24XLARGE: string;
```

- *Type:* string

r5d.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5D_2XLARGE`<sup>Required</sup> <a name="R5D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_2XLARGE"></a>

```typescript
public readonly R5D_2XLARGE: string;
```

- *Type:* string

r5d.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5D_4XLARGE`<sup>Required</sup> <a name="R5D_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_4XLARGE"></a>

```typescript
public readonly R5D_4XLARGE: string;
```

- *Type:* string

r5d.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5D_8XLARGE`<sup>Required</sup> <a name="R5D_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_8XLARGE"></a>

```typescript
public readonly R5D_8XLARGE: string;
```

- *Type:* string

r5d.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5D_LARGE`<sup>Required</sup> <a name="R5D_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_LARGE"></a>

```typescript
public readonly R5D_LARGE: string;
```

- *Type:* string

r5d.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5D_METAL`<sup>Required</sup> <a name="R5D_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_METAL"></a>

```typescript
public readonly R5D_METAL: string;
```

- *Type:* string

r5d.metal vCPUs: 96 Memory: 786432 MiB.

---

##### `R5D_XLARGE`<sup>Required</sup> <a name="R5D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5D_XLARGE"></a>

```typescript
public readonly R5D_XLARGE: string;
```

- *Type:* string

r5d.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R5DN_12XLARGE`<sup>Required</sup> <a name="R5DN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_12XLARGE"></a>

```typescript
public readonly R5DN_12XLARGE: string;
```

- *Type:* string

r5dn.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5DN_16XLARGE`<sup>Required</sup> <a name="R5DN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_16XLARGE"></a>

```typescript
public readonly R5DN_16XLARGE: string;
```

- *Type:* string

r5dn.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5DN_24XLARGE`<sup>Required</sup> <a name="R5DN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_24XLARGE"></a>

```typescript
public readonly R5DN_24XLARGE: string;
```

- *Type:* string

r5dn.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5DN_2XLARGE`<sup>Required</sup> <a name="R5DN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_2XLARGE"></a>

```typescript
public readonly R5DN_2XLARGE: string;
```

- *Type:* string

r5dn.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5DN_4XLARGE`<sup>Required</sup> <a name="R5DN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_4XLARGE"></a>

```typescript
public readonly R5DN_4XLARGE: string;
```

- *Type:* string

r5dn.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5DN_8XLARGE`<sup>Required</sup> <a name="R5DN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_8XLARGE"></a>

```typescript
public readonly R5DN_8XLARGE: string;
```

- *Type:* string

r5dn.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5DN_LARGE`<sup>Required</sup> <a name="R5DN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_LARGE"></a>

```typescript
public readonly R5DN_LARGE: string;
```

- *Type:* string

r5dn.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5DN_METAL`<sup>Required</sup> <a name="R5DN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_METAL"></a>

```typescript
public readonly R5DN_METAL: string;
```

- *Type:* string

r5dn.metal vCPUs: 96 Memory: 786432 MiB.

---

##### `R5DN_XLARGE`<sup>Required</sup> <a name="R5DN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5DN_XLARGE"></a>

```typescript
public readonly R5DN_XLARGE: string;
```

- *Type:* string

r5dn.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R5N_12XLARGE`<sup>Required</sup> <a name="R5N_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_12XLARGE"></a>

```typescript
public readonly R5N_12XLARGE: string;
```

- *Type:* string

r5n.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R5N_16XLARGE`<sup>Required</sup> <a name="R5N_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_16XLARGE"></a>

```typescript
public readonly R5N_16XLARGE: string;
```

- *Type:* string

r5n.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R5N_24XLARGE`<sup>Required</sup> <a name="R5N_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_24XLARGE"></a>

```typescript
public readonly R5N_24XLARGE: string;
```

- *Type:* string

r5n.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R5N_2XLARGE`<sup>Required</sup> <a name="R5N_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_2XLARGE"></a>

```typescript
public readonly R5N_2XLARGE: string;
```

- *Type:* string

r5n.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R5N_4XLARGE`<sup>Required</sup> <a name="R5N_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_4XLARGE"></a>

```typescript
public readonly R5N_4XLARGE: string;
```

- *Type:* string

r5n.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R5N_8XLARGE`<sup>Required</sup> <a name="R5N_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_8XLARGE"></a>

```typescript
public readonly R5N_8XLARGE: string;
```

- *Type:* string

r5n.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R5N_LARGE`<sup>Required</sup> <a name="R5N_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_LARGE"></a>

```typescript
public readonly R5N_LARGE: string;
```

- *Type:* string

r5n.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R5N_METAL`<sup>Required</sup> <a name="R5N_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_METAL"></a>

```typescript
public readonly R5N_METAL: string;
```

- *Type:* string

r5n.metal vCPUs: 96 Memory: 786432 MiB.

---

##### `R5N_XLARGE`<sup>Required</sup> <a name="R5N_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R5N_XLARGE"></a>

```typescript
public readonly R5N_XLARGE: string;
```

- *Type:* string

r5n.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6A_12XLARGE`<sup>Required</sup> <a name="R6A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_12XLARGE"></a>

```typescript
public readonly R6A_12XLARGE: string;
```

- *Type:* string

r6a.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6A_16XLARGE`<sup>Required</sup> <a name="R6A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_16XLARGE"></a>

```typescript
public readonly R6A_16XLARGE: string;
```

- *Type:* string

r6a.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6A_24XLARGE`<sup>Required</sup> <a name="R6A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_24XLARGE"></a>

```typescript
public readonly R6A_24XLARGE: string;
```

- *Type:* string

r6a.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R6A_2XLARGE`<sup>Required</sup> <a name="R6A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_2XLARGE"></a>

```typescript
public readonly R6A_2XLARGE: string;
```

- *Type:* string

r6a.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6A_32XLARGE`<sup>Required</sup> <a name="R6A_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_32XLARGE"></a>

```typescript
public readonly R6A_32XLARGE: string;
```

- *Type:* string

r6a.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6A_48XLARGE`<sup>Required</sup> <a name="R6A_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_48XLARGE"></a>

```typescript
public readonly R6A_48XLARGE: string;
```

- *Type:* string

r6a.48xlarge vCPUs: 192 Memory: 1572864 MiB.

---

##### `R6A_4XLARGE`<sup>Required</sup> <a name="R6A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_4XLARGE"></a>

```typescript
public readonly R6A_4XLARGE: string;
```

- *Type:* string

r6a.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6A_8XLARGE`<sup>Required</sup> <a name="R6A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_8XLARGE"></a>

```typescript
public readonly R6A_8XLARGE: string;
```

- *Type:* string

r6a.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6A_LARGE`<sup>Required</sup> <a name="R6A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_LARGE"></a>

```typescript
public readonly R6A_LARGE: string;
```

- *Type:* string

r6a.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6A_METAL`<sup>Required</sup> <a name="R6A_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_METAL"></a>

```typescript
public readonly R6A_METAL: string;
```

- *Type:* string

r6a.metal vCPUs: 192 Memory: 1572864 MiB.

---

##### `R6A_XLARGE`<sup>Required</sup> <a name="R6A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6A_XLARGE"></a>

```typescript
public readonly R6A_XLARGE: string;
```

- *Type:* string

r6a.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6G_12XLARGE`<sup>Required</sup> <a name="R6G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_12XLARGE"></a>

```typescript
public readonly R6G_12XLARGE: string;
```

- *Type:* string

r6g.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6G_16XLARGE`<sup>Required</sup> <a name="R6G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_16XLARGE"></a>

```typescript
public readonly R6G_16XLARGE: string;
```

- *Type:* string

r6g.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6G_2XLARGE`<sup>Required</sup> <a name="R6G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_2XLARGE"></a>

```typescript
public readonly R6G_2XLARGE: string;
```

- *Type:* string

r6g.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6G_4XLARGE`<sup>Required</sup> <a name="R6G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_4XLARGE"></a>

```typescript
public readonly R6G_4XLARGE: string;
```

- *Type:* string

r6g.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6G_8XLARGE`<sup>Required</sup> <a name="R6G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_8XLARGE"></a>

```typescript
public readonly R6G_8XLARGE: string;
```

- *Type:* string

r6g.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6G_LARGE`<sup>Required</sup> <a name="R6G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_LARGE"></a>

```typescript
public readonly R6G_LARGE: string;
```

- *Type:* string

r6g.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6G_MEDIUM`<sup>Required</sup> <a name="R6G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_MEDIUM"></a>

```typescript
public readonly R6G_MEDIUM: string;
```

- *Type:* string

r6g.medium vCPUs: 1 Memory: 8192 MiB.

---

##### `R6G_METAL`<sup>Required</sup> <a name="R6G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_METAL"></a>

```typescript
public readonly R6G_METAL: string;
```

- *Type:* string

r6g.metal vCPUs: 64 Memory: 524288 MiB.

---

##### `R6G_XLARGE`<sup>Required</sup> <a name="R6G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6G_XLARGE"></a>

```typescript
public readonly R6G_XLARGE: string;
```

- *Type:* string

r6g.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6GD_12XLARGE`<sup>Required</sup> <a name="R6GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_12XLARGE"></a>

```typescript
public readonly R6GD_12XLARGE: string;
```

- *Type:* string

r6gd.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6GD_16XLARGE`<sup>Required</sup> <a name="R6GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_16XLARGE"></a>

```typescript
public readonly R6GD_16XLARGE: string;
```

- *Type:* string

r6gd.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6GD_2XLARGE`<sup>Required</sup> <a name="R6GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_2XLARGE"></a>

```typescript
public readonly R6GD_2XLARGE: string;
```

- *Type:* string

r6gd.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6GD_4XLARGE`<sup>Required</sup> <a name="R6GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_4XLARGE"></a>

```typescript
public readonly R6GD_4XLARGE: string;
```

- *Type:* string

r6gd.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6GD_8XLARGE`<sup>Required</sup> <a name="R6GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_8XLARGE"></a>

```typescript
public readonly R6GD_8XLARGE: string;
```

- *Type:* string

r6gd.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6GD_LARGE`<sup>Required</sup> <a name="R6GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_LARGE"></a>

```typescript
public readonly R6GD_LARGE: string;
```

- *Type:* string

r6gd.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6GD_MEDIUM`<sup>Required</sup> <a name="R6GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_MEDIUM"></a>

```typescript
public readonly R6GD_MEDIUM: string;
```

- *Type:* string

r6gd.medium vCPUs: 1 Memory: 8192 MiB.

---

##### `R6GD_METAL`<sup>Required</sup> <a name="R6GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_METAL"></a>

```typescript
public readonly R6GD_METAL: string;
```

- *Type:* string

r6gd.metal vCPUs: 64 Memory: 524288 MiB.

---

##### `R6GD_XLARGE`<sup>Required</sup> <a name="R6GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6GD_XLARGE"></a>

```typescript
public readonly R6GD_XLARGE: string;
```

- *Type:* string

r6gd.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6I_12XLARGE`<sup>Required</sup> <a name="R6I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_12XLARGE"></a>

```typescript
public readonly R6I_12XLARGE: string;
```

- *Type:* string

r6i.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6I_16XLARGE`<sup>Required</sup> <a name="R6I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_16XLARGE"></a>

```typescript
public readonly R6I_16XLARGE: string;
```

- *Type:* string

r6i.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6I_24XLARGE`<sup>Required</sup> <a name="R6I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_24XLARGE"></a>

```typescript
public readonly R6I_24XLARGE: string;
```

- *Type:* string

r6i.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R6I_2XLARGE`<sup>Required</sup> <a name="R6I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_2XLARGE"></a>

```typescript
public readonly R6I_2XLARGE: string;
```

- *Type:* string

r6i.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6I_32XLARGE`<sup>Required</sup> <a name="R6I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_32XLARGE"></a>

```typescript
public readonly R6I_32XLARGE: string;
```

- *Type:* string

r6i.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6I_4XLARGE`<sup>Required</sup> <a name="R6I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_4XLARGE"></a>

```typescript
public readonly R6I_4XLARGE: string;
```

- *Type:* string

r6i.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6I_8XLARGE`<sup>Required</sup> <a name="R6I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_8XLARGE"></a>

```typescript
public readonly R6I_8XLARGE: string;
```

- *Type:* string

r6i.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6I_LARGE`<sup>Required</sup> <a name="R6I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_LARGE"></a>

```typescript
public readonly R6I_LARGE: string;
```

- *Type:* string

r6i.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6I_METAL`<sup>Required</sup> <a name="R6I_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_METAL"></a>

```typescript
public readonly R6I_METAL: string;
```

- *Type:* string

r6i.metal vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6I_XLARGE`<sup>Required</sup> <a name="R6I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6I_XLARGE"></a>

```typescript
public readonly R6I_XLARGE: string;
```

- *Type:* string

r6i.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6ID_12XLARGE`<sup>Required</sup> <a name="R6ID_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_12XLARGE"></a>

```typescript
public readonly R6ID_12XLARGE: string;
```

- *Type:* string

r6id.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6ID_16XLARGE`<sup>Required</sup> <a name="R6ID_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_16XLARGE"></a>

```typescript
public readonly R6ID_16XLARGE: string;
```

- *Type:* string

r6id.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6ID_24XLARGE`<sup>Required</sup> <a name="R6ID_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_24XLARGE"></a>

```typescript
public readonly R6ID_24XLARGE: string;
```

- *Type:* string

r6id.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R6ID_2XLARGE`<sup>Required</sup> <a name="R6ID_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_2XLARGE"></a>

```typescript
public readonly R6ID_2XLARGE: string;
```

- *Type:* string

r6id.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6ID_32XLARGE`<sup>Required</sup> <a name="R6ID_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_32XLARGE"></a>

```typescript
public readonly R6ID_32XLARGE: string;
```

- *Type:* string

r6id.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6ID_4XLARGE`<sup>Required</sup> <a name="R6ID_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_4XLARGE"></a>

```typescript
public readonly R6ID_4XLARGE: string;
```

- *Type:* string

r6id.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6ID_8XLARGE`<sup>Required</sup> <a name="R6ID_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_8XLARGE"></a>

```typescript
public readonly R6ID_8XLARGE: string;
```

- *Type:* string

r6id.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6ID_LARGE`<sup>Required</sup> <a name="R6ID_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_LARGE"></a>

```typescript
public readonly R6ID_LARGE: string;
```

- *Type:* string

r6id.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6ID_METAL`<sup>Required</sup> <a name="R6ID_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_METAL"></a>

```typescript
public readonly R6ID_METAL: string;
```

- *Type:* string

r6id.metal vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6ID_XLARGE`<sup>Required</sup> <a name="R6ID_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6ID_XLARGE"></a>

```typescript
public readonly R6ID_XLARGE: string;
```

- *Type:* string

r6id.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6IDN_12XLARGE`<sup>Required</sup> <a name="R6IDN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_12XLARGE"></a>

```typescript
public readonly R6IDN_12XLARGE: string;
```

- *Type:* string

r6idn.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6IDN_16XLARGE`<sup>Required</sup> <a name="R6IDN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_16XLARGE"></a>

```typescript
public readonly R6IDN_16XLARGE: string;
```

- *Type:* string

r6idn.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6IDN_24XLARGE`<sup>Required</sup> <a name="R6IDN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_24XLARGE"></a>

```typescript
public readonly R6IDN_24XLARGE: string;
```

- *Type:* string

r6idn.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R6IDN_2XLARGE`<sup>Required</sup> <a name="R6IDN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_2XLARGE"></a>

```typescript
public readonly R6IDN_2XLARGE: string;
```

- *Type:* string

r6idn.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6IDN_32XLARGE`<sup>Required</sup> <a name="R6IDN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_32XLARGE"></a>

```typescript
public readonly R6IDN_32XLARGE: string;
```

- *Type:* string

r6idn.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6IDN_4XLARGE`<sup>Required</sup> <a name="R6IDN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_4XLARGE"></a>

```typescript
public readonly R6IDN_4XLARGE: string;
```

- *Type:* string

r6idn.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6IDN_8XLARGE`<sup>Required</sup> <a name="R6IDN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_8XLARGE"></a>

```typescript
public readonly R6IDN_8XLARGE: string;
```

- *Type:* string

r6idn.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6IDN_LARGE`<sup>Required</sup> <a name="R6IDN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_LARGE"></a>

```typescript
public readonly R6IDN_LARGE: string;
```

- *Type:* string

r6idn.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6IDN_METAL`<sup>Required</sup> <a name="R6IDN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_METAL"></a>

```typescript
public readonly R6IDN_METAL: string;
```

- *Type:* string

r6idn.metal vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6IDN_XLARGE`<sup>Required</sup> <a name="R6IDN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IDN_XLARGE"></a>

```typescript
public readonly R6IDN_XLARGE: string;
```

- *Type:* string

r6idn.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R6IN_12XLARGE`<sup>Required</sup> <a name="R6IN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_12XLARGE"></a>

```typescript
public readonly R6IN_12XLARGE: string;
```

- *Type:* string

r6in.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R6IN_16XLARGE`<sup>Required</sup> <a name="R6IN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_16XLARGE"></a>

```typescript
public readonly R6IN_16XLARGE: string;
```

- *Type:* string

r6in.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R6IN_24XLARGE`<sup>Required</sup> <a name="R6IN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_24XLARGE"></a>

```typescript
public readonly R6IN_24XLARGE: string;
```

- *Type:* string

r6in.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R6IN_2XLARGE`<sup>Required</sup> <a name="R6IN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_2XLARGE"></a>

```typescript
public readonly R6IN_2XLARGE: string;
```

- *Type:* string

r6in.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R6IN_32XLARGE`<sup>Required</sup> <a name="R6IN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_32XLARGE"></a>

```typescript
public readonly R6IN_32XLARGE: string;
```

- *Type:* string

r6in.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6IN_4XLARGE`<sup>Required</sup> <a name="R6IN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_4XLARGE"></a>

```typescript
public readonly R6IN_4XLARGE: string;
```

- *Type:* string

r6in.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R6IN_8XLARGE`<sup>Required</sup> <a name="R6IN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_8XLARGE"></a>

```typescript
public readonly R6IN_8XLARGE: string;
```

- *Type:* string

r6in.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R6IN_LARGE`<sup>Required</sup> <a name="R6IN_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_LARGE"></a>

```typescript
public readonly R6IN_LARGE: string;
```

- *Type:* string

r6in.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R6IN_METAL`<sup>Required</sup> <a name="R6IN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_METAL"></a>

```typescript
public readonly R6IN_METAL: string;
```

- *Type:* string

r6in.metal vCPUs: 128 Memory: 1048576 MiB.

---

##### `R6IN_XLARGE`<sup>Required</sup> <a name="R6IN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R6IN_XLARGE"></a>

```typescript
public readonly R6IN_XLARGE: string;
```

- *Type:* string

r6in.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R7A_12XLARGE`<sup>Required</sup> <a name="R7A_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_12XLARGE"></a>

```typescript
public readonly R7A_12XLARGE: string;
```

- *Type:* string

r7a.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R7A_16XLARGE`<sup>Required</sup> <a name="R7A_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_16XLARGE"></a>

```typescript
public readonly R7A_16XLARGE: string;
```

- *Type:* string

r7a.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R7A_24XLARGE`<sup>Required</sup> <a name="R7A_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_24XLARGE"></a>

```typescript
public readonly R7A_24XLARGE: string;
```

- *Type:* string

r7a.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R7A_2XLARGE`<sup>Required</sup> <a name="R7A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_2XLARGE"></a>

```typescript
public readonly R7A_2XLARGE: string;
```

- *Type:* string

r7a.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R7A_32XLARGE`<sup>Required</sup> <a name="R7A_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_32XLARGE"></a>

```typescript
public readonly R7A_32XLARGE: string;
```

- *Type:* string

r7a.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R7A_48XLARGE`<sup>Required</sup> <a name="R7A_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_48XLARGE"></a>

```typescript
public readonly R7A_48XLARGE: string;
```

- *Type:* string

r7a.48xlarge vCPUs: 192 Memory: 1572864 MiB.

---

##### `R7A_4XLARGE`<sup>Required</sup> <a name="R7A_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_4XLARGE"></a>

```typescript
public readonly R7A_4XLARGE: string;
```

- *Type:* string

r7a.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R7A_8XLARGE`<sup>Required</sup> <a name="R7A_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_8XLARGE"></a>

```typescript
public readonly R7A_8XLARGE: string;
```

- *Type:* string

r7a.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R7A_LARGE`<sup>Required</sup> <a name="R7A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_LARGE"></a>

```typescript
public readonly R7A_LARGE: string;
```

- *Type:* string

r7a.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R7A_MEDIUM`<sup>Required</sup> <a name="R7A_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_MEDIUM"></a>

```typescript
public readonly R7A_MEDIUM: string;
```

- *Type:* string

r7a.medium vCPUs: 1 Memory: 8192 MiB.

---

##### `R7A_METAL_48XL`<sup>Required</sup> <a name="R7A_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_METAL_48XL"></a>

```typescript
public readonly R7A_METAL_48XL: string;
```

- *Type:* string

r7a.metal-48xl vCPUs: 192 Memory: 1572864 MiB.

---

##### `R7A_XLARGE`<sup>Required</sup> <a name="R7A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7A_XLARGE"></a>

```typescript
public readonly R7A_XLARGE: string;
```

- *Type:* string

r7a.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R7G_12XLARGE`<sup>Required</sup> <a name="R7G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_12XLARGE"></a>

```typescript
public readonly R7G_12XLARGE: string;
```

- *Type:* string

r7g.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R7G_16XLARGE`<sup>Required</sup> <a name="R7G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_16XLARGE"></a>

```typescript
public readonly R7G_16XLARGE: string;
```

- *Type:* string

r7g.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R7G_2XLARGE`<sup>Required</sup> <a name="R7G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_2XLARGE"></a>

```typescript
public readonly R7G_2XLARGE: string;
```

- *Type:* string

r7g.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R7G_4XLARGE`<sup>Required</sup> <a name="R7G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_4XLARGE"></a>

```typescript
public readonly R7G_4XLARGE: string;
```

- *Type:* string

r7g.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R7G_8XLARGE`<sup>Required</sup> <a name="R7G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_8XLARGE"></a>

```typescript
public readonly R7G_8XLARGE: string;
```

- *Type:* string

r7g.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R7G_LARGE`<sup>Required</sup> <a name="R7G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_LARGE"></a>

```typescript
public readonly R7G_LARGE: string;
```

- *Type:* string

r7g.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R7G_MEDIUM`<sup>Required</sup> <a name="R7G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_MEDIUM"></a>

```typescript
public readonly R7G_MEDIUM: string;
```

- *Type:* string

r7g.medium vCPUs: 1 Memory: 8192 MiB.

---

##### `R7G_METAL`<sup>Required</sup> <a name="R7G_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_METAL"></a>

```typescript
public readonly R7G_METAL: string;
```

- *Type:* string

r7g.metal vCPUs: 64 Memory: 524288 MiB.

---

##### `R7G_XLARGE`<sup>Required</sup> <a name="R7G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7G_XLARGE"></a>

```typescript
public readonly R7G_XLARGE: string;
```

- *Type:* string

r7g.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R7GD_12XLARGE`<sup>Required</sup> <a name="R7GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_12XLARGE"></a>

```typescript
public readonly R7GD_12XLARGE: string;
```

- *Type:* string

r7gd.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R7GD_16XLARGE`<sup>Required</sup> <a name="R7GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_16XLARGE"></a>

```typescript
public readonly R7GD_16XLARGE: string;
```

- *Type:* string

r7gd.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R7GD_2XLARGE`<sup>Required</sup> <a name="R7GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_2XLARGE"></a>

```typescript
public readonly R7GD_2XLARGE: string;
```

- *Type:* string

r7gd.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R7GD_4XLARGE`<sup>Required</sup> <a name="R7GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_4XLARGE"></a>

```typescript
public readonly R7GD_4XLARGE: string;
```

- *Type:* string

r7gd.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R7GD_8XLARGE`<sup>Required</sup> <a name="R7GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_8XLARGE"></a>

```typescript
public readonly R7GD_8XLARGE: string;
```

- *Type:* string

r7gd.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R7GD_LARGE`<sup>Required</sup> <a name="R7GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_LARGE"></a>

```typescript
public readonly R7GD_LARGE: string;
```

- *Type:* string

r7gd.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R7GD_MEDIUM`<sup>Required</sup> <a name="R7GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_MEDIUM"></a>

```typescript
public readonly R7GD_MEDIUM: string;
```

- *Type:* string

r7gd.medium vCPUs: 1 Memory: 8192 MiB.

---

##### `R7GD_METAL`<sup>Required</sup> <a name="R7GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_METAL"></a>

```typescript
public readonly R7GD_METAL: string;
```

- *Type:* string

r7gd.metal vCPUs: 64 Memory: 524288 MiB.

---

##### `R7GD_XLARGE`<sup>Required</sup> <a name="R7GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7GD_XLARGE"></a>

```typescript
public readonly R7GD_XLARGE: string;
```

- *Type:* string

r7gd.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R7I_12XLARGE`<sup>Required</sup> <a name="R7I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_12XLARGE"></a>

```typescript
public readonly R7I_12XLARGE: string;
```

- *Type:* string

r7i.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R7I_16XLARGE`<sup>Required</sup> <a name="R7I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_16XLARGE"></a>

```typescript
public readonly R7I_16XLARGE: string;
```

- *Type:* string

r7i.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R7I_24XLARGE`<sup>Required</sup> <a name="R7I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_24XLARGE"></a>

```typescript
public readonly R7I_24XLARGE: string;
```

- *Type:* string

r7i.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R7I_2XLARGE`<sup>Required</sup> <a name="R7I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_2XLARGE"></a>

```typescript
public readonly R7I_2XLARGE: string;
```

- *Type:* string

r7i.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R7I_48XLARGE`<sup>Required</sup> <a name="R7I_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_48XLARGE"></a>

```typescript
public readonly R7I_48XLARGE: string;
```

- *Type:* string

r7i.48xlarge vCPUs: 192 Memory: 1572864 MiB.

---

##### `R7I_4XLARGE`<sup>Required</sup> <a name="R7I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_4XLARGE"></a>

```typescript
public readonly R7I_4XLARGE: string;
```

- *Type:* string

r7i.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R7I_8XLARGE`<sup>Required</sup> <a name="R7I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_8XLARGE"></a>

```typescript
public readonly R7I_8XLARGE: string;
```

- *Type:* string

r7i.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R7I_LARGE`<sup>Required</sup> <a name="R7I_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_LARGE"></a>

```typescript
public readonly R7I_LARGE: string;
```

- *Type:* string

r7i.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R7I_METAL_24XL`<sup>Required</sup> <a name="R7I_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_METAL_24XL"></a>

```typescript
public readonly R7I_METAL_24XL: string;
```

- *Type:* string

r7i.metal-24xl vCPUs: 96 Memory: 786432 MiB.

---

##### `R7I_METAL_48XL`<sup>Required</sup> <a name="R7I_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_METAL_48XL"></a>

```typescript
public readonly R7I_METAL_48XL: string;
```

- *Type:* string

r7i.metal-48xl vCPUs: 192 Memory: 1572864 MiB.

---

##### `R7I_XLARGE`<sup>Required</sup> <a name="R7I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7I_XLARGE"></a>

```typescript
public readonly R7I_XLARGE: string;
```

- *Type:* string

r7i.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R7IZ_12XLARGE`<sup>Required</sup> <a name="R7IZ_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_12XLARGE"></a>

```typescript
public readonly R7IZ_12XLARGE: string;
```

- *Type:* string

r7iz.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R7IZ_16XLARGE`<sup>Required</sup> <a name="R7IZ_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_16XLARGE"></a>

```typescript
public readonly R7IZ_16XLARGE: string;
```

- *Type:* string

r7iz.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R7IZ_2XLARGE`<sup>Required</sup> <a name="R7IZ_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_2XLARGE"></a>

```typescript
public readonly R7IZ_2XLARGE: string;
```

- *Type:* string

r7iz.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R7IZ_32XLARGE`<sup>Required</sup> <a name="R7IZ_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_32XLARGE"></a>

```typescript
public readonly R7IZ_32XLARGE: string;
```

- *Type:* string

r7iz.32xlarge vCPUs: 128 Memory: 1048576 MiB.

---

##### `R7IZ_4XLARGE`<sup>Required</sup> <a name="R7IZ_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_4XLARGE"></a>

```typescript
public readonly R7IZ_4XLARGE: string;
```

- *Type:* string

r7iz.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R7IZ_8XLARGE`<sup>Required</sup> <a name="R7IZ_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_8XLARGE"></a>

```typescript
public readonly R7IZ_8XLARGE: string;
```

- *Type:* string

r7iz.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R7IZ_LARGE`<sup>Required</sup> <a name="R7IZ_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_LARGE"></a>

```typescript
public readonly R7IZ_LARGE: string;
```

- *Type:* string

r7iz.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R7IZ_METAL_16XL`<sup>Required</sup> <a name="R7IZ_METAL_16XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_METAL_16XL"></a>

```typescript
public readonly R7IZ_METAL_16XL: string;
```

- *Type:* string

r7iz.metal-16xl vCPUs: 64 Memory: 524288 MiB.

---

##### `R7IZ_METAL_32XL`<sup>Required</sup> <a name="R7IZ_METAL_32XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_METAL_32XL"></a>

```typescript
public readonly R7IZ_METAL_32XL: string;
```

- *Type:* string

r7iz.metal-32xl vCPUs: 128 Memory: 1048576 MiB.

---

##### `R7IZ_XLARGE`<sup>Required</sup> <a name="R7IZ_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R7IZ_XLARGE"></a>

```typescript
public readonly R7IZ_XLARGE: string;
```

- *Type:* string

r7iz.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `R8G_12XLARGE`<sup>Required</sup> <a name="R8G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_12XLARGE"></a>

```typescript
public readonly R8G_12XLARGE: string;
```

- *Type:* string

r8g.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `R8G_16XLARGE`<sup>Required</sup> <a name="R8G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_16XLARGE"></a>

```typescript
public readonly R8G_16XLARGE: string;
```

- *Type:* string

r8g.16xlarge vCPUs: 64 Memory: 524288 MiB.

---

##### `R8G_24XLARGE`<sup>Required</sup> <a name="R8G_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_24XLARGE"></a>

```typescript
public readonly R8G_24XLARGE: string;
```

- *Type:* string

r8g.24xlarge vCPUs: 96 Memory: 786432 MiB.

---

##### `R8G_2XLARGE`<sup>Required</sup> <a name="R8G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_2XLARGE"></a>

```typescript
public readonly R8G_2XLARGE: string;
```

- *Type:* string

r8g.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `R8G_48XLARGE`<sup>Required</sup> <a name="R8G_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_48XLARGE"></a>

```typescript
public readonly R8G_48XLARGE: string;
```

- *Type:* string

r8g.48xlarge vCPUs: 192 Memory: 1572864 MiB.

---

##### `R8G_4XLARGE`<sup>Required</sup> <a name="R8G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_4XLARGE"></a>

```typescript
public readonly R8G_4XLARGE: string;
```

- *Type:* string

r8g.4xlarge vCPUs: 16 Memory: 131072 MiB.

---

##### `R8G_8XLARGE`<sup>Required</sup> <a name="R8G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_8XLARGE"></a>

```typescript
public readonly R8G_8XLARGE: string;
```

- *Type:* string

r8g.8xlarge vCPUs: 32 Memory: 262144 MiB.

---

##### `R8G_LARGE`<sup>Required</sup> <a name="R8G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_LARGE"></a>

```typescript
public readonly R8G_LARGE: string;
```

- *Type:* string

r8g.large vCPUs: 2 Memory: 16384 MiB.

---

##### `R8G_MEDIUM`<sup>Required</sup> <a name="R8G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_MEDIUM"></a>

```typescript
public readonly R8G_MEDIUM: string;
```

- *Type:* string

r8g.medium vCPUs: 1 Memory: 8192 MiB.

---

##### `R8G_METAL_24XL`<sup>Required</sup> <a name="R8G_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_METAL_24XL"></a>

```typescript
public readonly R8G_METAL_24XL: string;
```

- *Type:* string

r8g.metal-24xl vCPUs: 96 Memory: 786432 MiB.

---

##### `R8G_METAL_48XL`<sup>Required</sup> <a name="R8G_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_METAL_48XL"></a>

```typescript
public readonly R8G_METAL_48XL: string;
```

- *Type:* string

r8g.metal-48xl vCPUs: 192 Memory: 1572864 MiB.

---

##### `R8G_XLARGE`<sup>Required</sup> <a name="R8G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.R8G_XLARGE"></a>

```typescript
public readonly R8G_XLARGE: string;
```

- *Type:* string

r8g.xlarge vCPUs: 4 Memory: 32768 MiB.

---

##### `T1_MICRO`<sup>Required</sup> <a name="T1_MICRO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T1_MICRO"></a>

```typescript
public readonly T1_MICRO: string;
```

- *Type:* string

t1.micro vCPUs: 1 Memory: 627 MiB.

---

##### `T2_2XLARGE`<sup>Required</sup> <a name="T2_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_2XLARGE"></a>

```typescript
public readonly T2_2XLARGE: string;
```

- *Type:* string

t2.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `T2_LARGE`<sup>Required</sup> <a name="T2_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_LARGE"></a>

```typescript
public readonly T2_LARGE: string;
```

- *Type:* string

t2.large vCPUs: 2 Memory: 8192 MiB.

---

##### `T2_MEDIUM`<sup>Required</sup> <a name="T2_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_MEDIUM"></a>

```typescript
public readonly T2_MEDIUM: string;
```

- *Type:* string

t2.medium vCPUs: 2 Memory: 4096 MiB.

---

##### `T2_MICRO`<sup>Required</sup> <a name="T2_MICRO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_MICRO"></a>

```typescript
public readonly T2_MICRO: string;
```

- *Type:* string

t2.micro vCPUs: 1 Memory: 1024 MiB.

---

##### `T2_NANO`<sup>Required</sup> <a name="T2_NANO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_NANO"></a>

```typescript
public readonly T2_NANO: string;
```

- *Type:* string

t2.nano vCPUs: 1 Memory: 512 MiB.

---

##### `T2_SMALL`<sup>Required</sup> <a name="T2_SMALL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_SMALL"></a>

```typescript
public readonly T2_SMALL: string;
```

- *Type:* string

t2.small vCPUs: 1 Memory: 2048 MiB.

---

##### `T2_XLARGE`<sup>Required</sup> <a name="T2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T2_XLARGE"></a>

```typescript
public readonly T2_XLARGE: string;
```

- *Type:* string

t2.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `T3_2XLARGE`<sup>Required</sup> <a name="T3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_2XLARGE"></a>

```typescript
public readonly T3_2XLARGE: string;
```

- *Type:* string

t3.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `T3_LARGE`<sup>Required</sup> <a name="T3_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_LARGE"></a>

```typescript
public readonly T3_LARGE: string;
```

- *Type:* string

t3.large vCPUs: 2 Memory: 8192 MiB.

---

##### `T3_MEDIUM`<sup>Required</sup> <a name="T3_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_MEDIUM"></a>

```typescript
public readonly T3_MEDIUM: string;
```

- *Type:* string

t3.medium vCPUs: 2 Memory: 4096 MiB.

---

##### `T3_MICRO`<sup>Required</sup> <a name="T3_MICRO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_MICRO"></a>

```typescript
public readonly T3_MICRO: string;
```

- *Type:* string

t3.micro vCPUs: 2 Memory: 1024 MiB.

---

##### `T3_NANO`<sup>Required</sup> <a name="T3_NANO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_NANO"></a>

```typescript
public readonly T3_NANO: string;
```

- *Type:* string

t3.nano vCPUs: 2 Memory: 512 MiB.

---

##### `T3_SMALL`<sup>Required</sup> <a name="T3_SMALL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_SMALL"></a>

```typescript
public readonly T3_SMALL: string;
```

- *Type:* string

t3.small vCPUs: 2 Memory: 2048 MiB.

---

##### `T3_XLARGE`<sup>Required</sup> <a name="T3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3_XLARGE"></a>

```typescript
public readonly T3_XLARGE: string;
```

- *Type:* string

t3.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `T3A_2XLARGE`<sup>Required</sup> <a name="T3A_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_2XLARGE"></a>

```typescript
public readonly T3A_2XLARGE: string;
```

- *Type:* string

t3a.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `T3A_LARGE`<sup>Required</sup> <a name="T3A_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_LARGE"></a>

```typescript
public readonly T3A_LARGE: string;
```

- *Type:* string

t3a.large vCPUs: 2 Memory: 8192 MiB.

---

##### `T3A_MEDIUM`<sup>Required</sup> <a name="T3A_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_MEDIUM"></a>

```typescript
public readonly T3A_MEDIUM: string;
```

- *Type:* string

t3a.medium vCPUs: 2 Memory: 4096 MiB.

---

##### `T3A_MICRO`<sup>Required</sup> <a name="T3A_MICRO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_MICRO"></a>

```typescript
public readonly T3A_MICRO: string;
```

- *Type:* string

t3a.micro vCPUs: 2 Memory: 1024 MiB.

---

##### `T3A_NANO`<sup>Required</sup> <a name="T3A_NANO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_NANO"></a>

```typescript
public readonly T3A_NANO: string;
```

- *Type:* string

t3a.nano vCPUs: 2 Memory: 512 MiB.

---

##### `T3A_SMALL`<sup>Required</sup> <a name="T3A_SMALL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_SMALL"></a>

```typescript
public readonly T3A_SMALL: string;
```

- *Type:* string

t3a.small vCPUs: 2 Memory: 2048 MiB.

---

##### `T3A_XLARGE`<sup>Required</sup> <a name="T3A_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T3A_XLARGE"></a>

```typescript
public readonly T3A_XLARGE: string;
```

- *Type:* string

t3a.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `T4G_2XLARGE`<sup>Required</sup> <a name="T4G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_2XLARGE"></a>

```typescript
public readonly T4G_2XLARGE: string;
```

- *Type:* string

t4g.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `T4G_LARGE`<sup>Required</sup> <a name="T4G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_LARGE"></a>

```typescript
public readonly T4G_LARGE: string;
```

- *Type:* string

t4g.large vCPUs: 2 Memory: 8192 MiB.

---

##### `T4G_MEDIUM`<sup>Required</sup> <a name="T4G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_MEDIUM"></a>

```typescript
public readonly T4G_MEDIUM: string;
```

- *Type:* string

t4g.medium vCPUs: 2 Memory: 4096 MiB.

---

##### `T4G_MICRO`<sup>Required</sup> <a name="T4G_MICRO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_MICRO"></a>

```typescript
public readonly T4G_MICRO: string;
```

- *Type:* string

t4g.micro vCPUs: 2 Memory: 1024 MiB.

---

##### `T4G_NANO`<sup>Required</sup> <a name="T4G_NANO" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_NANO"></a>

```typescript
public readonly T4G_NANO: string;
```

- *Type:* string

t4g.nano vCPUs: 2 Memory: 512 MiB.

---

##### `T4G_SMALL`<sup>Required</sup> <a name="T4G_SMALL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_SMALL"></a>

```typescript
public readonly T4G_SMALL: string;
```

- *Type:* string

t4g.small vCPUs: 2 Memory: 2048 MiB.

---

##### `T4G_XLARGE`<sup>Required</sup> <a name="T4G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.T4G_XLARGE"></a>

```typescript
public readonly T4G_XLARGE: string;
```

- *Type:* string

t4g.xlarge vCPUs: 4 Memory: 16384 MiB.

---

##### `TRN1_2XLARGE`<sup>Required</sup> <a name="TRN1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.TRN1_2XLARGE"></a>

```typescript
public readonly TRN1_2XLARGE: string;
```

- *Type:* string

trn1.2xlarge vCPUs: 8 Memory: 32768 MiB.

---

##### `TRN1_32XLARGE`<sup>Required</sup> <a name="TRN1_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.TRN1_32XLARGE"></a>

```typescript
public readonly TRN1_32XLARGE: string;
```

- *Type:* string

trn1.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `TRN1N_32XLARGE`<sup>Required</sup> <a name="TRN1N_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.TRN1N_32XLARGE"></a>

```typescript
public readonly TRN1N_32XLARGE: string;
```

- *Type:* string

trn1n.32xlarge vCPUs: 128 Memory: 524288 MiB.

---

##### `U_12TB1_112XLARGE`<sup>Required</sup> <a name="U_12TB1_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_12TB1_112XLARGE"></a>

```typescript
public readonly U_12TB1_112XLARGE: string;
```

- *Type:* string

u-12tb1.112xlarge vCPUs: 448 Memory: 12582912 MiB.

---

##### `U_18TB1_112XLARGE`<sup>Required</sup> <a name="U_18TB1_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_18TB1_112XLARGE"></a>

```typescript
public readonly U_18TB1_112XLARGE: string;
```

- *Type:* string

u-18tb1.112xlarge vCPUs: 448 Memory: 18874368 MiB.

---

##### `U_24TB1_112XLARGE`<sup>Required</sup> <a name="U_24TB1_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_24TB1_112XLARGE"></a>

```typescript
public readonly U_24TB1_112XLARGE: string;
```

- *Type:* string

u-24tb1.112xlarge vCPUs: 448 Memory: 25165824 MiB.

---

##### `U_3TB1_56XLARGE`<sup>Required</sup> <a name="U_3TB1_56XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_3TB1_56XLARGE"></a>

```typescript
public readonly U_3TB1_56XLARGE: string;
```

- *Type:* string

u-3tb1.56xlarge vCPUs: 224 Memory: 3145728 MiB.

---

##### `U_6TB1_112XLARGE`<sup>Required</sup> <a name="U_6TB1_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_6TB1_112XLARGE"></a>

```typescript
public readonly U_6TB1_112XLARGE: string;
```

- *Type:* string

u-6tb1.112xlarge vCPUs: 448 Memory: 6291456 MiB.

---

##### `U_6TB1_56XLARGE`<sup>Required</sup> <a name="U_6TB1_56XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_6TB1_56XLARGE"></a>

```typescript
public readonly U_6TB1_56XLARGE: string;
```

- *Type:* string

u-6tb1.56xlarge vCPUs: 224 Memory: 6291456 MiB.

---

##### `U_9TB1_112XLARGE`<sup>Required</sup> <a name="U_9TB1_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U_9TB1_112XLARGE"></a>

```typescript
public readonly U_9TB1_112XLARGE: string;
```

- *Type:* string

u-9tb1.112xlarge vCPUs: 448 Memory: 9437184 MiB.

---

##### `U7I_12TB_224XLARGE`<sup>Required</sup> <a name="U7I_12TB_224XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7I_12TB_224XLARGE"></a>

```typescript
public readonly U7I_12TB_224XLARGE: string;
```

- *Type:* string

u7i-12tb.224xlarge vCPUs: 896 Memory: 12582912 MiB.

---

##### `U7I_6TB_112XLARGE`<sup>Required</sup> <a name="U7I_6TB_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7I_6TB_112XLARGE"></a>

```typescript
public readonly U7I_6TB_112XLARGE: string;
```

- *Type:* string

u7i-6tb.112xlarge vCPUs: 448 Memory: 6291456 MiB.

---

##### `U7I_8TB_112XLARGE`<sup>Required</sup> <a name="U7I_8TB_112XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7I_8TB_112XLARGE"></a>

```typescript
public readonly U7I_8TB_112XLARGE: string;
```

- *Type:* string

u7i-8tb.112xlarge vCPUs: 448 Memory: 8388608 MiB.

---

##### `U7IN_16TB_224XLARGE`<sup>Required</sup> <a name="U7IN_16TB_224XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7IN_16TB_224XLARGE"></a>

```typescript
public readonly U7IN_16TB_224XLARGE: string;
```

- *Type:* string

u7in-16tb.224xlarge vCPUs: 896 Memory: 16777216 MiB.

---

##### `U7IN_24TB_224XLARGE`<sup>Required</sup> <a name="U7IN_24TB_224XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7IN_24TB_224XLARGE"></a>

```typescript
public readonly U7IN_24TB_224XLARGE: string;
```

- *Type:* string

u7in-24tb.224xlarge vCPUs: 896 Memory: 25165824 MiB.

---

##### `U7IN_32TB_224XLARGE`<sup>Required</sup> <a name="U7IN_32TB_224XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.U7IN_32TB_224XLARGE"></a>

```typescript
public readonly U7IN_32TB_224XLARGE: string;
```

- *Type:* string

u7in-32tb.224xlarge vCPUs: 896 Memory: 33554432 MiB.

---

##### `VT1_24XLARGE`<sup>Required</sup> <a name="VT1_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.VT1_24XLARGE"></a>

```typescript
public readonly VT1_24XLARGE: string;
```

- *Type:* string

vt1.24xlarge vCPUs: 96 Memory: 196608 MiB.

---

##### `VT1_3XLARGE`<sup>Required</sup> <a name="VT1_3XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.VT1_3XLARGE"></a>

```typescript
public readonly VT1_3XLARGE: string;
```

- *Type:* string

vt1.3xlarge vCPUs: 12 Memory: 24576 MiB.

---

##### `VT1_6XLARGE`<sup>Required</sup> <a name="VT1_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.VT1_6XLARGE"></a>

```typescript
public readonly VT1_6XLARGE: string;
```

- *Type:* string

vt1.6xlarge vCPUs: 24 Memory: 49152 MiB.

---

##### `X1_16XLARGE`<sup>Required</sup> <a name="X1_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1_16XLARGE"></a>

```typescript
public readonly X1_16XLARGE: string;
```

- *Type:* string

x1.16xlarge vCPUs: 64 Memory: 999424 MiB.

---

##### `X1_32XLARGE`<sup>Required</sup> <a name="X1_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1_32XLARGE"></a>

```typescript
public readonly X1_32XLARGE: string;
```

- *Type:* string

x1.32xlarge vCPUs: 128 Memory: 1998848 MiB.

---

##### `X1E_16XLARGE`<sup>Required</sup> <a name="X1E_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_16XLARGE"></a>

```typescript
public readonly X1E_16XLARGE: string;
```

- *Type:* string

x1e.16xlarge vCPUs: 64 Memory: 1998848 MiB.

---

##### `X1E_2XLARGE`<sup>Required</sup> <a name="X1E_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_2XLARGE"></a>

```typescript
public readonly X1E_2XLARGE: string;
```

- *Type:* string

x1e.2xlarge vCPUs: 8 Memory: 249856 MiB.

---

##### `X1E_32XLARGE`<sup>Required</sup> <a name="X1E_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_32XLARGE"></a>

```typescript
public readonly X1E_32XLARGE: string;
```

- *Type:* string

x1e.32xlarge vCPUs: 128 Memory: 3997696 MiB.

---

##### `X1E_4XLARGE`<sup>Required</sup> <a name="X1E_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_4XLARGE"></a>

```typescript
public readonly X1E_4XLARGE: string;
```

- *Type:* string

x1e.4xlarge vCPUs: 16 Memory: 499712 MiB.

---

##### `X1E_8XLARGE`<sup>Required</sup> <a name="X1E_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_8XLARGE"></a>

```typescript
public readonly X1E_8XLARGE: string;
```

- *Type:* string

x1e.8xlarge vCPUs: 32 Memory: 999424 MiB.

---

##### `X1E_XLARGE`<sup>Required</sup> <a name="X1E_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X1E_XLARGE"></a>

```typescript
public readonly X1E_XLARGE: string;
```

- *Type:* string

x1e.xlarge vCPUs: 4 Memory: 124928 MiB.

---

##### `X2GD_12XLARGE`<sup>Required</sup> <a name="X2GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_12XLARGE"></a>

```typescript
public readonly X2GD_12XLARGE: string;
```

- *Type:* string

x2gd.12xlarge vCPUs: 48 Memory: 786432 MiB.

---

##### `X2GD_16XLARGE`<sup>Required</sup> <a name="X2GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_16XLARGE"></a>

```typescript
public readonly X2GD_16XLARGE: string;
```

- *Type:* string

x2gd.16xlarge vCPUs: 64 Memory: 1048576 MiB.

---

##### `X2GD_2XLARGE`<sup>Required</sup> <a name="X2GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_2XLARGE"></a>

```typescript
public readonly X2GD_2XLARGE: string;
```

- *Type:* string

x2gd.2xlarge vCPUs: 8 Memory: 131072 MiB.

---

##### `X2GD_4XLARGE`<sup>Required</sup> <a name="X2GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_4XLARGE"></a>

```typescript
public readonly X2GD_4XLARGE: string;
```

- *Type:* string

x2gd.4xlarge vCPUs: 16 Memory: 262144 MiB.

---

##### `X2GD_8XLARGE`<sup>Required</sup> <a name="X2GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_8XLARGE"></a>

```typescript
public readonly X2GD_8XLARGE: string;
```

- *Type:* string

x2gd.8xlarge vCPUs: 32 Memory: 524288 MiB.

---

##### `X2GD_LARGE`<sup>Required</sup> <a name="X2GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_LARGE"></a>

```typescript
public readonly X2GD_LARGE: string;
```

- *Type:* string

x2gd.large vCPUs: 2 Memory: 32768 MiB.

---

##### `X2GD_MEDIUM`<sup>Required</sup> <a name="X2GD_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_MEDIUM"></a>

```typescript
public readonly X2GD_MEDIUM: string;
```

- *Type:* string

x2gd.medium vCPUs: 1 Memory: 16384 MiB.

---

##### `X2GD_METAL`<sup>Required</sup> <a name="X2GD_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_METAL"></a>

```typescript
public readonly X2GD_METAL: string;
```

- *Type:* string

x2gd.metal vCPUs: 64 Memory: 1048576 MiB.

---

##### `X2GD_XLARGE`<sup>Required</sup> <a name="X2GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2GD_XLARGE"></a>

```typescript
public readonly X2GD_XLARGE: string;
```

- *Type:* string

x2gd.xlarge vCPUs: 4 Memory: 65536 MiB.

---

##### `X2IDN_16XLARGE`<sup>Required</sup> <a name="X2IDN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_16XLARGE"></a>

```typescript
public readonly X2IDN_16XLARGE: string;
```

- *Type:* string

x2idn.16xlarge vCPUs: 64 Memory: 1048576 MiB.

---

##### `X2IDN_24XLARGE`<sup>Required</sup> <a name="X2IDN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_24XLARGE"></a>

```typescript
public readonly X2IDN_24XLARGE: string;
```

- *Type:* string

x2idn.24xlarge vCPUs: 96 Memory: 1572864 MiB.

---

##### `X2IDN_32XLARGE`<sup>Required</sup> <a name="X2IDN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_32XLARGE"></a>

```typescript
public readonly X2IDN_32XLARGE: string;
```

- *Type:* string

x2idn.32xlarge vCPUs: 128 Memory: 2097152 MiB.

---

##### `X2IDN_METAL`<sup>Required</sup> <a name="X2IDN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IDN_METAL"></a>

```typescript
public readonly X2IDN_METAL: string;
```

- *Type:* string

x2idn.metal vCPUs: 128 Memory: 2097152 MiB.

---

##### `X2IEDN_16XLARGE`<sup>Required</sup> <a name="X2IEDN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_16XLARGE"></a>

```typescript
public readonly X2IEDN_16XLARGE: string;
```

- *Type:* string

x2iedn.16xlarge vCPUs: 64 Memory: 2097152 MiB.

---

##### `X2IEDN_24XLARGE`<sup>Required</sup> <a name="X2IEDN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_24XLARGE"></a>

```typescript
public readonly X2IEDN_24XLARGE: string;
```

- *Type:* string

x2iedn.24xlarge vCPUs: 96 Memory: 3145728 MiB.

---

##### `X2IEDN_2XLARGE`<sup>Required</sup> <a name="X2IEDN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_2XLARGE"></a>

```typescript
public readonly X2IEDN_2XLARGE: string;
```

- *Type:* string

x2iedn.2xlarge vCPUs: 8 Memory: 262144 MiB.

---

##### `X2IEDN_32XLARGE`<sup>Required</sup> <a name="X2IEDN_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_32XLARGE"></a>

```typescript
public readonly X2IEDN_32XLARGE: string;
```

- *Type:* string

x2iedn.32xlarge vCPUs: 128 Memory: 4194304 MiB.

---

##### `X2IEDN_4XLARGE`<sup>Required</sup> <a name="X2IEDN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_4XLARGE"></a>

```typescript
public readonly X2IEDN_4XLARGE: string;
```

- *Type:* string

x2iedn.4xlarge vCPUs: 16 Memory: 524288 MiB.

---

##### `X2IEDN_8XLARGE`<sup>Required</sup> <a name="X2IEDN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_8XLARGE"></a>

```typescript
public readonly X2IEDN_8XLARGE: string;
```

- *Type:* string

x2iedn.8xlarge vCPUs: 32 Memory: 1048576 MiB.

---

##### `X2IEDN_METAL`<sup>Required</sup> <a name="X2IEDN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_METAL"></a>

```typescript
public readonly X2IEDN_METAL: string;
```

- *Type:* string

x2iedn.metal vCPUs: 128 Memory: 4194304 MiB.

---

##### `X2IEDN_XLARGE`<sup>Required</sup> <a name="X2IEDN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEDN_XLARGE"></a>

```typescript
public readonly X2IEDN_XLARGE: string;
```

- *Type:* string

x2iedn.xlarge vCPUs: 4 Memory: 131072 MiB.

---

##### `X2IEZN_12XLARGE`<sup>Required</sup> <a name="X2IEZN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_12XLARGE"></a>

```typescript
public readonly X2IEZN_12XLARGE: string;
```

- *Type:* string

x2iezn.12xlarge vCPUs: 48 Memory: 1572864 MiB.

---

##### `X2IEZN_2XLARGE`<sup>Required</sup> <a name="X2IEZN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_2XLARGE"></a>

```typescript
public readonly X2IEZN_2XLARGE: string;
```

- *Type:* string

x2iezn.2xlarge vCPUs: 8 Memory: 262144 MiB.

---

##### `X2IEZN_4XLARGE`<sup>Required</sup> <a name="X2IEZN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_4XLARGE"></a>

```typescript
public readonly X2IEZN_4XLARGE: string;
```

- *Type:* string

x2iezn.4xlarge vCPUs: 16 Memory: 524288 MiB.

---

##### `X2IEZN_6XLARGE`<sup>Required</sup> <a name="X2IEZN_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_6XLARGE"></a>

```typescript
public readonly X2IEZN_6XLARGE: string;
```

- *Type:* string

x2iezn.6xlarge vCPUs: 24 Memory: 786432 MiB.

---

##### `X2IEZN_8XLARGE`<sup>Required</sup> <a name="X2IEZN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_8XLARGE"></a>

```typescript
public readonly X2IEZN_8XLARGE: string;
```

- *Type:* string

x2iezn.8xlarge vCPUs: 32 Memory: 1048576 MiB.

---

##### `X2IEZN_METAL`<sup>Required</sup> <a name="X2IEZN_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X2IEZN_METAL"></a>

```typescript
public readonly X2IEZN_METAL: string;
```

- *Type:* string

x2iezn.metal vCPUs: 48 Memory: 1572864 MiB.

---

##### `X8G_12XLARGE`<sup>Required</sup> <a name="X8G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_12XLARGE"></a>

```typescript
public readonly X8G_12XLARGE: string;
```

- *Type:* string

x8g.12xlarge vCPUs: 48 Memory: 786432 MiB.

---

##### `X8G_16XLARGE`<sup>Required</sup> <a name="X8G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_16XLARGE"></a>

```typescript
public readonly X8G_16XLARGE: string;
```

- *Type:* string

x8g.16xlarge vCPUs: 64 Memory: 1048576 MiB.

---

##### `X8G_24XLARGE`<sup>Required</sup> <a name="X8G_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_24XLARGE"></a>

```typescript
public readonly X8G_24XLARGE: string;
```

- *Type:* string

x8g.24xlarge vCPUs: 96 Memory: 1572864 MiB.

---

##### `X8G_2XLARGE`<sup>Required</sup> <a name="X8G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_2XLARGE"></a>

```typescript
public readonly X8G_2XLARGE: string;
```

- *Type:* string

x8g.2xlarge vCPUs: 8 Memory: 131072 MiB.

---

##### `X8G_48XLARGE`<sup>Required</sup> <a name="X8G_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_48XLARGE"></a>

```typescript
public readonly X8G_48XLARGE: string;
```

- *Type:* string

x8g.48xlarge vCPUs: 192 Memory: 3145728 MiB.

---

##### `X8G_4XLARGE`<sup>Required</sup> <a name="X8G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_4XLARGE"></a>

```typescript
public readonly X8G_4XLARGE: string;
```

- *Type:* string

x8g.4xlarge vCPUs: 16 Memory: 262144 MiB.

---

##### `X8G_8XLARGE`<sup>Required</sup> <a name="X8G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_8XLARGE"></a>

```typescript
public readonly X8G_8XLARGE: string;
```

- *Type:* string

x8g.8xlarge vCPUs: 32 Memory: 524288 MiB.

---

##### `X8G_LARGE`<sup>Required</sup> <a name="X8G_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_LARGE"></a>

```typescript
public readonly X8G_LARGE: string;
```

- *Type:* string

x8g.large vCPUs: 2 Memory: 32768 MiB.

---

##### `X8G_MEDIUM`<sup>Required</sup> <a name="X8G_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_MEDIUM"></a>

```typescript
public readonly X8G_MEDIUM: string;
```

- *Type:* string

x8g.medium vCPUs: 1 Memory: 16384 MiB.

---

##### `X8G_METAL_24XL`<sup>Required</sup> <a name="X8G_METAL_24XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_METAL_24XL"></a>

```typescript
public readonly X8G_METAL_24XL: string;
```

- *Type:* string

x8g.metal-24xl vCPUs: 96 Memory: 1572864 MiB.

---

##### `X8G_METAL_48XL`<sup>Required</sup> <a name="X8G_METAL_48XL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_METAL_48XL"></a>

```typescript
public readonly X8G_METAL_48XL: string;
```

- *Type:* string

x8g.metal-48xl vCPUs: 192 Memory: 3145728 MiB.

---

##### `X8G_XLARGE`<sup>Required</sup> <a name="X8G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.X8G_XLARGE"></a>

```typescript
public readonly X8G_XLARGE: string;
```

- *Type:* string

x8g.xlarge vCPUs: 4 Memory: 65536 MiB.

---

##### `Z1D_12XLARGE`<sup>Required</sup> <a name="Z1D_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_12XLARGE"></a>

```typescript
public readonly Z1D_12XLARGE: string;
```

- *Type:* string

z1d.12xlarge vCPUs: 48 Memory: 393216 MiB.

---

##### `Z1D_2XLARGE`<sup>Required</sup> <a name="Z1D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_2XLARGE"></a>

```typescript
public readonly Z1D_2XLARGE: string;
```

- *Type:* string

z1d.2xlarge vCPUs: 8 Memory: 65536 MiB.

---

##### `Z1D_3XLARGE`<sup>Required</sup> <a name="Z1D_3XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_3XLARGE"></a>

```typescript
public readonly Z1D_3XLARGE: string;
```

- *Type:* string

z1d.3xlarge vCPUs: 12 Memory: 98304 MiB.

---

##### `Z1D_6XLARGE`<sup>Required</sup> <a name="Z1D_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_6XLARGE"></a>

```typescript
public readonly Z1D_6XLARGE: string;
```

- *Type:* string

z1d.6xlarge vCPUs: 24 Memory: 196608 MiB.

---

##### `Z1D_LARGE`<sup>Required</sup> <a name="Z1D_LARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_LARGE"></a>

```typescript
public readonly Z1D_LARGE: string;
```

- *Type:* string

z1d.large vCPUs: 2 Memory: 16384 MiB.

---

##### `Z1D_METAL`<sup>Required</sup> <a name="Z1D_METAL" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_METAL"></a>

```typescript
public readonly Z1D_METAL: string;
```

- *Type:* string

z1d.metal vCPUs: 48 Memory: 393216 MiB.

---

##### `Z1D_XLARGE`<sup>Required</sup> <a name="Z1D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.Ec2InstanceType.property.Z1D_XLARGE"></a>

```typescript
public readonly Z1D_XLARGE: string;
```

- *Type:* string

z1d.xlarge vCPUs: 4 Memory: 32768 MiB.

---

### SageMakerNotebookInstanceType <a name="SageMakerNotebookInstanceType" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType"></a>

SageMaker Instance Type.




#### Constants <a name="Constants" id="Constants"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_2XLARGE">ML_C4_2XLARGE</a></code> | <code>string</code> | ml.c4.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_4XLARGE">ML_C4_4XLARGE</a></code> | <code>string</code> | ml.c4.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_8XLARGE">ML_C4_8XLARGE</a></code> | <code>string</code> | ml.c4.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_LARGE">ML_C4_LARGE</a></code> | <code>string</code> | ml.c4.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_XLARGE">ML_C4_XLARGE</a></code> | <code>string</code> | ml.c4.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_12XLARGE">ML_C5_12XLARGE</a></code> | <code>string</code> | ml.c5.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_18XLARGE">ML_C5_18XLARGE</a></code> | <code>string</code> | ml.c5.18xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_24XLARGE">ML_C5_24XLARGE</a></code> | <code>string</code> | ml.c5.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_2XLARGE">ML_C5_2XLARGE</a></code> | <code>string</code> | ml.c5.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_4XLARGE">ML_C5_4XLARGE</a></code> | <code>string</code> | ml.c5.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_9XLARGE">ML_C5_9XLARGE</a></code> | <code>string</code> | ml.c5.9xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_LARGE">ML_C5_LARGE</a></code> | <code>string</code> | ml.c5.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_XLARGE">ML_C5_XLARGE</a></code> | <code>string</code> | ml.c5.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_18XLARGE">ML_C5D_18XLARGE</a></code> | <code>string</code> | ml.c5d.18xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_2XLARGE">ML_C5D_2XLARGE</a></code> | <code>string</code> | ml.c5d.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_4XLARGE">ML_C5D_4XLARGE</a></code> | <code>string</code> | ml.c5d.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_9XLARGE">ML_C5D_9XLARGE</a></code> | <code>string</code> | ml.c5d.9xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_LARGE">ML_C5D_LARGE</a></code> | <code>string</code> | ml.c5d.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_XLARGE">ML_C5D_XLARGE</a></code> | <code>string</code> | ml.c5d.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_18XLARGE">ML_C5N_18XLARGE</a></code> | <code>string</code> | ml.c5n.18xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_2XLARGE">ML_C5N_2XLARGE</a></code> | <code>string</code> | ml.c5n.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_4XLARGE">ML_C5N_4XLARGE</a></code> | <code>string</code> | ml.c5n.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_9XLARGE">ML_C5N_9XLARGE</a></code> | <code>string</code> | ml.c5n.9xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_LARGE">ML_C5N_LARGE</a></code> | <code>string</code> | ml.c5n.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_XLARGE">ML_C5N_XLARGE</a></code> | <code>string</code> | ml.c5n.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_12XLARGE">ML_C6G_12XLARGE</a></code> | <code>string</code> | ml.c6g.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_16XLARGE">ML_C6G_16XLARGE</a></code> | <code>string</code> | ml.c6g.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_2XLARGE">ML_C6G_2XLARGE</a></code> | <code>string</code> | ml.c6g.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_4XLARGE">ML_C6G_4XLARGE</a></code> | <code>string</code> | ml.c6g.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_8XLARGE">ML_C6G_8XLARGE</a></code> | <code>string</code> | ml.c6g.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_LARGE">ML_C6G_LARGE</a></code> | <code>string</code> | ml.c6g.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_XLARGE">ML_C6G_XLARGE</a></code> | <code>string</code> | ml.c6g.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_12XLARGE">ML_C6GD_12XLARGE</a></code> | <code>string</code> | ml.c6gd.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_16XLARGE">ML_C6GD_16XLARGE</a></code> | <code>string</code> | ml.c6gd.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_2XLARGE">ML_C6GD_2XLARGE</a></code> | <code>string</code> | ml.c6gd.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_4XLARGE">ML_C6GD_4XLARGE</a></code> | <code>string</code> | ml.c6gd.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_8XLARGE">ML_C6GD_8XLARGE</a></code> | <code>string</code> | ml.c6gd.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_LARGE">ML_C6GD_LARGE</a></code> | <code>string</code> | ml.c6gd.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_XLARGE">ML_C6GD_XLARGE</a></code> | <code>string</code> | ml.c6gd.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_12XLARGE">ML_C6GN_12XLARGE</a></code> | <code>string</code> | ml.c6gn.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_16XLARGE">ML_C6GN_16XLARGE</a></code> | <code>string</code> | ml.c6gn.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_2XLARGE">ML_C6GN_2XLARGE</a></code> | <code>string</code> | ml.c6gn.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_4XLARGE">ML_C6GN_4XLARGE</a></code> | <code>string</code> | ml.c6gn.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_8XLARGE">ML_C6GN_8XLARGE</a></code> | <code>string</code> | ml.c6gn.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_LARGE">ML_C6GN_LARGE</a></code> | <code>string</code> | ml.c6gn.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_XLARGE">ML_C6GN_XLARGE</a></code> | <code>string</code> | ml.c6gn.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_12XLARGE">ML_C6I_12XLARGE</a></code> | <code>string</code> | ml.c6i.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_16XLARGE">ML_C6I_16XLARGE</a></code> | <code>string</code> | ml.c6i.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_24XLARGE">ML_C6I_24XLARGE</a></code> | <code>string</code> | ml.c6i.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_2XLARGE">ML_C6I_2XLARGE</a></code> | <code>string</code> | ml.c6i.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_32XLARGE">ML_C6I_32XLARGE</a></code> | <code>string</code> | ml.c6i.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_4XLARGE">ML_C6I_4XLARGE</a></code> | <code>string</code> | ml.c6i.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_8XLARGE">ML_C6I_8XLARGE</a></code> | <code>string</code> | ml.c6i.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_LARGE">ML_C6I_LARGE</a></code> | <code>string</code> | ml.c6i.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_XLARGE">ML_C6I_XLARGE</a></code> | <code>string</code> | ml.c6i.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_12XLARGE">ML_C6ID_12XLARGE</a></code> | <code>string</code> | ml.c6id.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_16XLARGE">ML_C6ID_16XLARGE</a></code> | <code>string</code> | ml.c6id.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_24XLARGE">ML_C6ID_24XLARGE</a></code> | <code>string</code> | ml.c6id.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_2XLARGE">ML_C6ID_2XLARGE</a></code> | <code>string</code> | ml.c6id.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_32XLARGE">ML_C6ID_32XLARGE</a></code> | <code>string</code> | ml.c6id.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_4XLARGE">ML_C6ID_4XLARGE</a></code> | <code>string</code> | ml.c6id.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_8XLARGE">ML_C6ID_8XLARGE</a></code> | <code>string</code> | ml.c6id.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_LARGE">ML_C6ID_LARGE</a></code> | <code>string</code> | ml.c6id.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_XLARGE">ML_C6ID_XLARGE</a></code> | <code>string</code> | ml.c6id.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_12XLARGE">ML_C7G_12XLARGE</a></code> | <code>string</code> | ml.c7g.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_16XLARGE">ML_C7G_16XLARGE</a></code> | <code>string</code> | ml.c7g.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_2XLARGE">ML_C7G_2XLARGE</a></code> | <code>string</code> | ml.c7g.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_4XLARGE">ML_C7G_4XLARGE</a></code> | <code>string</code> | ml.c7g.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_8XLARGE">ML_C7G_8XLARGE</a></code> | <code>string</code> | ml.c7g.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_LARGE">ML_C7G_LARGE</a></code> | <code>string</code> | ml.c7g.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_XLARGE">ML_C7G_XLARGE</a></code> | <code>string</code> | ml.c7g.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_12XLARGE">ML_C7I_12XLARGE</a></code> | <code>string</code> | ml.c7i.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_16XLARGE">ML_C7I_16XLARGE</a></code> | <code>string</code> | ml.c7i.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_24XLARGE">ML_C7I_24XLARGE</a></code> | <code>string</code> | ml.c7i.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_2XLARGE">ML_C7I_2XLARGE</a></code> | <code>string</code> | ml.c7i.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_48XLARGE">ML_C7I_48XLARGE</a></code> | <code>string</code> | ml.c7i.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_4XLARGE">ML_C7I_4XLARGE</a></code> | <code>string</code> | ml.c7i.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_8XLARGE">ML_C7I_8XLARGE</a></code> | <code>string</code> | ml.c7i.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_LARGE">ML_C7I_LARGE</a></code> | <code>string</code> | ml.c7i.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_XLARGE">ML_C7I_XLARGE</a></code> | <code>string</code> | ml.c7i.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_12XLARGE">ML_G4DN_12XLARGE</a></code> | <code>string</code> | ml.g4dn.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_16XLARGE">ML_G4DN_16XLARGE</a></code> | <code>string</code> | ml.g4dn.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_2XLARGE">ML_G4DN_2XLARGE</a></code> | <code>string</code> | ml.g4dn.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_4XLARGE">ML_G4DN_4XLARGE</a></code> | <code>string</code> | ml.g4dn.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_8XLARGE">ML_G4DN_8XLARGE</a></code> | <code>string</code> | ml.g4dn.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_XLARGE">ML_G4DN_XLARGE</a></code> | <code>string</code> | ml.g4dn.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_12XLARGE">ML_G5_12XLARGE</a></code> | <code>string</code> | ml.g5.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_16XLARGE">ML_G5_16XLARGE</a></code> | <code>string</code> | ml.g5.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_24XLARGE">ML_G5_24XLARGE</a></code> | <code>string</code> | ml.g5.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_2XLARGE">ML_G5_2XLARGE</a></code> | <code>string</code> | ml.g5.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_48XLARGE">ML_G5_48XLARGE</a></code> | <code>string</code> | ml.g5.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_4XLARGE">ML_G5_4XLARGE</a></code> | <code>string</code> | ml.g5.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_8XLARGE">ML_G5_8XLARGE</a></code> | <code>string</code> | ml.g5.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_XLARGE">ML_G5_XLARGE</a></code> | <code>string</code> | ml.g5.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_12XLARGE">ML_G6_12XLARGE</a></code> | <code>string</code> | ml.g6.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_16XLARGE">ML_G6_16XLARGE</a></code> | <code>string</code> | ml.g6.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_24XLARGE">ML_G6_24XLARGE</a></code> | <code>string</code> | ml.g6.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_2XLARGE">ML_G6_2XLARGE</a></code> | <code>string</code> | ml.g6.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_48XLARGE">ML_G6_48XLARGE</a></code> | <code>string</code> | ml.g6.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_4XLARGE">ML_G6_4XLARGE</a></code> | <code>string</code> | ml.g6.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_8XLARGE">ML_G6_8XLARGE</a></code> | <code>string</code> | ml.g6.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_XLARGE">ML_G6_XLARGE</a></code> | <code>string</code> | ml.g6.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_12XLARGE">ML_G6E_12XLARGE</a></code> | <code>string</code> | ml.g6e.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_16XLARGE">ML_G6E_16XLARGE</a></code> | <code>string</code> | ml.g6e.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_24XLARGE">ML_G6E_24XLARGE</a></code> | <code>string</code> | ml.g6e.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_2XLARGE">ML_G6E_2XLARGE</a></code> | <code>string</code> | ml.g6e.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_48XLARGE">ML_G6E_48XLARGE</a></code> | <code>string</code> | ml.g6e.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_4XLARGE">ML_G6E_4XLARGE</a></code> | <code>string</code> | ml.g6e.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_8XLARGE">ML_G6E_8XLARGE</a></code> | <code>string</code> | ml.g6e.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_XLARGE">ML_G6E_XLARGE</a></code> | <code>string</code> | ml.g6e.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_GR6_4XLARGE">ML_GR6_4XLARGE</a></code> | <code>string</code> | ml.gr6.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_GR6_8XLARGE">ML_GR6_8XLARGE</a></code> | <code>string</code> | ml.gr6.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_24XLARGE">ML_INF1_24XLARGE</a></code> | <code>string</code> | ml.inf1.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_2XLARGE">ML_INF1_2XLARGE</a></code> | <code>string</code> | ml.inf1.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_6XLARGE">ML_INF1_6XLARGE</a></code> | <code>string</code> | ml.inf1.6xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_XLARGE">ML_INF1_XLARGE</a></code> | <code>string</code> | ml.inf1.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_24XLARGE">ML_INF2_24XLARGE</a></code> | <code>string</code> | ml.inf2.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_48XLARGE">ML_INF2_48XLARGE</a></code> | <code>string</code> | ml.inf2.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_8XLARGE">ML_INF2_8XLARGE</a></code> | <code>string</code> | ml.inf2.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_XLARGE">ML_INF2_XLARGE</a></code> | <code>string</code> | ml.inf2.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_10XLARGE">ML_M4_10XLARGE</a></code> | <code>string</code> | ml.m4.10xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_16XLARGE">ML_M4_16XLARGE</a></code> | <code>string</code> | ml.m4.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_2XLARGE">ML_M4_2XLARGE</a></code> | <code>string</code> | ml.m4.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_4XLARGE">ML_M4_4XLARGE</a></code> | <code>string</code> | ml.m4.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_XLARGE">ML_M4_XLARGE</a></code> | <code>string</code> | ml.m4.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_12XLARGE">ML_M5_12XLARGE</a></code> | <code>string</code> | ml.m5.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_16XLARGE">ML_M5_16XLARGE</a></code> | <code>string</code> | ml.m5.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_24XLARGE">ML_M5_24XLARGE</a></code> | <code>string</code> | ml.m5.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_2XLARGE">ML_M5_2XLARGE</a></code> | <code>string</code> | ml.m5.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_4XLARGE">ML_M5_4XLARGE</a></code> | <code>string</code> | ml.m5.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_8XLARGE">ML_M5_8XLARGE</a></code> | <code>string</code> | ml.m5.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_LARGE">ML_M5_LARGE</a></code> | <code>string</code> | ml.m5.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_XLARGE">ML_M5_XLARGE</a></code> | <code>string</code> | ml.m5.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_12XLARGE">ML_M5D_12XLARGE</a></code> | <code>string</code> | ml.m5d.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_16XLARGE">ML_M5D_16XLARGE</a></code> | <code>string</code> | ml.m5d.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_24XLARGE">ML_M5D_24XLARGE</a></code> | <code>string</code> | ml.m5d.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_2XLARGE">ML_M5D_2XLARGE</a></code> | <code>string</code> | ml.m5d.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_4XLARGE">ML_M5D_4XLARGE</a></code> | <code>string</code> | ml.m5d.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_8XLARGE">ML_M5D_8XLARGE</a></code> | <code>string</code> | ml.m5d.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_LARGE">ML_M5D_LARGE</a></code> | <code>string</code> | ml.m5d.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_XLARGE">ML_M5D_XLARGE</a></code> | <code>string</code> | ml.m5d.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_12XLARGE">ML_M6G_12XLARGE</a></code> | <code>string</code> | ml.m6g.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_16XLARGE">ML_M6G_16XLARGE</a></code> | <code>string</code> | ml.m6g.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_2XLARGE">ML_M6G_2XLARGE</a></code> | <code>string</code> | ml.m6g.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_4XLARGE">ML_M6G_4XLARGE</a></code> | <code>string</code> | ml.m6g.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_8XLARGE">ML_M6G_8XLARGE</a></code> | <code>string</code> | ml.m6g.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_LARGE">ML_M6G_LARGE</a></code> | <code>string</code> | ml.m6g.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_XLARGE">ML_M6G_XLARGE</a></code> | <code>string</code> | ml.m6g.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_12XLARGE">ML_M6GD_12XLARGE</a></code> | <code>string</code> | ml.m6gd.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_16XLARGE">ML_M6GD_16XLARGE</a></code> | <code>string</code> | ml.m6gd.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_2XLARGE">ML_M6GD_2XLARGE</a></code> | <code>string</code> | ml.m6gd.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_4XLARGE">ML_M6GD_4XLARGE</a></code> | <code>string</code> | ml.m6gd.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_8XLARGE">ML_M6GD_8XLARGE</a></code> | <code>string</code> | ml.m6gd.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_LARGE">ML_M6GD_LARGE</a></code> | <code>string</code> | ml.m6gd.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_XLARGE">ML_M6GD_XLARGE</a></code> | <code>string</code> | ml.m6gd.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_12XLARGE">ML_M6I_12XLARGE</a></code> | <code>string</code> | ml.m6i.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_16XLARGE">ML_M6I_16XLARGE</a></code> | <code>string</code> | ml.m6i.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_24XLARGE">ML_M6I_24XLARGE</a></code> | <code>string</code> | ml.m6i.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_2XLARGE">ML_M6I_2XLARGE</a></code> | <code>string</code> | ml.m6i.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_32XLARGE">ML_M6I_32XLARGE</a></code> | <code>string</code> | ml.m6i.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_4XLARGE">ML_M6I_4XLARGE</a></code> | <code>string</code> | ml.m6i.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_8XLARGE">ML_M6I_8XLARGE</a></code> | <code>string</code> | ml.m6i.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_LARGE">ML_M6I_LARGE</a></code> | <code>string</code> | ml.m6i.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_XLARGE">ML_M6I_XLARGE</a></code> | <code>string</code> | ml.m6i.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_12XLARGE">ML_M6ID_12XLARGE</a></code> | <code>string</code> | ml.m6id.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_16XLARGE">ML_M6ID_16XLARGE</a></code> | <code>string</code> | ml.m6id.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_24XLARGE">ML_M6ID_24XLARGE</a></code> | <code>string</code> | ml.m6id.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_2XLARGE">ML_M6ID_2XLARGE</a></code> | <code>string</code> | ml.m6id.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_32XLARGE">ML_M6ID_32XLARGE</a></code> | <code>string</code> | ml.m6id.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_4XLARGE">ML_M6ID_4XLARGE</a></code> | <code>string</code> | ml.m6id.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_8XLARGE">ML_M6ID_8XLARGE</a></code> | <code>string</code> | ml.m6id.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_LARGE">ML_M6ID_LARGE</a></code> | <code>string</code> | ml.m6id.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_XLARGE">ML_M6ID_XLARGE</a></code> | <code>string</code> | ml.m6id.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_12XLARGE">ML_M7I_12XLARGE</a></code> | <code>string</code> | ml.m7i.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_16XLARGE">ML_M7I_16XLARGE</a></code> | <code>string</code> | ml.m7i.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_24XLARGE">ML_M7I_24XLARGE</a></code> | <code>string</code> | ml.m7i.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_2XLARGE">ML_M7I_2XLARGE</a></code> | <code>string</code> | ml.m7i.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_48XLARGE">ML_M7I_48XLARGE</a></code> | <code>string</code> | ml.m7i.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_4XLARGE">ML_M7I_4XLARGE</a></code> | <code>string</code> | ml.m7i.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_8XLARGE">ML_M7I_8XLARGE</a></code> | <code>string</code> | ml.m7i.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_LARGE">ML_M7I_LARGE</a></code> | <code>string</code> | ml.m7i.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_XLARGE">ML_M7I_XLARGE</a></code> | <code>string</code> | ml.m7i.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P2_16XLARGE">ML_P2_16XLARGE</a></code> | <code>string</code> | ml.p2.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P2_8XLARGE">ML_P2_8XLARGE</a></code> | <code>string</code> | ml.p2.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P2_XLARGE">ML_P2_XLARGE</a></code> | <code>string</code> | ml.p2.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3_16XLARGE">ML_P3_16XLARGE</a></code> | <code>string</code> | ml.p3.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3_2XLARGE">ML_P3_2XLARGE</a></code> | <code>string</code> | ml.p3.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3_8XLARGE">ML_P3_8XLARGE</a></code> | <code>string</code> | ml.p3.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3DN_24XLARGE">ML_P3DN_24XLARGE</a></code> | <code>string</code> | ml.p3dn.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P4D_24XLARGE">ML_P4D_24XLARGE</a></code> | <code>string</code> | ml.p4d.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P4DE_24XLARGE">ML_P4DE_24XLARGE</a></code> | <code>string</code> | ml.p4de.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P5_48XLARGE">ML_P5_48XLARGE</a></code> | <code>string</code> | ml.p5.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_12XLARGE">ML_R5_12XLARGE</a></code> | <code>string</code> | ml.r5.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_16XLARGE">ML_R5_16XLARGE</a></code> | <code>string</code> | ml.r5.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_24XLARGE">ML_R5_24XLARGE</a></code> | <code>string</code> | ml.r5.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_2XLARGE">ML_R5_2XLARGE</a></code> | <code>string</code> | ml.r5.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_4XLARGE">ML_R5_4XLARGE</a></code> | <code>string</code> | ml.r5.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_8XLARGE">ML_R5_8XLARGE</a></code> | <code>string</code> | ml.r5.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_LARGE">ML_R5_LARGE</a></code> | <code>string</code> | ml.r5.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_XLARGE">ML_R5_XLARGE</a></code> | <code>string</code> | ml.r5.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_12XLARGE">ML_R5D_12XLARGE</a></code> | <code>string</code> | ml.r5d.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_16XLARGE">ML_R5D_16XLARGE</a></code> | <code>string</code> | ml.r5d.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_24XLARGE">ML_R5D_24XLARGE</a></code> | <code>string</code> | ml.r5d.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_2XLARGE">ML_R5D_2XLARGE</a></code> | <code>string</code> | ml.r5d.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_4XLARGE">ML_R5D_4XLARGE</a></code> | <code>string</code> | ml.r5d.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_8XLARGE">ML_R5D_8XLARGE</a></code> | <code>string</code> | ml.r5d.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_LARGE">ML_R5D_LARGE</a></code> | <code>string</code> | ml.r5d.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_XLARGE">ML_R5D_XLARGE</a></code> | <code>string</code> | ml.r5d.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_12XLARGE">ML_R6G_12XLARGE</a></code> | <code>string</code> | ml.r6g.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_16XLARGE">ML_R6G_16XLARGE</a></code> | <code>string</code> | ml.r6g.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_2XLARGE">ML_R6G_2XLARGE</a></code> | <code>string</code> | ml.r6g.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_4XLARGE">ML_R6G_4XLARGE</a></code> | <code>string</code> | ml.r6g.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_8XLARGE">ML_R6G_8XLARGE</a></code> | <code>string</code> | ml.r6g.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_LARGE">ML_R6G_LARGE</a></code> | <code>string</code> | ml.r6g.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_XLARGE">ML_R6G_XLARGE</a></code> | <code>string</code> | ml.r6g.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_12XLARGE">ML_R6GD_12XLARGE</a></code> | <code>string</code> | ml.r6gd.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_16XLARGE">ML_R6GD_16XLARGE</a></code> | <code>string</code> | ml.r6gd.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_2XLARGE">ML_R6GD_2XLARGE</a></code> | <code>string</code> | ml.r6gd.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_4XLARGE">ML_R6GD_4XLARGE</a></code> | <code>string</code> | ml.r6gd.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_8XLARGE">ML_R6GD_8XLARGE</a></code> | <code>string</code> | ml.r6gd.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_LARGE">ML_R6GD_LARGE</a></code> | <code>string</code> | ml.r6gd.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_XLARGE">ML_R6GD_XLARGE</a></code> | <code>string</code> | ml.r6gd.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_12XLARGE">ML_R6I_12XLARGE</a></code> | <code>string</code> | ml.r6i.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_16XLARGE">ML_R6I_16XLARGE</a></code> | <code>string</code> | ml.r6i.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_24XLARGE">ML_R6I_24XLARGE</a></code> | <code>string</code> | ml.r6i.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_2XLARGE">ML_R6I_2XLARGE</a></code> | <code>string</code> | ml.r6i.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_32XLARGE">ML_R6I_32XLARGE</a></code> | <code>string</code> | ml.r6i.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_4XLARGE">ML_R6I_4XLARGE</a></code> | <code>string</code> | ml.r6i.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_8XLARGE">ML_R6I_8XLARGE</a></code> | <code>string</code> | ml.r6i.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_LARGE">ML_R6I_LARGE</a></code> | <code>string</code> | ml.r6i.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_XLARGE">ML_R6I_XLARGE</a></code> | <code>string</code> | ml.r6i.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_12XLARGE">ML_R6ID_12XLARGE</a></code> | <code>string</code> | ml.r6id.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_16XLARGE">ML_R6ID_16XLARGE</a></code> | <code>string</code> | ml.r6id.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_24XLARGE">ML_R6ID_24XLARGE</a></code> | <code>string</code> | ml.r6id.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_2XLARGE">ML_R6ID_2XLARGE</a></code> | <code>string</code> | ml.r6id.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_32XLARGE">ML_R6ID_32XLARGE</a></code> | <code>string</code> | ml.r6id.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_4XLARGE">ML_R6ID_4XLARGE</a></code> | <code>string</code> | ml.r6id.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_8XLARGE">ML_R6ID_8XLARGE</a></code> | <code>string</code> | ml.r6id.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_LARGE">ML_R6ID_LARGE</a></code> | <code>string</code> | ml.r6id.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_XLARGE">ML_R6ID_XLARGE</a></code> | <code>string</code> | ml.r6id.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_12XLARGE">ML_R7I_12XLARGE</a></code> | <code>string</code> | ml.r7i.12xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_16XLARGE">ML_R7I_16XLARGE</a></code> | <code>string</code> | ml.r7i.16xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_24XLARGE">ML_R7I_24XLARGE</a></code> | <code>string</code> | ml.r7i.24xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_2XLARGE">ML_R7I_2XLARGE</a></code> | <code>string</code> | ml.r7i.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_48XLARGE">ML_R7I_48XLARGE</a></code> | <code>string</code> | ml.r7i.48xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_4XLARGE">ML_R7I_4XLARGE</a></code> | <code>string</code> | ml.r7i.4xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_8XLARGE">ML_R7I_8XLARGE</a></code> | <code>string</code> | ml.r7i.8xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_LARGE">ML_R7I_LARGE</a></code> | <code>string</code> | ml.r7i.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_XLARGE">ML_R7I_XLARGE</a></code> | <code>string</code> | ml.r7i.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_2XLARGE">ML_T2_2XLARGE</a></code> | <code>string</code> | ml.t2.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_LARGE">ML_T2_LARGE</a></code> | <code>string</code> | ml.t2.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_MEDIUM">ML_T2_MEDIUM</a></code> | <code>string</code> | ml.t2.medium Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_XLARGE">ML_T2_XLARGE</a></code> | <code>string</code> | ml.t2.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_2XLARGE">ML_T3_2XLARGE</a></code> | <code>string</code> | ml.t3.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_LARGE">ML_T3_LARGE</a></code> | <code>string</code> | ml.t3.large Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_MEDIUM">ML_T3_MEDIUM</a></code> | <code>string</code> | ml.t3.medium Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_XLARGE">ML_T3_XLARGE</a></code> | <code>string</code> | ml.t3.xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_TRN1_2XLARGE">ML_TRN1_2XLARGE</a></code> | <code>string</code> | ml.trn1.2xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_TRN1_32XLARGE">ML_TRN1_32XLARGE</a></code> | <code>string</code> | ml.trn1.32xlarge Notebook Instance Type. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_TRN1N_32XLARGE">ML_TRN1N_32XLARGE</a></code> | <code>string</code> | ml.trn1n.32xlarge Notebook Instance Type. |

---

##### `ML_C4_2XLARGE`<sup>Required</sup> <a name="ML_C4_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_2XLARGE"></a>

```typescript
public readonly ML_C4_2XLARGE: string;
```

- *Type:* string

ml.c4.2xlarge Notebook Instance Type.

---

##### `ML_C4_4XLARGE`<sup>Required</sup> <a name="ML_C4_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_4XLARGE"></a>

```typescript
public readonly ML_C4_4XLARGE: string;
```

- *Type:* string

ml.c4.4xlarge Notebook Instance Type.

---

##### `ML_C4_8XLARGE`<sup>Required</sup> <a name="ML_C4_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_8XLARGE"></a>

```typescript
public readonly ML_C4_8XLARGE: string;
```

- *Type:* string

ml.c4.8xlarge Notebook Instance Type.

---

##### `ML_C4_LARGE`<sup>Required</sup> <a name="ML_C4_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_LARGE"></a>

```typescript
public readonly ML_C4_LARGE: string;
```

- *Type:* string

ml.c4.large Notebook Instance Type.

---

##### `ML_C4_XLARGE`<sup>Required</sup> <a name="ML_C4_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C4_XLARGE"></a>

```typescript
public readonly ML_C4_XLARGE: string;
```

- *Type:* string

ml.c4.xlarge Notebook Instance Type.

---

##### `ML_C5_12XLARGE`<sup>Required</sup> <a name="ML_C5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_12XLARGE"></a>

```typescript
public readonly ML_C5_12XLARGE: string;
```

- *Type:* string

ml.c5.12xlarge Notebook Instance Type.

---

##### `ML_C5_18XLARGE`<sup>Required</sup> <a name="ML_C5_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_18XLARGE"></a>

```typescript
public readonly ML_C5_18XLARGE: string;
```

- *Type:* string

ml.c5.18xlarge Notebook Instance Type.

---

##### `ML_C5_24XLARGE`<sup>Required</sup> <a name="ML_C5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_24XLARGE"></a>

```typescript
public readonly ML_C5_24XLARGE: string;
```

- *Type:* string

ml.c5.24xlarge Notebook Instance Type.

---

##### `ML_C5_2XLARGE`<sup>Required</sup> <a name="ML_C5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_2XLARGE"></a>

```typescript
public readonly ML_C5_2XLARGE: string;
```

- *Type:* string

ml.c5.2xlarge Notebook Instance Type.

---

##### `ML_C5_4XLARGE`<sup>Required</sup> <a name="ML_C5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_4XLARGE"></a>

```typescript
public readonly ML_C5_4XLARGE: string;
```

- *Type:* string

ml.c5.4xlarge Notebook Instance Type.

---

##### `ML_C5_9XLARGE`<sup>Required</sup> <a name="ML_C5_9XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_9XLARGE"></a>

```typescript
public readonly ML_C5_9XLARGE: string;
```

- *Type:* string

ml.c5.9xlarge Notebook Instance Type.

---

##### `ML_C5_LARGE`<sup>Required</sup> <a name="ML_C5_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_LARGE"></a>

```typescript
public readonly ML_C5_LARGE: string;
```

- *Type:* string

ml.c5.large Notebook Instance Type.

---

##### `ML_C5_XLARGE`<sup>Required</sup> <a name="ML_C5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5_XLARGE"></a>

```typescript
public readonly ML_C5_XLARGE: string;
```

- *Type:* string

ml.c5.xlarge Notebook Instance Type.

---

##### `ML_C5D_18XLARGE`<sup>Required</sup> <a name="ML_C5D_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_18XLARGE"></a>

```typescript
public readonly ML_C5D_18XLARGE: string;
```

- *Type:* string

ml.c5d.18xlarge Notebook Instance Type.

---

##### `ML_C5D_2XLARGE`<sup>Required</sup> <a name="ML_C5D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_2XLARGE"></a>

```typescript
public readonly ML_C5D_2XLARGE: string;
```

- *Type:* string

ml.c5d.2xlarge Notebook Instance Type.

---

##### `ML_C5D_4XLARGE`<sup>Required</sup> <a name="ML_C5D_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_4XLARGE"></a>

```typescript
public readonly ML_C5D_4XLARGE: string;
```

- *Type:* string

ml.c5d.4xlarge Notebook Instance Type.

---

##### `ML_C5D_9XLARGE`<sup>Required</sup> <a name="ML_C5D_9XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_9XLARGE"></a>

```typescript
public readonly ML_C5D_9XLARGE: string;
```

- *Type:* string

ml.c5d.9xlarge Notebook Instance Type.

---

##### `ML_C5D_LARGE`<sup>Required</sup> <a name="ML_C5D_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_LARGE"></a>

```typescript
public readonly ML_C5D_LARGE: string;
```

- *Type:* string

ml.c5d.large Notebook Instance Type.

---

##### `ML_C5D_XLARGE`<sup>Required</sup> <a name="ML_C5D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5D_XLARGE"></a>

```typescript
public readonly ML_C5D_XLARGE: string;
```

- *Type:* string

ml.c5d.xlarge Notebook Instance Type.

---

##### `ML_C5N_18XLARGE`<sup>Required</sup> <a name="ML_C5N_18XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_18XLARGE"></a>

```typescript
public readonly ML_C5N_18XLARGE: string;
```

- *Type:* string

ml.c5n.18xlarge Notebook Instance Type.

---

##### `ML_C5N_2XLARGE`<sup>Required</sup> <a name="ML_C5N_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_2XLARGE"></a>

```typescript
public readonly ML_C5N_2XLARGE: string;
```

- *Type:* string

ml.c5n.2xlarge Notebook Instance Type.

---

##### `ML_C5N_4XLARGE`<sup>Required</sup> <a name="ML_C5N_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_4XLARGE"></a>

```typescript
public readonly ML_C5N_4XLARGE: string;
```

- *Type:* string

ml.c5n.4xlarge Notebook Instance Type.

---

##### `ML_C5N_9XLARGE`<sup>Required</sup> <a name="ML_C5N_9XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_9XLARGE"></a>

```typescript
public readonly ML_C5N_9XLARGE: string;
```

- *Type:* string

ml.c5n.9xlarge Notebook Instance Type.

---

##### `ML_C5N_LARGE`<sup>Required</sup> <a name="ML_C5N_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_LARGE"></a>

```typescript
public readonly ML_C5N_LARGE: string;
```

- *Type:* string

ml.c5n.large Notebook Instance Type.

---

##### `ML_C5N_XLARGE`<sup>Required</sup> <a name="ML_C5N_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C5N_XLARGE"></a>

```typescript
public readonly ML_C5N_XLARGE: string;
```

- *Type:* string

ml.c5n.xlarge Notebook Instance Type.

---

##### `ML_C6G_12XLARGE`<sup>Required</sup> <a name="ML_C6G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_12XLARGE"></a>

```typescript
public readonly ML_C6G_12XLARGE: string;
```

- *Type:* string

ml.c6g.12xlarge Notebook Instance Type.

---

##### `ML_C6G_16XLARGE`<sup>Required</sup> <a name="ML_C6G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_16XLARGE"></a>

```typescript
public readonly ML_C6G_16XLARGE: string;
```

- *Type:* string

ml.c6g.16xlarge Notebook Instance Type.

---

##### `ML_C6G_2XLARGE`<sup>Required</sup> <a name="ML_C6G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_2XLARGE"></a>

```typescript
public readonly ML_C6G_2XLARGE: string;
```

- *Type:* string

ml.c6g.2xlarge Notebook Instance Type.

---

##### `ML_C6G_4XLARGE`<sup>Required</sup> <a name="ML_C6G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_4XLARGE"></a>

```typescript
public readonly ML_C6G_4XLARGE: string;
```

- *Type:* string

ml.c6g.4xlarge Notebook Instance Type.

---

##### `ML_C6G_8XLARGE`<sup>Required</sup> <a name="ML_C6G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_8XLARGE"></a>

```typescript
public readonly ML_C6G_8XLARGE: string;
```

- *Type:* string

ml.c6g.8xlarge Notebook Instance Type.

---

##### `ML_C6G_LARGE`<sup>Required</sup> <a name="ML_C6G_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_LARGE"></a>

```typescript
public readonly ML_C6G_LARGE: string;
```

- *Type:* string

ml.c6g.large Notebook Instance Type.

---

##### `ML_C6G_XLARGE`<sup>Required</sup> <a name="ML_C6G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6G_XLARGE"></a>

```typescript
public readonly ML_C6G_XLARGE: string;
```

- *Type:* string

ml.c6g.xlarge Notebook Instance Type.

---

##### `ML_C6GD_12XLARGE`<sup>Required</sup> <a name="ML_C6GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_12XLARGE"></a>

```typescript
public readonly ML_C6GD_12XLARGE: string;
```

- *Type:* string

ml.c6gd.12xlarge Notebook Instance Type.

---

##### `ML_C6GD_16XLARGE`<sup>Required</sup> <a name="ML_C6GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_16XLARGE"></a>

```typescript
public readonly ML_C6GD_16XLARGE: string;
```

- *Type:* string

ml.c6gd.16xlarge Notebook Instance Type.

---

##### `ML_C6GD_2XLARGE`<sup>Required</sup> <a name="ML_C6GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_2XLARGE"></a>

```typescript
public readonly ML_C6GD_2XLARGE: string;
```

- *Type:* string

ml.c6gd.2xlarge Notebook Instance Type.

---

##### `ML_C6GD_4XLARGE`<sup>Required</sup> <a name="ML_C6GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_4XLARGE"></a>

```typescript
public readonly ML_C6GD_4XLARGE: string;
```

- *Type:* string

ml.c6gd.4xlarge Notebook Instance Type.

---

##### `ML_C6GD_8XLARGE`<sup>Required</sup> <a name="ML_C6GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_8XLARGE"></a>

```typescript
public readonly ML_C6GD_8XLARGE: string;
```

- *Type:* string

ml.c6gd.8xlarge Notebook Instance Type.

---

##### `ML_C6GD_LARGE`<sup>Required</sup> <a name="ML_C6GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_LARGE"></a>

```typescript
public readonly ML_C6GD_LARGE: string;
```

- *Type:* string

ml.c6gd.large Notebook Instance Type.

---

##### `ML_C6GD_XLARGE`<sup>Required</sup> <a name="ML_C6GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GD_XLARGE"></a>

```typescript
public readonly ML_C6GD_XLARGE: string;
```

- *Type:* string

ml.c6gd.xlarge Notebook Instance Type.

---

##### `ML_C6GN_12XLARGE`<sup>Required</sup> <a name="ML_C6GN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_12XLARGE"></a>

```typescript
public readonly ML_C6GN_12XLARGE: string;
```

- *Type:* string

ml.c6gn.12xlarge Notebook Instance Type.

---

##### `ML_C6GN_16XLARGE`<sup>Required</sup> <a name="ML_C6GN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_16XLARGE"></a>

```typescript
public readonly ML_C6GN_16XLARGE: string;
```

- *Type:* string

ml.c6gn.16xlarge Notebook Instance Type.

---

##### `ML_C6GN_2XLARGE`<sup>Required</sup> <a name="ML_C6GN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_2XLARGE"></a>

```typescript
public readonly ML_C6GN_2XLARGE: string;
```

- *Type:* string

ml.c6gn.2xlarge Notebook Instance Type.

---

##### `ML_C6GN_4XLARGE`<sup>Required</sup> <a name="ML_C6GN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_4XLARGE"></a>

```typescript
public readonly ML_C6GN_4XLARGE: string;
```

- *Type:* string

ml.c6gn.4xlarge Notebook Instance Type.

---

##### `ML_C6GN_8XLARGE`<sup>Required</sup> <a name="ML_C6GN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_8XLARGE"></a>

```typescript
public readonly ML_C6GN_8XLARGE: string;
```

- *Type:* string

ml.c6gn.8xlarge Notebook Instance Type.

---

##### `ML_C6GN_LARGE`<sup>Required</sup> <a name="ML_C6GN_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_LARGE"></a>

```typescript
public readonly ML_C6GN_LARGE: string;
```

- *Type:* string

ml.c6gn.large Notebook Instance Type.

---

##### `ML_C6GN_XLARGE`<sup>Required</sup> <a name="ML_C6GN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6GN_XLARGE"></a>

```typescript
public readonly ML_C6GN_XLARGE: string;
```

- *Type:* string

ml.c6gn.xlarge Notebook Instance Type.

---

##### `ML_C6I_12XLARGE`<sup>Required</sup> <a name="ML_C6I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_12XLARGE"></a>

```typescript
public readonly ML_C6I_12XLARGE: string;
```

- *Type:* string

ml.c6i.12xlarge Notebook Instance Type.

---

##### `ML_C6I_16XLARGE`<sup>Required</sup> <a name="ML_C6I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_16XLARGE"></a>

```typescript
public readonly ML_C6I_16XLARGE: string;
```

- *Type:* string

ml.c6i.16xlarge Notebook Instance Type.

---

##### `ML_C6I_24XLARGE`<sup>Required</sup> <a name="ML_C6I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_24XLARGE"></a>

```typescript
public readonly ML_C6I_24XLARGE: string;
```

- *Type:* string

ml.c6i.24xlarge Notebook Instance Type.

---

##### `ML_C6I_2XLARGE`<sup>Required</sup> <a name="ML_C6I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_2XLARGE"></a>

```typescript
public readonly ML_C6I_2XLARGE: string;
```

- *Type:* string

ml.c6i.2xlarge Notebook Instance Type.

---

##### `ML_C6I_32XLARGE`<sup>Required</sup> <a name="ML_C6I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_32XLARGE"></a>

```typescript
public readonly ML_C6I_32XLARGE: string;
```

- *Type:* string

ml.c6i.32xlarge Notebook Instance Type.

---

##### `ML_C6I_4XLARGE`<sup>Required</sup> <a name="ML_C6I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_4XLARGE"></a>

```typescript
public readonly ML_C6I_4XLARGE: string;
```

- *Type:* string

ml.c6i.4xlarge Notebook Instance Type.

---

##### `ML_C6I_8XLARGE`<sup>Required</sup> <a name="ML_C6I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_8XLARGE"></a>

```typescript
public readonly ML_C6I_8XLARGE: string;
```

- *Type:* string

ml.c6i.8xlarge Notebook Instance Type.

---

##### `ML_C6I_LARGE`<sup>Required</sup> <a name="ML_C6I_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_LARGE"></a>

```typescript
public readonly ML_C6I_LARGE: string;
```

- *Type:* string

ml.c6i.large Notebook Instance Type.

---

##### `ML_C6I_XLARGE`<sup>Required</sup> <a name="ML_C6I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6I_XLARGE"></a>

```typescript
public readonly ML_C6I_XLARGE: string;
```

- *Type:* string

ml.c6i.xlarge Notebook Instance Type.

---

##### `ML_C6ID_12XLARGE`<sup>Required</sup> <a name="ML_C6ID_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_12XLARGE"></a>

```typescript
public readonly ML_C6ID_12XLARGE: string;
```

- *Type:* string

ml.c6id.12xlarge Notebook Instance Type.

---

##### `ML_C6ID_16XLARGE`<sup>Required</sup> <a name="ML_C6ID_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_16XLARGE"></a>

```typescript
public readonly ML_C6ID_16XLARGE: string;
```

- *Type:* string

ml.c6id.16xlarge Notebook Instance Type.

---

##### `ML_C6ID_24XLARGE`<sup>Required</sup> <a name="ML_C6ID_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_24XLARGE"></a>

```typescript
public readonly ML_C6ID_24XLARGE: string;
```

- *Type:* string

ml.c6id.24xlarge Notebook Instance Type.

---

##### `ML_C6ID_2XLARGE`<sup>Required</sup> <a name="ML_C6ID_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_2XLARGE"></a>

```typescript
public readonly ML_C6ID_2XLARGE: string;
```

- *Type:* string

ml.c6id.2xlarge Notebook Instance Type.

---

##### `ML_C6ID_32XLARGE`<sup>Required</sup> <a name="ML_C6ID_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_32XLARGE"></a>

```typescript
public readonly ML_C6ID_32XLARGE: string;
```

- *Type:* string

ml.c6id.32xlarge Notebook Instance Type.

---

##### `ML_C6ID_4XLARGE`<sup>Required</sup> <a name="ML_C6ID_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_4XLARGE"></a>

```typescript
public readonly ML_C6ID_4XLARGE: string;
```

- *Type:* string

ml.c6id.4xlarge Notebook Instance Type.

---

##### `ML_C6ID_8XLARGE`<sup>Required</sup> <a name="ML_C6ID_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_8XLARGE"></a>

```typescript
public readonly ML_C6ID_8XLARGE: string;
```

- *Type:* string

ml.c6id.8xlarge Notebook Instance Type.

---

##### `ML_C6ID_LARGE`<sup>Required</sup> <a name="ML_C6ID_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_LARGE"></a>

```typescript
public readonly ML_C6ID_LARGE: string;
```

- *Type:* string

ml.c6id.large Notebook Instance Type.

---

##### `ML_C6ID_XLARGE`<sup>Required</sup> <a name="ML_C6ID_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C6ID_XLARGE"></a>

```typescript
public readonly ML_C6ID_XLARGE: string;
```

- *Type:* string

ml.c6id.xlarge Notebook Instance Type.

---

##### `ML_C7G_12XLARGE`<sup>Required</sup> <a name="ML_C7G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_12XLARGE"></a>

```typescript
public readonly ML_C7G_12XLARGE: string;
```

- *Type:* string

ml.c7g.12xlarge Notebook Instance Type.

---

##### `ML_C7G_16XLARGE`<sup>Required</sup> <a name="ML_C7G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_16XLARGE"></a>

```typescript
public readonly ML_C7G_16XLARGE: string;
```

- *Type:* string

ml.c7g.16xlarge Notebook Instance Type.

---

##### `ML_C7G_2XLARGE`<sup>Required</sup> <a name="ML_C7G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_2XLARGE"></a>

```typescript
public readonly ML_C7G_2XLARGE: string;
```

- *Type:* string

ml.c7g.2xlarge Notebook Instance Type.

---

##### `ML_C7G_4XLARGE`<sup>Required</sup> <a name="ML_C7G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_4XLARGE"></a>

```typescript
public readonly ML_C7G_4XLARGE: string;
```

- *Type:* string

ml.c7g.4xlarge Notebook Instance Type.

---

##### `ML_C7G_8XLARGE`<sup>Required</sup> <a name="ML_C7G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_8XLARGE"></a>

```typescript
public readonly ML_C7G_8XLARGE: string;
```

- *Type:* string

ml.c7g.8xlarge Notebook Instance Type.

---

##### `ML_C7G_LARGE`<sup>Required</sup> <a name="ML_C7G_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_LARGE"></a>

```typescript
public readonly ML_C7G_LARGE: string;
```

- *Type:* string

ml.c7g.large Notebook Instance Type.

---

##### `ML_C7G_XLARGE`<sup>Required</sup> <a name="ML_C7G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7G_XLARGE"></a>

```typescript
public readonly ML_C7G_XLARGE: string;
```

- *Type:* string

ml.c7g.xlarge Notebook Instance Type.

---

##### `ML_C7I_12XLARGE`<sup>Required</sup> <a name="ML_C7I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_12XLARGE"></a>

```typescript
public readonly ML_C7I_12XLARGE: string;
```

- *Type:* string

ml.c7i.12xlarge Notebook Instance Type.

---

##### `ML_C7I_16XLARGE`<sup>Required</sup> <a name="ML_C7I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_16XLARGE"></a>

```typescript
public readonly ML_C7I_16XLARGE: string;
```

- *Type:* string

ml.c7i.16xlarge Notebook Instance Type.

---

##### `ML_C7I_24XLARGE`<sup>Required</sup> <a name="ML_C7I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_24XLARGE"></a>

```typescript
public readonly ML_C7I_24XLARGE: string;
```

- *Type:* string

ml.c7i.24xlarge Notebook Instance Type.

---

##### `ML_C7I_2XLARGE`<sup>Required</sup> <a name="ML_C7I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_2XLARGE"></a>

```typescript
public readonly ML_C7I_2XLARGE: string;
```

- *Type:* string

ml.c7i.2xlarge Notebook Instance Type.

---

##### `ML_C7I_48XLARGE`<sup>Required</sup> <a name="ML_C7I_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_48XLARGE"></a>

```typescript
public readonly ML_C7I_48XLARGE: string;
```

- *Type:* string

ml.c7i.48xlarge Notebook Instance Type.

---

##### `ML_C7I_4XLARGE`<sup>Required</sup> <a name="ML_C7I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_4XLARGE"></a>

```typescript
public readonly ML_C7I_4XLARGE: string;
```

- *Type:* string

ml.c7i.4xlarge Notebook Instance Type.

---

##### `ML_C7I_8XLARGE`<sup>Required</sup> <a name="ML_C7I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_8XLARGE"></a>

```typescript
public readonly ML_C7I_8XLARGE: string;
```

- *Type:* string

ml.c7i.8xlarge Notebook Instance Type.

---

##### `ML_C7I_LARGE`<sup>Required</sup> <a name="ML_C7I_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_LARGE"></a>

```typescript
public readonly ML_C7I_LARGE: string;
```

- *Type:* string

ml.c7i.large Notebook Instance Type.

---

##### `ML_C7I_XLARGE`<sup>Required</sup> <a name="ML_C7I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_C7I_XLARGE"></a>

```typescript
public readonly ML_C7I_XLARGE: string;
```

- *Type:* string

ml.c7i.xlarge Notebook Instance Type.

---

##### `ML_G4DN_12XLARGE`<sup>Required</sup> <a name="ML_G4DN_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_12XLARGE"></a>

```typescript
public readonly ML_G4DN_12XLARGE: string;
```

- *Type:* string

ml.g4dn.12xlarge Notebook Instance Type.

---

##### `ML_G4DN_16XLARGE`<sup>Required</sup> <a name="ML_G4DN_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_16XLARGE"></a>

```typescript
public readonly ML_G4DN_16XLARGE: string;
```

- *Type:* string

ml.g4dn.16xlarge Notebook Instance Type.

---

##### `ML_G4DN_2XLARGE`<sup>Required</sup> <a name="ML_G4DN_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_2XLARGE"></a>

```typescript
public readonly ML_G4DN_2XLARGE: string;
```

- *Type:* string

ml.g4dn.2xlarge Notebook Instance Type.

---

##### `ML_G4DN_4XLARGE`<sup>Required</sup> <a name="ML_G4DN_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_4XLARGE"></a>

```typescript
public readonly ML_G4DN_4XLARGE: string;
```

- *Type:* string

ml.g4dn.4xlarge Notebook Instance Type.

---

##### `ML_G4DN_8XLARGE`<sup>Required</sup> <a name="ML_G4DN_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_8XLARGE"></a>

```typescript
public readonly ML_G4DN_8XLARGE: string;
```

- *Type:* string

ml.g4dn.8xlarge Notebook Instance Type.

---

##### `ML_G4DN_XLARGE`<sup>Required</sup> <a name="ML_G4DN_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G4DN_XLARGE"></a>

```typescript
public readonly ML_G4DN_XLARGE: string;
```

- *Type:* string

ml.g4dn.xlarge Notebook Instance Type.

---

##### `ML_G5_12XLARGE`<sup>Required</sup> <a name="ML_G5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_12XLARGE"></a>

```typescript
public readonly ML_G5_12XLARGE: string;
```

- *Type:* string

ml.g5.12xlarge Notebook Instance Type.

---

##### `ML_G5_16XLARGE`<sup>Required</sup> <a name="ML_G5_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_16XLARGE"></a>

```typescript
public readonly ML_G5_16XLARGE: string;
```

- *Type:* string

ml.g5.16xlarge Notebook Instance Type.

---

##### `ML_G5_24XLARGE`<sup>Required</sup> <a name="ML_G5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_24XLARGE"></a>

```typescript
public readonly ML_G5_24XLARGE: string;
```

- *Type:* string

ml.g5.24xlarge Notebook Instance Type.

---

##### `ML_G5_2XLARGE`<sup>Required</sup> <a name="ML_G5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_2XLARGE"></a>

```typescript
public readonly ML_G5_2XLARGE: string;
```

- *Type:* string

ml.g5.2xlarge Notebook Instance Type.

---

##### `ML_G5_48XLARGE`<sup>Required</sup> <a name="ML_G5_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_48XLARGE"></a>

```typescript
public readonly ML_G5_48XLARGE: string;
```

- *Type:* string

ml.g5.48xlarge Notebook Instance Type.

---

##### `ML_G5_4XLARGE`<sup>Required</sup> <a name="ML_G5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_4XLARGE"></a>

```typescript
public readonly ML_G5_4XLARGE: string;
```

- *Type:* string

ml.g5.4xlarge Notebook Instance Type.

---

##### `ML_G5_8XLARGE`<sup>Required</sup> <a name="ML_G5_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_8XLARGE"></a>

```typescript
public readonly ML_G5_8XLARGE: string;
```

- *Type:* string

ml.g5.8xlarge Notebook Instance Type.

---

##### `ML_G5_XLARGE`<sup>Required</sup> <a name="ML_G5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G5_XLARGE"></a>

```typescript
public readonly ML_G5_XLARGE: string;
```

- *Type:* string

ml.g5.xlarge Notebook Instance Type.

---

##### `ML_G6_12XLARGE`<sup>Required</sup> <a name="ML_G6_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_12XLARGE"></a>

```typescript
public readonly ML_G6_12XLARGE: string;
```

- *Type:* string

ml.g6.12xlarge Notebook Instance Type.

---

##### `ML_G6_16XLARGE`<sup>Required</sup> <a name="ML_G6_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_16XLARGE"></a>

```typescript
public readonly ML_G6_16XLARGE: string;
```

- *Type:* string

ml.g6.16xlarge Notebook Instance Type.

---

##### `ML_G6_24XLARGE`<sup>Required</sup> <a name="ML_G6_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_24XLARGE"></a>

```typescript
public readonly ML_G6_24XLARGE: string;
```

- *Type:* string

ml.g6.24xlarge Notebook Instance Type.

---

##### `ML_G6_2XLARGE`<sup>Required</sup> <a name="ML_G6_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_2XLARGE"></a>

```typescript
public readonly ML_G6_2XLARGE: string;
```

- *Type:* string

ml.g6.2xlarge Notebook Instance Type.

---

##### `ML_G6_48XLARGE`<sup>Required</sup> <a name="ML_G6_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_48XLARGE"></a>

```typescript
public readonly ML_G6_48XLARGE: string;
```

- *Type:* string

ml.g6.48xlarge Notebook Instance Type.

---

##### `ML_G6_4XLARGE`<sup>Required</sup> <a name="ML_G6_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_4XLARGE"></a>

```typescript
public readonly ML_G6_4XLARGE: string;
```

- *Type:* string

ml.g6.4xlarge Notebook Instance Type.

---

##### `ML_G6_8XLARGE`<sup>Required</sup> <a name="ML_G6_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_8XLARGE"></a>

```typescript
public readonly ML_G6_8XLARGE: string;
```

- *Type:* string

ml.g6.8xlarge Notebook Instance Type.

---

##### `ML_G6_XLARGE`<sup>Required</sup> <a name="ML_G6_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6_XLARGE"></a>

```typescript
public readonly ML_G6_XLARGE: string;
```

- *Type:* string

ml.g6.xlarge Notebook Instance Type.

---

##### `ML_G6E_12XLARGE`<sup>Required</sup> <a name="ML_G6E_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_12XLARGE"></a>

```typescript
public readonly ML_G6E_12XLARGE: string;
```

- *Type:* string

ml.g6e.12xlarge Notebook Instance Type.

---

##### `ML_G6E_16XLARGE`<sup>Required</sup> <a name="ML_G6E_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_16XLARGE"></a>

```typescript
public readonly ML_G6E_16XLARGE: string;
```

- *Type:* string

ml.g6e.16xlarge Notebook Instance Type.

---

##### `ML_G6E_24XLARGE`<sup>Required</sup> <a name="ML_G6E_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_24XLARGE"></a>

```typescript
public readonly ML_G6E_24XLARGE: string;
```

- *Type:* string

ml.g6e.24xlarge Notebook Instance Type.

---

##### `ML_G6E_2XLARGE`<sup>Required</sup> <a name="ML_G6E_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_2XLARGE"></a>

```typescript
public readonly ML_G6E_2XLARGE: string;
```

- *Type:* string

ml.g6e.2xlarge Notebook Instance Type.

---

##### `ML_G6E_48XLARGE`<sup>Required</sup> <a name="ML_G6E_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_48XLARGE"></a>

```typescript
public readonly ML_G6E_48XLARGE: string;
```

- *Type:* string

ml.g6e.48xlarge Notebook Instance Type.

---

##### `ML_G6E_4XLARGE`<sup>Required</sup> <a name="ML_G6E_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_4XLARGE"></a>

```typescript
public readonly ML_G6E_4XLARGE: string;
```

- *Type:* string

ml.g6e.4xlarge Notebook Instance Type.

---

##### `ML_G6E_8XLARGE`<sup>Required</sup> <a name="ML_G6E_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_8XLARGE"></a>

```typescript
public readonly ML_G6E_8XLARGE: string;
```

- *Type:* string

ml.g6e.8xlarge Notebook Instance Type.

---

##### `ML_G6E_XLARGE`<sup>Required</sup> <a name="ML_G6E_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_G6E_XLARGE"></a>

```typescript
public readonly ML_G6E_XLARGE: string;
```

- *Type:* string

ml.g6e.xlarge Notebook Instance Type.

---

##### `ML_GR6_4XLARGE`<sup>Required</sup> <a name="ML_GR6_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_GR6_4XLARGE"></a>

```typescript
public readonly ML_GR6_4XLARGE: string;
```

- *Type:* string

ml.gr6.4xlarge Notebook Instance Type.

---

##### `ML_GR6_8XLARGE`<sup>Required</sup> <a name="ML_GR6_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_GR6_8XLARGE"></a>

```typescript
public readonly ML_GR6_8XLARGE: string;
```

- *Type:* string

ml.gr6.8xlarge Notebook Instance Type.

---

##### `ML_INF1_24XLARGE`<sup>Required</sup> <a name="ML_INF1_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_24XLARGE"></a>

```typescript
public readonly ML_INF1_24XLARGE: string;
```

- *Type:* string

ml.inf1.24xlarge Notebook Instance Type.

---

##### `ML_INF1_2XLARGE`<sup>Required</sup> <a name="ML_INF1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_2XLARGE"></a>

```typescript
public readonly ML_INF1_2XLARGE: string;
```

- *Type:* string

ml.inf1.2xlarge Notebook Instance Type.

---

##### `ML_INF1_6XLARGE`<sup>Required</sup> <a name="ML_INF1_6XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_6XLARGE"></a>

```typescript
public readonly ML_INF1_6XLARGE: string;
```

- *Type:* string

ml.inf1.6xlarge Notebook Instance Type.

---

##### `ML_INF1_XLARGE`<sup>Required</sup> <a name="ML_INF1_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF1_XLARGE"></a>

```typescript
public readonly ML_INF1_XLARGE: string;
```

- *Type:* string

ml.inf1.xlarge Notebook Instance Type.

---

##### `ML_INF2_24XLARGE`<sup>Required</sup> <a name="ML_INF2_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_24XLARGE"></a>

```typescript
public readonly ML_INF2_24XLARGE: string;
```

- *Type:* string

ml.inf2.24xlarge Notebook Instance Type.

---

##### `ML_INF2_48XLARGE`<sup>Required</sup> <a name="ML_INF2_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_48XLARGE"></a>

```typescript
public readonly ML_INF2_48XLARGE: string;
```

- *Type:* string

ml.inf2.48xlarge Notebook Instance Type.

---

##### `ML_INF2_8XLARGE`<sup>Required</sup> <a name="ML_INF2_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_8XLARGE"></a>

```typescript
public readonly ML_INF2_8XLARGE: string;
```

- *Type:* string

ml.inf2.8xlarge Notebook Instance Type.

---

##### `ML_INF2_XLARGE`<sup>Required</sup> <a name="ML_INF2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_INF2_XLARGE"></a>

```typescript
public readonly ML_INF2_XLARGE: string;
```

- *Type:* string

ml.inf2.xlarge Notebook Instance Type.

---

##### `ML_M4_10XLARGE`<sup>Required</sup> <a name="ML_M4_10XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_10XLARGE"></a>

```typescript
public readonly ML_M4_10XLARGE: string;
```

- *Type:* string

ml.m4.10xlarge Notebook Instance Type.

---

##### `ML_M4_16XLARGE`<sup>Required</sup> <a name="ML_M4_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_16XLARGE"></a>

```typescript
public readonly ML_M4_16XLARGE: string;
```

- *Type:* string

ml.m4.16xlarge Notebook Instance Type.

---

##### `ML_M4_2XLARGE`<sup>Required</sup> <a name="ML_M4_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_2XLARGE"></a>

```typescript
public readonly ML_M4_2XLARGE: string;
```

- *Type:* string

ml.m4.2xlarge Notebook Instance Type.

---

##### `ML_M4_4XLARGE`<sup>Required</sup> <a name="ML_M4_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_4XLARGE"></a>

```typescript
public readonly ML_M4_4XLARGE: string;
```

- *Type:* string

ml.m4.4xlarge Notebook Instance Type.

---

##### `ML_M4_XLARGE`<sup>Required</sup> <a name="ML_M4_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M4_XLARGE"></a>

```typescript
public readonly ML_M4_XLARGE: string;
```

- *Type:* string

ml.m4.xlarge Notebook Instance Type.

---

##### `ML_M5_12XLARGE`<sup>Required</sup> <a name="ML_M5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_12XLARGE"></a>

```typescript
public readonly ML_M5_12XLARGE: string;
```

- *Type:* string

ml.m5.12xlarge Notebook Instance Type.

---

##### `ML_M5_16XLARGE`<sup>Required</sup> <a name="ML_M5_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_16XLARGE"></a>

```typescript
public readonly ML_M5_16XLARGE: string;
```

- *Type:* string

ml.m5.16xlarge Notebook Instance Type.

---

##### `ML_M5_24XLARGE`<sup>Required</sup> <a name="ML_M5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_24XLARGE"></a>

```typescript
public readonly ML_M5_24XLARGE: string;
```

- *Type:* string

ml.m5.24xlarge Notebook Instance Type.

---

##### `ML_M5_2XLARGE`<sup>Required</sup> <a name="ML_M5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_2XLARGE"></a>

```typescript
public readonly ML_M5_2XLARGE: string;
```

- *Type:* string

ml.m5.2xlarge Notebook Instance Type.

---

##### `ML_M5_4XLARGE`<sup>Required</sup> <a name="ML_M5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_4XLARGE"></a>

```typescript
public readonly ML_M5_4XLARGE: string;
```

- *Type:* string

ml.m5.4xlarge Notebook Instance Type.

---

##### `ML_M5_8XLARGE`<sup>Required</sup> <a name="ML_M5_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_8XLARGE"></a>

```typescript
public readonly ML_M5_8XLARGE: string;
```

- *Type:* string

ml.m5.8xlarge Notebook Instance Type.

---

##### `ML_M5_LARGE`<sup>Required</sup> <a name="ML_M5_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_LARGE"></a>

```typescript
public readonly ML_M5_LARGE: string;
```

- *Type:* string

ml.m5.large Notebook Instance Type.

---

##### `ML_M5_XLARGE`<sup>Required</sup> <a name="ML_M5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5_XLARGE"></a>

```typescript
public readonly ML_M5_XLARGE: string;
```

- *Type:* string

ml.m5.xlarge Notebook Instance Type.

---

##### `ML_M5D_12XLARGE`<sup>Required</sup> <a name="ML_M5D_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_12XLARGE"></a>

```typescript
public readonly ML_M5D_12XLARGE: string;
```

- *Type:* string

ml.m5d.12xlarge Notebook Instance Type.

---

##### `ML_M5D_16XLARGE`<sup>Required</sup> <a name="ML_M5D_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_16XLARGE"></a>

```typescript
public readonly ML_M5D_16XLARGE: string;
```

- *Type:* string

ml.m5d.16xlarge Notebook Instance Type.

---

##### `ML_M5D_24XLARGE`<sup>Required</sup> <a name="ML_M5D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_24XLARGE"></a>

```typescript
public readonly ML_M5D_24XLARGE: string;
```

- *Type:* string

ml.m5d.24xlarge Notebook Instance Type.

---

##### `ML_M5D_2XLARGE`<sup>Required</sup> <a name="ML_M5D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_2XLARGE"></a>

```typescript
public readonly ML_M5D_2XLARGE: string;
```

- *Type:* string

ml.m5d.2xlarge Notebook Instance Type.

---

##### `ML_M5D_4XLARGE`<sup>Required</sup> <a name="ML_M5D_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_4XLARGE"></a>

```typescript
public readonly ML_M5D_4XLARGE: string;
```

- *Type:* string

ml.m5d.4xlarge Notebook Instance Type.

---

##### `ML_M5D_8XLARGE`<sup>Required</sup> <a name="ML_M5D_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_8XLARGE"></a>

```typescript
public readonly ML_M5D_8XLARGE: string;
```

- *Type:* string

ml.m5d.8xlarge Notebook Instance Type.

---

##### `ML_M5D_LARGE`<sup>Required</sup> <a name="ML_M5D_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_LARGE"></a>

```typescript
public readonly ML_M5D_LARGE: string;
```

- *Type:* string

ml.m5d.large Notebook Instance Type.

---

##### `ML_M5D_XLARGE`<sup>Required</sup> <a name="ML_M5D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M5D_XLARGE"></a>

```typescript
public readonly ML_M5D_XLARGE: string;
```

- *Type:* string

ml.m5d.xlarge Notebook Instance Type.

---

##### `ML_M6G_12XLARGE`<sup>Required</sup> <a name="ML_M6G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_12XLARGE"></a>

```typescript
public readonly ML_M6G_12XLARGE: string;
```

- *Type:* string

ml.m6g.12xlarge Notebook Instance Type.

---

##### `ML_M6G_16XLARGE`<sup>Required</sup> <a name="ML_M6G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_16XLARGE"></a>

```typescript
public readonly ML_M6G_16XLARGE: string;
```

- *Type:* string

ml.m6g.16xlarge Notebook Instance Type.

---

##### `ML_M6G_2XLARGE`<sup>Required</sup> <a name="ML_M6G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_2XLARGE"></a>

```typescript
public readonly ML_M6G_2XLARGE: string;
```

- *Type:* string

ml.m6g.2xlarge Notebook Instance Type.

---

##### `ML_M6G_4XLARGE`<sup>Required</sup> <a name="ML_M6G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_4XLARGE"></a>

```typescript
public readonly ML_M6G_4XLARGE: string;
```

- *Type:* string

ml.m6g.4xlarge Notebook Instance Type.

---

##### `ML_M6G_8XLARGE`<sup>Required</sup> <a name="ML_M6G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_8XLARGE"></a>

```typescript
public readonly ML_M6G_8XLARGE: string;
```

- *Type:* string

ml.m6g.8xlarge Notebook Instance Type.

---

##### `ML_M6G_LARGE`<sup>Required</sup> <a name="ML_M6G_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_LARGE"></a>

```typescript
public readonly ML_M6G_LARGE: string;
```

- *Type:* string

ml.m6g.large Notebook Instance Type.

---

##### `ML_M6G_XLARGE`<sup>Required</sup> <a name="ML_M6G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6G_XLARGE"></a>

```typescript
public readonly ML_M6G_XLARGE: string;
```

- *Type:* string

ml.m6g.xlarge Notebook Instance Type.

---

##### `ML_M6GD_12XLARGE`<sup>Required</sup> <a name="ML_M6GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_12XLARGE"></a>

```typescript
public readonly ML_M6GD_12XLARGE: string;
```

- *Type:* string

ml.m6gd.12xlarge Notebook Instance Type.

---

##### `ML_M6GD_16XLARGE`<sup>Required</sup> <a name="ML_M6GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_16XLARGE"></a>

```typescript
public readonly ML_M6GD_16XLARGE: string;
```

- *Type:* string

ml.m6gd.16xlarge Notebook Instance Type.

---

##### `ML_M6GD_2XLARGE`<sup>Required</sup> <a name="ML_M6GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_2XLARGE"></a>

```typescript
public readonly ML_M6GD_2XLARGE: string;
```

- *Type:* string

ml.m6gd.2xlarge Notebook Instance Type.

---

##### `ML_M6GD_4XLARGE`<sup>Required</sup> <a name="ML_M6GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_4XLARGE"></a>

```typescript
public readonly ML_M6GD_4XLARGE: string;
```

- *Type:* string

ml.m6gd.4xlarge Notebook Instance Type.

---

##### `ML_M6GD_8XLARGE`<sup>Required</sup> <a name="ML_M6GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_8XLARGE"></a>

```typescript
public readonly ML_M6GD_8XLARGE: string;
```

- *Type:* string

ml.m6gd.8xlarge Notebook Instance Type.

---

##### `ML_M6GD_LARGE`<sup>Required</sup> <a name="ML_M6GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_LARGE"></a>

```typescript
public readonly ML_M6GD_LARGE: string;
```

- *Type:* string

ml.m6gd.large Notebook Instance Type.

---

##### `ML_M6GD_XLARGE`<sup>Required</sup> <a name="ML_M6GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6GD_XLARGE"></a>

```typescript
public readonly ML_M6GD_XLARGE: string;
```

- *Type:* string

ml.m6gd.xlarge Notebook Instance Type.

---

##### `ML_M6I_12XLARGE`<sup>Required</sup> <a name="ML_M6I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_12XLARGE"></a>

```typescript
public readonly ML_M6I_12XLARGE: string;
```

- *Type:* string

ml.m6i.12xlarge Notebook Instance Type.

---

##### `ML_M6I_16XLARGE`<sup>Required</sup> <a name="ML_M6I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_16XLARGE"></a>

```typescript
public readonly ML_M6I_16XLARGE: string;
```

- *Type:* string

ml.m6i.16xlarge Notebook Instance Type.

---

##### `ML_M6I_24XLARGE`<sup>Required</sup> <a name="ML_M6I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_24XLARGE"></a>

```typescript
public readonly ML_M6I_24XLARGE: string;
```

- *Type:* string

ml.m6i.24xlarge Notebook Instance Type.

---

##### `ML_M6I_2XLARGE`<sup>Required</sup> <a name="ML_M6I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_2XLARGE"></a>

```typescript
public readonly ML_M6I_2XLARGE: string;
```

- *Type:* string

ml.m6i.2xlarge Notebook Instance Type.

---

##### `ML_M6I_32XLARGE`<sup>Required</sup> <a name="ML_M6I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_32XLARGE"></a>

```typescript
public readonly ML_M6I_32XLARGE: string;
```

- *Type:* string

ml.m6i.32xlarge Notebook Instance Type.

---

##### `ML_M6I_4XLARGE`<sup>Required</sup> <a name="ML_M6I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_4XLARGE"></a>

```typescript
public readonly ML_M6I_4XLARGE: string;
```

- *Type:* string

ml.m6i.4xlarge Notebook Instance Type.

---

##### `ML_M6I_8XLARGE`<sup>Required</sup> <a name="ML_M6I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_8XLARGE"></a>

```typescript
public readonly ML_M6I_8XLARGE: string;
```

- *Type:* string

ml.m6i.8xlarge Notebook Instance Type.

---

##### `ML_M6I_LARGE`<sup>Required</sup> <a name="ML_M6I_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_LARGE"></a>

```typescript
public readonly ML_M6I_LARGE: string;
```

- *Type:* string

ml.m6i.large Notebook Instance Type.

---

##### `ML_M6I_XLARGE`<sup>Required</sup> <a name="ML_M6I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6I_XLARGE"></a>

```typescript
public readonly ML_M6I_XLARGE: string;
```

- *Type:* string

ml.m6i.xlarge Notebook Instance Type.

---

##### `ML_M6ID_12XLARGE`<sup>Required</sup> <a name="ML_M6ID_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_12XLARGE"></a>

```typescript
public readonly ML_M6ID_12XLARGE: string;
```

- *Type:* string

ml.m6id.12xlarge Notebook Instance Type.

---

##### `ML_M6ID_16XLARGE`<sup>Required</sup> <a name="ML_M6ID_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_16XLARGE"></a>

```typescript
public readonly ML_M6ID_16XLARGE: string;
```

- *Type:* string

ml.m6id.16xlarge Notebook Instance Type.

---

##### `ML_M6ID_24XLARGE`<sup>Required</sup> <a name="ML_M6ID_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_24XLARGE"></a>

```typescript
public readonly ML_M6ID_24XLARGE: string;
```

- *Type:* string

ml.m6id.24xlarge Notebook Instance Type.

---

##### `ML_M6ID_2XLARGE`<sup>Required</sup> <a name="ML_M6ID_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_2XLARGE"></a>

```typescript
public readonly ML_M6ID_2XLARGE: string;
```

- *Type:* string

ml.m6id.2xlarge Notebook Instance Type.

---

##### `ML_M6ID_32XLARGE`<sup>Required</sup> <a name="ML_M6ID_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_32XLARGE"></a>

```typescript
public readonly ML_M6ID_32XLARGE: string;
```

- *Type:* string

ml.m6id.32xlarge Notebook Instance Type.

---

##### `ML_M6ID_4XLARGE`<sup>Required</sup> <a name="ML_M6ID_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_4XLARGE"></a>

```typescript
public readonly ML_M6ID_4XLARGE: string;
```

- *Type:* string

ml.m6id.4xlarge Notebook Instance Type.

---

##### `ML_M6ID_8XLARGE`<sup>Required</sup> <a name="ML_M6ID_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_8XLARGE"></a>

```typescript
public readonly ML_M6ID_8XLARGE: string;
```

- *Type:* string

ml.m6id.8xlarge Notebook Instance Type.

---

##### `ML_M6ID_LARGE`<sup>Required</sup> <a name="ML_M6ID_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_LARGE"></a>

```typescript
public readonly ML_M6ID_LARGE: string;
```

- *Type:* string

ml.m6id.large Notebook Instance Type.

---

##### `ML_M6ID_XLARGE`<sup>Required</sup> <a name="ML_M6ID_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M6ID_XLARGE"></a>

```typescript
public readonly ML_M6ID_XLARGE: string;
```

- *Type:* string

ml.m6id.xlarge Notebook Instance Type.

---

##### `ML_M7I_12XLARGE`<sup>Required</sup> <a name="ML_M7I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_12XLARGE"></a>

```typescript
public readonly ML_M7I_12XLARGE: string;
```

- *Type:* string

ml.m7i.12xlarge Notebook Instance Type.

---

##### `ML_M7I_16XLARGE`<sup>Required</sup> <a name="ML_M7I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_16XLARGE"></a>

```typescript
public readonly ML_M7I_16XLARGE: string;
```

- *Type:* string

ml.m7i.16xlarge Notebook Instance Type.

---

##### `ML_M7I_24XLARGE`<sup>Required</sup> <a name="ML_M7I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_24XLARGE"></a>

```typescript
public readonly ML_M7I_24XLARGE: string;
```

- *Type:* string

ml.m7i.24xlarge Notebook Instance Type.

---

##### `ML_M7I_2XLARGE`<sup>Required</sup> <a name="ML_M7I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_2XLARGE"></a>

```typescript
public readonly ML_M7I_2XLARGE: string;
```

- *Type:* string

ml.m7i.2xlarge Notebook Instance Type.

---

##### `ML_M7I_48XLARGE`<sup>Required</sup> <a name="ML_M7I_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_48XLARGE"></a>

```typescript
public readonly ML_M7I_48XLARGE: string;
```

- *Type:* string

ml.m7i.48xlarge Notebook Instance Type.

---

##### `ML_M7I_4XLARGE`<sup>Required</sup> <a name="ML_M7I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_4XLARGE"></a>

```typescript
public readonly ML_M7I_4XLARGE: string;
```

- *Type:* string

ml.m7i.4xlarge Notebook Instance Type.

---

##### `ML_M7I_8XLARGE`<sup>Required</sup> <a name="ML_M7I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_8XLARGE"></a>

```typescript
public readonly ML_M7I_8XLARGE: string;
```

- *Type:* string

ml.m7i.8xlarge Notebook Instance Type.

---

##### `ML_M7I_LARGE`<sup>Required</sup> <a name="ML_M7I_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_LARGE"></a>

```typescript
public readonly ML_M7I_LARGE: string;
```

- *Type:* string

ml.m7i.large Notebook Instance Type.

---

##### `ML_M7I_XLARGE`<sup>Required</sup> <a name="ML_M7I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_M7I_XLARGE"></a>

```typescript
public readonly ML_M7I_XLARGE: string;
```

- *Type:* string

ml.m7i.xlarge Notebook Instance Type.

---

##### `ML_P2_16XLARGE`<sup>Required</sup> <a name="ML_P2_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P2_16XLARGE"></a>

```typescript
public readonly ML_P2_16XLARGE: string;
```

- *Type:* string

ml.p2.16xlarge Notebook Instance Type.

---

##### `ML_P2_8XLARGE`<sup>Required</sup> <a name="ML_P2_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P2_8XLARGE"></a>

```typescript
public readonly ML_P2_8XLARGE: string;
```

- *Type:* string

ml.p2.8xlarge Notebook Instance Type.

---

##### `ML_P2_XLARGE`<sup>Required</sup> <a name="ML_P2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P2_XLARGE"></a>

```typescript
public readonly ML_P2_XLARGE: string;
```

- *Type:* string

ml.p2.xlarge Notebook Instance Type.

---

##### `ML_P3_16XLARGE`<sup>Required</sup> <a name="ML_P3_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3_16XLARGE"></a>

```typescript
public readonly ML_P3_16XLARGE: string;
```

- *Type:* string

ml.p3.16xlarge Notebook Instance Type.

---

##### `ML_P3_2XLARGE`<sup>Required</sup> <a name="ML_P3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3_2XLARGE"></a>

```typescript
public readonly ML_P3_2XLARGE: string;
```

- *Type:* string

ml.p3.2xlarge Notebook Instance Type.

---

##### `ML_P3_8XLARGE`<sup>Required</sup> <a name="ML_P3_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3_8XLARGE"></a>

```typescript
public readonly ML_P3_8XLARGE: string;
```

- *Type:* string

ml.p3.8xlarge Notebook Instance Type.

---

##### `ML_P3DN_24XLARGE`<sup>Required</sup> <a name="ML_P3DN_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P3DN_24XLARGE"></a>

```typescript
public readonly ML_P3DN_24XLARGE: string;
```

- *Type:* string

ml.p3dn.24xlarge Notebook Instance Type.

---

##### `ML_P4D_24XLARGE`<sup>Required</sup> <a name="ML_P4D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P4D_24XLARGE"></a>

```typescript
public readonly ML_P4D_24XLARGE: string;
```

- *Type:* string

ml.p4d.24xlarge Notebook Instance Type.

---

##### `ML_P4DE_24XLARGE`<sup>Required</sup> <a name="ML_P4DE_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P4DE_24XLARGE"></a>

```typescript
public readonly ML_P4DE_24XLARGE: string;
```

- *Type:* string

ml.p4de.24xlarge Notebook Instance Type.

---

##### `ML_P5_48XLARGE`<sup>Required</sup> <a name="ML_P5_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_P5_48XLARGE"></a>

```typescript
public readonly ML_P5_48XLARGE: string;
```

- *Type:* string

ml.p5.48xlarge Notebook Instance Type.

---

##### `ML_R5_12XLARGE`<sup>Required</sup> <a name="ML_R5_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_12XLARGE"></a>

```typescript
public readonly ML_R5_12XLARGE: string;
```

- *Type:* string

ml.r5.12xlarge Notebook Instance Type.

---

##### `ML_R5_16XLARGE`<sup>Required</sup> <a name="ML_R5_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_16XLARGE"></a>

```typescript
public readonly ML_R5_16XLARGE: string;
```

- *Type:* string

ml.r5.16xlarge Notebook Instance Type.

---

##### `ML_R5_24XLARGE`<sup>Required</sup> <a name="ML_R5_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_24XLARGE"></a>

```typescript
public readonly ML_R5_24XLARGE: string;
```

- *Type:* string

ml.r5.24xlarge Notebook Instance Type.

---

##### `ML_R5_2XLARGE`<sup>Required</sup> <a name="ML_R5_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_2XLARGE"></a>

```typescript
public readonly ML_R5_2XLARGE: string;
```

- *Type:* string

ml.r5.2xlarge Notebook Instance Type.

---

##### `ML_R5_4XLARGE`<sup>Required</sup> <a name="ML_R5_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_4XLARGE"></a>

```typescript
public readonly ML_R5_4XLARGE: string;
```

- *Type:* string

ml.r5.4xlarge Notebook Instance Type.

---

##### `ML_R5_8XLARGE`<sup>Required</sup> <a name="ML_R5_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_8XLARGE"></a>

```typescript
public readonly ML_R5_8XLARGE: string;
```

- *Type:* string

ml.r5.8xlarge Notebook Instance Type.

---

##### `ML_R5_LARGE`<sup>Required</sup> <a name="ML_R5_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_LARGE"></a>

```typescript
public readonly ML_R5_LARGE: string;
```

- *Type:* string

ml.r5.large Notebook Instance Type.

---

##### `ML_R5_XLARGE`<sup>Required</sup> <a name="ML_R5_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5_XLARGE"></a>

```typescript
public readonly ML_R5_XLARGE: string;
```

- *Type:* string

ml.r5.xlarge Notebook Instance Type.

---

##### `ML_R5D_12XLARGE`<sup>Required</sup> <a name="ML_R5D_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_12XLARGE"></a>

```typescript
public readonly ML_R5D_12XLARGE: string;
```

- *Type:* string

ml.r5d.12xlarge Notebook Instance Type.

---

##### `ML_R5D_16XLARGE`<sup>Required</sup> <a name="ML_R5D_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_16XLARGE"></a>

```typescript
public readonly ML_R5D_16XLARGE: string;
```

- *Type:* string

ml.r5d.16xlarge Notebook Instance Type.

---

##### `ML_R5D_24XLARGE`<sup>Required</sup> <a name="ML_R5D_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_24XLARGE"></a>

```typescript
public readonly ML_R5D_24XLARGE: string;
```

- *Type:* string

ml.r5d.24xlarge Notebook Instance Type.

---

##### `ML_R5D_2XLARGE`<sup>Required</sup> <a name="ML_R5D_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_2XLARGE"></a>

```typescript
public readonly ML_R5D_2XLARGE: string;
```

- *Type:* string

ml.r5d.2xlarge Notebook Instance Type.

---

##### `ML_R5D_4XLARGE`<sup>Required</sup> <a name="ML_R5D_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_4XLARGE"></a>

```typescript
public readonly ML_R5D_4XLARGE: string;
```

- *Type:* string

ml.r5d.4xlarge Notebook Instance Type.

---

##### `ML_R5D_8XLARGE`<sup>Required</sup> <a name="ML_R5D_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_8XLARGE"></a>

```typescript
public readonly ML_R5D_8XLARGE: string;
```

- *Type:* string

ml.r5d.8xlarge Notebook Instance Type.

---

##### `ML_R5D_LARGE`<sup>Required</sup> <a name="ML_R5D_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_LARGE"></a>

```typescript
public readonly ML_R5D_LARGE: string;
```

- *Type:* string

ml.r5d.large Notebook Instance Type.

---

##### `ML_R5D_XLARGE`<sup>Required</sup> <a name="ML_R5D_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R5D_XLARGE"></a>

```typescript
public readonly ML_R5D_XLARGE: string;
```

- *Type:* string

ml.r5d.xlarge Notebook Instance Type.

---

##### `ML_R6G_12XLARGE`<sup>Required</sup> <a name="ML_R6G_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_12XLARGE"></a>

```typescript
public readonly ML_R6G_12XLARGE: string;
```

- *Type:* string

ml.r6g.12xlarge Notebook Instance Type.

---

##### `ML_R6G_16XLARGE`<sup>Required</sup> <a name="ML_R6G_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_16XLARGE"></a>

```typescript
public readonly ML_R6G_16XLARGE: string;
```

- *Type:* string

ml.r6g.16xlarge Notebook Instance Type.

---

##### `ML_R6G_2XLARGE`<sup>Required</sup> <a name="ML_R6G_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_2XLARGE"></a>

```typescript
public readonly ML_R6G_2XLARGE: string;
```

- *Type:* string

ml.r6g.2xlarge Notebook Instance Type.

---

##### `ML_R6G_4XLARGE`<sup>Required</sup> <a name="ML_R6G_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_4XLARGE"></a>

```typescript
public readonly ML_R6G_4XLARGE: string;
```

- *Type:* string

ml.r6g.4xlarge Notebook Instance Type.

---

##### `ML_R6G_8XLARGE`<sup>Required</sup> <a name="ML_R6G_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_8XLARGE"></a>

```typescript
public readonly ML_R6G_8XLARGE: string;
```

- *Type:* string

ml.r6g.8xlarge Notebook Instance Type.

---

##### `ML_R6G_LARGE`<sup>Required</sup> <a name="ML_R6G_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_LARGE"></a>

```typescript
public readonly ML_R6G_LARGE: string;
```

- *Type:* string

ml.r6g.large Notebook Instance Type.

---

##### `ML_R6G_XLARGE`<sup>Required</sup> <a name="ML_R6G_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6G_XLARGE"></a>

```typescript
public readonly ML_R6G_XLARGE: string;
```

- *Type:* string

ml.r6g.xlarge Notebook Instance Type.

---

##### `ML_R6GD_12XLARGE`<sup>Required</sup> <a name="ML_R6GD_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_12XLARGE"></a>

```typescript
public readonly ML_R6GD_12XLARGE: string;
```

- *Type:* string

ml.r6gd.12xlarge Notebook Instance Type.

---

##### `ML_R6GD_16XLARGE`<sup>Required</sup> <a name="ML_R6GD_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_16XLARGE"></a>

```typescript
public readonly ML_R6GD_16XLARGE: string;
```

- *Type:* string

ml.r6gd.16xlarge Notebook Instance Type.

---

##### `ML_R6GD_2XLARGE`<sup>Required</sup> <a name="ML_R6GD_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_2XLARGE"></a>

```typescript
public readonly ML_R6GD_2XLARGE: string;
```

- *Type:* string

ml.r6gd.2xlarge Notebook Instance Type.

---

##### `ML_R6GD_4XLARGE`<sup>Required</sup> <a name="ML_R6GD_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_4XLARGE"></a>

```typescript
public readonly ML_R6GD_4XLARGE: string;
```

- *Type:* string

ml.r6gd.4xlarge Notebook Instance Type.

---

##### `ML_R6GD_8XLARGE`<sup>Required</sup> <a name="ML_R6GD_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_8XLARGE"></a>

```typescript
public readonly ML_R6GD_8XLARGE: string;
```

- *Type:* string

ml.r6gd.8xlarge Notebook Instance Type.

---

##### `ML_R6GD_LARGE`<sup>Required</sup> <a name="ML_R6GD_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_LARGE"></a>

```typescript
public readonly ML_R6GD_LARGE: string;
```

- *Type:* string

ml.r6gd.large Notebook Instance Type.

---

##### `ML_R6GD_XLARGE`<sup>Required</sup> <a name="ML_R6GD_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6GD_XLARGE"></a>

```typescript
public readonly ML_R6GD_XLARGE: string;
```

- *Type:* string

ml.r6gd.xlarge Notebook Instance Type.

---

##### `ML_R6I_12XLARGE`<sup>Required</sup> <a name="ML_R6I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_12XLARGE"></a>

```typescript
public readonly ML_R6I_12XLARGE: string;
```

- *Type:* string

ml.r6i.12xlarge Notebook Instance Type.

---

##### `ML_R6I_16XLARGE`<sup>Required</sup> <a name="ML_R6I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_16XLARGE"></a>

```typescript
public readonly ML_R6I_16XLARGE: string;
```

- *Type:* string

ml.r6i.16xlarge Notebook Instance Type.

---

##### `ML_R6I_24XLARGE`<sup>Required</sup> <a name="ML_R6I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_24XLARGE"></a>

```typescript
public readonly ML_R6I_24XLARGE: string;
```

- *Type:* string

ml.r6i.24xlarge Notebook Instance Type.

---

##### `ML_R6I_2XLARGE`<sup>Required</sup> <a name="ML_R6I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_2XLARGE"></a>

```typescript
public readonly ML_R6I_2XLARGE: string;
```

- *Type:* string

ml.r6i.2xlarge Notebook Instance Type.

---

##### `ML_R6I_32XLARGE`<sup>Required</sup> <a name="ML_R6I_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_32XLARGE"></a>

```typescript
public readonly ML_R6I_32XLARGE: string;
```

- *Type:* string

ml.r6i.32xlarge Notebook Instance Type.

---

##### `ML_R6I_4XLARGE`<sup>Required</sup> <a name="ML_R6I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_4XLARGE"></a>

```typescript
public readonly ML_R6I_4XLARGE: string;
```

- *Type:* string

ml.r6i.4xlarge Notebook Instance Type.

---

##### `ML_R6I_8XLARGE`<sup>Required</sup> <a name="ML_R6I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_8XLARGE"></a>

```typescript
public readonly ML_R6I_8XLARGE: string;
```

- *Type:* string

ml.r6i.8xlarge Notebook Instance Type.

---

##### `ML_R6I_LARGE`<sup>Required</sup> <a name="ML_R6I_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_LARGE"></a>

```typescript
public readonly ML_R6I_LARGE: string;
```

- *Type:* string

ml.r6i.large Notebook Instance Type.

---

##### `ML_R6I_XLARGE`<sup>Required</sup> <a name="ML_R6I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6I_XLARGE"></a>

```typescript
public readonly ML_R6I_XLARGE: string;
```

- *Type:* string

ml.r6i.xlarge Notebook Instance Type.

---

##### `ML_R6ID_12XLARGE`<sup>Required</sup> <a name="ML_R6ID_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_12XLARGE"></a>

```typescript
public readonly ML_R6ID_12XLARGE: string;
```

- *Type:* string

ml.r6id.12xlarge Notebook Instance Type.

---

##### `ML_R6ID_16XLARGE`<sup>Required</sup> <a name="ML_R6ID_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_16XLARGE"></a>

```typescript
public readonly ML_R6ID_16XLARGE: string;
```

- *Type:* string

ml.r6id.16xlarge Notebook Instance Type.

---

##### `ML_R6ID_24XLARGE`<sup>Required</sup> <a name="ML_R6ID_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_24XLARGE"></a>

```typescript
public readonly ML_R6ID_24XLARGE: string;
```

- *Type:* string

ml.r6id.24xlarge Notebook Instance Type.

---

##### `ML_R6ID_2XLARGE`<sup>Required</sup> <a name="ML_R6ID_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_2XLARGE"></a>

```typescript
public readonly ML_R6ID_2XLARGE: string;
```

- *Type:* string

ml.r6id.2xlarge Notebook Instance Type.

---

##### `ML_R6ID_32XLARGE`<sup>Required</sup> <a name="ML_R6ID_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_32XLARGE"></a>

```typescript
public readonly ML_R6ID_32XLARGE: string;
```

- *Type:* string

ml.r6id.32xlarge Notebook Instance Type.

---

##### `ML_R6ID_4XLARGE`<sup>Required</sup> <a name="ML_R6ID_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_4XLARGE"></a>

```typescript
public readonly ML_R6ID_4XLARGE: string;
```

- *Type:* string

ml.r6id.4xlarge Notebook Instance Type.

---

##### `ML_R6ID_8XLARGE`<sup>Required</sup> <a name="ML_R6ID_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_8XLARGE"></a>

```typescript
public readonly ML_R6ID_8XLARGE: string;
```

- *Type:* string

ml.r6id.8xlarge Notebook Instance Type.

---

##### `ML_R6ID_LARGE`<sup>Required</sup> <a name="ML_R6ID_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_LARGE"></a>

```typescript
public readonly ML_R6ID_LARGE: string;
```

- *Type:* string

ml.r6id.large Notebook Instance Type.

---

##### `ML_R6ID_XLARGE`<sup>Required</sup> <a name="ML_R6ID_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R6ID_XLARGE"></a>

```typescript
public readonly ML_R6ID_XLARGE: string;
```

- *Type:* string

ml.r6id.xlarge Notebook Instance Type.

---

##### `ML_R7I_12XLARGE`<sup>Required</sup> <a name="ML_R7I_12XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_12XLARGE"></a>

```typescript
public readonly ML_R7I_12XLARGE: string;
```

- *Type:* string

ml.r7i.12xlarge Notebook Instance Type.

---

##### `ML_R7I_16XLARGE`<sup>Required</sup> <a name="ML_R7I_16XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_16XLARGE"></a>

```typescript
public readonly ML_R7I_16XLARGE: string;
```

- *Type:* string

ml.r7i.16xlarge Notebook Instance Type.

---

##### `ML_R7I_24XLARGE`<sup>Required</sup> <a name="ML_R7I_24XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_24XLARGE"></a>

```typescript
public readonly ML_R7I_24XLARGE: string;
```

- *Type:* string

ml.r7i.24xlarge Notebook Instance Type.

---

##### `ML_R7I_2XLARGE`<sup>Required</sup> <a name="ML_R7I_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_2XLARGE"></a>

```typescript
public readonly ML_R7I_2XLARGE: string;
```

- *Type:* string

ml.r7i.2xlarge Notebook Instance Type.

---

##### `ML_R7I_48XLARGE`<sup>Required</sup> <a name="ML_R7I_48XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_48XLARGE"></a>

```typescript
public readonly ML_R7I_48XLARGE: string;
```

- *Type:* string

ml.r7i.48xlarge Notebook Instance Type.

---

##### `ML_R7I_4XLARGE`<sup>Required</sup> <a name="ML_R7I_4XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_4XLARGE"></a>

```typescript
public readonly ML_R7I_4XLARGE: string;
```

- *Type:* string

ml.r7i.4xlarge Notebook Instance Type.

---

##### `ML_R7I_8XLARGE`<sup>Required</sup> <a name="ML_R7I_8XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_8XLARGE"></a>

```typescript
public readonly ML_R7I_8XLARGE: string;
```

- *Type:* string

ml.r7i.8xlarge Notebook Instance Type.

---

##### `ML_R7I_LARGE`<sup>Required</sup> <a name="ML_R7I_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_LARGE"></a>

```typescript
public readonly ML_R7I_LARGE: string;
```

- *Type:* string

ml.r7i.large Notebook Instance Type.

---

##### `ML_R7I_XLARGE`<sup>Required</sup> <a name="ML_R7I_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_R7I_XLARGE"></a>

```typescript
public readonly ML_R7I_XLARGE: string;
```

- *Type:* string

ml.r7i.xlarge Notebook Instance Type.

---

##### `ML_T2_2XLARGE`<sup>Required</sup> <a name="ML_T2_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_2XLARGE"></a>

```typescript
public readonly ML_T2_2XLARGE: string;
```

- *Type:* string

ml.t2.2xlarge Notebook Instance Type.

---

##### `ML_T2_LARGE`<sup>Required</sup> <a name="ML_T2_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_LARGE"></a>

```typescript
public readonly ML_T2_LARGE: string;
```

- *Type:* string

ml.t2.large Notebook Instance Type.

---

##### `ML_T2_MEDIUM`<sup>Required</sup> <a name="ML_T2_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_MEDIUM"></a>

```typescript
public readonly ML_T2_MEDIUM: string;
```

- *Type:* string

ml.t2.medium Notebook Instance Type.

---

##### `ML_T2_XLARGE`<sup>Required</sup> <a name="ML_T2_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T2_XLARGE"></a>

```typescript
public readonly ML_T2_XLARGE: string;
```

- *Type:* string

ml.t2.xlarge Notebook Instance Type.

---

##### `ML_T3_2XLARGE`<sup>Required</sup> <a name="ML_T3_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_2XLARGE"></a>

```typescript
public readonly ML_T3_2XLARGE: string;
```

- *Type:* string

ml.t3.2xlarge Notebook Instance Type.

---

##### `ML_T3_LARGE`<sup>Required</sup> <a name="ML_T3_LARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_LARGE"></a>

```typescript
public readonly ML_T3_LARGE: string;
```

- *Type:* string

ml.t3.large Notebook Instance Type.

---

##### `ML_T3_MEDIUM`<sup>Required</sup> <a name="ML_T3_MEDIUM" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_MEDIUM"></a>

```typescript
public readonly ML_T3_MEDIUM: string;
```

- *Type:* string

ml.t3.medium Notebook Instance Type.

---

##### `ML_T3_XLARGE`<sup>Required</sup> <a name="ML_T3_XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_T3_XLARGE"></a>

```typescript
public readonly ML_T3_XLARGE: string;
```

- *Type:* string

ml.t3.xlarge Notebook Instance Type.

---

##### `ML_TRN1_2XLARGE`<sup>Required</sup> <a name="ML_TRN1_2XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_TRN1_2XLARGE"></a>

```typescript
public readonly ML_TRN1_2XLARGE: string;
```

- *Type:* string

ml.trn1.2xlarge Notebook Instance Type.

---

##### `ML_TRN1_32XLARGE`<sup>Required</sup> <a name="ML_TRN1_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_TRN1_32XLARGE"></a>

```typescript
public readonly ML_TRN1_32XLARGE: string;
```

- *Type:* string

ml.trn1.32xlarge Notebook Instance Type.

---

##### `ML_TRN1N_32XLARGE`<sup>Required</sup> <a name="ML_TRN1N_32XLARGE" id="@cdklabs/cdk-proserve-lib.types.SageMakerNotebookInstanceType.property.ML_TRN1N_32XLARGE"></a>

```typescript
public readonly ML_TRN1N_32XLARGE: string;
```

- *Type:* string

ml.trn1n.32xlarge Notebook Instance Type.

---

### SecureSageMakerNotebook <a name="SecureSageMakerNotebook" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook"></a>

- *Implements:* aws-cdk-lib.IAspect

Aspect that enforces security controls on SageMaker Notebook Instances by requiring VPC placement, disabling direct internet access, and preventing root access to the notebook environment.

This Aspect enforces these settings through a combination of setting
the CloudFormation properties on the Notebook resource and attaching a
DENY policy to the role that is used by the notebook. The policy will enforce
that the following API actions contain the correct properties to ensure
network isolation and that the VPC subnets are set:

- 'sagemaker:CreateTrainingJob',
- 'sagemaker:CreateHyperParameterTuningJob',
- 'sagemaker:CreateModel',
- 'sagemaker:CreateProcessingJob'

#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.SecureSageMakerNotebook(props: SecureSageMakerNotebookProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps</code> | *No description.* |

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebookProps

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook.visit">visit</a></code> | All aspects can visit an IConstruct. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook.visit"></a>

```typescript
public visit(node: IConstruct): void
```

All aspects can visit an IConstruct.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.SecureSageMakerNotebook.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

---




### SecurityCompliance <a name="SecurityCompliance" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance"></a>

- *Implements:* aws-cdk-lib.IAspect

Applies best practice security settings to be in compliance with security tools such as CDK Nag.

This aspect automatically implements AWS security best practices and compliance
requirements for various AWS services used in your CDK applications.
It can be configured with custom settings and supports suppressing specific
CDK Nag warnings with proper justification.

*Example*

```typescript
import { App, Stack, Aspects } from 'aws-cdk-lib';
import { Function, Runtime, Code } from 'aws-cdk-lib/aws-lambda';
import { Bucket } from 'aws-cdk-lib/aws-s3';
import { SecurityCompliance } from '../../../src/aspects/security-compliance';

const app = new App();
const stack = new Stack(app, 'MySecureStack');

// Create resources
const myBucket = new Bucket(stack, 'MyBucket');
const myFunction = new Function(stack, 'MyFunction', {
    runtime: Runtime.NODEJS_18_X,
    handler: 'index.handler',
    code: Code.fromInline(
        'exports.handler = async () => { return { statusCode: 200 }; }'
    )
});

// Apply the SecurityCompliance aspect with custom settings
const securityAspect = new SecurityCompliance({
    settings: {
        s3: {
            serverAccessLogs: {
                destinationBucketName: 'my-access-logs-bucket'
            },
            versioning: {
                disabled: false
            }
        },
        lambda: {
            reservedConcurrentExecutions: {
                concurrentExecutionCount: 5
            }
        }
    },
    suppressions: {
        lambdaNotInVpc:
            'This is a development environment where VPC is not required',
        iamNoInlinePolicies: 'Inline policies are acceptable for this use case'
    }
});

// Apply the aspect to the stack
Aspects.of(app).add(securityAspect);
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.SecurityCompliance(props?: SecurityComplianceProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps</code> | *No description.* |

---

##### `props`<sup>Optional</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SecurityComplianceProps

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.visit">visit</a></code> | Apply the aspect to the node. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.visit"></a>

```typescript
public visit(node: IConstruct): void
```

Apply the aspect to the node.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.SecurityCompliance.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

---




### SetLogRetention <a name="SetLogRetention" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetention"></a>

- *Implements:* aws-cdk-lib.IAspect

Aspect that sets the log retention period for CloudWatch log groups to a user-supplied retention period.

*Example*

```typescript
import { App, Aspects } from 'aws-cdk-lib';
import { RetentionDays } from 'aws-cdk-lib/aws-logs';
import { SetLogRetention } from '@cdklabs/cdk-proserve-lib/aspects';

const app = new App();

Aspects.of(app).add(
  new SetLogRetention({ period: RetentionDays.EIGHTEEN_MONTHS })
);
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetention.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.SetLogRetention(props: SetLogRetentionProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SetLogRetention.Initializer.parameter.props">props</a></code> | <code>@cdklabs/cdk-proserve-lib.aspects.SetLogRetentionProps</code> | Configuration properties for log retention. |

---

##### `props`<sup>Required</sup> <a name="props" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetention.Initializer.parameter.props"></a>

- *Type:* @cdklabs/cdk-proserve-lib.aspects.SetLogRetentionProps

Configuration properties for log retention.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SetLogRetention.visit">visit</a></code> | Visits a construct and sets log retention if applicable. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetention.visit"></a>

```typescript
public visit(node: IConstruct): void
```

Visits a construct and sets log retention if applicable.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.SetLogRetention.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

The construct being visited.

---




### SqsRequireSsl <a name="SqsRequireSsl" id="@cdklabs/cdk-proserve-lib.aspects.SqsRequireSsl"></a>

- *Implements:* aws-cdk-lib.IAspect

Enforces SSL/TLS requirements on Simple Queue Service (SQS) for all resources that the aspect applies to.

This is accomplished by adding a resource policy to any SQS queue that denies
all actions when the request is not made over a secure transport.

*Example*

```typescript
import { App, Aspects } from 'aws-cdk-lib';
import { SqsRequireSsl } from '@cdklabs/cdk-proserve-lib/aspects';

const app = new App();

Aspects.of(app).add(new SqsRequireSsl());
```


#### Initializers <a name="Initializers" id="@cdklabs/cdk-proserve-lib.aspects.SqsRequireSsl.Initializer"></a>

```typescript
import { aspects } from '@cdklabs/cdk-proserve-lib'

new aspects.SqsRequireSsl()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.SqsRequireSsl.visit">visit</a></code> | Visits a construct and adds SSL/TLS requirement policy if it's an SQS queue. |

---

##### `visit` <a name="visit" id="@cdklabs/cdk-proserve-lib.aspects.SqsRequireSsl.visit"></a>

```typescript
public visit(node: IConstruct): void
```

Visits a construct and adds SSL/TLS requirement policy if it's an SQS queue.

###### `node`<sup>Required</sup> <a name="node" id="@cdklabs/cdk-proserve-lib.aspects.SqsRequireSsl.visit.parameter.node"></a>

- *Type:* constructs.IConstruct

The construct being visited.

---





## Enums <a name="Enums" id="Enums"></a>

### AwsManagedRuleGroup <a name="AwsManagedRuleGroup" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup"></a>

WAF Managed Rule Groups.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.COMMON_RULE_SET">COMMON_RULE_SET</a></code> | Contains rules that are generally applicable to web applications. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ADMIN_PROTECTION_RULE_SET">ADMIN_PROTECTION_RULE_SET</a></code> | Contains rules that allow you to block external access to exposed admin pages. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.KNOWN_BAD_INPUTS_RULE_SET">KNOWN_BAD_INPUTS_RULE_SET</a></code> | Contains rules that allow you to block request patterns that are known to be invalid and are associated with exploitation or discovery of vulnerabilities. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.SQL_DATABASE_RULE_SET">SQL_DATABASE_RULE_SET</a></code> | Contains rules that allow you to block request patterns associated with exploitation of SQL databases, like SQL injection attacks. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.LINUX_RULE_SET">LINUX_RULE_SET</a></code> | Contains rules that block request patterns associated with exploitation of vulnerabilities specific to Linux, including LFI attacks. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.UNIX_RULE_SET">UNIX_RULE_SET</a></code> | Contains rules that block request patterns associated with exploiting vulnerabilities specific to POSIX/POSIX-like OS, including LFI attacks. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.WINDOWS_RULE_SET">WINDOWS_RULE_SET</a></code> | Contains rules that block request patterns associated with exploiting vulnerabilities specific to Windows, (e.g., PowerShell commands). This can help prevent exploits that allow attacker to run unauthorized commands or execute malicious code. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.PHP_RULE_SET">PHP_RULE_SET</a></code> | Contains rules that block request patterns associated with exploiting vulnerabilities specific to the use of the PHP, including injection of unsafe PHP functions. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.WORD_PRESS_RULE_SET">WORD_PRESS_RULE_SET</a></code> | The WordPress Applications group contains rules that block request patterns associated with the exploitation of vulnerabilities specific to WordPress sites. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.AMAZON_IP_REPUTATION_LIST">AMAZON_IP_REPUTATION_LIST</a></code> | This group contains rules that are based on Amazon threat intelligence. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ANONYMOUS_IP_LIST">ANONYMOUS_IP_LIST</a></code> | This group contains rules that allow you to block requests from services that allow obfuscation of viewer identity. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.BOT_CONTROL_RULE_SET">BOT_CONTROL_RULE_SET</a></code> | Provides protection against automated bots that can consume excess resources, skew business metrics, cause downtime, or perform malicious activities. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ATP_RULE_SET">ATP_RULE_SET</a></code> | Provides protection for your login page against stolen credentials, credential stuffing attacks, brute force login attempts, and other anomalous login activities. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ACFP_RULE_SET">ACFP_RULE_SET</a></code> | Provides protection against the creation of fraudulent accounts on your site. |

---

##### `COMMON_RULE_SET` <a name="COMMON_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.COMMON_RULE_SET"></a>

Contains rules that are generally applicable to web applications.

This provides protection against exploitation of a wide range of vulnerabilities, including those described in OWASP publications.

---


##### `ADMIN_PROTECTION_RULE_SET` <a name="ADMIN_PROTECTION_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ADMIN_PROTECTION_RULE_SET"></a>

Contains rules that allow you to block external access to exposed admin pages.

This may be useful if you are running third-party software or would like to reduce the risk of a malicious actor gaining administrative access to your application.

---


##### `KNOWN_BAD_INPUTS_RULE_SET` <a name="KNOWN_BAD_INPUTS_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.KNOWN_BAD_INPUTS_RULE_SET"></a>

Contains rules that allow you to block request patterns that are known to be invalid and are associated with exploitation or discovery of vulnerabilities.

This can help reduce the risk of a malicious actor discovering a vulnerable application.

---


##### `SQL_DATABASE_RULE_SET` <a name="SQL_DATABASE_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.SQL_DATABASE_RULE_SET"></a>

Contains rules that allow you to block request patterns associated with exploitation of SQL databases, like SQL injection attacks.

This can help prevent remote injection of unauthorized queries.

---


##### `LINUX_RULE_SET` <a name="LINUX_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.LINUX_RULE_SET"></a>

Contains rules that block request patterns associated with exploitation of vulnerabilities specific to Linux, including LFI attacks.

This can help prevent attacks that expose file contents or execute code for which the attacker should not have had access.

---


##### `UNIX_RULE_SET` <a name="UNIX_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.UNIX_RULE_SET"></a>

Contains rules that block request patterns associated with exploiting vulnerabilities specific to POSIX/POSIX-like OS, including LFI attacks.

This can help prevent attacks that expose file contents or execute code for which access should not been allowed.

---


##### `WINDOWS_RULE_SET` <a name="WINDOWS_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.WINDOWS_RULE_SET"></a>

Contains rules that block request patterns associated with exploiting vulnerabilities specific to Windows, (e.g., PowerShell commands). This can help prevent exploits that allow attacker to run unauthorized commands or execute malicious code.

---


##### `PHP_RULE_SET` <a name="PHP_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.PHP_RULE_SET"></a>

Contains rules that block request patterns associated with exploiting vulnerabilities specific to the use of the PHP, including injection of unsafe PHP functions.

This can help prevent exploits that allow an attacker to remotely execute code or commands.

---


##### `WORD_PRESS_RULE_SET` <a name="WORD_PRESS_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.WORD_PRESS_RULE_SET"></a>

The WordPress Applications group contains rules that block request patterns associated with the exploitation of vulnerabilities specific to WordPress sites.

---


##### `AMAZON_IP_REPUTATION_LIST` <a name="AMAZON_IP_REPUTATION_LIST" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.AMAZON_IP_REPUTATION_LIST"></a>

This group contains rules that are based on Amazon threat intelligence.

This is useful if you would like to block sources associated with bots or other threats.

---


##### `ANONYMOUS_IP_LIST` <a name="ANONYMOUS_IP_LIST" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ANONYMOUS_IP_LIST"></a>

This group contains rules that allow you to block requests from services that allow obfuscation of viewer identity.

This can include request originating from VPN, proxies, Tor nodes, and hosting providers. This is useful if you want to filter out viewers that may be trying to hide their identity from your application.

---


##### `BOT_CONTROL_RULE_SET` <a name="BOT_CONTROL_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.BOT_CONTROL_RULE_SET"></a>

Provides protection against automated bots that can consume excess resources, skew business metrics, cause downtime, or perform malicious activities.

Bot Control provides additional visibility through Amazon CloudWatch and generates labels that you can use to control bot traffic to your applications.

---


##### `ATP_RULE_SET` <a name="ATP_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ATP_RULE_SET"></a>

Provides protection for your login page against stolen credentials, credential stuffing attacks, brute force login attempts, and other anomalous login activities.

With account takeover prevention, you can prevent unauthorized access that may lead to fraudulent activities, or inform legitimate users to take a preventive action.

---


##### `ACFP_RULE_SET` <a name="ACFP_RULE_SET" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.AwsManagedRuleGroup.ACFP_RULE_SET"></a>

Provides protection against the creation of fraudulent accounts on your site.

Fraudulent accounts can be used for activities such as obtaining sign-up bonuses and impersonating legitimate users.

---


### Component <a name="Component" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component"></a>

Image Builder Component.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CLOUDWATCH_AGENT_LINUX">AMAZON_CLOUDWATCH_AGENT_LINUX</a></code> | Installs the latest version of the Amazon CloudWatch agent. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CLOUDWATCH_AGENT_WINDOWS">AMAZON_CLOUDWATCH_AGENT_WINDOWS</a></code> | Installs the latest version of the Amazon CloudWatch agent. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_APT_GENERIC">AMAZON_CORRETTO_11_APT_GENERIC</a></code> | Installs Amazon Corretto 11 for Debian-based Linux platforms in accordance with the Amazon Corretto 11 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-11-ug/generic-linux-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_HEADLESS">AMAZON_CORRETTO_11_HEADLESS</a></code> | Installs Amazon Corretto 11 Headless. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_RPM_GENERIC">AMAZON_CORRETTO_11_RPM_GENERIC</a></code> | Installs Amazon Corretto 11 for RPM-based Linux platforms in accordance with the Amazon Corretto 11 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-11-ug/generic-linux-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_WINDOWS">AMAZON_CORRETTO_11_WINDOWS</a></code> | Installs Amazon Corretto 11 for Windows in accordance with the Amazon Corretto 11 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-11-ug/windows-7-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11">AMAZON_CORRETTO_11</a></code> | Installs Amazon Corretto 11. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_HEADLESS">AMAZON_CORRETTO_17_HEADLESS</a></code> | Installs Amazon Corretto 17 Headless. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_JDK">AMAZON_CORRETTO_17_JDK</a></code> | Installs Amazon Corretto 17 JDK in accordance with the Amazon Corretto 17 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-17-ug/linux-info.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_JRE">AMAZON_CORRETTO_17_JRE</a></code> | Installs Amazon Corretto 17 JRE. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_WINDOWS">AMAZON_CORRETTO_17_WINDOWS</a></code> | Installs Amazon Corretto 17 for Windows in accordance with the Amazon Corretto 17 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-17-ug/windows-7-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_HEADLESS">AMAZON_CORRETTO_21_HEADLESS</a></code> | Installs Amazon Corretto 21 Headless. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_JDK">AMAZON_CORRETTO_21_JDK</a></code> | Installs Amazon Corretto 21 JDK in accordance with the Amazon Corretto 21 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-21-ug/linux-info.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_JRE">AMAZON_CORRETTO_21_JRE</a></code> | Installs Amazon Corretto 21 JRE. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_WINDOWS">AMAZON_CORRETTO_21_WINDOWS</a></code> | Installs Amazon Corretto 21 for Windows in accordance with the Amazon Corretto 21 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-21-ug/windows-10-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_APT_GENERIC">AMAZON_CORRETTO_8_APT_GENERIC</a></code> | Installs Amazon Corretto 8 for Debian-based Linux platforms in accordance with the Amazon Corretto 8 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-8-ug/generic-linux-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_JDK">AMAZON_CORRETTO_8_JDK</a></code> | Installs Amazon Corretto 8 JDK. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_JRE">AMAZON_CORRETTO_8_JRE</a></code> | Installs Amazon Corretto 8 JRE. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_RPM_GENERIC">AMAZON_CORRETTO_8_RPM_GENERIC</a></code> | Installs Amazon Corretto 8 for RPM-based Linux platforms in accordance with the Amazon Corretto 8 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-8-ug/generic-linux-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_WINDOWS">AMAZON_CORRETTO_8_WINDOWS</a></code> | Installs Amazon Corretto 8 for Windows in accordance with the Amazon Corretto 8 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-8-ug/windows-7-install.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_KINESIS_AGENT_WINDOWS">AMAZON_KINESIS_AGENT_WINDOWS</a></code> | Installs the latest version of Amazon Kinesis Agent for Windows. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ANACONDA_WINDOWS">ANACONDA_WINDOWS</a></code> | Installs the Anaconda distribution and environments for Tensorflow, PyTorch, and MXNet. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.APACHE_TOMCAT_9_LINUX">APACHE_TOMCAT_9_LINUX</a></code> | Installs the latest version of Apache Tomcat and the JRE, sets required environment variables, and schedules Tomcat to run on startup. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.APT_REPOSITORY_TEST_LINUX">APT_REPOSITORY_TEST_LINUX</a></code> | Tests whether the apt package manager is functioning correctly. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CLI_VERSION_2_LINUX">AWS_CLI_VERSION_2_LINUX</a></code> | Installs the latest version of the AWS CLI version 2, and creates the symlink /usr/bin/aws that points to the installed application. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CLI_VERSION_2_WINDOWS">AWS_CLI_VERSION_2_WINDOWS</a></code> | Installs the latest version of the AWS CLI version 2. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CODEDEPLOY_AGENT_LINUX">AWS_CODEDEPLOY_AGENT_LINUX</a></code> | Installs the latest version of the AWS CodeDeploy agent. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CODEDEPLOY_AGENT_WINDOWS">AWS_CODEDEPLOY_AGENT_WINDOWS</a></code> | Installs the latest version of the AWS CodeDeploy agent. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_VSS_COMPONENTS_WINDOWS">AWS_VSS_COMPONENTS_WINDOWS</a></code> | Installs the AwsVssComponents Distributor package on a Windows instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.CHOCOLATEY">CHOCOLATEY</a></code> | Installs Chocolatey for Windows. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.CHRONY_TIME_CONFIGURATION_TEST">CHRONY_TIME_CONFIGURATION_TEST</a></code> | Validates the Chrony configuration file and ensures that Chrony time sources on Amazon Linux 2 are configured for the Amazon time servers. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DCV_SERVER_LINUX">DCV_SERVER_LINUX</a></code> | Install and configure the latest NICE DCV server on Linux. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DCV_SERVER_WINDOWS">DCV_SERVER_WINDOWS</a></code> | Install and configure the latest NICE DCV server on Windows. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DISTRIBUTOR_PACKAGE_WINDOWS">DISTRIBUTOR_PACKAGE_WINDOWS</a></code> | Installs a Distributor package on a Windows instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOCKER_CE_CENTOS">DOCKER_CE_CENTOS</a></code> | Installs Docker Community Edition from the Docker package repository, and enables the centos user to manage Docker without using sudo. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOCKER_CE_LINUX">DOCKER_CE_LINUX</a></code> | Install the latest Docker Community Edition from Amazon Linux Extras, and enable the ec2-user user to manage docker without using sudo. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOCKER_CE_UBUNTU">DOCKER_CE_UBUNTU</a></code> | Installs Docker Community Edition from the Docker package repository, and enables the ubuntu user to manage Docker without using sudo. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_DESKTOP_RUNTIME_LTS_WINDOWS">DOTNET_DESKTOP_RUNTIME_LTS_WINDOWS</a></code> | Installs the latest 8.0 channel release of the Microsoft .NET Desktop Runtime. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_HOSTING_BUNDLE_LTS_WINDOWS">DOTNET_HOSTING_BUNDLE_LTS_WINDOWS</a></code> | Installs the latest 8.0 channel release of the Microsoft .NET Hosting Bundle. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_RUNTIME_LTS_LINUX">DOTNET_RUNTIME_LTS_LINUX</a></code> | Installs the latest 8.0 channel release of the Microsoft .NET Runtime. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_RUNTIME_LTS_WINDOWS">DOTNET_RUNTIME_LTS_WINDOWS</a></code> | Installs the latest 8.0 channel release of the Microsoft .NET Runtime. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_SDK_LTS_LINUX">DOTNET_SDK_LTS_LINUX</a></code> | Installs the latest 8.0 channel release of the Microsoft .NET SDK. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_SDK_LTS_WINDOWS">DOTNET_SDK_LTS_WINDOWS</a></code> | Installs the latest 8.0 channel release of the Microsoft .NET SDK. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EBS_VOLUME_USAGE_TEST_LINUX">EBS_VOLUME_USAGE_TEST_LINUX</a></code> | The EBS volume usage test performs the following actions: 1) It creates an EBS volume and attaches it to the instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EBS_VOLUME_USAGE_TEST_WINDOWS">EBS_VOLUME_USAGE_TEST_WINDOWS</a></code> | The EBS volume usage test performs the following actions: 1) It creates an EBS volume and attaches it to the instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EC2_NETWORK_ROUTE_TEST_WINDOWS">EC2_NETWORK_ROUTE_TEST_WINDOWS</a></code> | Test to ensure all required EC2 network routes exist in the route table. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EC2LAUNCH_V2_WINDOWS">EC2LAUNCH_V2_WINDOWS</a></code> | Installs the latest version of EC2Launch v2. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ECS_OPTIMIZED_AMI_WINDOWS">ECS_OPTIMIZED_AMI_WINDOWS</a></code> | Installs Amazon ECS-optimized Windows artifacts. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EKS_OPTIMIZED_AMI_WINDOWS">EKS_OPTIMIZED_AMI_WINDOWS</a></code> | Installs Amazon EKS-optimized Windows artifacts for Amazon EKS version 1.32. This includes kubelet version 1.32.0, containerd version 1.7.20, and CSI Proxy version 1.1.2. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ENI_ATTACHMENT_TEST_LINUX">ENI_ATTACHMENT_TEST_LINUX</a></code> | The ENI attachment test performs the following actions: 1) It creates an elastic network interface (ENI) and attaches it to the instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ENI_ATTACHMENT_TEST_WINDOWS">ENI_ATTACHMENT_TEST_WINDOWS</a></code> | The ENI attachment test performs the following actions: 1) It creates an elastic network interface (ENI) and attaches it to the instance. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.GO_STABLE_LINUX">GO_STABLE_LINUX</a></code> | Installs the latest stable release of the Go programming language using the release information from https://go.dev/dl/. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.GO_STABLE_WINDOWS">GO_STABLE_WINDOWS</a></code> | Installs the latest stable release of the Go programming language using the release information from https://go.dev/dl/. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.HELLO_WORLD_LINUX">HELLO_WORLD_LINUX</a></code> | Hello world testing document for Linux. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.HELLO_WORLD_WINDOWS">HELLO_WORLD_WINDOWS</a></code> | Hello world testing document for Windows. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.INSPECTOR_TEST_LINUX">INSPECTOR_TEST_LINUX</a></code> | Performs a Center for Internet Security (CIS) security assessment for an instance, using Amazon Inspector (Inspector). |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.INSPECTOR_TEST_WINDOWS">INSPECTOR_TEST_WINDOWS</a></code> | Performs a Center for Internet Security (CIS) security assessment for an instance, using Amazon Inspector (Inspector). |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.INSTALL_PACKAGE_FROM_REPOSITORY">INSTALL_PACKAGE_FROM_REPOSITORY</a></code> | Installs a package from the Linux repository. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.MARIADB_LINUX">MARIADB_LINUX</a></code> | Installs the MariaDB package using apt, yum, or zypper. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.MATE_DE_LINUX">MATE_DE_LINUX</a></code> | Installs the MATE Desktop Environment, xrdp, TigerVNC server, and enables the xrdp service. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.MONO_LINUX">MONO_LINUX</a></code> | Installs the latest version of the Mono framework. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PHP_8_2_LINUX">PHP_8_2_LINUX</a></code> | Installs PHP 8.2. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_LTS_LINUX">POWERSHELL_LTS_LINUX</a></code> | Installs the latest LTS 7.4 release of PowerShell following the instructions at https://docs.microsoft.com/en-us/powershell/scripting/install/installing-powershell-on-linux?view=powershell-7.4. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_LTS_WINDOWS">POWERSHELL_LTS_WINDOWS</a></code> | Installs the latest LTS 7.4 release of PowerShell using the MSI installer from the GitHub repository located at https://github.com/PowerShell/PowerShell. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_SNAP">POWERSHELL_SNAP</a></code> | Installs the latest version of PowerShell using snap. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_YUM">POWERSHELL_YUM</a></code> | Installs the latest version of PowerShell from the Microsoft RedHat repository. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PUTTY">PUTTY</a></code> | Installs the latest version of PuTTY from the 64-bit MSI link on the release page: https://the.earth.li/~sgtatham/putty/latest/w64/. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PYTHON_3_LINUX">PYTHON_3_LINUX</a></code> | Installs the Python 3 package using apt, yum, or zypper. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PYTHON_3_WINDOWS">PYTHON_3_WINDOWS</a></code> | Installs Python 3.8.2 for Windows. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_LINUX">REBOOT_LINUX</a></code> | Reboots the system. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_TEST_LINUX">REBOOT_TEST_LINUX</a></code> | Tests whether the system can reboot successfully. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_TEST_WINDOWS">REBOOT_TEST_WINDOWS</a></code> | Tests whether the system can reboot successfully. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_WINDOWS">REBOOT_WINDOWS</a></code> | Reboots the system. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SCAP_COMPLIANCE_CHECKER_LINUX">SCAP_COMPLIANCE_CHECKER_LINUX</a></code> | Installs and runs SCAP Compliance Checker (SCC) 5.10 for Red Hat Enterprise Linux (RHEL) 7/8, Ubuntu 18.04/20.04/22.04 with all current STIG Q1 2025 benchmarks. SCC supports the AMD64 architecture. Other architectures are not currently supported or contain issues within the EC2 environment. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SCAP_COMPLIANCE_CHECKER_WINDOWS">SCAP_COMPLIANCE_CHECKER_WINDOWS</a></code> | Installs and runs SCAP Compliance Checker (SCC) 5.10 for Windows with all current STIG Q3 2024 benchmarks. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/image-builder-stig.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SIMPLE_BOOT_TEST_LINUX">SIMPLE_BOOT_TEST_LINUX</a></code> | Executes a simple boot test. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SIMPLE_BOOT_TEST_WINDOWS">SIMPLE_BOOT_TEST_WINDOWS</a></code> | Executes a simple boot test. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_LINUX_HIGH">STIG_BUILD_LINUX_HIGH</a></code> | Applies the high, medium, and low severity STIG settings for Red Hat Enterprise Linux (RHEL) to Amazon Linux 2, Amazon Linux 2023, RHEL 7, CentOS Linux 7, CentOS Linux 8, CentOS Stream 9, RHEL 8, RHEL 9, Ubuntu 18.04, Ubuntu 20.04, and Ubuntu 22.04 instances. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_LINUX_LOW">STIG_BUILD_LINUX_LOW</a></code> | Applies the low severity STIG settings for Red Hat Enterprise Linux (RHEL) to Amazon Linux 2, Amazon Linux 2023, RHEL 7, CentOS Linux 7, CentOS Linux 8, CentOS Stream 9, RHEL 8, RHEL 9, Ubuntu 18.04, Ubuntu 20.04, and Ubuntu 22.04 instances. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_LINUX_MEDIUM">STIG_BUILD_LINUX_MEDIUM</a></code> | Applies the medium and low severity STIG settings for Red Hat Enterprise Linux (RHEL) to Amazon Linux 2, Amazon Linux 2023, RHEL 7, CentOS Linux 7, CentOS Linux 8, CentOS Stream 9, RHEL 8, RHEL 9, Ubuntu 18.04, Ubuntu 20.04, and Ubuntu 22.04 instances. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_WINDOWS_HIGH">STIG_BUILD_WINDOWS_HIGH</a></code> | Applies the high, medium, and low severity STIG settings to Windows instances. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_WINDOWS_LOW">STIG_BUILD_WINDOWS_LOW</a></code> | Applies the low severity STIG settings to Windows instances. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_WINDOWS_MEDIUM">STIG_BUILD_WINDOWS_MEDIUM</a></code> | Applies the medium and low severity STIG settings to Windows instances. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_LINUX_KERNEL_5">UPDATE_LINUX_KERNEL_5</a></code> | Installs the Linux kernel 5.* for Amazon Linux 2 from Amazon Linux Extras. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_LINUX_KERNEL_ML">UPDATE_LINUX_KERNEL_ML</a></code> | Installs the latest mainline release of the Linux kernel for CentOS 7 and Red Hat Enterprise Linux 7 and 8 via the 'kernel-ml' package from https://www.elrepo.org. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_LINUX">UPDATE_LINUX</a></code> | Updates Linux by installing all available updates via the UpdateOS action module. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_WINDOWS">UPDATE_WINDOWS</a></code> | Updates Windows with the latest security updates. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.VALIDATE_SINGLE_SSH_PUBLIC_KEY_TEST_LINUX">VALIDATE_SINGLE_SSH_PUBLIC_KEY_TEST_LINUX</a></code> | Ensures the `authorized_keys` file contains only the SSH public key returned from the EC2 Instance Metadata Service. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.VALIDATE_SSH_HOST_KEY_GENERATION_LINUX">VALIDATE_SSH_HOST_KEY_GENERATION_LINUX</a></code> | Verifies whether the SSH host key was generated after the latest boot. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.VALIDATE_SSH_PUBLIC_KEY_LINUX">VALIDATE_SSH_PUBLIC_KEY_LINUX</a></code> | Ensures the `authorized_keys` file contains the SSH public key returned from the EC2 Instance Metadata Service. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.WINDOWS_ACTIVATION_TEST">WINDOWS_ACTIVATION_TEST</a></code> | Verifies the Windows license status in the Common Information Model. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.WINDOWS_IS_READY_WITH_PASSWORD_GENERATION_TEST">WINDOWS_IS_READY_WITH_PASSWORD_GENERATION_TEST</a></code> | Checks the EC2 logs for the statement `Windows is Ready to use` and for the password generation message on Windows Server 2016 and later SKUs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.WINDOWS_SERVER_IIS">WINDOWS_SERVER_IIS</a></code> | Installs the Internet Information Services (IIS) web server and management tools. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.YUM_REPOSITORY_TEST_LINUX">YUM_REPOSITORY_TEST_LINUX</a></code> | Tests whether yum repository works successfully. |

---

##### `AMAZON_CLOUDWATCH_AGENT_LINUX` <a name="AMAZON_CLOUDWATCH_AGENT_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CLOUDWATCH_AGENT_LINUX"></a>

Installs the latest version of the Amazon CloudWatch agent.

This component installs only the agent. You must take additional steps to configure and use the Amazon CloudWatch agent. For more information, see the documentation at https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/install-CloudWatch-Agent-on-EC2-Instance.html.

---


##### `AMAZON_CLOUDWATCH_AGENT_WINDOWS` <a name="AMAZON_CLOUDWATCH_AGENT_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CLOUDWATCH_AGENT_WINDOWS"></a>

Installs the latest version of the Amazon CloudWatch agent.

This component installs only the agent. You must take additional steps to configure and use the Amazon CloudWatch agent. For more information, see the documentation at https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/install-CloudWatch-Agent-on-EC2-Instance.html.

---


##### `AMAZON_CORRETTO_11_APT_GENERIC` <a name="AMAZON_CORRETTO_11_APT_GENERIC" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_APT_GENERIC"></a>

Installs Amazon Corretto 11 for Debian-based Linux platforms in accordance with the Amazon Corretto 11 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-11-ug/generic-linux-install.html.

---


##### `AMAZON_CORRETTO_11_HEADLESS` <a name="AMAZON_CORRETTO_11_HEADLESS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_HEADLESS"></a>

Installs Amazon Corretto 11 Headless.

---


##### `AMAZON_CORRETTO_11_RPM_GENERIC` <a name="AMAZON_CORRETTO_11_RPM_GENERIC" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_RPM_GENERIC"></a>

Installs Amazon Corretto 11 for RPM-based Linux platforms in accordance with the Amazon Corretto 11 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-11-ug/generic-linux-install.html.

---


##### `AMAZON_CORRETTO_11_WINDOWS` <a name="AMAZON_CORRETTO_11_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11_WINDOWS"></a>

Installs Amazon Corretto 11 for Windows in accordance with the Amazon Corretto 11 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-11-ug/windows-7-install.html.

---


##### `AMAZON_CORRETTO_11` <a name="AMAZON_CORRETTO_11" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_11"></a>

Installs Amazon Corretto 11.

---


##### `AMAZON_CORRETTO_17_HEADLESS` <a name="AMAZON_CORRETTO_17_HEADLESS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_HEADLESS"></a>

Installs Amazon Corretto 17 Headless.

---


##### `AMAZON_CORRETTO_17_JDK` <a name="AMAZON_CORRETTO_17_JDK" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_JDK"></a>

Installs Amazon Corretto 17 JDK in accordance with the Amazon Corretto 17 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-17-ug/linux-info.html.

---


##### `AMAZON_CORRETTO_17_JRE` <a name="AMAZON_CORRETTO_17_JRE" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_JRE"></a>

Installs Amazon Corretto 17 JRE.

---


##### `AMAZON_CORRETTO_17_WINDOWS` <a name="AMAZON_CORRETTO_17_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_17_WINDOWS"></a>

Installs Amazon Corretto 17 for Windows in accordance with the Amazon Corretto 17 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-17-ug/windows-7-install.html.

---


##### `AMAZON_CORRETTO_21_HEADLESS` <a name="AMAZON_CORRETTO_21_HEADLESS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_HEADLESS"></a>

Installs Amazon Corretto 21 Headless.

---


##### `AMAZON_CORRETTO_21_JDK` <a name="AMAZON_CORRETTO_21_JDK" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_JDK"></a>

Installs Amazon Corretto 21 JDK in accordance with the Amazon Corretto 21 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-21-ug/linux-info.html.

---


##### `AMAZON_CORRETTO_21_JRE` <a name="AMAZON_CORRETTO_21_JRE" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_JRE"></a>

Installs Amazon Corretto 21 JRE.

---


##### `AMAZON_CORRETTO_21_WINDOWS` <a name="AMAZON_CORRETTO_21_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_21_WINDOWS"></a>

Installs Amazon Corretto 21 for Windows in accordance with the Amazon Corretto 21 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-21-ug/windows-10-install.html.

---


##### `AMAZON_CORRETTO_8_APT_GENERIC` <a name="AMAZON_CORRETTO_8_APT_GENERIC" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_APT_GENERIC"></a>

Installs Amazon Corretto 8 for Debian-based Linux platforms in accordance with the Amazon Corretto 8 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-8-ug/generic-linux-install.html.

---


##### `AMAZON_CORRETTO_8_JDK` <a name="AMAZON_CORRETTO_8_JDK" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_JDK"></a>

Installs Amazon Corretto 8 JDK.

---


##### `AMAZON_CORRETTO_8_JRE` <a name="AMAZON_CORRETTO_8_JRE" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_JRE"></a>

Installs Amazon Corretto 8 JRE.

---


##### `AMAZON_CORRETTO_8_RPM_GENERIC` <a name="AMAZON_CORRETTO_8_RPM_GENERIC" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_RPM_GENERIC"></a>

Installs Amazon Corretto 8 for RPM-based Linux platforms in accordance with the Amazon Corretto 8 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-8-ug/generic-linux-install.html.

---


##### `AMAZON_CORRETTO_8_WINDOWS` <a name="AMAZON_CORRETTO_8_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_CORRETTO_8_WINDOWS"></a>

Installs Amazon Corretto 8 for Windows in accordance with the Amazon Corretto 8 User Guide at https://docs.aws.amazon.com/corretto/latest/corretto-8-ug/windows-7-install.html.

---


##### `AMAZON_KINESIS_AGENT_WINDOWS` <a name="AMAZON_KINESIS_AGENT_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AMAZON_KINESIS_AGENT_WINDOWS"></a>

Installs the latest version of Amazon Kinesis Agent for Windows.

---


##### `ANACONDA_WINDOWS` <a name="ANACONDA_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ANACONDA_WINDOWS"></a>

Installs the Anaconda distribution and environments for Tensorflow, PyTorch, and MXNet.

---


##### `APACHE_TOMCAT_9_LINUX` <a name="APACHE_TOMCAT_9_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.APACHE_TOMCAT_9_LINUX"></a>

Installs the latest version of Apache Tomcat and the JRE, sets required environment variables, and schedules Tomcat to run on startup.

---


##### `APT_REPOSITORY_TEST_LINUX` <a name="APT_REPOSITORY_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.APT_REPOSITORY_TEST_LINUX"></a>

Tests whether the apt package manager is functioning correctly.

---


##### `AWS_CLI_VERSION_2_LINUX` <a name="AWS_CLI_VERSION_2_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CLI_VERSION_2_LINUX"></a>

Installs the latest version of the AWS CLI version 2, and creates the symlink /usr/bin/aws that points to the installed application.

For more information, see https://docs.aws.amazon.com/cli/latest/userguide/.

---


##### `AWS_CLI_VERSION_2_WINDOWS` <a name="AWS_CLI_VERSION_2_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CLI_VERSION_2_WINDOWS"></a>

Installs the latest version of the AWS CLI version 2.

For more information, review the user guide at https://docs.aws.amazon.com/cli/latest/userguide/.

---


##### `AWS_CODEDEPLOY_AGENT_LINUX` <a name="AWS_CODEDEPLOY_AGENT_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CODEDEPLOY_AGENT_LINUX"></a>

Installs the latest version of the AWS CodeDeploy agent.

This component installs only the agent. You must take additional steps to configure and use the AWS CodeDeploy agent. For more information, see the documentation at https://docs.aws.amazon.com/codedeploy/latest/userguide/welcome.html.

---


##### `AWS_CODEDEPLOY_AGENT_WINDOWS` <a name="AWS_CODEDEPLOY_AGENT_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_CODEDEPLOY_AGENT_WINDOWS"></a>

Installs the latest version of the AWS CodeDeploy agent.

This component installs only the agent. You must take additional steps to configure and use the agent. For more information, see the documentation at https://docs.aws.amazon.com/codedeploy/latest/userguide/codedeploy-agent-operations-install-windows.html.

---


##### `AWS_VSS_COMPONENTS_WINDOWS` <a name="AWS_VSS_COMPONENTS_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.AWS_VSS_COMPONENTS_WINDOWS"></a>

Installs the AwsVssComponents Distributor package on a Windows instance.

The instance must have an AWS Tools for PowerShell version that includes Systems Manager modules installed. The IAM profile attached to the build instance must have the following permissions - configure the ssm:SendCommand permission with the AWS-ConfigureAWSPackage Systems Manager document on all instances in the Region, and configure the ssm:GetCommandInvocation permission for '*'. For more information, see the documentation at https://docs.aws.amazon.com/imagebuilder/latest/userguide/mgdcomponent-distributor-win.html and https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/application-consistent-snapshots.html.

---


##### `CHOCOLATEY` <a name="CHOCOLATEY" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.CHOCOLATEY"></a>

Installs Chocolatey for Windows.

---


##### `CHRONY_TIME_CONFIGURATION_TEST` <a name="CHRONY_TIME_CONFIGURATION_TEST" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.CHRONY_TIME_CONFIGURATION_TEST"></a>

Validates the Chrony configuration file and ensures that Chrony time sources on Amazon Linux 2 are configured for the Amazon time servers.

Uses validation steps outlined here: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/set-time.html.

---


##### `DCV_SERVER_LINUX` <a name="DCV_SERVER_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DCV_SERVER_LINUX"></a>

Install and configure the latest NICE DCV server on Linux.

---


##### `DCV_SERVER_WINDOWS` <a name="DCV_SERVER_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DCV_SERVER_WINDOWS"></a>

Install and configure the latest NICE DCV server on Windows.

---


##### `DISTRIBUTOR_PACKAGE_WINDOWS` <a name="DISTRIBUTOR_PACKAGE_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DISTRIBUTOR_PACKAGE_WINDOWS"></a>

Installs a Distributor package on a Windows instance.

The instance must have an AWS Tools for PowerShell version that includes Systems Manager modules installed. The IAM profile attached to the build instance must have the following permissions - configure the ssm:SendCommand permission with the AWS-ConfigureAWSPackage Systems Manager document on all instances in the Region, and configure the ssm:GetCommandInvocation permission for '*'. For more information, see the documentation at https://docs.aws.amazon.com/imagebuilder/latest/userguide/mgdcomponent-distributor-win.html.

---


##### `DOCKER_CE_CENTOS` <a name="DOCKER_CE_CENTOS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOCKER_CE_CENTOS"></a>

Installs Docker Community Edition from the Docker package repository, and enables the centos user to manage Docker without using sudo.

For more information, review the installation guide at https://docs.docker.com/install/linux/docker-ce/centos/.

---


##### `DOCKER_CE_LINUX` <a name="DOCKER_CE_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOCKER_CE_LINUX"></a>

Install the latest Docker Community Edition from Amazon Linux Extras, and enable the ec2-user user to manage docker without using sudo.

---


##### `DOCKER_CE_UBUNTU` <a name="DOCKER_CE_UBUNTU" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOCKER_CE_UBUNTU"></a>

Installs Docker Community Edition from the Docker package repository, and enables the ubuntu user to manage Docker without using sudo.

For more information, review the installation guide at https://docs.docker.com/install/linux/docker-ce/ubuntu/.

---


##### `DOTNET_DESKTOP_RUNTIME_LTS_WINDOWS` <a name="DOTNET_DESKTOP_RUNTIME_LTS_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_DESKTOP_RUNTIME_LTS_WINDOWS"></a>

Installs the latest 8.0 channel release of the Microsoft .NET Desktop Runtime. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0.

---


##### `DOTNET_HOSTING_BUNDLE_LTS_WINDOWS` <a name="DOTNET_HOSTING_BUNDLE_LTS_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_HOSTING_BUNDLE_LTS_WINDOWS"></a>

Installs the latest 8.0 channel release of the Microsoft .NET Hosting Bundle. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0.

---


##### `DOTNET_RUNTIME_LTS_LINUX` <a name="DOTNET_RUNTIME_LTS_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_RUNTIME_LTS_LINUX"></a>

Installs the latest 8.0 channel release of the Microsoft .NET Runtime. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0.

---


##### `DOTNET_RUNTIME_LTS_WINDOWS` <a name="DOTNET_RUNTIME_LTS_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_RUNTIME_LTS_WINDOWS"></a>

Installs the latest 8.0 channel release of the Microsoft .NET Runtime. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0.

---


##### `DOTNET_SDK_LTS_LINUX` <a name="DOTNET_SDK_LTS_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_SDK_LTS_LINUX"></a>

Installs the latest 8.0 channel release of the Microsoft .NET SDK. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0.

---


##### `DOTNET_SDK_LTS_WINDOWS` <a name="DOTNET_SDK_LTS_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.DOTNET_SDK_LTS_WINDOWS"></a>

Installs the latest 8.0 channel release of the Microsoft .NET SDK. For more information, see the .NET 8.0 download page at https://dotnet.microsoft.com/download/dotnet/8.0.

---


##### `EBS_VOLUME_USAGE_TEST_LINUX` <a name="EBS_VOLUME_USAGE_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EBS_VOLUME_USAGE_TEST_LINUX"></a>

The EBS volume usage test performs the following actions: 1) It creates an EBS volume and attaches it to the instance.

2) It creates a temporary file on the volume and detaches the volume. 3) It reattaches the volume and validates that the file exists. 4) It detaches and deletes the volume. To perform this test, an IAM policy with the following actions is required: ec2:AttachVolume, ec2:Create Tags, ec2:CreateVolume, ec2:DeleteVolume, ec2:DescribeVolumes, and ec2:DetachVolume.

---


##### `EBS_VOLUME_USAGE_TEST_WINDOWS` <a name="EBS_VOLUME_USAGE_TEST_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EBS_VOLUME_USAGE_TEST_WINDOWS"></a>

The EBS volume usage test performs the following actions: 1) It creates an EBS volume and attaches it to the instance.

2) It creates a temporary file on the volume and detaches the volume. 3) It reattaches the volume and validates that the file exists. 4) It detaches and deletes the volume. To perform this test, an IAM policy with the following actions is required: ec2:AttachVolume, ec2:Create Tags, ec2:CreateVolume, ec2:DeleteVolume, ec2:DescribeVolumes, and ec2:DetachVolume.

---


##### `EC2_NETWORK_ROUTE_TEST_WINDOWS` <a name="EC2_NETWORK_ROUTE_TEST_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EC2_NETWORK_ROUTE_TEST_WINDOWS"></a>

Test to ensure all required EC2 network routes exist in the route table.

---


##### `EC2LAUNCH_V2_WINDOWS` <a name="EC2LAUNCH_V2_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EC2LAUNCH_V2_WINDOWS"></a>

Installs the latest version of EC2Launch v2.

For more information, see the documentation at https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2launch-v2.html.

---


##### `ECS_OPTIMIZED_AMI_WINDOWS` <a name="ECS_OPTIMIZED_AMI_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ECS_OPTIMIZED_AMI_WINDOWS"></a>

Installs Amazon ECS-optimized Windows artifacts.

This includes latest Amazon ECS Container Agent and Docker CE version 20.10.21.

---


##### `EKS_OPTIMIZED_AMI_WINDOWS` <a name="EKS_OPTIMIZED_AMI_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.EKS_OPTIMIZED_AMI_WINDOWS"></a>

Installs Amazon EKS-optimized Windows artifacts for Amazon EKS version 1.32. This includes kubelet version 1.32.0, containerd version 1.7.20, and CSI Proxy version 1.1.2.

---


##### `ENI_ATTACHMENT_TEST_LINUX` <a name="ENI_ATTACHMENT_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ENI_ATTACHMENT_TEST_LINUX"></a>

The ENI attachment test performs the following actions: 1) It creates an elastic network interface (ENI) and attaches it to the instance.

2) It validates that the attached ENI has an IP address. 3) It detaches and deletes the ENI. To perform this test, an IAM policy with the following actions is required: ec2:AttachNetworkInterface, ec2:CreateNetworkInterface, ec2:CreateTags, ec2:DeleteNetworkInterface, ec2:DescribeNetworkInterfaces, ec2:DescribeNetworkInterfaceAttribute, and ec2:DetachNetworkInterface.

---


##### `ENI_ATTACHMENT_TEST_WINDOWS` <a name="ENI_ATTACHMENT_TEST_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.ENI_ATTACHMENT_TEST_WINDOWS"></a>

The ENI attachment test performs the following actions: 1) It creates an elastic network interface (ENI) and attaches it to the instance.

2) It validates that the attached ENI has an IP address. 3) It detaches and deletes the ENI. To perform this test, an IAM policy with the following actions is required: ec2:AttachNetworkInterface, ec2:CreateNetworkInterface, ec2:CreateTags, ec2:DeleteNetworkInterface, ec2:DescribeNetworkInterfaces, ec2:DescribeNetworkInterfaceAttribute, and ec2:DetachNetworkInterface.

---


##### `GO_STABLE_LINUX` <a name="GO_STABLE_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.GO_STABLE_LINUX"></a>

Installs the latest stable release of the Go programming language using the release information from https://go.dev/dl/.

---


##### `GO_STABLE_WINDOWS` <a name="GO_STABLE_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.GO_STABLE_WINDOWS"></a>

Installs the latest stable release of the Go programming language using the release information from https://go.dev/dl/.

---


##### `HELLO_WORLD_LINUX` <a name="HELLO_WORLD_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.HELLO_WORLD_LINUX"></a>

Hello world testing document for Linux.

---


##### `HELLO_WORLD_WINDOWS` <a name="HELLO_WORLD_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.HELLO_WORLD_WINDOWS"></a>

Hello world testing document for Windows.

---


##### `INSPECTOR_TEST_LINUX` <a name="INSPECTOR_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.INSPECTOR_TEST_LINUX"></a>

Performs a Center for Internet Security (CIS) security assessment for an instance, using Amazon Inspector (Inspector).

This component performs the following actions: 1) It installs the Inspector agent. 2) It creates a resource group, assessment target, and assessment template. 3) It runs the assessment and provides a link to the results in the logs and on the Inspector Service console. In order to run successfully, this component requires that the AmazonInspectorFullAccess IAM policy and the ssm:SendCommand and ec2:CreateTags IAM permissions are attached to the instance profile. To find the list of supported Operating Systems and their rules packages, refer to the Inspector documentation https://docs.aws.amazon.com/inspector/v1/userguide/inspector_rule-packages_across_os.html.

---


##### `INSPECTOR_TEST_WINDOWS` <a name="INSPECTOR_TEST_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.INSPECTOR_TEST_WINDOWS"></a>

Performs a Center for Internet Security (CIS) security assessment for an instance, using Amazon Inspector (Inspector).

This component performs the following actions: 1) It installs the Inspector agent. 2) It creates a resource group, assessment target, and assessment template. 3) It runs the assessment and provides a link to the results in the logs and on the Inspector Service console. In order to run successfully, this component requires that the AmazonInspectorFullAccess IAM policy and the ssm:SendCommand and ec2:CreateTags IAM permissions are attached to the instance profile. To find the list of supported Operating Systems and their rules packages, refer to the Inspector documentation https://docs.aws.amazon.com/inspector/v1/userguide/inspector_rule-packages_across_os.html.

---


##### `INSTALL_PACKAGE_FROM_REPOSITORY` <a name="INSTALL_PACKAGE_FROM_REPOSITORY" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.INSTALL_PACKAGE_FROM_REPOSITORY"></a>

Installs a package from the Linux repository.

---


##### `MARIADB_LINUX` <a name="MARIADB_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.MARIADB_LINUX"></a>

Installs the MariaDB package using apt, yum, or zypper.

---


##### `MATE_DE_LINUX` <a name="MATE_DE_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.MATE_DE_LINUX"></a>

Installs the MATE Desktop Environment, xrdp, TigerVNC server, and enables the xrdp service.

---


##### `MONO_LINUX` <a name="MONO_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.MONO_LINUX"></a>

Installs the latest version of the Mono framework.

Follows the instructions found at https://www.mono-project.com/.

---


##### `PHP_8_2_LINUX` <a name="PHP_8_2_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PHP_8_2_LINUX"></a>

Installs PHP 8.2.

---


##### `POWERSHELL_LTS_LINUX` <a name="POWERSHELL_LTS_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_LTS_LINUX"></a>

Installs the latest LTS 7.4 release of PowerShell following the instructions at https://docs.microsoft.com/en-us/powershell/scripting/install/installing-powershell-on-linux?view=powershell-7.4.

---


##### `POWERSHELL_LTS_WINDOWS` <a name="POWERSHELL_LTS_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_LTS_WINDOWS"></a>

Installs the latest LTS 7.4 release of PowerShell using the MSI installer from the GitHub repository located at https://github.com/PowerShell/PowerShell.

---


##### `POWERSHELL_SNAP` <a name="POWERSHELL_SNAP" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_SNAP"></a>

Installs the latest version of PowerShell using snap.

---


##### `POWERSHELL_YUM` <a name="POWERSHELL_YUM" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.POWERSHELL_YUM"></a>

Installs the latest version of PowerShell from the Microsoft RedHat repository.

---


##### `PUTTY` <a name="PUTTY" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PUTTY"></a>

Installs the latest version of PuTTY from the 64-bit MSI link on the release page: https://the.earth.li/~sgtatham/putty/latest/w64/.

---


##### `PYTHON_3_LINUX` <a name="PYTHON_3_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PYTHON_3_LINUX"></a>

Installs the Python 3 package using apt, yum, or zypper.

---


##### `PYTHON_3_WINDOWS` <a name="PYTHON_3_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.PYTHON_3_WINDOWS"></a>

Installs Python 3.8.2 for Windows.

---


##### `REBOOT_LINUX` <a name="REBOOT_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_LINUX"></a>

Reboots the system.

---


##### `REBOOT_TEST_LINUX` <a name="REBOOT_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_TEST_LINUX"></a>

Tests whether the system can reboot successfully.

---


##### `REBOOT_TEST_WINDOWS` <a name="REBOOT_TEST_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_TEST_WINDOWS"></a>

Tests whether the system can reboot successfully.

---


##### `REBOOT_WINDOWS` <a name="REBOOT_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.REBOOT_WINDOWS"></a>

Reboots the system.

---


##### `SCAP_COMPLIANCE_CHECKER_LINUX` <a name="SCAP_COMPLIANCE_CHECKER_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SCAP_COMPLIANCE_CHECKER_LINUX"></a>

Installs and runs SCAP Compliance Checker (SCC) 5.10 for Red Hat Enterprise Linux (RHEL) 7/8, Ubuntu 18.04/20.04/22.04 with all current STIG Q1 2025 benchmarks. SCC supports the AMD64 architecture. Other architectures are not currently supported or contain issues within the EC2 environment. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html.

---


##### `SCAP_COMPLIANCE_CHECKER_WINDOWS` <a name="SCAP_COMPLIANCE_CHECKER_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SCAP_COMPLIANCE_CHECKER_WINDOWS"></a>

Installs and runs SCAP Compliance Checker (SCC) 5.10 for Windows with all current STIG Q3 2024 benchmarks. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/image-builder-stig.html.

---


##### `SIMPLE_BOOT_TEST_LINUX` <a name="SIMPLE_BOOT_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SIMPLE_BOOT_TEST_LINUX"></a>

Executes a simple boot test.

---


##### `SIMPLE_BOOT_TEST_WINDOWS` <a name="SIMPLE_BOOT_TEST_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.SIMPLE_BOOT_TEST_WINDOWS"></a>

Executes a simple boot test.

---


##### `STIG_BUILD_LINUX_HIGH` <a name="STIG_BUILD_LINUX_HIGH" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_LINUX_HIGH"></a>

Applies the high, medium, and low severity STIG settings for Red Hat Enterprise Linux (RHEL) to Amazon Linux 2, Amazon Linux 2023, RHEL 7, CentOS Linux 7, CentOS Linux 8, CentOS Stream 9, RHEL 8, RHEL 9, Ubuntu 18.04, Ubuntu 20.04, and Ubuntu 22.04 instances. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html.

---


##### `STIG_BUILD_LINUX_LOW` <a name="STIG_BUILD_LINUX_LOW" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_LINUX_LOW"></a>

Applies the low severity STIG settings for Red Hat Enterprise Linux (RHEL) to Amazon Linux 2, Amazon Linux 2023, RHEL 7, CentOS Linux 7, CentOS Linux 8, CentOS Stream 9, RHEL 8, RHEL 9, Ubuntu 18.04, Ubuntu 20.04, and Ubuntu 22.04 instances. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html.

---


##### `STIG_BUILD_LINUX_MEDIUM` <a name="STIG_BUILD_LINUX_MEDIUM" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_LINUX_MEDIUM"></a>

Applies the medium and low severity STIG settings for Red Hat Enterprise Linux (RHEL) to Amazon Linux 2, Amazon Linux 2023, RHEL 7, CentOS Linux 7, CentOS Linux 8, CentOS Stream 9, RHEL 8, RHEL 9, Ubuntu 18.04, Ubuntu 20.04, and Ubuntu 22.04 instances. For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/toe-stig.html.

---


##### `STIG_BUILD_WINDOWS_HIGH` <a name="STIG_BUILD_WINDOWS_HIGH" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_WINDOWS_HIGH"></a>

Applies the high, medium, and low severity STIG settings to Windows instances.

For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/image-builder-stig.html.

---


##### `STIG_BUILD_WINDOWS_LOW` <a name="STIG_BUILD_WINDOWS_LOW" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_WINDOWS_LOW"></a>

Applies the low severity STIG settings to Windows instances.

For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/image-builder-stig.html.

---


##### `STIG_BUILD_WINDOWS_MEDIUM` <a name="STIG_BUILD_WINDOWS_MEDIUM" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.STIG_BUILD_WINDOWS_MEDIUM"></a>

Applies the medium and low severity STIG settings to Windows instances.

For more information, see https://docs.aws.amazon.com/imagebuilder/latest/userguide/image-builder-stig.html.

---


##### `UPDATE_LINUX_KERNEL_5` <a name="UPDATE_LINUX_KERNEL_5" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_LINUX_KERNEL_5"></a>

Installs the Linux kernel 5.* for Amazon Linux 2 from Amazon Linux Extras.

---


##### `UPDATE_LINUX_KERNEL_ML` <a name="UPDATE_LINUX_KERNEL_ML" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_LINUX_KERNEL_ML"></a>

Installs the latest mainline release of the Linux kernel for CentOS 7 and Red Hat Enterprise Linux 7 and 8 via the 'kernel-ml' package from https://www.elrepo.org.

---


##### `UPDATE_LINUX` <a name="UPDATE_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_LINUX"></a>

Updates Linux by installing all available updates via the UpdateOS action module.

---


##### `UPDATE_WINDOWS` <a name="UPDATE_WINDOWS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.UPDATE_WINDOWS"></a>

Updates Windows with the latest security updates.

---


##### `VALIDATE_SINGLE_SSH_PUBLIC_KEY_TEST_LINUX` <a name="VALIDATE_SINGLE_SSH_PUBLIC_KEY_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.VALIDATE_SINGLE_SSH_PUBLIC_KEY_TEST_LINUX"></a>

Ensures the `authorized_keys` file contains only the SSH public key returned from the EC2 Instance Metadata Service.

---


##### `VALIDATE_SSH_HOST_KEY_GENERATION_LINUX` <a name="VALIDATE_SSH_HOST_KEY_GENERATION_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.VALIDATE_SSH_HOST_KEY_GENERATION_LINUX"></a>

Verifies whether the SSH host key was generated after the latest boot.

---


##### `VALIDATE_SSH_PUBLIC_KEY_LINUX` <a name="VALIDATE_SSH_PUBLIC_KEY_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.VALIDATE_SSH_PUBLIC_KEY_LINUX"></a>

Ensures the `authorized_keys` file contains the SSH public key returned from the EC2 Instance Metadata Service.

---


##### `WINDOWS_ACTIVATION_TEST` <a name="WINDOWS_ACTIVATION_TEST" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.WINDOWS_ACTIVATION_TEST"></a>

Verifies the Windows license status in the Common Information Model.

---


##### `WINDOWS_IS_READY_WITH_PASSWORD_GENERATION_TEST` <a name="WINDOWS_IS_READY_WITH_PASSWORD_GENERATION_TEST" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.WINDOWS_IS_READY_WITH_PASSWORD_GENERATION_TEST"></a>

Checks the EC2 logs for the statement `Windows is Ready to use` and for the password generation message on Windows Server 2016 and later SKUs.

This component does not support instances launched without an EC2 key pair.

---


##### `WINDOWS_SERVER_IIS` <a name="WINDOWS_SERVER_IIS" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.WINDOWS_SERVER_IIS"></a>

Installs the Internet Information Services (IIS) web server and management tools.

The installation is performed by enabling the Windows features built into the Windows operating system.

---


##### `YUM_REPOSITORY_TEST_LINUX` <a name="YUM_REPOSITORY_TEST_LINUX" id="@cdklabs/cdk-proserve-lib.constructs.Ec2ImagePipeline.Component.YUM_REPOSITORY_TEST_LINUX"></a>

Tests whether yum repository works successfully.

---


### DestructiveOperation <a name="DestructiveOperation" id="@cdklabs/cdk-proserve-lib.types.DestructiveOperation"></a>

Represents types of destructive operations that can be performed on resources.

Destructive operations are actions that modify or remove existing resources,
potentially resulting in data loss if not handled properly.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.DestructiveOperation.UPDATE">UPDATE</a></code> | Indicates an operation that modifies existing resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.DestructiveOperation.DELETE">DELETE</a></code> | Indicates an operation that removes resources. |
| <code><a href="#@cdklabs/cdk-proserve-lib.types.DestructiveOperation.ALL">ALL</a></code> | Represents all types of destructive operations. |

---

##### `UPDATE` <a name="UPDATE" id="@cdklabs/cdk-proserve-lib.types.DestructiveOperation.UPDATE"></a>

Indicates an operation that modifies existing resources.

---


##### `DELETE` <a name="DELETE" id="@cdklabs/cdk-proserve-lib.types.DestructiveOperation.DELETE"></a>

Indicates an operation that removes resources.

---


##### `ALL` <a name="ALL" id="@cdklabs/cdk-proserve-lib.types.DestructiveOperation.ALL"></a>

Represents all types of destructive operations.

---


### Ec2MetricName <a name="Ec2MetricName" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName"></a>

CloudWatch Alarm Metric Names.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_UTILIZATION">CPU_UTILIZATION</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_READ_OPS">DISK_READ_OPS</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_WRITE_OPS">DISK_WRITE_OPS</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_READ_BYTES">DISK_READ_BYTES</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_WRITE_BYTES">DISK_WRITE_BYTES</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_IN">NETWORK_IN</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_OUT">NETWORK_OUT</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_PACKETS_IN">NETWORK_PACKETS_IN</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_PACKETS_OUT">NETWORK_PACKETS_OUT</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.STATUS_CHECK_FAILED">STATUS_CHECK_FAILED</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.STATUS_CHECK_FAILED_INSTANCE">STATUS_CHECK_FAILED_INSTANCE</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.STATUS_CHECK_FAILED_SYSTEM">STATUS_CHECK_FAILED_SYSTEM</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.METADATA_NO_TOKEN">METADATA_NO_TOKEN</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_CREDIT_USAGE">CPU_CREDIT_USAGE</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_CREDIT_BALANCE">CPU_CREDIT_BALANCE</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_SURPLUS_CREDIT_BALANCE">CPU_SURPLUS_CREDIT_BALANCE</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_SURPLUS_CREDITS_CHARGED">CPU_SURPLUS_CREDITS_CHARGED</a></code> | *No description.* |

---

##### `CPU_UTILIZATION` <a name="CPU_UTILIZATION" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_UTILIZATION"></a>

---


##### `DISK_READ_OPS` <a name="DISK_READ_OPS" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_READ_OPS"></a>

---


##### `DISK_WRITE_OPS` <a name="DISK_WRITE_OPS" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_WRITE_OPS"></a>

---


##### `DISK_READ_BYTES` <a name="DISK_READ_BYTES" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_READ_BYTES"></a>

---


##### `DISK_WRITE_BYTES` <a name="DISK_WRITE_BYTES" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.DISK_WRITE_BYTES"></a>

---


##### `NETWORK_IN` <a name="NETWORK_IN" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_IN"></a>

---


##### `NETWORK_OUT` <a name="NETWORK_OUT" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_OUT"></a>

---


##### `NETWORK_PACKETS_IN` <a name="NETWORK_PACKETS_IN" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_PACKETS_IN"></a>

---


##### `NETWORK_PACKETS_OUT` <a name="NETWORK_PACKETS_OUT" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.NETWORK_PACKETS_OUT"></a>

---


##### `STATUS_CHECK_FAILED` <a name="STATUS_CHECK_FAILED" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.STATUS_CHECK_FAILED"></a>

---


##### `STATUS_CHECK_FAILED_INSTANCE` <a name="STATUS_CHECK_FAILED_INSTANCE" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.STATUS_CHECK_FAILED_INSTANCE"></a>

---


##### `STATUS_CHECK_FAILED_SYSTEM` <a name="STATUS_CHECK_FAILED_SYSTEM" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.STATUS_CHECK_FAILED_SYSTEM"></a>

---


##### `METADATA_NO_TOKEN` <a name="METADATA_NO_TOKEN" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.METADATA_NO_TOKEN"></a>

---


##### `CPU_CREDIT_USAGE` <a name="CPU_CREDIT_USAGE" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_CREDIT_USAGE"></a>

---


##### `CPU_CREDIT_BALANCE` <a name="CPU_CREDIT_BALANCE" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_CREDIT_BALANCE"></a>

---


##### `CPU_SURPLUS_CREDIT_BALANCE` <a name="CPU_SURPLUS_CREDIT_BALANCE" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_SURPLUS_CREDIT_BALANCE"></a>

---


##### `CPU_SURPLUS_CREDITS_CHARGED` <a name="CPU_SURPLUS_CREDITS_CHARGED" id="@cdklabs/cdk-proserve-lib.aspects.Ec2AutomatedShutdown.Ec2MetricName.CPU_SURPLUS_CREDITS_CHARGED"></a>

---


### Feature <a name="Feature" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.AWS_CLI">AWS_CLI</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.NICE_DCV">NICE_DCV</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.RETAIN_SSM_AGENT">RETAIN_SSM_AGENT</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.STIG">STIG</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.SCAP">SCAP</a></code> | *No description.* |

---

##### `AWS_CLI` <a name="AWS_CLI" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.AWS_CLI"></a>

---


##### `NICE_DCV` <a name="NICE_DCV" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.NICE_DCV"></a>

---


##### `RETAIN_SSM_AGENT` <a name="RETAIN_SSM_AGENT" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.RETAIN_SSM_AGENT"></a>

---


##### `STIG` <a name="STIG" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.STIG"></a>

---


##### `SCAP` <a name="SCAP" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.Feature.SCAP"></a>

---


### LogType <a name="LogType" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType.TLS">TLS</a></code> | Logs for events that are related to TLS inspection. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType.FLOW">FLOW</a></code> | Standard network traffic flow logs. |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType.ALERT">ALERT</a></code> | Logs for traffic that matches your stateful rules and that have an action that sends an alert. |

---

##### `TLS` <a name="TLS" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType.TLS"></a>

Logs for events that are related to TLS inspection.

For more information, see Inspecting SSL/TLS traffic with TLS inspection configurations in the Network Firewall Developer Guide .

---


##### `FLOW` <a name="FLOW" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType.FLOW"></a>

Standard network traffic flow logs.

The stateful rules engine records flow logs for all network traffic that it receives. Each flow log record captures the network flow for a specific standard stateless rule group.

---


##### `ALERT` <a name="ALERT" id="@cdklabs/cdk-proserve-lib.constructs.NetworkFirewall.LogType.ALERT"></a>

Logs for traffic that matches your stateful rules and that have an action that sends an alert.

A stateful rule sends alerts for the rule actions DROP, ALERT, and REJECT. For more information, see the StatefulRule property.

---


### OperatingSystem <a name="OperatingSystem" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem"></a>

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem.RED_HAT_ENTERPRISE_LINUX_8_9">RED_HAT_ENTERPRISE_LINUX_8_9</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem.AMAZON_LINUX_2">AMAZON_LINUX_2</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem.AMAZON_LINUX_2023">AMAZON_LINUX_2023</a></code> | *No description.* |

---

##### `RED_HAT_ENTERPRISE_LINUX_8_9` <a name="RED_HAT_ENTERPRISE_LINUX_8_9" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem.RED_HAT_ENTERPRISE_LINUX_8_9"></a>

---


##### `AMAZON_LINUX_2` <a name="AMAZON_LINUX_2" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem.AMAZON_LINUX_2"></a>

---


##### `AMAZON_LINUX_2023` <a name="AMAZON_LINUX_2023" id="@cdklabs/cdk-proserve-lib.patterns.Ec2LinuxImagePipeline.OperatingSystem.AMAZON_LINUX_2023"></a>

---


### OverrideAction <a name="OverrideAction" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction"></a>

Enum representing possible override actions for WAF rules.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction.ALLOW">ALLOW</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction.BLOCK">BLOCK</a></code> | *No description.* |
| <code><a href="#@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction.COUNT">COUNT</a></code> | *No description.* |

---

##### `ALLOW` <a name="ALLOW" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction.ALLOW"></a>

---


##### `BLOCK` <a name="BLOCK" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction.BLOCK"></a>

---


##### `COUNT` <a name="COUNT" id="@cdklabs/cdk-proserve-lib.constructs.WebApplicationFirewall.OverrideAction.COUNT"></a>

---

